/****************************************************************************
** Meta object code from reading C++ file 'server_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-workspace-6.7.1/libnotificationmanager/server_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'server_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19NotificationManager13ServerPrivateE_t {};
} // unnamed namespace

template <> constexpr inline auto NotificationManager::ServerPrivate::qt_create_metaobjectdata<qt_meta_tag_ZN19NotificationManager13ServerPrivateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NotificationManager::ServerPrivate",
        "NotificationClosed",
        "",
        "id",
        "reason",
        "ActionInvoked",
        "actionKey",
        "ActivationToken",
        "xdgActivationToken",
        "NotificationReplied",
        "text",
        "validChanged",
        "inhibitedChanged",
        "externalInhibitedChanged",
        "externalInhibitionsChanged",
        "serviceOwnershipLost",
        "onBroadcastNotification",
        "QMap<QString,QVariant>",
        "properties",
        "Inhibited"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'NotificationClosed'
        QtMocHelpers::SignalData<void(uint, uint)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'ActionInvoked'
        QtMocHelpers::SignalData<void(uint, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::QString, 6 },
        }}),
        // Signal 'ActivationToken'
        QtMocHelpers::SignalData<void(uint, const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'NotificationReplied'
        QtMocHelpers::SignalData<void(uint, const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::QString, 10 },
        }}),
        // Signal 'validChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inhibitedChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'externalInhibitedChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'externalInhibitionsChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'serviceOwnershipLost'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onBroadcastNotification'
        QtMocHelpers::SlotData<void(const QMap<QString,QVariant> &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Inhibited'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ServerPrivate, qt_meta_tag_ZN19NotificationManager13ServerPrivateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject NotificationManager::ServerPrivate::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationManager13ServerPrivateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationManager13ServerPrivateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19NotificationManager13ServerPrivateE_t>.metaTypes,
    nullptr
} };

void NotificationManager::ServerPrivate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ServerPrivate *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->NotificationClosed((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 1: _t->ActionInvoked((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->ActivationToken((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->NotificationReplied((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->validChanged(); break;
        case 5: _t->inhibitedChanged(); break;
        case 6: _t->externalInhibitedChanged(); break;
        case 7: _t->externalInhibitionsChanged(); break;
        case 8: _t->serviceOwnershipLost(); break;
        case 9: _t->onBroadcastNotification((*reinterpret_cast<std::add_pointer_t<QMap<QString,QVariant>>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ServerPrivate::*)(uint , uint )>(_a, &ServerPrivate::NotificationClosed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ServerPrivate::*)(uint , const QString & )>(_a, &ServerPrivate::ActionInvoked, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ServerPrivate::*)(uint , const QString & )>(_a, &ServerPrivate::ActivationToken, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ServerPrivate::*)(uint , const QString & )>(_a, &ServerPrivate::NotificationReplied, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ServerPrivate::*)()>(_a, &ServerPrivate::validChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ServerPrivate::*)()>(_a, &ServerPrivate::inhibitedChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ServerPrivate::*)()>(_a, &ServerPrivate::externalInhibitedChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ServerPrivate::*)()>(_a, &ServerPrivate::externalInhibitionsChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ServerPrivate::*)()>(_a, &ServerPrivate::serviceOwnershipLost, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->inhibited(); break;
        default: break;
        }
    }
}

const QMetaObject *NotificationManager::ServerPrivate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NotificationManager::ServerPrivate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationManager13ServerPrivateE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QObject::qt_metacast(_clname);
}

int NotificationManager::ServerPrivate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void NotificationManager::ServerPrivate::NotificationClosed(uint _t1, uint _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void NotificationManager::ServerPrivate::ActionInvoked(uint _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void NotificationManager::ServerPrivate::ActivationToken(uint _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void NotificationManager::ServerPrivate::NotificationReplied(uint _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void NotificationManager::ServerPrivate::validChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void NotificationManager::ServerPrivate::inhibitedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void NotificationManager::ServerPrivate::externalInhibitedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void NotificationManager::ServerPrivate::externalInhibitionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void NotificationManager::ServerPrivate::serviceOwnershipLost()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
