// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#include "lookandfeeldata.h"

#include "lookandfeelsettings.h"




LookAndFeelData::LookAndFeelData(QObject *parent)
: KCModuleData(parent)
, m_settings(new LookAndFeelSettings(this))

{
autoRegisterSkeletons();
}

LookAndFeelSettings *LookAndFeelData::settings() const
{
    return m_settings;
}





#include "moc_lookandfeeldata.cpp"
