// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#ifndef LOOKANDFEELDATA_H
#define LOOKANDFEELDATA_H

#include <QObject>

#include "kcmoduledata.h"



class LookAndFeelSettings;


class LookAndFeelData : public KCModuleData
{
    Q_OBJECT

public:
    explicit LookAndFeelData(QObject *parent = nullptr);
    LookAndFeelSettings *settings() const;


private:
    LookAndFeelSettings *m_settings;

};



#endif
