/****************************************************************************
** Meta object code from reading C++ file 'notificationsadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "notificationsadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'notificationsadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20NotificationsAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto NotificationsAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN20NotificationsAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NotificationsAdaptor",
        "D-Bus Interface",
        "org.freedesktop.Notifications",
        "D-Bus Introspection",
        "  <interface name=\"org.freedesktop.Notifications\">\n    <signal "
        "name=\"NotificationClosed\">\n      <arg direction=\"out\" type=\""
        "u\" name=\"id\"/>\n      <arg direction=\"out\" type=\"u\" name=\""
        "reason\"/>\n    </signal>\n    <signal name=\"ActionInvoked\">\n  "
        "    <arg direction=\"out\" type=\"u\" name=\"id\"/>\n      <arg di"
        "rection=\"out\" type=\"s\" name=\"action_key\"/>\n    </signal>\n "
        "   <signal name=\"NotificationReplied\">\n      <arg direction=\"o"
        "ut\" type=\"u\" name=\"id\"/>\n      <arg direction=\"out\" type=\""
        "s\" name=\"text\"/>\n    </signal>\n    <signal name=\"ActivationT"
        "oken\">\n      <arg direction=\"out\" type=\"u\" name=\"id\"/>\n  "
        "    <arg direction=\"out\" type=\"s\" name=\"activation_token\"/>\n"
        "    </signal>\n    <method name=\"Notify\">\n      <annotation val"
        "ue=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.In6\"/>\n"
        "      <arg direction=\"out\" type=\"u\"/>\n      <arg direction=\""
        "in\" type=\"s\" name=\"app_name\"/>\n      <arg direction=\"in\" t"
        "ype=\"u\" name=\"replaces_id\"/>\n      <arg direction=\"in\" type"
        "=\"s\" name=\"app_icon\"/>\n      <arg direction=\"in\" type=\"s\""
        " name=\"summary\"/>\n      <arg direction=\"in\" type=\"s\" name=\""
        "body\"/>\n      <arg direction=\"in\" type=\"as\" name=\"actions\""
        "/>\n      <arg direction=\"in\" type=\"a{sv}\" name=\"hints\"/>\n "
        "     <arg direction=\"in\" type=\"i\" name=\"timeout\"/>\n    </me"
        "thod>\n    <method name=\"CloseNotification\">\n      <arg directi"
        "on=\"in\" type=\"u\" name=\"id\"/>\n    </method>\n    <method nam"
        "e=\"GetCapabilities\">\n      <arg direction=\"out\" type=\"as\" n"
        "ame=\"caps\"/>\n    </method>\n    <method name=\"GetServerInforma"
        "tion\">\n      <arg direction=\"out\" type=\"s\" name=\"name\"/>\n"
        "      <arg direction=\"out\" type=\"s\" name=\"vendor\"/>\n      <"
        "arg direction=\"out\" type=\"s\" name=\"version\"/>\n      <arg di"
        "rection=\"out\" type=\"s\" name=\"spec_version\"/>\n    </method>\n"
        "    <method name=\"Inhibit\">\n      <annotation value=\"QVariantM"
        "ap\" name=\"org.qtproject.QtDBus.QtTypeName.In2\"/>\n      <arg di"
        "rection=\"out\" type=\"u\"/>\n      <arg direction=\"in\" type=\"s"
        "\" name=\"desktop_entry\"/>\n      <arg direction=\"in\" type=\"s\""
        " name=\"reason\"/>\n      <arg direction=\"in\" type=\"a{sv}\" nam"
        "e=\"hints\"/>\n    </method>\n    <method name=\"UnInhibit\">\n   "
        "   <arg direction=\"in\" type=\"u\"/>\n    </method>\n    <propert"
        "y access=\"read\" type=\"b\" name=\"Inhibited\">\n      <annotatio"
        "n value=\"true\" name=\"org.freedesktop.DBus.Property.EmitsChanged"
        "Signal\"/>\n    </property>\n  </interface>\n",
        "ActionInvoked",
        "",
        "id",
        "action_key",
        "ActivationToken",
        "activation_token",
        "NotificationClosed",
        "reason",
        "NotificationReplied",
        "text",
        "CloseNotification",
        "GetCapabilities",
        "GetServerInformation",
        "QString&",
        "vendor",
        "version",
        "spec_version",
        "Inhibit",
        "desktop_entry",
        "QVariantMap",
        "hints",
        "Notify",
        "app_name",
        "replaces_id",
        "app_icon",
        "summary",
        "body",
        "actions",
        "timeout",
        "UnInhibit",
        "in0",
        "Inhibited"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ActionInvoked'
        QtMocHelpers::SignalData<void(uint, const QString &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 7 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'ActivationToken'
        QtMocHelpers::SignalData<void(uint, const QString &)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 7 }, { QMetaType::QString, 10 },
        }}),
        // Signal 'NotificationClosed'
        QtMocHelpers::SignalData<void(uint, uint)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 7 }, { QMetaType::UInt, 12 },
        }}),
        // Signal 'NotificationReplied'
        QtMocHelpers::SignalData<void(uint, const QString &)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 7 }, { QMetaType::QString, 14 },
        }}),
        // Slot 'CloseNotification'
        QtMocHelpers::SlotData<void(uint)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 7 },
        }}),
        // Slot 'GetCapabilities'
        QtMocHelpers::SlotData<QStringList()>(16, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'GetServerInformation'
        QtMocHelpers::SlotData<QString(QString &, QString &, QString &)>(17, 6, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 18, 19 }, { 0x80000000 | 18, 20 }, { 0x80000000 | 18, 21 },
        }}),
        // Slot 'Inhibit'
        QtMocHelpers::SlotData<uint(const QString &, const QString &, const QVariantMap &)>(22, 6, QMC::AccessPublic, QMetaType::UInt, {{
            { QMetaType::QString, 23 }, { QMetaType::QString, 12 }, { 0x80000000 | 24, 25 },
        }}),
        // Slot 'Notify'
        QtMocHelpers::SlotData<uint(const QString &, uint, const QString &, const QString &, const QString &, const QStringList &, const QVariantMap &, int)>(26, 6, QMC::AccessPublic, QMetaType::UInt, {{
            { QMetaType::QString, 27 }, { QMetaType::UInt, 28 }, { QMetaType::QString, 29 }, { QMetaType::QString, 30 },
            { QMetaType::QString, 31 }, { QMetaType::QStringList, 32 }, { 0x80000000 | 24, 25 }, { QMetaType::Int, 33 },
        }}),
        // Slot 'UnInhibit'
        QtMocHelpers::SlotData<void(uint)>(34, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 35 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Inhibited'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<NotificationsAdaptor, qt_meta_tag_ZN20NotificationsAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject NotificationsAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20NotificationsAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20NotificationsAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20NotificationsAdaptorE_t>.metaTypes,
    nullptr
} };

void NotificationsAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NotificationsAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ActionInvoked((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->ActivationToken((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->NotificationClosed((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 3: _t->NotificationReplied((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->CloseNotification((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 5: { QStringList _r = _t->GetCapabilities();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 6: { QString _r = _t->GetServerInformation((*reinterpret_cast<std::add_pointer_t<QString&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 7: { uint _r = _t->Inhibit((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3])));
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 8: { uint _r = _t->Notify((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[8])));
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->UnInhibit((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NotificationsAdaptor::*)(uint , const QString & )>(_a, &NotificationsAdaptor::ActionInvoked, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationsAdaptor::*)(uint , const QString & )>(_a, &NotificationsAdaptor::ActivationToken, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationsAdaptor::*)(uint , uint )>(_a, &NotificationsAdaptor::NotificationClosed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationsAdaptor::*)(uint , const QString & )>(_a, &NotificationsAdaptor::NotificationReplied, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->inhibited(); break;
        default: break;
        }
    }
}

const QMetaObject *NotificationsAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NotificationsAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20NotificationsAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int NotificationsAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void NotificationsAdaptor::ActionInvoked(uint _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void NotificationsAdaptor::ActivationToken(uint _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void NotificationsAdaptor::NotificationClosed(uint _t1, uint _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void NotificationsAdaptor::NotificationReplied(uint _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}
QT_WARNING_POP
