/****************************************************************************
** Meta object code from reading C++ file 'sortingmode.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../plasma-workspace-6.7.1/wallpapers/image/plugin/sortingmode.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sortingmode.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11SortingModeE_t {};
} // unnamed namespace

template <> constexpr inline auto SortingMode::qt_create_metaobjectdata<qt_meta_tag_ZN11SortingModeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SortingMode",
        "QML.Element",
        "auto",
        "Mode",
        "Random",
        "Alphabetical",
        "AlphabeticalReversed",
        "Modified",
        "ModifiedReversed"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Mode'
        QtMocHelpers::EnumData<Mode>(3, 3, QMC::EnumFlags{}).add({
            {    4, Mode::Random },
            {    5, Mode::Alphabetical },
            {    6, Mode::AlphabeticalReversed },
            {    7, Mode::Modified },
            {    8, Mode::ModifiedReversed },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN11SortingModeE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN11SortingModeE =
    SortingMode::qt_create_metaobjectdata<qt_meta_tag_ZN11SortingModeE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN11SortingModeE =
    qt_staticMetaObjectContent_ZN11SortingModeE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN11SortingModeE =
    qt_staticMetaObjectContent_ZN11SortingModeE.relocatingData;

Q_CONSTINIT const QMetaObject SortingMode::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN11SortingModeE.stringdata,
    qt_staticMetaObjectStaticContent_ZN11SortingModeE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN11SortingModeE.metaTypes,
    nullptr
} };

QT_WARNING_POP
