/****************************************************************************
** Meta object code from reading C++ file 'containmentconfigview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-workspace-6.7.1/shell/containmentconfigview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'containmentconfigview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21ContainmentConfigViewE_t {};
} // unnamed namespace

template <> constexpr inline auto ContainmentConfigView::qt_create_metaobjectdata<qt_meta_tag_ZN21ContainmentConfigViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ContainmentConfigView",
        "currentWallpaperChanged",
        "",
        "wallpaperConfigurationChanged",
        "containmentPluginChanged",
        "onWallpaperChanged",
        "screenIdx",
        "applyWallpaper",
        "containmentActionConfigModel",
        "PlasmaQuick::ConfigModel*",
        "currentContainmentActionsModel",
        "QAbstractItemModel*",
        "wallpaperConfigModel",
        "containmentPluginsConfigModel",
        "wallpaperConfiguration",
        "QQmlPropertyMap*",
        "currentWallpaper",
        "containmentPlugin"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentWallpaperChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wallpaperConfigurationChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'containmentPluginChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onWallpaperChanged'
        QtMocHelpers::SlotData<void(uint)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 6 },
        }}),
        // Method 'applyWallpaper'
        QtMocHelpers::MethodData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'containmentActionConfigModel'
        QtMocHelpers::PropertyData<PlasmaQuick::ConfigModel*>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'currentContainmentActionsModel'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'wallpaperConfigModel'
        QtMocHelpers::PropertyData<PlasmaQuick::ConfigModel*>(12, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'containmentPluginsConfigModel'
        QtMocHelpers::PropertyData<PlasmaQuick::ConfigModel*>(13, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'wallpaperConfiguration'
        QtMocHelpers::PropertyData<QQmlPropertyMap*>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'currentWallpaper'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'containmentPlugin'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ContainmentConfigView, qt_meta_tag_ZN21ContainmentConfigViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ContainmentConfigView::staticMetaObject = { {
    QMetaObject::SuperData::link<PlasmaQuick::ConfigView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ContainmentConfigViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ContainmentConfigViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21ContainmentConfigViewE_t>.metaTypes,
    nullptr
} };

void ContainmentConfigView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ContainmentConfigView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentWallpaperChanged(); break;
        case 1: _t->wallpaperConfigurationChanged(); break;
        case 2: _t->containmentPluginChanged(); break;
        case 3: _t->onWallpaperChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 4: _t->applyWallpaper(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ContainmentConfigView::*)()>(_a, &ContainmentConfigView::currentWallpaperChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ContainmentConfigView::*)()>(_a, &ContainmentConfigView::wallpaperConfigurationChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ContainmentConfigView::*)()>(_a, &ContainmentConfigView::containmentPluginChanged, 2))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
        case 2:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< PlasmaQuick::ConfigModel* >(); break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractItemModel* >(); break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlPropertyMap* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<PlasmaQuick::ConfigModel**>(_v) = _t->containmentActionConfigModel(); break;
        case 1: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->currentContainmentActionsModel(); break;
        case 2: *reinterpret_cast<PlasmaQuick::ConfigModel**>(_v) = _t->wallpaperConfigModel(); break;
        case 3: *reinterpret_cast<PlasmaQuick::ConfigModel**>(_v) = _t->containmentPluginsConfigModel(); break;
        case 4: *reinterpret_cast<QQmlPropertyMap**>(_v) = _t->wallpaperConfiguration(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->currentWallpaper(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->containmentPlugin(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 5: _t->setCurrentWallpaper(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setContainmentPlugin(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ContainmentConfigView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ContainmentConfigView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ContainmentConfigViewE_t>.strings))
        return static_cast<void*>(this);
    return PlasmaQuick::ConfigView::qt_metacast(_clname);
}

int ContainmentConfigView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PlasmaQuick::ConfigView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void ContainmentConfigView::currentWallpaperChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ContainmentConfigView::wallpaperConfigurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ContainmentConfigView::containmentPluginChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
