// This file is generated by kconfig_compiler_kf6 from geotimezonedstate.kcfg.
// All changes you do to this file will be lost.

#include "geotimezonedstate.h"

GeotimezonedState::GeotimezonedState( )
  : KConfigSkeleton( KSharedConfig::openStateConfig(QStringLiteral( "geotimezonedstaterc") ) )
{
  setCurrentGroup( QStringLiteral( "Network" ) );

  KConfigSkeleton::ItemString  *itemLastConnectionUuid;
  itemLastConnectionUuid = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "LastConnectionUuid" ), mLastConnectionUuid );
  addItem( itemLastConnectionUuid, QStringLiteral( "lastConnectionUuid" ) );
}

GeotimezonedState::~GeotimezonedState()
{
}

