// This file is generated by kconfig_compiler_kf6 from fontssettings.kcfg.
// All changes you do to this file will be lost.

#include "fontssettings.h"

FontsSettings::FontsSettings( QObject *parent )
  : KConfigSkeleton( QStringLiteral( "kdeglobals" ) )
{
  setParent(parent);
  KConfigCompilerSignallingItem::NotifyFunction notifyFunction = static_cast<KConfigCompilerSignallingItem::NotifyFunction>(&FontsSettings::itemChanged);

  setCurrentGroup( QStringLiteral( "General" ) );


      QFont generalFont = QFont(QStringLiteral("Noto Sans"), 10);
      generalFont.setStyleName(QStringLiteral("Regular"));
      
  KConfigCompilerSignallingItem  *itemFont;
  KConfigSkeleton::ItemFont  *innerItemFont;
  innerItemFont = new KConfigSkeleton::ItemFont( currentGroup(), QStringLiteral( "font" ), mFont, generalFont );
  itemFont = new KConfigCompilerSignallingItem(innerItemFont, this, notifyFunction, signalFontChanged);
  itemFont->setWriteFlags(KConfigBase::Notify);
  addItem( itemFont, QStringLiteral( "font" ) );

      QFont fixedWidthFont = QFont(QStringLiteral("Hack"), 10);
      fixedWidthFont.setStyleName(QStringLiteral("Regular"));
      
  KConfigCompilerSignallingItem  *itemFixed;
  KConfigSkeleton::ItemFont  *innerItemFixed;
  innerItemFixed = new KConfigSkeleton::ItemFont( currentGroup(), QStringLiteral( "fixed" ), mFixed, fixedWidthFont );
  itemFixed = new KConfigCompilerSignallingItem(innerItemFixed, this, notifyFunction, signalFixedChanged);
  itemFixed->setWriteFlags(KConfigBase::Notify);
  addItem( itemFixed, QStringLiteral( "fixed" ) );

      QFont smallFont = QFont(QStringLiteral("Noto Sans"), 8);
      smallFont.setStyleName(QStringLiteral("Regular"));
      
  KConfigCompilerSignallingItem  *itemSmallestReadableFont;
  KConfigSkeleton::ItemFont  *innerItemSmallestReadableFont;
  innerItemSmallestReadableFont = new KConfigSkeleton::ItemFont( currentGroup(), QStringLiteral( "smallestReadableFont" ), mSmallestReadableFont, smallFont );
  itemSmallestReadableFont = new KConfigCompilerSignallingItem(innerItemSmallestReadableFont, this, notifyFunction, signalSmallestReadableFontChanged);
  addItem( itemSmallestReadableFont, QStringLiteral( "smallestReadableFont" ) );

      QFont toolBarFont = QFont(QStringLiteral("Noto Sans"), 10);
      toolBarFont.setStyleName(QStringLiteral("Regular"));
      
  KConfigCompilerSignallingItem  *itemToolBarFont;
  KConfigSkeleton::ItemFont  *innerItemToolBarFont;
  innerItemToolBarFont = new KConfigSkeleton::ItemFont( currentGroup(), QStringLiteral( "toolBarFont" ), mToolBarFont, toolBarFont );
  itemToolBarFont = new KConfigCompilerSignallingItem(innerItemToolBarFont, this, notifyFunction, signalToolBarFontChanged);
  addItem( itemToolBarFont, QStringLiteral( "toolBarFont" ) );

      QFont menuFont = QFont(QStringLiteral("Noto Sans"), 10);
      menuFont.setStyleName(QStringLiteral("Regular"));
      
  KConfigCompilerSignallingItem  *itemMenuFont;
  KConfigSkeleton::ItemFont  *innerItemMenuFont;
  innerItemMenuFont = new KConfigSkeleton::ItemFont( currentGroup(), QStringLiteral( "menuFont" ), mMenuFont, menuFont );
  itemMenuFont = new KConfigCompilerSignallingItem(innerItemMenuFont, this, notifyFunction, signalMenuFontChanged);
  addItem( itemMenuFont, QStringLiteral( "menuFont" ) );

  setCurrentGroup( QStringLiteral( "WM" ) );


      QFont windowTitleFont = QFont(QStringLiteral("Noto Sans"), 10);
      windowTitleFont.setStyleName(QStringLiteral("Regular"));
      
  KConfigCompilerSignallingItem  *itemActiveFont;
  KConfigSkeleton::ItemFont  *innerItemActiveFont;
  innerItemActiveFont = new KConfigSkeleton::ItemFont( currentGroup(), QStringLiteral( "activeFont" ), mActiveFont, windowTitleFont );
  itemActiveFont = new KConfigCompilerSignallingItem(innerItemActiveFont, this, notifyFunction, signalActiveFontChanged);
  addItem( itemActiveFont, QStringLiteral( "activeFont" ) );
}

QFont FontsSettings::defaultFontValue_helper() const
{

      QFont generalFont = QFont(QStringLiteral("Noto Sans"), 10);
      generalFont.setStyleName(QStringLiteral("Regular"));
      
  return generalFont;
}

QFont FontsSettings::defaultFixedValue_helper() const
{

      QFont fixedWidthFont = QFont(QStringLiteral("Hack"), 10);
      fixedWidthFont.setStyleName(QStringLiteral("Regular"));
      
  return fixedWidthFont;
}

QFont FontsSettings::defaultSmallestReadableFontValue_helper() const
{

      QFont smallFont = QFont(QStringLiteral("Noto Sans"), 8);
      smallFont.setStyleName(QStringLiteral("Regular"));
      
  return smallFont;
}

QFont FontsSettings::defaultToolBarFontValue_helper() const
{

      QFont toolBarFont = QFont(QStringLiteral("Noto Sans"), 10);
      toolBarFont.setStyleName(QStringLiteral("Regular"));
      
  return toolBarFont;
}

QFont FontsSettings::defaultMenuFontValue_helper() const
{

      QFont menuFont = QFont(QStringLiteral("Noto Sans"), 10);
      menuFont.setStyleName(QStringLiteral("Regular"));
      
  return menuFont;
}

QFont FontsSettings::defaultActiveFontValue_helper() const
{

      QFont windowTitleFont = QFont(QStringLiteral("Noto Sans"), 10);
      windowTitleFont.setStyleName(QStringLiteral("Regular"));
      
  return windowTitleFont;
}

FontsSettings::~FontsSettings()
{
}


void FontsSettings::itemChanged(quint64 signalFlag) {

  switch (signalFlag) {
  case signalFontChanged:
    Q_EMIT fontChanged();
    break;
  case signalFixedChanged:
    Q_EMIT fixedChanged();
    break;
  case signalSmallestReadableFontChanged:
    Q_EMIT smallestReadableFontChanged();
    break;
  case signalToolBarFontChanged:
    Q_EMIT toolBarFontChanged();
    break;
  case signalMenuFontChanged:
    Q_EMIT menuFontChanged();
    break;
  case signalActiveFontChanged:
    Q_EMIT activeFontChanged();
    break;
  }
}
