/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.KSMServerInterface.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef KSMSERVERINTERFACEADAPTOR_H
#define KSMSERVERINTERFACEADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "server.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.KSMServerInterface
 */
class KSMServerInterfaceAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.KSMServerInterface")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.KSMServerInterface\">\n"
"    <method name=\"isShuttingDown\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"sessionList\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"currentSession\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"saveCurrentSession\"/>\n"
"    <method name=\"saveCurrentSessionAs\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"restoreSession\"/>\n"
"    <method name=\"closeSession\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"resetLogout\"/>\n"
"  </interface>\n"
        "")
public:
    KSMServerInterfaceAdaptor(KSMServer *parent);
    ~KSMServerInterfaceAdaptor() override;

    inline KSMServer *parent() const
    { return static_cast<KSMServer *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    bool closeSession();
    QString currentSession();
    bool isShuttingDown();
    void resetLogout();
    void restoreSession();
    void saveCurrentSession();
    void saveCurrentSessionAs(const QString &in0);
    QStringList sessionList();
Q_SIGNALS: // SIGNALS
};

#endif
