// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "containmentactions_paste_debug.h"


Q_LOGGING_CATEGORY(CONTAINMENTACTIONS_PASTE_DEBUG, "org.kde.plasma.containmentactions_paste", QtInfoMsg)

