/****************************************************************************
** Meta object code from reading C++ file 'calendar.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/components/calendar/calendar.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'calendar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8CalendarE_t {};
} // unnamed namespace

template <> constexpr inline auto Calendar::qt_create_metaobjectdata<qt_meta_tag_ZN8CalendarE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Calendar",
        "QML.Element",
        "auto",
        "displayedDateChanged",
        "",
        "todayChanged",
        "typesChanged",
        "daysChanged",
        "weeksChanged",
        "firstDayOfWeekChanged",
        "errorMessageChanged",
        "monthNameChanged",
        "monthChanged",
        "yearChanged",
        "weeksModelChanged",
        "updateData",
        "nextMonth",
        "previousMonth",
        "nextYear",
        "previousYear",
        "nextDecade",
        "previousDecade",
        "dayName",
        "weekday",
        "currentWeek",
        "resetToToday",
        "goToMonth",
        "month",
        "goToYear",
        "year",
        "goToYearAndMonth",
        "displayedDate",
        "today",
        "types",
        "weeksModel",
        "QJsonArray",
        "days",
        "weeks",
        "firstDayOfWeek",
        "errorMessage",
        "monthName",
        "daysModel",
        "DaysModel*",
        "Type",
        "Holiday",
        "Event",
        "Todo",
        "Journal",
        "DateMatchingPrecision",
        "MatchYear",
        "MatchYearAndMonth",
        "MatchYearMonthAndDay"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'displayedDateChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'todayChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'typesChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'daysChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'weeksChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'firstDayOfWeekChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorMessageChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'monthNameChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'monthChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'yearChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'weeksModelChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateData'
        QtMocHelpers::SlotData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'nextMonth'
        QtMocHelpers::MethodData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'previousMonth'
        QtMocHelpers::MethodData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'nextYear'
        QtMocHelpers::MethodData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'previousYear'
        QtMocHelpers::MethodData<void()>(19, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'nextDecade'
        QtMocHelpers::MethodData<void()>(20, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'previousDecade'
        QtMocHelpers::MethodData<void()>(21, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'dayName'
        QtMocHelpers::MethodData<QString(int) const>(22, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 23 },
        }}),
        // Method 'currentWeek'
        QtMocHelpers::MethodData<int() const>(24, 4, QMC::AccessPublic, QMetaType::Int),
        // Method 'resetToToday'
        QtMocHelpers::MethodData<void()>(25, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'goToMonth'
        QtMocHelpers::MethodData<void(int)>(26, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 27 },
        }}),
        // Method 'goToYear'
        QtMocHelpers::MethodData<void(int)>(28, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 29 },
        }}),
        // Method 'goToYearAndMonth'
        QtMocHelpers::MethodData<void(int, int)>(30, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 29 }, { QMetaType::Int, 27 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'displayedDate'
        QtMocHelpers::PropertyData<QDateTime>(31, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'today'
        QtMocHelpers::PropertyData<QDateTime>(32, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'types'
        QtMocHelpers::PropertyData<int>(33, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'weeksModel'
        QtMocHelpers::PropertyData<QJsonArray>(34, 0x80000000 | 35, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 10),
        // property 'days'
        QtMocHelpers::PropertyData<int>(36, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'weeks'
        QtMocHelpers::PropertyData<int>(37, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'firstDayOfWeek'
        QtMocHelpers::PropertyData<int>(38, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'year'
        QtMocHelpers::PropertyData<int>(29, QMetaType::Int, QMC::DefaultPropertyFlags, 9),
        // property 'errorMessage'
        QtMocHelpers::PropertyData<QString>(39, QMetaType::QString, QMC::DefaultPropertyFlags, 6),
        // property 'monthName'
        QtMocHelpers::PropertyData<QString>(40, QMetaType::QString, QMC::DefaultPropertyFlags, 7),
        // property 'month'
        QtMocHelpers::PropertyData<int>(27, QMetaType::Int, QMC::DefaultPropertyFlags, 8),
        // property 'daysModel'
        QtMocHelpers::PropertyData<DaysModel*>(41, 0x80000000 | 42, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Type'
        QtMocHelpers::EnumData<enum Type>(43, 43, QMC::EnumFlags{}).add({
            {   44, Type::Holiday },
            {   45, Type::Event },
            {   46, Type::Todo },
            {   47, Type::Journal },
        }),
        // enum 'DateMatchingPrecision'
        QtMocHelpers::EnumData<enum DateMatchingPrecision>(48, 48, QMC::EnumFlags{}).add({
            {   49, DateMatchingPrecision::MatchYear },
            {   50, DateMatchingPrecision::MatchYearAndMonth },
            {   51, DateMatchingPrecision::MatchYearMonthAndDay },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Calendar, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Calendar::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8CalendarE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8CalendarE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8CalendarE_t>.metaTypes,
    nullptr
} };

void Calendar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Calendar *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->displayedDateChanged(); break;
        case 1: _t->todayChanged(); break;
        case 2: _t->typesChanged(); break;
        case 3: _t->daysChanged(); break;
        case 4: _t->weeksChanged(); break;
        case 5: _t->firstDayOfWeekChanged(); break;
        case 6: _t->errorMessageChanged(); break;
        case 7: _t->monthNameChanged(); break;
        case 8: _t->monthChanged(); break;
        case 9: _t->yearChanged(); break;
        case 10: _t->weeksModelChanged(); break;
        case 11: _t->updateData(); break;
        case 12: _t->nextMonth(); break;
        case 13: _t->previousMonth(); break;
        case 14: _t->nextYear(); break;
        case 15: _t->previousYear(); break;
        case 16: _t->nextDecade(); break;
        case 17: _t->previousDecade(); break;
        case 18: { QString _r = _t->dayName((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 19: { int _r = _t->currentWeek();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 20: _t->resetToToday(); break;
        case 21: _t->goToMonth((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 22: _t->goToYear((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 23: _t->goToYearAndMonth((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Calendar::*)()>(_a, &Calendar::displayedDateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Calendar::*)()>(_a, &Calendar::todayChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Calendar::*)()>(_a, &Calendar::typesChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Calendar::*)()>(_a, &Calendar::daysChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Calendar::*)()>(_a, &Calendar::weeksChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Calendar::*)()>(_a, &Calendar::firstDayOfWeekChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Calendar::*)()>(_a, &Calendar::errorMessageChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Calendar::*)()>(_a, &Calendar::monthNameChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Calendar::*)()>(_a, &Calendar::monthChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Calendar::*)()>(_a, &Calendar::yearChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Calendar::*)()>(_a, &Calendar::weeksModelChanged, 10))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 11:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< DaysModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QDateTime*>(_v) = _t->displayedDate(); break;
        case 1: *reinterpret_cast<QDateTime*>(_v) = _t->today(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->types(); break;
        case 3: *reinterpret_cast<QJsonArray*>(_v) = _t->weeksModel(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->days(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->weeks(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->firstDayOfWeek(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->year(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->errorMessage(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->monthName(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->month(); break;
        case 11: *reinterpret_cast<DaysModel**>(_v) = _t->daysModel(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDisplayedDate(*reinterpret_cast<QDateTime*>(_v)); break;
        case 1: _t->setToday(*reinterpret_cast<QDateTime*>(_v)); break;
        case 2: _t->setTypes(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setDays(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setWeeks(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setFirstDayOfWeek(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Calendar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Calendar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8CalendarE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Calendar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 24;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void Calendar::displayedDateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Calendar::todayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Calendar::typesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Calendar::daysChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Calendar::weeksChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Calendar::firstDayOfWeekChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Calendar::errorMessageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Calendar::monthNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Calendar::monthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Calendar::yearChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Calendar::weeksModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
