/********************************************************************************
** Form generated from reading UI file 'config.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIG_H
#define UI_CONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_Config
{
public:
    QVBoxLayout *verticalLayout;
    QRadioButton *flatButton;
    QRadioButton *subButton;
    QRadioButton *curButton;

    void setupUi(QWidget *Config)
    {
        if (Config->objectName().isEmpty())
            Config->setObjectName("Config");
        Config->resize(388, 108);
        verticalLayout = new QVBoxLayout(Config);
        verticalLayout->setObjectName("verticalLayout");
        flatButton = new QRadioButton(Config);
        flatButton->setObjectName("flatButton");

        verticalLayout->addWidget(flatButton);

        subButton = new QRadioButton(Config);
        subButton->setObjectName("subButton");

        verticalLayout->addWidget(subButton);

        curButton = new QRadioButton(Config);
        curButton->setObjectName("curButton");

        verticalLayout->addWidget(curButton);


        retranslateUi(Config);

        QMetaObject::connectSlotsByName(Config);
    } // setupUi

    void retranslateUi(QWidget *Config)
    {
        flatButton->setText(tr2i18n("Display all windows in one list", nullptr));
        subButton->setText(tr2i18n("Display a submenu for each desktop", nullptr));
        curButton->setText(tr2i18n("Display only the current desktop's windows", nullptr));
        (void)Config;
    } // retranslateUi

};

namespace Ui {
    class Config: public Ui_Config {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONFIG_H

