/****************************************************************************
** Meta object code from reading C++ file 'gtkactions_interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "gtkactions_interface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'gtkactions_interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22OrgGtkActionsInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgGtkActionsInterface::qt_create_metaobjectdata<qt_meta_tag_ZN22OrgGtkActionsInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgGtkActionsInterface",
        "Changed",
        "",
        "removals",
        "StringBoolMap",
        "enable_changes",
        "QVariantMap",
        "state_changes",
        "GMenuActionMap",
        "additions",
        "Activate",
        "QDBusPendingReply<>",
        "action_name",
        "QVariantList",
        "parameter",
        "platform_data",
        "Describe",
        "QDBusPendingReply<GMenuAction>",
        "DescribeAll",
        "QDBusPendingReply<GMenuActionMap>",
        "List",
        "QDBusPendingReply<QStringList>",
        "SetState",
        "QDBusVariant",
        "value"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Changed'
        QtMocHelpers::SignalData<void(const QStringList &, StringBoolMap, const QVariantMap &, GMenuActionMap)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Slot 'Activate'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QVariantList &, const QVariantMap &)>(10, 2, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::QString, 12 }, { 0x80000000 | 13, 14 }, { 0x80000000 | 6, 15 },
        }}),
        // Slot 'Describe'
        QtMocHelpers::SlotData<QDBusPendingReply<GMenuAction>(const QString &)>(16, 2, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'DescribeAll'
        QtMocHelpers::SlotData<QDBusPendingReply<GMenuActionMap>()>(18, 2, QMC::AccessPublic, 0x80000000 | 19),
        // Slot 'List'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(20, 2, QMC::AccessPublic, 0x80000000 | 21),
        // Slot 'SetState'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QDBusVariant &, const QVariantMap &)>(22, 2, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::QString, 12 }, { 0x80000000 | 23, 24 }, { 0x80000000 | 6, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgGtkActionsInterface, qt_meta_tag_ZN22OrgGtkActionsInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgGtkActionsInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22OrgGtkActionsInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22OrgGtkActionsInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22OrgGtkActionsInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgGtkActionsInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgGtkActionsInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Changed((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StringBoolMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<GMenuActionMap>>(_a[4]))); break;
        case 1: { QDBusPendingReply<> _r = _t->Activate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<GMenuAction> _r = _t->Describe((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<GMenuAction>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<GMenuActionMap> _r = _t->DescribeAll();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<GMenuActionMap>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<QStringList> _r = _t->List();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<> _r = _t->SetState((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgGtkActionsInterface::*)(const QStringList & , StringBoolMap , const QVariantMap & , GMenuActionMap )>(_a, &OrgGtkActionsInterface::Changed, 0))
            return;
    }
}

const QMetaObject *OrgGtkActionsInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgGtkActionsInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22OrgGtkActionsInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgGtkActionsInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void OrgGtkActionsInterface::Changed(const QStringList & _t1, StringBoolMap _t2, const QVariantMap & _t3, GMenuActionMap _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4);
}
QT_WARNING_POP
