/****************************************************************************
** Meta object code from reading C++ file 'mediaproxy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../plasma-workspace-6.7.1/wallpapers/image/plugin/utils/mediaproxy.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mediaproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10MediaProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto MediaProxy::qt_create_metaobjectdata<qt_meta_tag_ZN10MediaProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MediaProxy",
        "QML.Element",
        "auto",
        "sourceChanged",
        "",
        "modelImageChanged",
        "backgroundTypeChanged",
        "targetSizeChanged",
        "QSize",
        "size",
        "actualSizeChanged",
        "colorSchemeChanged",
        "providerTypeChanged",
        "customColorChanged",
        "sourceFileUpdated",
        "slotPlasmaThemeChanged",
        "slotSourceFileUpdated",
        "path",
        "openModelImage",
        "useSingleImageDefaults",
        "source",
        "modelImage",
        "QUrl",
        "providerType",
        "Provider::Type",
        "backgroundType",
        "BackgroundType::Type",
        "targetSize",
        "customColor",
        "QColor"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sourceChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modelImageChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'backgroundTypeChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'targetSizeChanged'
        QtMocHelpers::SignalData<void(const QSize &)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'actualSizeChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorSchemeChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'providerTypeChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'customColorChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sourceFileUpdated'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPlasmaThemeChanged'
        QtMocHelpers::SlotData<void()>(15, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSourceFileUpdated'
        QtMocHelpers::SlotData<void(const QString &)>(16, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Method 'openModelImage'
        QtMocHelpers::MethodData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'useSingleImageDefaults'
        QtMocHelpers::MethodData<void()>(19, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'source'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'modelImage'
        QtMocHelpers::PropertyData<QUrl>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'providerType'
        QtMocHelpers::PropertyData<Provider::Type>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 6),
        // property 'backgroundType'
        QtMocHelpers::PropertyData<BackgroundType::Type>(25, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 2),
        // property 'targetSize'
        QtMocHelpers::PropertyData<QSize>(27, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'customColor'
        QtMocHelpers::PropertyData<QColor>(28, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 7),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<MediaProxy, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN10MediaProxyE[] = {
    QMetaObject::SuperData::link<Provider::staticMetaObject>(),
    QMetaObject::SuperData::link<BackgroundType::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject MediaProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MediaProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MediaProxyE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN10MediaProxyE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10MediaProxyE_t>.metaTypes,
    nullptr
} };

void MediaProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MediaProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sourceChanged(); break;
        case 1: _t->modelImageChanged(); break;
        case 2: _t->backgroundTypeChanged(); break;
        case 3: _t->targetSizeChanged((*reinterpret_cast<std::add_pointer_t<QSize>>(_a[1]))); break;
        case 4: _t->actualSizeChanged(); break;
        case 5: _t->colorSchemeChanged(); break;
        case 6: _t->providerTypeChanged(); break;
        case 7: _t->customColorChanged(); break;
        case 8: _t->sourceFileUpdated(); break;
        case 9: _t->slotPlasmaThemeChanged(); break;
        case 10: _t->slotSourceFileUpdated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->openModelImage(); break;
        case 12: _t->useSingleImageDefaults(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MediaProxy::*)()>(_a, &MediaProxy::sourceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaProxy::*)()>(_a, &MediaProxy::modelImageChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaProxy::*)()>(_a, &MediaProxy::backgroundTypeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaProxy::*)(const QSize & )>(_a, &MediaProxy::targetSizeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaProxy::*)()>(_a, &MediaProxy::actualSizeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaProxy::*)()>(_a, &MediaProxy::colorSchemeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaProxy::*)()>(_a, &MediaProxy::providerTypeChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaProxy::*)()>(_a, &MediaProxy::customColorChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaProxy::*)()>(_a, &MediaProxy::sourceFileUpdated, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->source(); break;
        case 1: *reinterpret_cast<QUrl*>(_v) = _t->modelImage(); break;
        case 2: *reinterpret_cast<Provider::Type*>(_v) = _t->m_providerType; break;
        case 3: *reinterpret_cast<BackgroundType::Type*>(_v) = _t->m_backgroundType; break;
        case 4: *reinterpret_cast<QSize*>(_v) = _t->targetSize(); break;
        case 5: *reinterpret_cast<QColor*>(_v) = _t->m_customColor; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSource(*reinterpret_cast<QString*>(_v)); break;
        case 2:
            if (QtMocHelpers::setProperty(_t->m_providerType, *reinterpret_cast<Provider::Type*>(_v)))
                Q_EMIT _t->providerTypeChanged();
            break;
        case 3:
            if (QtMocHelpers::setProperty(_t->m_backgroundType, *reinterpret_cast<BackgroundType::Type*>(_v)))
                Q_EMIT _t->backgroundTypeChanged();
            break;
        case 4: _t->setTargetSize(*reinterpret_cast<QSize*>(_v)); break;
        case 5:
            if (QtMocHelpers::setProperty(_t->m_customColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->customColorChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *MediaProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MediaProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MediaProxyE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QObject::qt_metacast(_clname);
}

int MediaProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void MediaProxy::sourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MediaProxy::modelImageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void MediaProxy::backgroundTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MediaProxy::targetSizeChanged(const QSize & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void MediaProxy::actualSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void MediaProxy::colorSchemeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void MediaProxy::providerTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void MediaProxy::customColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void MediaProxy::sourceFileUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
