/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.PlasmaShell.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "plasmashelladaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class PlasmaShellAdaptor
 */

PlasmaShellAdaptor::PlasmaShellAdaptor(ShellCorona *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

PlasmaShellAdaptor::~PlasmaShellAdaptor()
{
    // destructor
}

bool PlasmaShellAdaptor::editMode() const
{
    // get the value of property editMode
    return qvariant_cast< bool >(parent()->property("editMode"));
}

void PlasmaShellAdaptor::setEditMode(bool value)
{
    // set the value of property editMode
    parent()->setProperty("editMode", QVariant::fromValue(value));
}

QString PlasmaShellAdaptor::shell() const
{
    // get the value of property shell
    return qvariant_cast< QString >(parent()->property("shell"));
}

void PlasmaShellAdaptor::activateLauncherMenu()
{
    // handle method call org.kde.PlasmaShell.activateLauncherMenu
    parent()->activateLauncherMenu();
}

void PlasmaShellAdaptor::changeShell(const QString &shell)
{
    // handle method call org.kde.PlasmaShell.changeShell
    parent()->changeShell(shell);
}

uint PlasmaShellAdaptor::color()
{
    // handle method call org.kde.PlasmaShell.color
    return parent()->color();
}

QByteArray PlasmaShellAdaptor::dumpCurrentLayoutJS()
{
    // handle method call org.kde.PlasmaShell.dumpCurrentLayoutJS
    return parent()->dumpCurrentLayoutJS();
}

QString PlasmaShellAdaptor::evaluateScript(const QString &script)
{
    // handle method call org.kde.PlasmaShell.evaluateScript
    return parent()->evaluateScript(script);
}

bool PlasmaShellAdaptor::grabContainmentImage(const QString &name, int width, int height, const QString &targetPath)
{
    // handle method call org.kde.PlasmaShell.grabContainmentImage
    return parent()->grabContainmentImage(name, width, height, targetPath);
}

bool PlasmaShellAdaptor::immutable()
{
    // handle method call org.kde.PlasmaShell.immutable
    return parent()->immutable();
}

void PlasmaShellAdaptor::loadLookAndFeelDefaultLayout(const QString &layout)
{
    // handle method call org.kde.PlasmaShell.loadLookAndFeelDefaultLayout
    parent()->loadLookAndFeelDefaultLayout(layout);
}

void PlasmaShellAdaptor::refreshCurrentShell()
{
    // handle method call org.kde.PlasmaShell.refreshCurrentShell
    parent()->refreshCurrentShell();
}

void PlasmaShellAdaptor::setDashboardShown(bool show)
{
    // handle method call org.kde.PlasmaShell.setDashboardShown
    parent()->setDashboardShown(show);
}

void PlasmaShellAdaptor::setWallpaper(const QString &wallpaperPlugin, const QVariantMap &parameters, uint screenNum)
{
    // handle method call org.kde.PlasmaShell.setWallpaper
    parent()->setWallpaper(wallpaperPlugin, parameters, screenNum);
}

void PlasmaShellAdaptor::toggleActivityManager()
{
    // handle method call org.kde.PlasmaShell.toggleActivityManager
    parent()->toggleActivityManager();
}

void PlasmaShellAdaptor::toggleDashboard()
{
    // handle method call org.kde.PlasmaShell.toggleDashboard
    parent()->toggleDashboard();
}

void PlasmaShellAdaptor::toggleWidgetExplorer()
{
    // handle method call org.kde.PlasmaShell.toggleWidgetExplorer
    parent()->toggleWidgetExplorer();
}

QVariantMap PlasmaShellAdaptor::wallpaper(uint screenNum)
{
    // handle method call org.kde.PlasmaShell.wallpaper
    return parent()->wallpaper(screenNum);
}


#include "moc_plasmashelladaptor.cpp"
