/****************************************************************************
** Meta object code from reading C++ file 'user.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../plasma-workspace-6.7.1/kcms/users/src/user.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'user.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12UserApplyJobE_t {};
} // unnamed namespace

template <> constexpr inline auto UserApplyJob::qt_create_metaobjectdata<qt_meta_tag_ZN12UserApplyJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UserApplyJob"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UserApplyJob, qt_meta_tag_ZN12UserApplyJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UserApplyJob::staticMetaObject = { {
    QMetaObject::SuperData::link<KJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12UserApplyJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12UserApplyJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12UserApplyJobE_t>.metaTypes,
    nullptr
} };

void UserApplyJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UserApplyJob *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *UserApplyJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UserApplyJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12UserApplyJobE_t>.strings))
        return static_cast<void*>(this);
    return KJob::qt_metacast(_clname);
}

int UserApplyJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KJob::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN4UserE_t {};
} // unnamed namespace

template <> constexpr inline auto User::qt_create_metaobjectdata<qt_meta_tag_ZN4UserE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "User",
        "dataChanged",
        "",
        "uidChanged",
        "nameChanged",
        "realNameChanged",
        "displayNamesChanged",
        "emailChanged",
        "loggedInChanged",
        "faceChanged",
        "faceValidChanged",
        "administratorChanged",
        "applyError",
        "errorMessage",
        "passwordSuccessfullyChanged",
        "lastFileDialogLocationChanged",
        "apply",
        "usesDefaultWallet",
        "changeWalletPassword",
        "setPassword",
        "value",
        "uid",
        "name",
        "realName",
        "displayPrimaryName",
        "displaySecondaryName",
        "email",
        "face",
        "QUrl",
        "faceCrop",
        "QRect",
        "faceValid",
        "isCurrentUser",
        "loggedIn",
        "administrator",
        "lastFileDialogLocation"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'dataChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'uidChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'realNameChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'displayNamesChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'emailChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loggedInChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'faceChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'faceValidChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'administratorChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'applyError'
        QtMocHelpers::SignalData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'passwordSuccessfullyChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastFileDialogLocationChanged'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'apply'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'usesDefaultWallet'
        QtMocHelpers::SlotData<bool()>(17, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'changeWalletPassword'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'setPassword'
        QtMocHelpers::SlotData<void(const QString &)>(19, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'uid'
        QtMocHelpers::PropertyData<qulonglong>(21, QMetaType::ULongLong, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'realName'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'displayPrimaryName'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'displaySecondaryName'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'email'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'face'
        QtMocHelpers::PropertyData<QUrl>(27, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'faceCrop'
        QtMocHelpers::PropertyData<QRect>(29, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'faceValid'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags, 8),
        // property 'isCurrentUser'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'loggedIn'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'administrator'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'lastFileDialogLocation'
        QtMocHelpers::PropertyData<QUrl>(35, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 12),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<User, qt_meta_tag_ZN4UserE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject User::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4UserE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4UserE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4UserE_t>.metaTypes,
    nullptr
} };

void User::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<User *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dataChanged(); break;
        case 1: _t->uidChanged(); break;
        case 2: _t->nameChanged(); break;
        case 3: _t->realNameChanged(); break;
        case 4: _t->displayNamesChanged(); break;
        case 5: _t->emailChanged(); break;
        case 6: _t->loggedInChanged(); break;
        case 7: _t->faceChanged(); break;
        case 8: _t->faceValidChanged(); break;
        case 9: _t->administratorChanged(); break;
        case 10: _t->applyError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->passwordSuccessfullyChanged(); break;
        case 12: _t->lastFileDialogLocationChanged(); break;
        case 13: _t->apply(); break;
        case 14: { bool _r = _t->usesDefaultWallet();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->changeWalletPassword(); break;
        case 16: _t->setPassword((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (User::*)()>(_a, &User::dataChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)()>(_a, &User::uidChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)()>(_a, &User::nameChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)()>(_a, &User::realNameChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)()>(_a, &User::displayNamesChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)()>(_a, &User::emailChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)()>(_a, &User::loggedInChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)()>(_a, &User::faceChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)()>(_a, &User::faceValidChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)()>(_a, &User::administratorChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)(const QString & )>(_a, &User::applyError, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)()>(_a, &User::passwordSuccessfullyChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (User::*)()>(_a, &User::lastFileDialogLocationChanged, 12))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qulonglong*>(_v) = _t->uid(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->realName(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->displayPrimaryName(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->displaySecondaryName(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->email(); break;
        case 6: *reinterpret_cast<QUrl*>(_v) = _t->face(); break;
        case 7: *reinterpret_cast<QRect*>(_v) = _t->faceCrop(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->faceValid(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isCurrentUser(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->loggedIn(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->administrator(); break;
        case 12: *reinterpret_cast<QUrl*>(_v) = _t->lastFileDialogLocation(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setUid(*reinterpret_cast<qulonglong*>(_v)); break;
        case 1: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setRealName(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setEmail(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setFace(*reinterpret_cast<QUrl*>(_v)); break;
        case 7: _t->setFaceCrop(*reinterpret_cast<QRect*>(_v)); break;
        case 11: _t->setAdministrator(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setLastFileDialogLocation(*reinterpret_cast<QUrl*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *User::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *User::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4UserE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int User::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void User::dataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void User::uidChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void User::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void User::realNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void User::displayNamesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void User::emailChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void User::loggedInChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void User::faceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void User::faceValidChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void User::administratorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void User::applyError(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void User::passwordSuccessfullyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void User::lastFileDialogLocationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}
QT_WARNING_POP
