/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kuiserver.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef KUISERVERADAPTOR_H
#define KUISERVERADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "jobsmodel_p.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.kuiserver
 */
class KuiserverAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.kuiserver")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.kuiserver\">\n"
"    <method name=\"registerService\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"service\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"objectPath\"/>\n"
"    </method>\n"
"    <method name=\"emitJobUrlsChanged\"/>\n"
"    <method name=\"requiresJobTracker\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"registeredJobContacts\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"    </method>\n"
"    <signal name=\"jobUrlsChanged\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"      <annotation value=\"QList&lt;QString&gt;\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </signal>\n"
"    <signal name=\"requiresJobTrackerChanged\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    KuiserverAdaptor(NotificationManager::JobsModelPrivate *parent);
    ~KuiserverAdaptor() override;

    inline NotificationManager::JobsModelPrivate *parent() const
    { return static_cast<NotificationManager::JobsModelPrivate *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void emitJobUrlsChanged();
    void registerService(const QString &service, const QString &objectPath);
    QStringList registeredJobContacts();
    bool requiresJobTracker();
Q_SIGNALS: // SIGNALS
    void jobUrlsChanged(const QStringList &in0);
    void requiresJobTrackerChanged(bool in0);
};

#endif
