// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#include "nighttimedata.h"

#include "nighttimesettings.h"




NightTimeData::NightTimeData(QObject *parent)
: KCModuleData(parent)
, m_settings(new NightTimeSettings(this))

{
autoRegisterSkeletons();
}

NightTimeSettings *NightTimeData::settings() const
{
    return m_settings;
}





#include "moc_nighttimedata.cpp"
