#ifndef plasma_wallpaper_imageplugin_static_plasma_wallpaper_image_H
#define plasma_wallpaper_imageplugin_static_plasma_wallpaper_image_H
#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#include <backgroundtype.h>
#include <dynamicmode.h>
#include <maximizedwindowmonitor.h>
#include <mediaproxy.h>
#include <daynightwallpaper.h>
#include <daynightwallpaper.h>
#include <imagebackend.h>
#include <sortingmode.h>
#include <transientimage.h>
#include <providertype.h>
namespace BackgroundTypeForeign{
    Q_NAMESPACE
    QML_FOREIGN_NAMESPACE(BackgroundType)
    QML_NAMED_ELEMENT(BackgroundType)
}

namespace DynamicModeForeign{
    Q_NAMESPACE
    QML_FOREIGN_NAMESPACE(DynamicMode)
    QML_NAMED_ELEMENT(DynamicMode)
}

struct MaximizedWindowMonitorForeign{
    Q_GADGET
    QML_FOREIGN(MaximizedWindowMonitor)
    QML_NAMED_ELEMENT(MaximizedWindowMonitor)
};

struct MediaProxyForeign{
    Q_GADGET
    QML_FOREIGN(MediaProxy)
    QML_NAMED_ELEMENT(MediaProxy)
};

struct DayNightSnapshotForeign{
    Q_GADGET
    QML_FOREIGN(DayNightSnapshot)
    QML_NAMED_ELEMENT(dayNightSnapshot)
};

struct DayNightWallpaperForeign{
    Q_GADGET
    QML_FOREIGN(DayNightWallpaper)
    QML_NAMED_ELEMENT(DayNightWallpaper)
};

struct ImageBackendForeign{
    Q_GADGET
    QML_FOREIGN(ImageBackend)
    QML_NAMED_ELEMENT(ImageBackend)
};

namespace SortingModeForeign{
    Q_NAMESPACE
    QML_FOREIGN_NAMESPACE(SortingMode)
    QML_NAMED_ELEMENT(SortingMode)
}

struct TransientImageForeign{
    Q_GADGET
    QML_FOREIGN(TransientImage)
    QML_NAMED_ELEMENT(TransientImage)
};

namespace ProviderForeign{
    Q_NAMESPACE
    QML_FOREIGN_NAMESPACE(Provider)
    QML_NAMED_ELEMENT(Provider)
}

#endif // plasma_wallpaper_imageplugin_static_plasma_wallpaper_image_H
