/****************************************************************************
** Meta object code from reading C++ file 'taskfilterproxymodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-workspace-6.7.1/libtaskmanager/taskfilterproxymodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'taskfilterproxymodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11TaskManager20TaskFilterProxyModelE_t {};
} // unnamed namespace

template <> constexpr inline auto TaskManager::TaskFilterProxyModel::qt_create_metaobjectdata<qt_meta_tag_ZN11TaskManager20TaskFilterProxyModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TaskManager::TaskFilterProxyModel",
        "virtualDesktopChanged",
        "",
        "screenGeometryChanged",
        "regionGeometryChanged",
        "activityChanged",
        "filterByVirtualDesktopChanged",
        "filterByCurrentVirtualDesktopChanged",
        "filterByScreenChanged",
        "filterByActivityChanged",
        "filterByRegionChanged",
        "filterMinimizedChanged",
        "filterNotMinimizedChanged",
        "filterNotMaximizedChanged",
        "filterHiddenChanged",
        "filterSkipTaskbarChanged",
        "filterSkipPagerChanged",
        "demandingAttentionSkipsFiltersChanged",
        "virtualDesktop",
        "QVariant",
        "screenGeometry",
        "QRect",
        "regionGeometry",
        "activity",
        "filterByVirtualDesktop",
        "filterByCurrentVirtualDesktop",
        "filterByScreen",
        "filterByActivity",
        "filterByRegion",
        "RegionFilterMode::Mode",
        "filterMinimized",
        "filterNotMinimized",
        "filterNotMaximized",
        "filterHidden",
        "filterSkipTaskbar",
        "filterSkipPager",
        "demandingAttentionSkipsFilters"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'virtualDesktopChanged'
        QtMocHelpers::SignalData<void() const>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'screenGeometryChanged'
        QtMocHelpers::SignalData<void() const>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'regionGeometryChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activityChanged'
        QtMocHelpers::SignalData<void() const>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterByVirtualDesktopChanged'
        QtMocHelpers::SignalData<void() const>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterByCurrentVirtualDesktopChanged'
        QtMocHelpers::SignalData<void() const>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterByScreenChanged'
        QtMocHelpers::SignalData<void() const>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterByActivityChanged'
        QtMocHelpers::SignalData<void() const>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterByRegionChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterMinimizedChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterNotMinimizedChanged'
        QtMocHelpers::SignalData<void() const>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterNotMaximizedChanged'
        QtMocHelpers::SignalData<void() const>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterHiddenChanged'
        QtMocHelpers::SignalData<void() const>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterSkipTaskbarChanged'
        QtMocHelpers::SignalData<void() const>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterSkipPagerChanged'
        QtMocHelpers::SignalData<void() const>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'demandingAttentionSkipsFiltersChanged'
        QtMocHelpers::SignalData<void() const>(17, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'virtualDesktop'
        QtMocHelpers::PropertyData<QVariant>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'screenGeometry'
        QtMocHelpers::PropertyData<QRect>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'regionGeometry'
        QtMocHelpers::PropertyData<QRect>(22, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'activity'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'filterByVirtualDesktop'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'filterByCurrentVirtualDesktop'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'filterByScreen'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'filterByActivity'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'filterByRegion'
        QtMocHelpers::PropertyData<RegionFilterMode::Mode>(28, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 8),
        // property 'filterMinimized'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'filterNotMinimized'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'filterNotMaximized'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'filterHidden'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'filterSkipTaskbar'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'filterSkipPager'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'demandingAttentionSkipsFilters'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TaskFilterProxyModel, qt_meta_tag_ZN11TaskManager20TaskFilterProxyModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN11TaskManager20TaskFilterProxyModelE[] = {
    QMetaObject::SuperData::link<RegionFilterMode::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject TaskManager::TaskFilterProxyModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QSortFilterProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11TaskManager20TaskFilterProxyModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11TaskManager20TaskFilterProxyModelE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN11TaskManager20TaskFilterProxyModelE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11TaskManager20TaskFilterProxyModelE_t>.metaTypes,
    nullptr
} };

void TaskManager::TaskFilterProxyModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TaskFilterProxyModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->virtualDesktopChanged(); break;
        case 1: _t->screenGeometryChanged(); break;
        case 2: _t->regionGeometryChanged(); break;
        case 3: _t->activityChanged(); break;
        case 4: _t->filterByVirtualDesktopChanged(); break;
        case 5: _t->filterByCurrentVirtualDesktopChanged(); break;
        case 6: _t->filterByScreenChanged(); break;
        case 7: _t->filterByActivityChanged(); break;
        case 8: _t->filterByRegionChanged(); break;
        case 9: _t->filterMinimizedChanged(); break;
        case 10: _t->filterNotMinimizedChanged(); break;
        case 11: _t->filterNotMaximizedChanged(); break;
        case 12: _t->filterHiddenChanged(); break;
        case 13: _t->filterSkipTaskbarChanged(); break;
        case 14: _t->filterSkipPagerChanged(); break;
        case 15: _t->demandingAttentionSkipsFiltersChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TaskFilterProxyModel::*)() const>(_a, &TaskFilterProxyModel::virtualDesktopChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TaskFilterProxyModel::*)() const>(_a, &TaskFilterProxyModel::screenGeometryChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TaskFilterProxyModel::*)()>(_a, &TaskFilterProxyModel::regionGeometryChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TaskFilterProxyModel::*)() const>(_a, &TaskFilterProxyModel::activityChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TaskFilterProxyModel::*)() const>(_a, &TaskFilterProxyModel::filterByVirtualDesktopChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TaskFilterProxyModel::*)() const>(_a, &TaskFilterProxyModel::filterByCurrentVirtualDesktopChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TaskFilterProxyModel::*)() const>(_a, &TaskFilterProxyModel::filterByScreenChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (TaskFilterProxyModel::*)() const>(_a, &TaskFilterProxyModel::filterByActivityChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (TaskFilterProxyModel::*)()>(_a, &TaskFilterProxyModel::filterByRegionChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (TaskFilterProxyModel::*)()>(_a, &TaskFilterProxyModel::filterMinimizedChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (TaskFilterProxyModel::*)() const>(_a, &TaskFilterProxyModel::filterNotMinimizedChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (TaskFilterProxyModel::*)() const>(_a, &TaskFilterProxyModel::filterNotMaximizedChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (TaskFilterProxyModel::*)() const>(_a, &TaskFilterProxyModel::filterHiddenChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (TaskFilterProxyModel::*)() const>(_a, &TaskFilterProxyModel::filterSkipTaskbarChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (TaskFilterProxyModel::*)() const>(_a, &TaskFilterProxyModel::filterSkipPagerChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (TaskFilterProxyModel::*)() const>(_a, &TaskFilterProxyModel::demandingAttentionSkipsFiltersChanged, 15))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QVariant*>(_v) = _t->virtualDesktop(); break;
        case 1: *reinterpret_cast<QRect*>(_v) = _t->screenGeometry(); break;
        case 2: *reinterpret_cast<QRect*>(_v) = _t->regionGeometry(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->activity(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->filterByVirtualDesktop(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->filterByCurrentVirtualDesktop(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->filterByScreen(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->filterByActivity(); break;
        case 8: *reinterpret_cast<RegionFilterMode::Mode*>(_v) = _t->filterByRegion(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->filterMinimized(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->filterNotMinimized(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->filterNotMaximized(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->filterHidden(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->filterSkipTaskbar(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->filterSkipPager(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->demandingAttentionSkipsFilters(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setVirtualDesktop(*reinterpret_cast<QVariant*>(_v)); break;
        case 1: _t->setScreenGeometry(*reinterpret_cast<QRect*>(_v)); break;
        case 2: _t->setRegionGeometry(*reinterpret_cast<QRect*>(_v)); break;
        case 3: _t->setActivity(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setFilterByVirtualDesktop(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setFilterByCurrentVirtualDesktop(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setFilterByScreen(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setFilterByActivity(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setFilterByRegion(*reinterpret_cast<RegionFilterMode::Mode*>(_v)); break;
        case 9: _t->setFilterMinimized(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setFilterNotMinimized(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setFilterNotMaximized(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setFilterHidden(*reinterpret_cast<bool*>(_v)); break;
        case 13: _t->setFilterSkipTaskbar(*reinterpret_cast<bool*>(_v)); break;
        case 14: _t->setFilterSkipPager(*reinterpret_cast<bool*>(_v)); break;
        case 15: _t->setDemandingAttentionSkipsFilters(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *TaskManager::TaskFilterProxyModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TaskManager::TaskFilterProxyModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11TaskManager20TaskFilterProxyModelE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "AbstractTasksProxyModelIface"))
        return static_cast< AbstractTasksProxyModelIface*>(this);
    return QSortFilterProxyModel::qt_metacast(_clname);
}

int TaskManager::TaskFilterProxyModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSortFilterProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void TaskManager::TaskFilterProxyModel::virtualDesktopChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TaskFilterProxyModel *>(this), &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TaskManager::TaskFilterProxyModel::screenGeometryChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TaskFilterProxyModel *>(this), &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void TaskManager::TaskFilterProxyModel::regionGeometryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void TaskManager::TaskFilterProxyModel::activityChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TaskFilterProxyModel *>(this), &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void TaskManager::TaskFilterProxyModel::filterByVirtualDesktopChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TaskFilterProxyModel *>(this), &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void TaskManager::TaskFilterProxyModel::filterByCurrentVirtualDesktopChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TaskFilterProxyModel *>(this), &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void TaskManager::TaskFilterProxyModel::filterByScreenChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TaskFilterProxyModel *>(this), &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void TaskManager::TaskFilterProxyModel::filterByActivityChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TaskFilterProxyModel *>(this), &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void TaskManager::TaskFilterProxyModel::filterByRegionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void TaskManager::TaskFilterProxyModel::filterMinimizedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void TaskManager::TaskFilterProxyModel::filterNotMinimizedChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TaskFilterProxyModel *>(this), &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void TaskManager::TaskFilterProxyModel::filterNotMaximizedChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TaskFilterProxyModel *>(this), &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void TaskManager::TaskFilterProxyModel::filterHiddenChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TaskFilterProxyModel *>(this), &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void TaskManager::TaskFilterProxyModel::filterSkipTaskbarChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TaskFilterProxyModel *>(this), &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void TaskManager::TaskFilterProxyModel::filterSkipPagerChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TaskFilterProxyModel *>(this), &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void TaskManager::TaskFilterProxyModel::demandingAttentionSkipsFiltersChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TaskFilterProxyModel *>(this), &staticMetaObject, 15, nullptr);
}
QT_WARNING_POP
