// This file is generated by kconfig_compiler_kf6 from lookandfeelsettings.kcfg.
// All changes you do to this file will be lost.
#ifndef LOOKANDFEELSETTINGS_H
#define LOOKANDFEELSETTINGS_H

#include <qglobal.h>
#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class LookAndFeelSettings : public KConfigSkeleton
{
  public:

    LookAndFeelSettings( );
    ~LookAndFeelSettings() override;

    /**
      Get Global look and feel
    */
    QString lookAndFeelPackage() const
    {
      return mLookAndFeelPackage;
    }

    /**
      Is Global look and feel Immutable
    */
    bool isLookAndFeelPackageImmutable() const
    {
      return isImmutable( QStringLiteral( "lookAndFeelPackage" ) );
    }

    /**
      Get Global Look and Feel package, alternate
    */
    QString defaultLightLookAndFeel() const
    {
      return mDefaultLightLookAndFeel;
    }

    /**
      Is Global Look and Feel package, alternate Immutable
    */
    bool isDefaultLightLookAndFeelImmutable() const
    {
      return isImmutable( QStringLiteral( "defaultLightLookAndFeel" ) );
    }

    /**
      Get Global Look and Feel package, alternate
    */
    QString defaultDarkLookAndFeel() const
    {
      return mDefaultDarkLookAndFeel;
    }

    /**
      Is Global Look and Feel package, alternate Immutable
    */
    bool isDefaultDarkLookAndFeelImmutable() const
    {
      return isImmutable( QStringLiteral( "defaultDarkLookAndFeel" ) );
    }

    /**
      Get Switch between dark and light global themes depending on time of day
    */
    bool automaticLookAndFeel() const
    {
      return mAutomaticLookAndFeel;
    }

    /**
      Is Switch between dark and light global themes depending on time of day Immutable
    */
    bool isAutomaticLookAndFeelImmutable() const
    {
      return isImmutable( QStringLiteral( "automaticLookAndFeel" ) );
    }

    /**
      Get Switch between dark and light global themes when the computer is idle
    */
    bool automaticLookAndFeelOnIdle() const
    {
      return mAutomaticLookAndFeelOnIdle;
    }

    /**
      Is Switch between dark and light global themes when the computer is idle Immutable
    */
    bool isAutomaticLookAndFeelOnIdleImmutable() const
    {
      return isImmutable( QStringLiteral( "automaticLookAndFeelOnIdle" ) );
    }

    /**
      Get How long the computer should be idle in order to switch between dark and light global themes, in seconds
    */
    uint automaticLookAndFeelIdleInterval() const
    {
      return mAutomaticLookAndFeelIdleInterval;
    }

    /**
      Is How long the computer should be idle in order to switch between dark and light global themes, in seconds Immutable
    */
    bool isAutomaticLookAndFeelIdleIntervalImmutable() const
    {
      return isImmutable( QStringLiteral( "automaticLookAndFeelIdleInterval" ) );
    }

  protected:

    // KDE
    QString mLookAndFeelPackage;
    QString mDefaultLightLookAndFeel;
    QString mDefaultDarkLookAndFeel;
    bool mAutomaticLookAndFeel;
    bool mAutomaticLookAndFeelOnIdle;
    uint mAutomaticLookAndFeelIdleInterval;
};

#endif

