/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.LogoutPrompt.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef LOGOUTPROMPTADAPTOR_H
#define LOGOUTPROMPTADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "greeter.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.LogoutPrompt
 */
class LogoutPromptAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.LogoutPrompt")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.LogoutPrompt\">\n"
"    <method name=\"promptLogout\"/>\n"
"    <method name=\"promptShutDown\"/>\n"
"    <method name=\"promptReboot\"/>\n"
"    <method name=\"promptAll\"/>\n"
"  </interface>\n"
        "")
public:
    LogoutPromptAdaptor(Greeter *parent);
    ~LogoutPromptAdaptor() override;

    inline Greeter *parent() const
    { return static_cast<Greeter *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void promptAll();
    void promptLogout();
    void promptReboot();
    void promptShutDown();
Q_SIGNALS: // SIGNALS
};

#endif
