/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.notificationmanager.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "notificationmanageradaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class NotificationManagerAdaptor
 */

NotificationManagerAdaptor::NotificationManagerAdaptor(NotificationManager::ServerPrivate *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

NotificationManagerAdaptor::~NotificationManagerAdaptor()
{
    // destructor
}

void NotificationManagerAdaptor::InvokeAction(uint id, const QString &action_key)
{
    // handle method call org.kde.NotificationManager.InvokeAction
    parent()->InvokeAction(id, action_key);
}

void NotificationManagerAdaptor::RegisterWatcher()
{
    // handle method call org.kde.NotificationManager.RegisterWatcher
    parent()->RegisterWatcher();
}

void NotificationManagerAdaptor::UnRegisterWatcher()
{
    // handle method call org.kde.NotificationManager.UnRegisterWatcher
    parent()->UnRegisterWatcher();
}


#include "moc_notificationmanageradaptor.cpp"
