/****************************************************************************
** Meta object code from reading C++ file 'FontinstIface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../plasma-workspace-6.7.1/kcms/kfontinst/dbus/FontinstIface.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'FontinstIface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23OrgKdeFontinstInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgKdeFontinstInterface::qt_create_metaobjectdata<qt_meta_tag_ZN23OrgKdeFontinstInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgKdeFontinstInterface",
        "fontList",
        "",
        "pid",
        "QList<KFI::Families>",
        "families",
        "fontStat",
        "KFI::Family",
        "family",
        "fontsAdded",
        "KFI::Families",
        "fontsRemoved",
        "status",
        "value",
        "disable",
        "Q_NOREPLY",
        "style",
        "inSystem",
        "checkConfig",
        "enable",
        "folderName",
        "QDBusPendingReply<QString>",
        "sys",
        "install",
        "file",
        "createAfm",
        "toSystem",
        "list",
        "folders",
        "move",
        "reconfigure",
        "force",
        "removeFile",
        "fromSystem",
        "saveDisabled",
        "QDBusPendingReply<>",
        "statFont",
        "name",
        "uninstall"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'fontList'
        QtMocHelpers::SignalData<void(int, const QList<KFI::Families> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'fontStat'
        QtMocHelpers::SignalData<void(int, const KFI::Family &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 7, 8 },
        }}),
        // Signal 'fontsAdded'
        QtMocHelpers::SignalData<void(const KFI::Families &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 5 },
        }}),
        // Signal 'fontsRemoved'
        QtMocHelpers::SignalData<void(const KFI::Families &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 5 },
        }}),
        // Signal 'status'
        QtMocHelpers::SignalData<void(int, int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 13 },
        }}),
        // Slot 'disable'
        QtMocHelpers::SlotData<void(const QString &, uint, bool, int, bool)>(14, 15, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::UInt, 16 }, { QMetaType::Bool, 17 }, { QMetaType::Int, 3 },
            { QMetaType::Bool, 18 },
        }}),
        // Slot 'enable'
        QtMocHelpers::SlotData<void(const QString &, uint, bool, int, bool)>(19, 15, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::UInt, 16 }, { QMetaType::Bool, 17 }, { QMetaType::Int, 3 },
            { QMetaType::Bool, 18 },
        }}),
        // Slot 'folderName'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(bool)>(20, 2, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'install'
        QtMocHelpers::SlotData<void(const QString &, bool, bool, int, bool)>(23, 15, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 24 }, { QMetaType::Bool, 25 }, { QMetaType::Bool, 26 }, { QMetaType::Int, 3 },
            { QMetaType::Bool, 18 },
        }}),
        // Slot 'list'
        QtMocHelpers::SlotData<void(int, int)>(27, 15, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 28 }, { QMetaType::Int, 3 },
        }}),
        // Slot 'move'
        QtMocHelpers::SlotData<void(const QString &, uint, bool, int, bool)>(29, 15, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::UInt, 16 }, { QMetaType::Bool, 26 }, { QMetaType::Int, 3 },
            { QMetaType::Bool, 18 },
        }}),
        // Slot 'reconfigure'
        QtMocHelpers::SlotData<void(int, bool)>(30, 15, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Bool, 31 },
        }}),
        // Slot 'removeFile'
        QtMocHelpers::SlotData<void(const QString &, uint, const QString &, bool, int, bool)>(32, 15, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::UInt, 16 }, { QMetaType::QString, 24 }, { QMetaType::Bool, 33 },
            { QMetaType::Int, 3 }, { QMetaType::Bool, 18 },
        }}),
        // Slot 'saveDisabled'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(34, 2, QMC::AccessPublic, 0x80000000 | 35),
        // Slot 'statFont'
        QtMocHelpers::SlotData<void(const QString &, int, int)>(36, 15, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 }, { QMetaType::Int, 28 }, { QMetaType::Int, 3 },
        }}),
        // Slot 'uninstall'
        QtMocHelpers::SlotData<void(const QString &, bool, int, bool)>(38, 15, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 }, { QMetaType::Bool, 33 }, { QMetaType::Int, 3 }, { QMetaType::Bool, 18 },
        }}),
        // Slot 'uninstall'
        QtMocHelpers::SlotData<void(const QString &, uint, bool, int, bool)>(38, 15, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::UInt, 16 }, { QMetaType::Bool, 33 }, { QMetaType::Int, 3 },
            { QMetaType::Bool, 18 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgKdeFontinstInterface, qt_meta_tag_ZN23OrgKdeFontinstInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgKdeFontinstInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23OrgKdeFontinstInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23OrgKdeFontinstInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23OrgKdeFontinstInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgKdeFontinstInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgKdeFontinstInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->fontList((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<KFI::Families>>>(_a[2]))); break;
        case 1: _t->fontStat((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KFI::Family>>(_a[2]))); break;
        case 2: _t->fontsAdded((*reinterpret_cast<std::add_pointer_t<KFI::Families>>(_a[1]))); break;
        case 3: _t->fontsRemoved((*reinterpret_cast<std::add_pointer_t<KFI::Families>>(_a[1]))); break;
        case 4: _t->status((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 5: _t->disable((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 6: _t->enable((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 7: { QDBusPendingReply<QString> _r = _t->folderName((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->install((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 9: _t->list((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 10: _t->move((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 11: _t->reconfigure((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 12: _t->removeFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6]))); break;
        case 13: { QDBusPendingReply<> _r = _t->saveDisabled();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->statFont((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 15: _t->uninstall((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 16: _t->uninstall((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgKdeFontinstInterface::*)(int , const QList<KFI::Families> & )>(_a, &OrgKdeFontinstInterface::fontList, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeFontinstInterface::*)(int , const KFI::Family & )>(_a, &OrgKdeFontinstInterface::fontStat, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeFontinstInterface::*)(const KFI::Families & )>(_a, &OrgKdeFontinstInterface::fontsAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeFontinstInterface::*)(const KFI::Families & )>(_a, &OrgKdeFontinstInterface::fontsRemoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeFontinstInterface::*)(int , int )>(_a, &OrgKdeFontinstInterface::status, 4))
            return;
    }
}

const QMetaObject *OrgKdeFontinstInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgKdeFontinstInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23OrgKdeFontinstInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgKdeFontinstInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void OrgKdeFontinstInterface::fontList(int _t1, const QList<KFI::Families> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void OrgKdeFontinstInterface::fontStat(int _t1, const KFI::Family & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void OrgKdeFontinstInterface::fontsAdded(const KFI::Families & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void OrgKdeFontinstInterface::fontsRemoved(const KFI::Families & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void OrgKdeFontinstInterface::status(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}
QT_WARNING_POP
