/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.JobViewV2.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef JOBVIEWV2ADAPTOR_H
#define JOBVIEWV2ADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "job_p.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.JobViewV2
 */
class JobViewV2Adaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.JobViewV2")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.JobViewV2\">\n"
"    <method name=\"terminate\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"errorMessage\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"setSuspended\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"suspended\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"setTotalAmount\">\n"
"      <arg direction=\"in\" type=\"t\" name=\"amount\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"unit\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"setProcessedAmount\">\n"
"      <arg direction=\"in\" type=\"t\" name=\"amount\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"unit\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"setPercent\">\n"
"      <arg direction=\"in\" type=\"u\" name=\"percent\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"setSpeed\">\n"
"      <arg direction=\"in\" type=\"t\" name=\"bytesPerSecond\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"setInfoMessage\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"message\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"setDescriptionField\">\n"
"      <arg direction=\"in\" type=\"u\" name=\"number\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"value\"/>\n"
"      <arg direction=\"out\" type=\"b\" name=\"res\"/>\n"
"    </method>\n"
"    <method name=\"clearDescriptionField\">\n"
"      <arg direction=\"in\" type=\"u\" name=\"number\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"setDestUrl\">\n"
"      <arg direction=\"in\" type=\"v\" name=\"destUrl\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"setError\">\n"
"      <arg direction=\"in\" type=\"u\" name=\"errorCode\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <signal name=\"suspendRequested\"/>\n"
"    <signal name=\"resumeRequested\"/>\n"
"    <signal name=\"cancelRequested\"/>\n"
"  </interface>\n"
        "")
public:
    JobViewV2Adaptor(NotificationManager::JobPrivate *parent);
    ~JobViewV2Adaptor() override;

    inline NotificationManager::JobPrivate *parent() const
    { return static_cast<NotificationManager::JobPrivate *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    Q_NOREPLY void clearDescriptionField(uint number);
    bool setDescriptionField(uint number, const QString &name, const QString &value);
    Q_NOREPLY void setDestUrl(const QDBusVariant &destUrl);
    Q_NOREPLY void setError(uint errorCode);
    Q_NOREPLY void setInfoMessage(const QString &message);
    Q_NOREPLY void setPercent(uint percent);
    Q_NOREPLY void setProcessedAmount(qulonglong amount, const QString &unit);
    Q_NOREPLY void setSpeed(qulonglong bytesPerSecond);
    Q_NOREPLY void setSuspended(bool suspended);
    Q_NOREPLY void setTotalAmount(qulonglong amount, const QString &unit);
    Q_NOREPLY void terminate(const QString &errorMessage);
Q_SIGNALS: // SIGNALS
    void cancelRequested();
    void resumeRequested();
    void suspendRequested();
};

#endif
