// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#include "feedbackdata.h"

#include "feedbacksettings.h"




FeedbackData::FeedbackData(QObject *parent)
: KCModuleData(parent)
, m_settings(new FeedbackSettings(this))

{
autoRegisterSkeletons();
}

FeedbackSettings *FeedbackData::settings() const
{
    return m_settings;
}





#include "moc_feedbackdata.cpp"
