/********************************************************************************
** Form generated from reading UI file 'scmeditordialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SCMEDITORDIALOG_H
#define UI_SCMEDITORDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ScmEditorDialog
{
public:
    QVBoxLayout *vboxLayout;
    QTabWidget *tabWidget;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer_2;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *ScmEditorDialog)
    {
        if (ScmEditorDialog->objectName().isEmpty())
            ScmEditorDialog->setObjectName("ScmEditorDialog");
        ScmEditorDialog->resize(477, 422);
        vboxLayout = new QVBoxLayout(ScmEditorDialog);
        vboxLayout->setObjectName("vboxLayout");
        tabWidget = new QTabWidget(ScmEditorDialog);
        tabWidget->setObjectName("tabWidget");

        vboxLayout->addWidget(tabWidget);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);

        buttonBox = new QDialogButtonBox(ScmEditorDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Close|QDialogButtonBox::Reset|QDialogButtonBox::Apply|QDialogButtonBox::Save);

        horizontalLayout->addWidget(buttonBox);


        vboxLayout->addLayout(horizontalLayout);


        retranslateUi(ScmEditorDialog);

        tabWidget->setCurrentIndex(-1);


        QMetaObject::connectSlotsByName(ScmEditorDialog);
    } // setupUi

    void retranslateUi(QWidget *ScmEditorDialog)
    {
        (void)ScmEditorDialog;
    } // retranslateUi

};

namespace Ui {
    class ScmEditorDialog: public Ui_ScmEditorDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SCMEDITORDIALOG_H

