/****************************************************************************
** Meta object code from reading C++ file 'plasmashelladaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "plasmashelladaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'plasmashelladaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18PlasmaShellAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto PlasmaShellAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN18PlasmaShellAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PlasmaShellAdaptor",
        "D-Bus Interface",
        "org.kde.PlasmaShell",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.PlasmaShell\">\n    <property access=\""
        "readwrite\" type=\"b\" name=\"editMode\"/>\n    <property access=\""
        "read\" type=\"s\" name=\"shell\"/>\n    <method name=\"changeShell"
        "\">\n      <arg direction=\"in\" type=\"s\" name=\"shell\"/>\n    "
        "</method>\n    <method name=\"toggleDashboard\"/>\n    <method nam"
        "e=\"toggleActivityManager\"/>\n    <method name=\"toggleWidgetExpl"
        "orer\"/>\n    <method name=\"setDashboardShown\">\n      <arg dire"
        "ction=\"in\" type=\"b\" name=\"show\"/>\n    </method>\n    <metho"
        "d name=\"evaluateScript\">\n      <arg direction=\"in\" type=\"s\""
        " name=\"script\"/>\n      <arg direction=\"out\" type=\"s\" name=\""
        "output\"/>\n    </method>\n    <method name=\"color\">\n      <arg"
        " direction=\"out\" type=\"u\" name=\"output\"/>\n    </method>\n  "
        "  <method name=\"immutable\">\n      <arg direction=\"out\" type=\""
        "b\" name=\"output\"/>\n    </method>\n    <method name=\"dumpCurre"
        "ntLayoutJS\">\n      <arg direction=\"out\" type=\"ay\" name=\"scr"
        "ipt\"/>\n    </method>\n    <method name=\"loadLookAndFeelDefaultL"
        "ayout\">\n      <arg direction=\"in\" type=\"s\" name=\"layout\"/>"
        "\n    </method>\n    <method name=\"activateLauncherMenu\"/>\n    "
        "<method name=\"refreshCurrentShell\"/>\n    <method name=\"wallpap"
        "er\">\n      <arg direction=\"in\" type=\"u\" name=\"screenNum\"/>"
        "\n      <arg direction=\"out\" type=\"a{sv}\" name=\"parameters\"/"
        ">\n      <annotation value=\"QVariantMap\" name=\"org.qtproject.Qt"
        "DBus.QtTypeName.Out0\"/>\n    </method>\n    <method name=\"setWal"
        "lpaper\">\n      <arg direction=\"in\" type=\"s\" name=\"wallpaper"
        "Plugin\"/>\n      <arg direction=\"in\" type=\"a{sv}\" name=\"para"
        "meters\"/>\n      <arg direction=\"in\" type=\"u\" name=\"screenNu"
        "m\"/>\n      <annotation value=\"QVariantMap\" name=\"org.qtprojec"
        "t.QtDBus.QtTypeName.In1\"/>\n    </method>\n    <signal name=\"she"
        "llChanged\">\n      <arg direction=\"out\" type=\"s\" name=\"shell"
        "\"/>\n    </signal>\n    <signal name=\"wallpaperChanged\">\n     "
        " <arg direction=\"out\" type=\"u\" name=\"screenNum\"/>\n    </sig"
        "nal>\n    <method name=\"grabContainmentImage\">\n      <arg direc"
        "tion=\"in\" type=\"s\" name=\"name\"/>\n      <arg direction=\"in\""
        " type=\"i\" name=\"width\"/>\n      <arg direction=\"in\" type=\"i"
        "\" name=\"height\"/>\n      <arg direction=\"in\" type=\"s\" name="
        "\"targetPath\"/>\n      <arg direction=\"out\" type=\"b\" name=\"r"
        "esult\"/>\n    </method>\n    <signal name=\"colorChanged\">\n    "
        "  <arg direction=\"out\" type=\"s\" name=\"changedColor\"/>\n    <"
        "/signal>\n  </interface>\n",
        "colorChanged",
        "",
        "changedColor",
        "shellChanged",
        "shell",
        "wallpaperChanged",
        "screenNum",
        "activateLauncherMenu",
        "changeShell",
        "color",
        "dumpCurrentLayoutJS",
        "evaluateScript",
        "script",
        "grabContainmentImage",
        "name",
        "width",
        "height",
        "targetPath",
        "immutable",
        "loadLookAndFeelDefaultLayout",
        "layout",
        "refreshCurrentShell",
        "setDashboardShown",
        "show",
        "setWallpaper",
        "wallpaperPlugin",
        "QVariantMap",
        "parameters",
        "toggleActivityManager",
        "toggleDashboard",
        "toggleWidgetExplorer",
        "wallpaper",
        "editMode"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'colorChanged'
        QtMocHelpers::SignalData<void(const QString &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'shellChanged'
        QtMocHelpers::SignalData<void(const QString &)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'wallpaperChanged'
        QtMocHelpers::SignalData<void(uint)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 11 },
        }}),
        // Slot 'activateLauncherMenu'
        QtMocHelpers::SlotData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'changeShell'
        QtMocHelpers::SlotData<void(const QString &)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'color'
        QtMocHelpers::SlotData<uint()>(14, 6, QMC::AccessPublic, QMetaType::UInt),
        // Slot 'dumpCurrentLayoutJS'
        QtMocHelpers::SlotData<QByteArray()>(15, 6, QMC::AccessPublic, QMetaType::QByteArray),
        // Slot 'evaluateScript'
        QtMocHelpers::SlotData<QString(const QString &)>(16, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'grabContainmentImage'
        QtMocHelpers::SlotData<bool(const QString &, int, int, const QString &)>(18, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 19 }, { QMetaType::Int, 20 }, { QMetaType::Int, 21 }, { QMetaType::QString, 22 },
        }}),
        // Slot 'immutable'
        QtMocHelpers::SlotData<bool()>(23, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'loadLookAndFeelDefaultLayout'
        QtMocHelpers::SlotData<void(const QString &)>(24, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'refreshCurrentShell'
        QtMocHelpers::SlotData<void()>(26, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setDashboardShown'
        QtMocHelpers::SlotData<void(bool)>(27, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 28 },
        }}),
        // Slot 'setWallpaper'
        QtMocHelpers::SlotData<void(const QString &, const QVariantMap &, uint)>(29, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 30 }, { 0x80000000 | 31, 32 }, { QMetaType::UInt, 11 },
        }}),
        // Slot 'toggleActivityManager'
        QtMocHelpers::SlotData<void()>(33, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleDashboard'
        QtMocHelpers::SlotData<void()>(34, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleWidgetExplorer'
        QtMocHelpers::SlotData<void()>(35, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'wallpaper'
        QtMocHelpers::SlotData<QVariantMap(uint)>(36, 6, QMC::AccessPublic, 0x80000000 | 31, {{
            { QMetaType::UInt, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'editMode'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'shell'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<PlasmaShellAdaptor, qt_meta_tag_ZN18PlasmaShellAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PlasmaShellAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18PlasmaShellAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18PlasmaShellAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18PlasmaShellAdaptorE_t>.metaTypes,
    nullptr
} };

void PlasmaShellAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PlasmaShellAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->colorChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->shellChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->wallpaperChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 3: _t->activateLauncherMenu(); break;
        case 4: _t->changeShell((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: { uint _r = _t->color();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 6: { QByteArray _r = _t->dumpCurrentLayoutJS();
            if (_a[0]) *reinterpret_cast<QByteArray*>(_a[0]) = std::move(_r); }  break;
        case 7: { QString _r = _t->evaluateScript((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->grabContainmentImage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->immutable();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->loadLookAndFeelDefaultLayout((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->refreshCurrentShell(); break;
        case 12: _t->setDashboardShown((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->setWallpaper((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3]))); break;
        case 14: _t->toggleActivityManager(); break;
        case 15: _t->toggleDashboard(); break;
        case 16: _t->toggleWidgetExplorer(); break;
        case 17: { QVariantMap _r = _t->wallpaper((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PlasmaShellAdaptor::*)(const QString & )>(_a, &PlasmaShellAdaptor::colorChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaShellAdaptor::*)(const QString & )>(_a, &PlasmaShellAdaptor::shellChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaShellAdaptor::*)(uint )>(_a, &PlasmaShellAdaptor::wallpaperChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->editMode(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->shell(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setEditMode(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PlasmaShellAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PlasmaShellAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18PlasmaShellAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int PlasmaShellAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void PlasmaShellAdaptor::colorChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PlasmaShellAdaptor::shellChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void PlasmaShellAdaptor::wallpaperChanged(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
