/****************************************************************************
** Meta object code from reading C++ file 'sessionmanagementbackend.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-workspace-6.7.1/libkworkspace/sessionmanagementbackend.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sessionmanagementbackend.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14SessionBackendE_t {};
} // unnamed namespace

template <> constexpr inline auto SessionBackend::qt_create_metaobjectdata<qt_meta_tag_ZN14SessionBackendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SessionBackend",
        "stateChanged",
        "",
        "canShutdownChanged",
        "canRebootChanged",
        "canSuspendChanged",
        "canHybridSuspendChanged",
        "canHibernateChanged",
        "canSuspendThenHibernateChanged",
        "aboutToSuspend",
        "resumingFromSuspend"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canShutdownChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canRebootChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canSuspendChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canHybridSuspendChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canHibernateChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canSuspendThenHibernateChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'aboutToSuspend'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resumingFromSuspend'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SessionBackend, qt_meta_tag_ZN14SessionBackendE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SessionBackend::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SessionBackendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SessionBackendE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14SessionBackendE_t>.metaTypes,
    nullptr
} };

void SessionBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SessionBackend *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->stateChanged(); break;
        case 1: _t->canShutdownChanged(); break;
        case 2: _t->canRebootChanged(); break;
        case 3: _t->canSuspendChanged(); break;
        case 4: _t->canHybridSuspendChanged(); break;
        case 5: _t->canHibernateChanged(); break;
        case 6: _t->canSuspendThenHibernateChanged(); break;
        case 7: _t->aboutToSuspend(); break;
        case 8: _t->resumingFromSuspend(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SessionBackend::*)()>(_a, &SessionBackend::stateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionBackend::*)()>(_a, &SessionBackend::canShutdownChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionBackend::*)()>(_a, &SessionBackend::canRebootChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionBackend::*)()>(_a, &SessionBackend::canSuspendChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionBackend::*)()>(_a, &SessionBackend::canHybridSuspendChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionBackend::*)()>(_a, &SessionBackend::canHibernateChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionBackend::*)()>(_a, &SessionBackend::canSuspendThenHibernateChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionBackend::*)()>(_a, &SessionBackend::aboutToSuspend, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionBackend::*)()>(_a, &SessionBackend::resumingFromSuspend, 8))
            return;
    }
}

const QMetaObject *SessionBackend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SessionBackend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SessionBackendE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SessionBackend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void SessionBackend::stateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SessionBackend::canShutdownChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SessionBackend::canRebootChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void SessionBackend::canSuspendChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void SessionBackend::canHybridSuspendChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void SessionBackend::canHibernateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void SessionBackend::canSuspendThenHibernateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void SessionBackend::aboutToSuspend()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void SessionBackend::resumingFromSuspend()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
namespace {
struct qt_meta_tag_ZN20LogindSessionBackendE_t {};
} // unnamed namespace

template <> constexpr inline auto LogindSessionBackend::qt_create_metaobjectdata<qt_meta_tag_ZN20LogindSessionBackendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LogindSessionBackend"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LogindSessionBackend, qt_meta_tag_ZN20LogindSessionBackendE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LogindSessionBackend::staticMetaObject = { {
    QMetaObject::SuperData::link<SessionBackend::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20LogindSessionBackendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20LogindSessionBackendE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20LogindSessionBackendE_t>.metaTypes,
    nullptr
} };

void LogindSessionBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LogindSessionBackend *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *LogindSessionBackend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LogindSessionBackend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20LogindSessionBackendE_t>.strings))
        return static_cast<void*>(this);
    return SessionBackend::qt_metacast(_clname);
}

int LogindSessionBackend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SessionBackend::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN19DummySessionBackendE_t {};
} // unnamed namespace

template <> constexpr inline auto DummySessionBackend::qt_create_metaobjectdata<qt_meta_tag_ZN19DummySessionBackendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DummySessionBackend"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DummySessionBackend, qt_meta_tag_ZN19DummySessionBackendE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DummySessionBackend::staticMetaObject = { {
    QMetaObject::SuperData::link<SessionBackend::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DummySessionBackendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DummySessionBackendE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19DummySessionBackendE_t>.metaTypes,
    nullptr
} };

void DummySessionBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DummySessionBackend *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *DummySessionBackend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DummySessionBackend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DummySessionBackendE_t>.strings))
        return static_cast<void*>(this);
    return SessionBackend::qt_metacast(_clname);
}

int DummySessionBackend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SessionBackend::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN18TestSessionBackendE_t {};
} // unnamed namespace

template <> constexpr inline auto TestSessionBackend::qt_create_metaobjectdata<qt_meta_tag_ZN18TestSessionBackendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TestSessionBackend"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TestSessionBackend, qt_meta_tag_ZN18TestSessionBackendE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TestSessionBackend::staticMetaObject = { {
    QMetaObject::SuperData::link<SessionBackend::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18TestSessionBackendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18TestSessionBackendE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18TestSessionBackendE_t>.metaTypes,
    nullptr
} };

void TestSessionBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TestSessionBackend *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *TestSessionBackend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TestSessionBackend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18TestSessionBackendE_t>.strings))
        return static_cast<void*>(this);
    return SessionBackend::qt_metacast(_clname);
}

int TestSessionBackend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SessionBackend::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
