/****************************************************************************
** Meta object code from reading C++ file 'unit.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/kcms/autostart/unit.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'unit.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4UnitE_t {};
} // unnamed namespace

template <> constexpr inline auto Unit::qt_create_metaobjectdata<qt_meta_tag_ZN4UnitE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Unit",
        "journalError",
        "",
        "message",
        "error",
        "dataChanged",
        "dbusPropertiesChanged",
        "name",
        "QVariantMap",
        "map",
        "list",
        "callFinishedSlot",
        "QDBusPendingCallWatcher*",
        "call",
        "start",
        "stop",
        "reloadLogs",
        "activeState",
        "activeStateValue",
        "description",
        "timeActivated",
        "logs",
        "invalid"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'journalError'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'error'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'dataChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'dbusPropertiesChanged'
        QtMocHelpers::SlotData<void(QString, QVariantMap, QStringList)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { 0x80000000 | 8, 9 }, { QMetaType::QStringList, 10 },
        }}),
        // Slot 'callFinishedSlot'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Method 'start'
        QtMocHelpers::MethodData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'stop'
        QtMocHelpers::MethodData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'reloadLogs'
        QtMocHelpers::MethodData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'activeState'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 2),
        // property 'activeStateValue'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 2),
        // property 'description'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 2),
        // property 'timeActivated'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 2),
        // property 'logs'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 2),
        // property 'invalid'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Unit, qt_meta_tag_ZN4UnitE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Unit::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4UnitE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4UnitE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4UnitE_t>.metaTypes,
    nullptr
} };

void Unit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Unit *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->journalError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->dataChanged(); break;
        case 3: _t->dbusPropertiesChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        case 4: _t->callFinishedSlot((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 5: _t->start(); break;
        case 6: _t->stop(); break;
        case 7: _t->reloadLogs(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Unit::*)(const QString & )>(_a, &Unit::journalError, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Unit::*)(const QString & )>(_a, &Unit::error, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Unit::*)()>(_a, &Unit::dataChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->m_activeState; break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->m_activeStateValue; break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->m_description; break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->m_timeActivated; break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->m_logs; break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->m_invalid; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->m_activeState, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->dataChanged();
            break;
        case 1:
            if (QtMocHelpers::setProperty(_t->m_activeStateValue, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->dataChanged();
            break;
        case 2:
            if (QtMocHelpers::setProperty(_t->m_description, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->dataChanged();
            break;
        case 3:
            if (QtMocHelpers::setProperty(_t->m_timeActivated, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->dataChanged();
            break;
        case 4:
            if (QtMocHelpers::setProperty(_t->m_logs, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->dataChanged();
            break;
        case 5:
            if (QtMocHelpers::setProperty(_t->m_invalid, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->dataChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *Unit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Unit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4UnitE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Unit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void Unit::journalError(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Unit::error(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Unit::dataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
