// This file is generated by kconfig_compiler_kf6 from iconssettingsbase.kcfg.
// All changes you do to this file will be lost.
#ifndef ICONSSETTINGSBASE_H
#define ICONSSETTINGSBASE_H

#include <qglobal.h>
#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class IconsSettingsBase : public KConfigSkeleton
{
  Q_OBJECT
  public:

    IconsSettingsBase( QObject *parent = nullptr );
    ~IconsSettingsBase() override;

    /**
      Set Name of the current icon theme
    */
    void setTheme( const QString & v )
    {
      if (v != mTheme && !isThemeImmutable()) {
        mTheme = v;
        Q_EMIT ThemeChanged();
      }
    }

    Q_PROPERTY(QString theme READ theme WRITE setTheme NOTIFY ThemeChanged)
    Q_PROPERTY(bool isThemeImmutable READ isThemeImmutable CONSTANT)
    Q_PROPERTY(QString defaultThemeValue READ defaultThemeValue CONSTANT)
    /**
      Get Name of the current icon theme
    */
    QString theme() const
    {
      return mTheme;
    }

    /**
      Is Name of the current icon theme Immutable
    */
    bool isThemeImmutable() const
    {
      return isImmutable( QStringLiteral( "Theme" ) );
    }

    /**
      Get Name of the current icon theme default value
    */
    QString defaultThemeValue() const
    {
        return defaultThemeValue_helper();
    }


    enum {
      signalThemeChanged = 1
    };

  Q_SIGNALS:
    void ThemeChanged();

  private:
    void itemChanged(quint64 signalFlag);

  protected:

    // Icons
    QString mTheme;
    QString defaultThemeValue_helper() const;
};

#endif

