/****************************************************************************
** Meta object code from reading C++ file 'tasksmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-workspace-6.7.1/libtaskmanager/tasksmodel.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tasksmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11TaskManager10TasksModelE_t {};
} // unnamed namespace

template <> constexpr inline auto TaskManager::TasksModel::qt_create_metaobjectdata<qt_meta_tag_ZN11TaskManager10TasksModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TaskManager::TasksModel",
        "QML.Element",
        "auto",
        "countChanged",
        "",
        "launcherCountChanged",
        "launcherListChanged",
        "anyTaskDemandsAttentionChanged",
        "virtualDesktopChanged",
        "screenGeometryChanged",
        "regionGeometryChanged",
        "activityChanged",
        "filterByVirtualDesktopChanged",
        "filterByCurrentVirtualDesktopChanged",
        "filterByScreenChanged",
        "filterByActivityChanged",
        "filterByRegionChanged",
        "filterMinimizedChanged",
        "filterNotMinimizedChanged",
        "filterNotMaximizedChanged",
        "filterHiddenChanged",
        "sortModeChanged",
        "separateLaunchersChanged",
        "launchInPlaceChanged",
        "hideActivatedLaunchersChanged",
        "groupModeChanged",
        "groupInlineChanged",
        "groupingWindowTasksThresholdChanged",
        "groupingAppIdBlacklistChanged",
        "groupingLauncherUrlBlacklistChanged",
        "taskReorderingEnabledChanged",
        "activeTaskChanged",
        "rowCount",
        "QModelIndex",
        "parent",
        "requestAddLauncher",
        "QUrl",
        "url",
        "requestRemoveLauncher",
        "requestAddLauncherToActivity",
        "activity",
        "requestRemoveLauncherFromActivity",
        "launcherActivities",
        "launcherPosition",
        "requestActivate",
        "index",
        "requestNewInstance",
        "requestOpenUrls",
        "QList<QUrl>",
        "urls",
        "requestClose",
        "requestMove",
        "requestResize",
        "requestToggleMinimized",
        "requestToggleMaximized",
        "requestToggleKeepAbove",
        "requestToggleKeepBelow",
        "requestToggleFullScreen",
        "requestToggleShaded",
        "requestToggleNoBorder",
        "requestToggleExcludeFromCapture",
        "requestVirtualDesktops",
        "QVariantList",
        "desktops",
        "requestNewVirtualDesktop",
        "requestActivities",
        "activities",
        "requestPublishDelegateGeometry",
        "QRect",
        "geometry",
        "delegate",
        "requestToggleGrouping",
        "move",
        "row",
        "newPos",
        "syncLaunchers",
        "makeModelIndex",
        "childRow",
        "makePersistentModelIndex",
        "QPersistentModelIndex",
        "updateLauncherCount",
        "count",
        "launcherCount",
        "launcherList",
        "anyTaskDemandsAttention",
        "virtualDesktop",
        "QVariant",
        "screenGeometry",
        "regionGeometry",
        "filterByVirtualDesktop",
        "filterByCurrentVirtualDesktop",
        "filterByScreen",
        "filterByActivity",
        "filterByRegion",
        "RegionFilterMode::Mode",
        "filterMinimized",
        "filterNotMinimized",
        "filterNotMaximized",
        "filterHidden",
        "sortMode",
        "SortMode",
        "separateLaunchers",
        "launchInPlace",
        "hideActivatedLaunchers",
        "groupMode",
        "GroupMode",
        "groupInline",
        "groupingWindowTasksThreshold",
        "groupingAppIdBlacklist",
        "groupingLauncherUrlBlacklist",
        "taskReorderingEnabled",
        "activeTask",
        "SortDisabled",
        "SortManual",
        "SortAlpha",
        "SortVirtualDesktop",
        "SortActivity",
        "SortLastActivated",
        "SortWindowPositionHorizontal",
        "GroupDisabled",
        "GroupApplications"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'countChanged'
        QtMocHelpers::SignalData<void() const>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'launcherCountChanged'
        QtMocHelpers::SignalData<void() const>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'launcherListChanged'
        QtMocHelpers::SignalData<void() const>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'anyTaskDemandsAttentionChanged'
        QtMocHelpers::SignalData<void() const>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'virtualDesktopChanged'
        QtMocHelpers::SignalData<void() const>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'screenGeometryChanged'
        QtMocHelpers::SignalData<void() const>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'regionGeometryChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activityChanged'
        QtMocHelpers::SignalData<void() const>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterByVirtualDesktopChanged'
        QtMocHelpers::SignalData<void() const>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterByCurrentVirtualDesktopChanged'
        QtMocHelpers::SignalData<void() const>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterByScreenChanged'
        QtMocHelpers::SignalData<void() const>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterByActivityChanged'
        QtMocHelpers::SignalData<void() const>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterByRegionChanged'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterMinimizedChanged'
        QtMocHelpers::SignalData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterNotMinimizedChanged'
        QtMocHelpers::SignalData<void() const>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterNotMaximizedChanged'
        QtMocHelpers::SignalData<void() const>(19, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterHiddenChanged'
        QtMocHelpers::SignalData<void() const>(20, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sortModeChanged'
        QtMocHelpers::SignalData<void() const>(21, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'separateLaunchersChanged'
        QtMocHelpers::SignalData<void() const>(22, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'launchInPlaceChanged'
        QtMocHelpers::SignalData<void() const>(23, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hideActivatedLaunchersChanged'
        QtMocHelpers::SignalData<void() const>(24, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'groupModeChanged'
        QtMocHelpers::SignalData<void() const>(25, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'groupInlineChanged'
        QtMocHelpers::SignalData<void() const>(26, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'groupingWindowTasksThresholdChanged'
        QtMocHelpers::SignalData<void() const>(27, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'groupingAppIdBlacklistChanged'
        QtMocHelpers::SignalData<void() const>(28, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'groupingLauncherUrlBlacklistChanged'
        QtMocHelpers::SignalData<void() const>(29, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'taskReorderingEnabledChanged'
        QtMocHelpers::SignalData<void() const>(30, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeTaskChanged'
        QtMocHelpers::SignalData<void() const>(31, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'rowCount'
        QtMocHelpers::MethodData<int(const QModelIndex &) const>(32, 4, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Method 'rowCount'
        QtMocHelpers::MethodData<int() const>(32, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int),
        // Method 'requestAddLauncher'
        QtMocHelpers::MethodData<bool(const QUrl &)>(35, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 36, 37 },
        }}),
        // Method 'requestRemoveLauncher'
        QtMocHelpers::MethodData<bool(const QUrl &)>(38, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 36, 37 },
        }}),
        // Method 'requestAddLauncherToActivity'
        QtMocHelpers::MethodData<bool(const QUrl &, const QString &)>(39, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 36, 37 }, { QMetaType::QString, 40 },
        }}),
        // Method 'requestRemoveLauncherFromActivity'
        QtMocHelpers::MethodData<bool(const QUrl &, const QString &)>(41, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 36, 37 }, { QMetaType::QString, 40 },
        }}),
        // Method 'launcherActivities'
        QtMocHelpers::MethodData<QStringList(const QUrl &)>(42, 4, QMC::AccessPublic, QMetaType::QStringList, {{
            { 0x80000000 | 36, 37 },
        }}),
        // Method 'launcherPosition'
        QtMocHelpers::MethodData<int(const QUrl &) const>(43, 4, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 36, 37 },
        }}),
        // Method 'requestActivate'
        QtMocHelpers::MethodData<void(const QModelIndex &)>(44, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 45 },
        }}),
        // Method 'requestNewInstance'
        QtMocHelpers::MethodData<void(const QModelIndex &)>(46, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 45 },
        }}),
        // Method 'requestOpenUrls'
        QtMocHelpers::MethodData<void(const QModelIndex &, const QList<QUrl> &)>(47, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 45 }, { 0x80000000 | 48, 49 },
        }}),
        // Method 'requestClose'
        QtMocHelpers::MethodData<void(const QModelIndex &)>(50, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 45 },
        }}),
        // Method 'requestMove'
        QtMocHelpers::MethodData<void(const QModelIndex &)>(51, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 45 },
        }}),
        // Method 'requestResize'
        QtMocHelpers::MethodData<void(const QModelIndex &)>(52, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 45 },
        }}),
        // Method 'requestToggleMinimized'
        QtMocHelpers::MethodData<void(const QModelIndex &)>(53, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 45 },
        }}),
        // Method 'requestToggleMaximized'
        QtMocHelpers::MethodData<void(const QModelIndex &)>(54, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 45 },
        }}),
        // Method 'requestToggleKeepAbove'
        QtMocHelpers::MethodData<void(const QModelIndex &)>(55, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 45 },
        }}),
        // Method 'requestToggleKeepBelow'
        QtMocHelpers::MethodData<void(const QModelIndex &)>(56, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 45 },
        }}),
        // Method 'requestToggleFullScreen'
        QtMocHelpers::MethodData<void(const QModelIndex &)>(57, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 45 },
        }}),
        // Method 'requestToggleShaded'
        QtMocHelpers::MethodData<void(const QModelIndex &)>(58, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 45 },
        }}),
        // Method 'requestToggleNoBorder'
        QtMocHelpers::MethodData<void(const QModelIndex &)>(59, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 45 },
        }}),
        // Method 'requestToggleExcludeFromCapture'
        QtMocHelpers::MethodData<void(const QModelIndex &)>(60, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 45 },
        }}),
        // Method 'requestVirtualDesktops'
        QtMocHelpers::MethodData<void(const QModelIndex &, const QVariantList &)>(61, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 45 }, { 0x80000000 | 62, 63 },
        }}),
        // Method 'requestNewVirtualDesktop'
        QtMocHelpers::MethodData<void(const QModelIndex &)>(64, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 45 },
        }}),
        // Method 'requestActivities'
        QtMocHelpers::MethodData<void(const QModelIndex &, const QStringList &)>(65, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 45 }, { QMetaType::QStringList, 66 },
        }}),
        // Method 'requestPublishDelegateGeometry'
        QtMocHelpers::MethodData<void(const QModelIndex &, const QRect &, QObject *)>(67, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 45 }, { 0x80000000 | 68, 69 }, { QMetaType::QObjectStar, 70 },
        }}),
        // Method 'requestPublishDelegateGeometry'
        QtMocHelpers::MethodData<void(const QModelIndex &, const QRect &)>(67, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 33, 45 }, { 0x80000000 | 68, 69 },
        }}),
        // Method 'requestToggleGrouping'
        QtMocHelpers::MethodData<void(const QModelIndex &)>(71, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 45 },
        }}),
        // Method 'move'
        QtMocHelpers::MethodData<bool(int, int, const QModelIndex &)>(72, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 73 }, { QMetaType::Int, 74 }, { 0x80000000 | 33, 34 },
        }}),
        // Method 'move'
        QtMocHelpers::MethodData<bool(int, int)>(72, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Int, 73 }, { QMetaType::Int, 74 },
        }}),
        // Method 'syncLaunchers'
        QtMocHelpers::MethodData<void()>(75, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'makeModelIndex'
        QtMocHelpers::MethodData<QModelIndex(int, int) const>(76, 4, QMC::AccessPublic, 0x80000000 | 33, {{
            { QMetaType::Int, 73 }, { QMetaType::Int, 77 },
        }}),
        // Method 'makeModelIndex'
        QtMocHelpers::MethodData<QModelIndex(int) const>(76, 4, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 33, {{
            { QMetaType::Int, 73 },
        }}),
        // Method 'makePersistentModelIndex'
        QtMocHelpers::MethodData<QPersistentModelIndex(int, int) const>(78, 4, QMC::AccessPublic, 0x80000000 | 79, {{
            { QMetaType::Int, 73 }, { QMetaType::Int, 77 },
        }}),
        // Method 'makePersistentModelIndex'
        QtMocHelpers::MethodData<QPersistentModelIndex(int) const>(78, 4, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 79, {{
            { QMetaType::Int, 73 },
        }}),
        // Method 'updateLauncherCount'
        QtMocHelpers::MethodData<void()>(80, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'count'
        QtMocHelpers::PropertyData<int>(81, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'launcherCount'
        QtMocHelpers::PropertyData<int>(82, QMetaType::Int, QMC::DefaultPropertyFlags, 1),
        // property 'launcherList'
        QtMocHelpers::PropertyData<QStringList>(83, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'anyTaskDemandsAttention'
        QtMocHelpers::PropertyData<bool>(84, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'virtualDesktop'
        QtMocHelpers::PropertyData<QVariant>(85, 0x80000000 | 86, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'screenGeometry'
        QtMocHelpers::PropertyData<QRect>(87, 0x80000000 | 68, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'regionGeometry'
        QtMocHelpers::PropertyData<QRect>(88, 0x80000000 | 68, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'activity'
        QtMocHelpers::PropertyData<QString>(40, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'filterByVirtualDesktop'
        QtMocHelpers::PropertyData<bool>(89, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'filterByCurrentVirtualDesktop'
        QtMocHelpers::PropertyData<bool>(90, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'filterByScreen'
        QtMocHelpers::PropertyData<bool>(91, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'filterByActivity'
        QtMocHelpers::PropertyData<bool>(92, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'filterByRegion'
        QtMocHelpers::PropertyData<RegionFilterMode::Mode>(93, 0x80000000 | 94, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 12),
        // property 'filterMinimized'
        QtMocHelpers::PropertyData<bool>(95, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'filterNotMinimized'
        QtMocHelpers::PropertyData<bool>(96, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'filterNotMaximized'
        QtMocHelpers::PropertyData<bool>(97, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'filterHidden'
        QtMocHelpers::PropertyData<bool>(98, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'sortMode'
        QtMocHelpers::PropertyData<enum SortMode>(99, 0x80000000 | 100, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 17),
        // property 'separateLaunchers'
        QtMocHelpers::PropertyData<bool>(101, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'launchInPlace'
        QtMocHelpers::PropertyData<bool>(102, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'hideActivatedLaunchers'
        QtMocHelpers::PropertyData<bool>(103, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 20),
        // property 'groupMode'
        QtMocHelpers::PropertyData<enum GroupMode>(104, 0x80000000 | 105, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 21),
        // property 'groupInline'
        QtMocHelpers::PropertyData<bool>(106, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 22),
        // property 'groupingWindowTasksThreshold'
        QtMocHelpers::PropertyData<int>(107, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 23),
        // property 'groupingAppIdBlacklist'
        QtMocHelpers::PropertyData<QStringList>(108, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 24),
        // property 'groupingLauncherUrlBlacklist'
        QtMocHelpers::PropertyData<QStringList>(109, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 25),
        // property 'taskReorderingEnabled'
        QtMocHelpers::PropertyData<bool>(110, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 26),
        // property 'activeTask'
        QtMocHelpers::PropertyData<QModelIndex>(111, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 27),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'SortMode'
        QtMocHelpers::EnumData<enum SortMode>(100, 100, QMC::EnumFlags{}).add({
            {  112, SortMode::SortDisabled },
            {  113, SortMode::SortManual },
            {  114, SortMode::SortAlpha },
            {  115, SortMode::SortVirtualDesktop },
            {  116, SortMode::SortActivity },
            {  117, SortMode::SortLastActivated },
            {  118, SortMode::SortWindowPositionHorizontal },
        }),
        // enum 'GroupMode'
        QtMocHelpers::EnumData<enum GroupMode>(105, 105, QMC::EnumFlags{}).add({
            {  119, GroupMode::GroupDisabled },
            {  120, GroupMode::GroupApplications },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<TasksModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN11TaskManager10TasksModelE[] = {
    QMetaObject::SuperData::link<RegionFilterMode::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject TaskManager::TasksModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QSortFilterProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11TaskManager10TasksModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11TaskManager10TasksModelE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN11TaskManager10TasksModelE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11TaskManager10TasksModelE_t>.metaTypes,
    nullptr
} };

void TaskManager::TasksModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TasksModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->countChanged(); break;
        case 1: _t->launcherCountChanged(); break;
        case 2: _t->launcherListChanged(); break;
        case 3: _t->anyTaskDemandsAttentionChanged(); break;
        case 4: _t->virtualDesktopChanged(); break;
        case 5: _t->screenGeometryChanged(); break;
        case 6: _t->regionGeometryChanged(); break;
        case 7: _t->activityChanged(); break;
        case 8: _t->filterByVirtualDesktopChanged(); break;
        case 9: _t->filterByCurrentVirtualDesktopChanged(); break;
        case 10: _t->filterByScreenChanged(); break;
        case 11: _t->filterByActivityChanged(); break;
        case 12: _t->filterByRegionChanged(); break;
        case 13: _t->filterMinimizedChanged(); break;
        case 14: _t->filterNotMinimizedChanged(); break;
        case 15: _t->filterNotMaximizedChanged(); break;
        case 16: _t->filterHiddenChanged(); break;
        case 17: _t->sortModeChanged(); break;
        case 18: _t->separateLaunchersChanged(); break;
        case 19: _t->launchInPlaceChanged(); break;
        case 20: _t->hideActivatedLaunchersChanged(); break;
        case 21: _t->groupModeChanged(); break;
        case 22: _t->groupInlineChanged(); break;
        case 23: _t->groupingWindowTasksThresholdChanged(); break;
        case 24: _t->groupingAppIdBlacklistChanged(); break;
        case 25: _t->groupingLauncherUrlBlacklistChanged(); break;
        case 26: _t->taskReorderingEnabledChanged(); break;
        case 27: _t->activeTaskChanged(); break;
        case 28: { int _r = _t->rowCount((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 29: { int _r = _t->rowCount();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 30: { bool _r = _t->requestAddLauncher((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 31: { bool _r = _t->requestRemoveLauncher((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 32: { bool _r = _t->requestAddLauncherToActivity((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 33: { bool _r = _t->requestRemoveLauncherFromActivity((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 34: { QStringList _r = _t->launcherActivities((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 35: { int _r = _t->launcherPosition((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 36: _t->requestActivate((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 37: _t->requestNewInstance((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 38: _t->requestOpenUrls((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2]))); break;
        case 39: _t->requestClose((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 40: _t->requestMove((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 41: _t->requestResize((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 42: _t->requestToggleMinimized((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 43: _t->requestToggleMaximized((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 44: _t->requestToggleKeepAbove((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 45: _t->requestToggleKeepBelow((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 46: _t->requestToggleFullScreen((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 47: _t->requestToggleShaded((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 48: _t->requestToggleNoBorder((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 49: _t->requestToggleExcludeFromCapture((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 50: _t->requestVirtualDesktops((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[2]))); break;
        case 51: _t->requestNewVirtualDesktop((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 52: _t->requestActivities((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 53: _t->requestPublishDelegateGeometry((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QRect>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[3]))); break;
        case 54: _t->requestPublishDelegateGeometry((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QRect>>(_a[2]))); break;
        case 55: _t->requestToggleGrouping((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 56: { bool _r = _t->move((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 57: { bool _r = _t->move((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 58: _t->syncLaunchers(); break;
        case 59: { QModelIndex _r = _t->makeModelIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QModelIndex*>(_a[0]) = std::move(_r); }  break;
        case 60: { QModelIndex _r = _t->makeModelIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QModelIndex*>(_a[0]) = std::move(_r); }  break;
        case 61: { QPersistentModelIndex _r = _t->makePersistentModelIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QPersistentModelIndex*>(_a[0]) = std::move(_r); }  break;
        case 62: { QPersistentModelIndex _r = _t->makePersistentModelIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QPersistentModelIndex*>(_a[0]) = std::move(_r); }  break;
        case 63: _t->updateLauncherCount(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TasksModel::*)() const>(_a, &TasksModel::countChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TasksModel::*)() const>(_a, &TasksModel::launcherCountChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TasksModel::*)() const>(_a, &TasksModel::launcherListChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TasksModel::*)() const>(_a, &TasksModel::anyTaskDemandsAttentionChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TasksModel::*)() const>(_a, &TasksModel::virtualDesktopChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TasksModel::*)() const>(_a, &TasksModel::screenGeometryChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TasksModel::*)()>(_a, &TasksModel::regionGeometryChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (TasksModel::*)() const>(_a, &TasksModel::activityChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (TasksModel::*)() const>(_a, &TasksModel::filterByVirtualDesktopChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (TasksModel::*)() const>(_a, &TasksModel::filterByCurrentVirtualDesktopChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (TasksModel::*)() const>(_a, &TasksModel::filterByScreenChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (TasksModel::*)() const>(_a, &TasksModel::filterByActivityChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (TasksModel::*)()>(_a, &TasksModel::filterByRegionChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (TasksModel::*)()>(_a, &TasksModel::filterMinimizedChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (TasksModel::*)() const>(_a, &TasksModel::filterNotMinimizedChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (TasksModel::*)() const>(_a, &TasksModel::filterNotMaximizedChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (TasksModel::*)() const>(_a, &TasksModel::filterHiddenChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (TasksModel::*)() const>(_a, &TasksModel::sortModeChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (TasksModel::*)() const>(_a, &TasksModel::separateLaunchersChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (TasksModel::*)() const>(_a, &TasksModel::launchInPlaceChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (TasksModel::*)() const>(_a, &TasksModel::hideActivatedLaunchersChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (TasksModel::*)() const>(_a, &TasksModel::groupModeChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (TasksModel::*)() const>(_a, &TasksModel::groupInlineChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (TasksModel::*)() const>(_a, &TasksModel::groupingWindowTasksThresholdChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (TasksModel::*)() const>(_a, &TasksModel::groupingAppIdBlacklistChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (TasksModel::*)() const>(_a, &TasksModel::groupingLauncherUrlBlacklistChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (TasksModel::*)() const>(_a, &TasksModel::taskReorderingEnabledChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (TasksModel::*)() const>(_a, &TasksModel::activeTaskChanged, 27))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->rowCount(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->launcherCount(); break;
        case 2: *reinterpret_cast<QStringList*>(_v) = _t->launcherList(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->anyTaskDemandsAttention(); break;
        case 4: *reinterpret_cast<QVariant*>(_v) = _t->virtualDesktop(); break;
        case 5: *reinterpret_cast<QRect*>(_v) = _t->screenGeometry(); break;
        case 6: *reinterpret_cast<QRect*>(_v) = _t->regionGeometry(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->activity(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->filterByVirtualDesktop(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->filterByCurrentVirtualDesktop(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->filterByScreen(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->filterByActivity(); break;
        case 12: *reinterpret_cast<RegionFilterMode::Mode*>(_v) = _t->filterByRegion(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->filterMinimized(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->filterNotMinimized(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->filterNotMaximized(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->filterHidden(); break;
        case 17: *reinterpret_cast<enum SortMode*>(_v) = _t->sortMode(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->separateLaunchers(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->launchInPlace(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->hideActivatedLaunchers(); break;
        case 21: *reinterpret_cast<enum GroupMode*>(_v) = _t->groupMode(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->groupInline(); break;
        case 23: *reinterpret_cast<int*>(_v) = _t->groupingWindowTasksThreshold(); break;
        case 24: *reinterpret_cast<QStringList*>(_v) = _t->groupingAppIdBlacklist(); break;
        case 25: *reinterpret_cast<QStringList*>(_v) = _t->groupingLauncherUrlBlacklist(); break;
        case 26: *reinterpret_cast<bool*>(_v) = _t->taskReorderingEnabled(); break;
        case 27: *reinterpret_cast<QModelIndex*>(_v) = _t->activeTask(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setLauncherList(*reinterpret_cast<QStringList*>(_v)); break;
        case 4: _t->setVirtualDesktop(*reinterpret_cast<QVariant*>(_v)); break;
        case 5: _t->setScreenGeometry(*reinterpret_cast<QRect*>(_v)); break;
        case 6: _t->setRegionGeometry(*reinterpret_cast<QRect*>(_v)); break;
        case 7: _t->setActivity(*reinterpret_cast<QString*>(_v)); break;
        case 8: _t->setFilterByVirtualDesktop(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setFilterByCurrentVirtualDesktop(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setFilterByScreen(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setFilterByActivity(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setFilterByRegion(*reinterpret_cast<RegionFilterMode::Mode*>(_v)); break;
        case 13: _t->setFilterMinimized(*reinterpret_cast<bool*>(_v)); break;
        case 14: _t->setFilterNotMinimized(*reinterpret_cast<bool*>(_v)); break;
        case 15: _t->setFilterNotMaximized(*reinterpret_cast<bool*>(_v)); break;
        case 16: _t->setFilterHidden(*reinterpret_cast<bool*>(_v)); break;
        case 17: _t->setSortMode(*reinterpret_cast<enum SortMode*>(_v)); break;
        case 18: _t->setSeparateLaunchers(*reinterpret_cast<bool*>(_v)); break;
        case 19: _t->setLaunchInPlace(*reinterpret_cast<bool*>(_v)); break;
        case 20: _t->setHideActivatedLaunchers(*reinterpret_cast<bool*>(_v)); break;
        case 21: _t->setGroupMode(*reinterpret_cast<enum GroupMode*>(_v)); break;
        case 22: _t->setGroupInline(*reinterpret_cast<bool*>(_v)); break;
        case 23: _t->setGroupingWindowTasksThreshold(*reinterpret_cast<int*>(_v)); break;
        case 24: _t->setGroupingAppIdBlacklist(*reinterpret_cast<QStringList*>(_v)); break;
        case 25: _t->setGroupingLauncherUrlBlacklist(*reinterpret_cast<QStringList*>(_v)); break;
        case 26: _t->setTaskReorderingEnabled(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *TaskManager::TasksModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TaskManager::TasksModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11TaskManager10TasksModelE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "AbstractTasksModelIface"))
        return static_cast< AbstractTasksModelIface*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QSortFilterProxyModel::qt_metacast(_clname);
}

int TaskManager::TasksModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSortFilterProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 64)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 64;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 64)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 64;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    return _id;
}

// SIGNAL 0
void TaskManager::TasksModel::countChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TasksModel *>(this), &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TaskManager::TasksModel::launcherCountChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TasksModel *>(this), &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void TaskManager::TasksModel::launcherListChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TasksModel *>(this), &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void TaskManager::TasksModel::anyTaskDemandsAttentionChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TasksModel *>(this), &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void TaskManager::TasksModel::virtualDesktopChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TasksModel *>(this), &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void TaskManager::TasksModel::screenGeometryChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TasksModel *>(this), &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void TaskManager::TasksModel::regionGeometryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void TaskManager::TasksModel::activityChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TasksModel *>(this), &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void TaskManager::TasksModel::filterByVirtualDesktopChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TasksModel *>(this), &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void TaskManager::TasksModel::filterByCurrentVirtualDesktopChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TasksModel *>(this), &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void TaskManager::TasksModel::filterByScreenChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TasksModel *>(this), &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void TaskManager::TasksModel::filterByActivityChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TasksModel *>(this), &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void TaskManager::TasksModel::filterByRegionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void TaskManager::TasksModel::filterMinimizedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void TaskManager::TasksModel::filterNotMinimizedChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TasksModel *>(this), &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void TaskManager::TasksModel::filterNotMaximizedChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TasksModel *>(this), &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void TaskManager::TasksModel::filterHiddenChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TasksModel *>(this), &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void TaskManager::TasksModel::sortModeChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TasksModel *>(this), &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void TaskManager::TasksModel::separateLaunchersChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TasksModel *>(this), &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void TaskManager::TasksModel::launchInPlaceChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TasksModel *>(this), &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void TaskManager::TasksModel::hideActivatedLaunchersChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TasksModel *>(this), &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void TaskManager::TasksModel::groupModeChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TasksModel *>(this), &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void TaskManager::TasksModel::groupInlineChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TasksModel *>(this), &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void TaskManager::TasksModel::groupingWindowTasksThresholdChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TasksModel *>(this), &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void TaskManager::TasksModel::groupingAppIdBlacklistChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TasksModel *>(this), &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void TaskManager::TasksModel::groupingLauncherUrlBlacklistChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TasksModel *>(this), &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void TaskManager::TasksModel::taskReorderingEnabledChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TasksModel *>(this), &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void TaskManager::TasksModel::activeTaskChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TasksModel *>(this), &staticMetaObject, 27, nullptr);
}
QT_WARNING_POP
