/****************************************************************************
** Meta object code from reading C++ file 'kcmregionandlang.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/kcms/region_language/kcmregionandlang.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcmregionandlang.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KCMRegionAndLangE_t {};
} // unnamed namespace

template <> constexpr inline auto KCMRegionAndLang::qt_create_metaobjectdata<qt_meta_tag_ZN16KCMRegionAndLangE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KCMRegionAndLang",
        "saveClicked",
        "",
        "loadClicked",
        "defaultsClicked",
        "takeEffectNextTime",
        "startGenerateLocale",
        "generateFinished",
        "requireInstallFont",
        "enabledChanged",
        "encountedError",
        "reason",
        "userHasToGenerateManually",
        "saveToConfigFile",
        "unset",
        "KCM_RegionAndLang::SettingType",
        "setting",
        "reboot",
        "settings",
        "RegionAndLangSettings*",
        "optionsModel",
        "OptionsModel*",
        "enabled"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'saveClicked'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loadClicked'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultsClicked'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'takeEffectNextTime'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'startGenerateLocale'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'generateFinished'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requireInstallFont'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'encountedError'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Signal 'userHasToGenerateManually'
        QtMocHelpers::SignalData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'saveToConfigFile'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'unset'
        QtMocHelpers::MethodData<void(KCM_RegionAndLang::SettingType) const>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Method 'reboot'
        QtMocHelpers::MethodData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'settings'
        QtMocHelpers::PropertyData<RegionAndLangSettings*>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'optionsModel'
        QtMocHelpers::PropertyData<OptionsModel*>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags, 7),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KCMRegionAndLang, qt_meta_tag_ZN16KCMRegionAndLangE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KCMRegionAndLang::staticMetaObject = { {
    QMetaObject::SuperData::link<KQuickManagedConfigModule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KCMRegionAndLangE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KCMRegionAndLangE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KCMRegionAndLangE_t>.metaTypes,
    nullptr
} };

void KCMRegionAndLang::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KCMRegionAndLang *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->saveClicked(); break;
        case 1: _t->loadClicked(); break;
        case 2: _t->defaultsClicked(); break;
        case 3: _t->takeEffectNextTime(); break;
        case 4: _t->startGenerateLocale(); break;
        case 5: _t->generateFinished(); break;
        case 6: _t->requireInstallFont(); break;
        case 7: _t->enabledChanged(); break;
        case 8: _t->encountedError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->userHasToGenerateManually((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->saveToConfigFile(); break;
        case 11: _t->unset((*reinterpret_cast<std::add_pointer_t<KCM_RegionAndLang::SettingType>>(_a[1]))); break;
        case 12: _t->reboot(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KCMRegionAndLang::*)()>(_a, &KCMRegionAndLang::saveClicked, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMRegionAndLang::*)()>(_a, &KCMRegionAndLang::loadClicked, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMRegionAndLang::*)()>(_a, &KCMRegionAndLang::defaultsClicked, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMRegionAndLang::*)()>(_a, &KCMRegionAndLang::takeEffectNextTime, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMRegionAndLang::*)()>(_a, &KCMRegionAndLang::startGenerateLocale, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMRegionAndLang::*)()>(_a, &KCMRegionAndLang::generateFinished, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMRegionAndLang::*)()>(_a, &KCMRegionAndLang::requireInstallFont, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMRegionAndLang::*)()>(_a, &KCMRegionAndLang::enabledChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMRegionAndLang::*)(const QString & )>(_a, &KCMRegionAndLang::encountedError, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMRegionAndLang::*)(const QString & )>(_a, &KCMRegionAndLang::userHasToGenerateManually, 9))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<RegionAndLangSettings**>(_v) = _t->settings(); break;
        case 1: *reinterpret_cast<OptionsModel**>(_v) = _t->optionsModel(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        default: break;
        }
    }
}

const QMetaObject *KCMRegionAndLang::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KCMRegionAndLang::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KCMRegionAndLangE_t>.strings))
        return static_cast<void*>(this);
    return KQuickManagedConfigModule::qt_metacast(_clname);
}

int KCMRegionAndLang::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KQuickManagedConfigModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void KCMRegionAndLang::saveClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KCMRegionAndLang::loadClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KCMRegionAndLang::defaultsClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KCMRegionAndLang::takeEffectNextTime()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KCMRegionAndLang::startGenerateLocale()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KCMRegionAndLang::generateFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KCMRegionAndLang::requireInstallFont()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KCMRegionAndLang::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KCMRegionAndLang::encountedError(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void KCMRegionAndLang::userHasToGenerateManually(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}
QT_WARNING_POP
