/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.krunner.App.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "appadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class AppAdaptor
 */

AppAdaptor::AppAdaptor(View *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

AppAdaptor::~AppAdaptor()
{
    // destructor
}

void AppAdaptor::display()
{
    // handle method call org.kde.krunner.App.display
    parent()->display();
}

void AppAdaptor::displaySingleRunner(const QString &runnerName)
{
    // handle method call org.kde.krunner.App.displaySingleRunner
    parent()->displaySingleRunner(runnerName);
}

void AppAdaptor::displayWithClipboardContents()
{
    // handle method call org.kde.krunner.App.displayWithClipboardContents
    parent()->displayWithClipboardContents();
}

void AppAdaptor::query(const QString &term)
{
    // handle method call org.kde.krunner.App.query
    parent()->query(term);
}

void AppAdaptor::querySingleRunner(const QString &runnerName, const QString &term)
{
    // handle method call org.kde.krunner.App.querySingleRunner
    parent()->querySingleRunner(runnerName, term);
}

void AppAdaptor::toggleDisplay()
{
    // handle method call org.kde.krunner.App.toggleDisplay
    parent()->toggleDisplay();
}


#include "moc_appadaptor.cpp"
