// This file is generated by kconfig_compiler_kf6 from lookandfeelsettings.kcfg.
// All changes you do to this file will be lost.

#include "lookandfeelsettings.h"

LookAndFeelSettings::LookAndFeelSettings( QObject *parent )
  : KConfigSkeleton( QStringLiteral( "kdeglobals" ) )
{
  setParent(parent);
  KConfigCompilerSignallingItem::NotifyFunction notifyFunction = static_cast<KConfigCompilerSignallingItem::NotifyFunction>(&LookAndFeelSettings::itemChanged);

  setCurrentGroup( QStringLiteral( "KDE" ) );

  KConfigCompilerSignallingItem  *itemLookAndFeelPackage;
  KConfigSkeleton::ItemString  *innerItemLookAndFeelPackage;
  innerItemLookAndFeelPackage = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "LookAndFeelPackage" ), mLookAndFeelPackage, QStringLiteral( "org.kde.breeze.desktop" ) );
  itemLookAndFeelPackage = new KConfigCompilerSignallingItem(innerItemLookAndFeelPackage, this, notifyFunction, signalLookAndFeelPackageChanged);
  itemLookAndFeelPackage->setWriteFlags(KConfigBase::Notify);
  addItem( itemLookAndFeelPackage, QStringLiteral( "lookAndFeelPackage" ) );
  KConfigCompilerSignallingItem  *itemDefaultLightLookAndFeel;
  KConfigSkeleton::ItemString  *innerItemDefaultLightLookAndFeel;
  innerItemDefaultLightLookAndFeel = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "DefaultLightLookAndFeel" ), mDefaultLightLookAndFeel, QStringLiteral( "org.kde.breeze.desktop" ) );
  itemDefaultLightLookAndFeel = new KConfigCompilerSignallingItem(innerItemDefaultLightLookAndFeel, this, notifyFunction, signalDefaultLightLookAndFeelChanged);
  itemDefaultLightLookAndFeel->setWriteFlags(KConfigBase::Notify);
  addItem( itemDefaultLightLookAndFeel, QStringLiteral( "defaultLightLookAndFeel" ) );
  KConfigCompilerSignallingItem  *itemDefaultDarkLookAndFeel;
  KConfigSkeleton::ItemString  *innerItemDefaultDarkLookAndFeel;
  innerItemDefaultDarkLookAndFeel = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "DefaultDarkLookAndFeel" ), mDefaultDarkLookAndFeel, QStringLiteral( "org.kde.breezedark.desktop" ) );
  itemDefaultDarkLookAndFeel = new KConfigCompilerSignallingItem(innerItemDefaultDarkLookAndFeel, this, notifyFunction, signalDefaultDarkLookAndFeelChanged);
  itemDefaultDarkLookAndFeel->setWriteFlags(KConfigBase::Notify);
  addItem( itemDefaultDarkLookAndFeel, QStringLiteral( "defaultDarkLookAndFeel" ) );
  KConfigCompilerSignallingItem  *itemAutomaticLookAndFeel;
  KConfigSkeleton::ItemBool  *innerItemAutomaticLookAndFeel;
  innerItemAutomaticLookAndFeel = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AutomaticLookAndFeel" ), mAutomaticLookAndFeel, false );
  itemAutomaticLookAndFeel = new KConfigCompilerSignallingItem(innerItemAutomaticLookAndFeel, this, notifyFunction, signalAutomaticLookAndFeelChanged);
  itemAutomaticLookAndFeel->setWriteFlags(KConfigBase::Notify);
  addItem( itemAutomaticLookAndFeel, QStringLiteral( "automaticLookAndFeel" ) );
  KConfigCompilerSignallingItem  *itemAutomaticLookAndFeelOnIdle;
  KConfigSkeleton::ItemBool  *innerItemAutomaticLookAndFeelOnIdle;
  innerItemAutomaticLookAndFeelOnIdle = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AutomaticLookAndFeelOnIdle" ), mAutomaticLookAndFeelOnIdle, true );
  itemAutomaticLookAndFeelOnIdle = new KConfigCompilerSignallingItem(innerItemAutomaticLookAndFeelOnIdle, this, notifyFunction, signalAutomaticLookAndFeelOnIdleChanged);
  itemAutomaticLookAndFeelOnIdle->setWriteFlags(KConfigBase::Notify);
  addItem( itemAutomaticLookAndFeelOnIdle, QStringLiteral( "automaticLookAndFeelOnIdle" ) );
  KConfigCompilerSignallingItem  *itemAutomaticLookAndFeelIdleInterval;
  KConfigSkeleton::ItemUInt  *innerItemAutomaticLookAndFeelIdleInterval;
  innerItemAutomaticLookAndFeelIdleInterval = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "AutomaticLookAndFeelIdleInterval" ), mAutomaticLookAndFeelIdleInterval, 5 );
  itemAutomaticLookAndFeelIdleInterval = new KConfigCompilerSignallingItem(innerItemAutomaticLookAndFeelIdleInterval, this, notifyFunction, signalAutomaticLookAndFeelIdleIntervalChanged);
  itemAutomaticLookAndFeelIdleInterval->setWriteFlags(KConfigBase::Notify);
  addItem( itemAutomaticLookAndFeelIdleInterval, QStringLiteral( "automaticLookAndFeelIdleInterval" ) );
}

QString LookAndFeelSettings::defaultLookAndFeelPackageValue_helper() const
{

  return QStringLiteral( "org.kde.breeze.desktop" );
}

QString LookAndFeelSettings::defaultDefaultLightLookAndFeelValue_helper() const
{

  return QStringLiteral( "org.kde.breeze.desktop" );
}

QString LookAndFeelSettings::defaultDefaultDarkLookAndFeelValue_helper() const
{

  return QStringLiteral( "org.kde.breezedark.desktop" );
}

bool LookAndFeelSettings::defaultAutomaticLookAndFeelValue_helper() const
{

  return false;
}

bool LookAndFeelSettings::defaultAutomaticLookAndFeelOnIdleValue_helper() const
{

  return true;
}

uint LookAndFeelSettings::defaultAutomaticLookAndFeelIdleIntervalValue_helper() const
{

  return 5;
}

LookAndFeelSettings::~LookAndFeelSettings()
{
}


void LookAndFeelSettings::itemChanged(quint64 signalFlag) {

  switch (signalFlag) {
  case signalLookAndFeelPackageChanged:
    Q_EMIT lookAndFeelPackageChanged();
    break;
  case signalDefaultLightLookAndFeelChanged:
    Q_EMIT defaultLightLookAndFeelChanged();
    break;
  case signalDefaultDarkLookAndFeelChanged:
    Q_EMIT defaultDarkLookAndFeelChanged();
    break;
  case signalAutomaticLookAndFeelChanged:
    Q_EMIT automaticLookAndFeelChanged();
    break;
  case signalAutomaticLookAndFeelOnIdleChanged:
    Q_EMIT automaticLookAndFeelOnIdleChanged();
    break;
  case signalAutomaticLookAndFeelIdleIntervalChanged:
    Q_EMIT automaticLookAndFeelIdleIntervalChanged();
    break;
  }
}
