// This file is generated by kconfig_compiler_kf6 from geotimezonedstate.kcfg.
// All changes you do to this file will be lost.
#ifndef GEOTIMEZONEDSTATE_H
#define GEOTIMEZONEDSTATE_H

#include <qglobal.h>
#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class GeotimezonedState : public KConfigSkeleton
{
  public:

    GeotimezonedState( );
    ~GeotimezonedState() override;

    /**
      Set UUID of last used network connection
    */
    void setLastConnectionUuid( const QString & v )
    {
      if (!isLastConnectionUuidImmutable())
        mLastConnectionUuid = v;
    }

    /**
      Get UUID of last used network connection
    */
    QString lastConnectionUuid() const
    {
      return mLastConnectionUuid;
    }

    /**
      Is UUID of last used network connection Immutable
    */
    bool isLastConnectionUuidImmutable() const
    {
      return isImmutable( QStringLiteral( "lastConnectionUuid" ) );
    }

  protected:

    // Network
    QString mLastConnectionUuid;
};

#endif

