// This file was generated by qtwaylandscanner
// source file is org-kde-plasma-virtual-desktop.xml

#ifndef QT_WAYLAND_ORG_KDE_PLASMA_VIRTUAL_DESKTOP
#define QT_WAYLAND_ORG_KDE_PLASMA_VIRTUAL_DESKTOP

#include "wayland-org-kde-plasma-virtual-desktop-client-protocol.h"
#include <QByteArray>
#include <QString>

struct wl_registry;

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")

namespace QtWayland {
    class  org_kde_plasma_virtual_desktop_management
    {
    public:
        org_kde_plasma_virtual_desktop_management(struct ::wl_registry *registry, uint32_t id, int version);
        org_kde_plasma_virtual_desktop_management(struct ::org_kde_plasma_virtual_desktop_management *object);
        org_kde_plasma_virtual_desktop_management();

        virtual ~org_kde_plasma_virtual_desktop_management();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::org_kde_plasma_virtual_desktop_management *object);

        struct ::org_kde_plasma_virtual_desktop_management *object() { return m_org_kde_plasma_virtual_desktop_management; }
        const struct ::org_kde_plasma_virtual_desktop_management *object() const { return m_org_kde_plasma_virtual_desktop_management; }
        static org_kde_plasma_virtual_desktop_management *fromObject(struct ::org_kde_plasma_virtual_desktop_management *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        struct ::org_kde_plasma_virtual_desktop *get_virtual_desktop(const QString &desktop_id);
        void request_create_virtual_desktop(const QString &name, uint32_t position);
        void request_remove_virtual_desktop(const QString &desktop_id);

    protected:
        virtual void org_kde_plasma_virtual_desktop_management_desktop_created(const QString &desktop_id, uint32_t position);
        virtual void org_kde_plasma_virtual_desktop_management_desktop_removed(const QString &desktop_id);
        virtual void org_kde_plasma_virtual_desktop_management_done();
        virtual void org_kde_plasma_virtual_desktop_management_rows(uint32_t rows);

    private:
        void init_listener();
        static const struct org_kde_plasma_virtual_desktop_management_listener m_org_kde_plasma_virtual_desktop_management_listener;
        static void handle_desktop_created(
            void *data,
            struct ::org_kde_plasma_virtual_desktop_management *object,
            const char *desktop_id,
            uint32_t position);
        static void handle_desktop_removed(
            void *data,
            struct ::org_kde_plasma_virtual_desktop_management *object,
            const char *desktop_id);
        static void handle_done(
            void *data,
            struct ::org_kde_plasma_virtual_desktop_management *object);
        static void handle_rows(
            void *data,
            struct ::org_kde_plasma_virtual_desktop_management *object,
            uint32_t rows);
        struct ::org_kde_plasma_virtual_desktop_management *m_org_kde_plasma_virtual_desktop_management;
    };

    class  org_kde_plasma_virtual_desktop
    {
    public:
        org_kde_plasma_virtual_desktop(struct ::wl_registry *registry, uint32_t id, int version);
        org_kde_plasma_virtual_desktop(struct ::org_kde_plasma_virtual_desktop *object);
        org_kde_plasma_virtual_desktop();

        virtual ~org_kde_plasma_virtual_desktop();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::org_kde_plasma_virtual_desktop *object);

        struct ::org_kde_plasma_virtual_desktop *object() { return m_org_kde_plasma_virtual_desktop; }
        const struct ::org_kde_plasma_virtual_desktop *object() const { return m_org_kde_plasma_virtual_desktop; }
        static org_kde_plasma_virtual_desktop *fromObject(struct ::org_kde_plasma_virtual_desktop *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        void request_activate();
        void request_enter_output(const QString &output_name);

    protected:
        virtual void org_kde_plasma_virtual_desktop_desktop_id(const QString &desktop_id);
        virtual void org_kde_plasma_virtual_desktop_name(const QString &name);
        virtual void org_kde_plasma_virtual_desktop_activated();
        virtual void org_kde_plasma_virtual_desktop_deactivated();
        virtual void org_kde_plasma_virtual_desktop_done();
        virtual void org_kde_plasma_virtual_desktop_removed();
        virtual void org_kde_plasma_virtual_desktop_position(uint32_t index);
        virtual void org_kde_plasma_virtual_desktop_output_entered(const QString &output_name);

    private:
        void init_listener();
        static const struct org_kde_plasma_virtual_desktop_listener m_org_kde_plasma_virtual_desktop_listener;
        static void handle_desktop_id(
            void *data,
            struct ::org_kde_plasma_virtual_desktop *object,
            const char *desktop_id);
        static void handle_name(
            void *data,
            struct ::org_kde_plasma_virtual_desktop *object,
            const char *name);
        static void handle_activated(
            void *data,
            struct ::org_kde_plasma_virtual_desktop *object);
        static void handle_deactivated(
            void *data,
            struct ::org_kde_plasma_virtual_desktop *object);
        static void handle_done(
            void *data,
            struct ::org_kde_plasma_virtual_desktop *object);
        static void handle_removed(
            void *data,
            struct ::org_kde_plasma_virtual_desktop *object);
        static void handle_position(
            void *data,
            struct ::org_kde_plasma_virtual_desktop *object,
            uint32_t index);
        static void handle_output_entered(
            void *data,
            struct ::org_kde_plasma_virtual_desktop *object,
            const char *output_name);
        struct ::org_kde_plasma_virtual_desktop *m_org_kde_plasma_virtual_desktop;
    };
}

QT_WARNING_POP
QT_END_NAMESPACE

#endif
