// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "debug_p.h"

 namespace COMPONENTS {
Q_LOGGING_CATEGORY(CALENDAR, "org.kde.plasma.workspace.calendar", QtWarningMsg)
} 
