/****************************************************************************
** Meta object code from reading C++ file 'launchfeedbacksettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../launchfeedbacksettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'launchfeedbacksettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22LaunchFeedbackSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto LaunchFeedbackSettings::qt_create_metaobjectdata<qt_meta_tag_ZN22LaunchFeedbackSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LaunchFeedbackSettings",
        "blinkingChanged",
        "",
        "bouncingChanged",
        "cursorTimeoutChanged",
        "busyCursorChanged",
        "taskbarButtonChanged",
        "taskbarTimeoutChanged",
        "blinking",
        "isBlinkingImmutable",
        "defaultBlinkingValue",
        "bouncing",
        "isBouncingImmutable",
        "defaultBouncingValue",
        "cursorTimeout",
        "isCursorTimeoutImmutable",
        "defaultCursorTimeoutValue",
        "busyCursor",
        "isBusyCursorImmutable",
        "defaultBusyCursorValue",
        "taskbarButton",
        "isTaskbarButtonImmutable",
        "defaultTaskbarButtonValue",
        "taskbarTimeout",
        "isTaskbarTimeoutImmutable",
        "defaultTaskbarTimeoutValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'blinkingChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bouncingChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cursorTimeoutChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'busyCursorChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'taskbarButtonChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'taskbarTimeoutChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'blinking'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isBlinkingImmutable'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBlinkingValue'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bouncing'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isBouncingImmutable'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBouncingValue'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'cursorTimeout'
        QtMocHelpers::PropertyData<int>(14, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isCursorTimeoutImmutable'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCursorTimeoutValue'
        QtMocHelpers::PropertyData<int>(16, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'busyCursor'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isBusyCursorImmutable'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBusyCursorValue'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'taskbarButton'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isTaskbarButtonImmutable'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTaskbarButtonValue'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'taskbarTimeout'
        QtMocHelpers::PropertyData<int>(23, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isTaskbarTimeoutImmutable'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTaskbarTimeoutValue'
        QtMocHelpers::PropertyData<int>(25, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LaunchFeedbackSettings, qt_meta_tag_ZN22LaunchFeedbackSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LaunchFeedbackSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22LaunchFeedbackSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22LaunchFeedbackSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22LaunchFeedbackSettingsE_t>.metaTypes,
    nullptr
} };

void LaunchFeedbackSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LaunchFeedbackSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->blinkingChanged(); break;
        case 1: _t->bouncingChanged(); break;
        case 2: _t->cursorTimeoutChanged(); break;
        case 3: _t->busyCursorChanged(); break;
        case 4: _t->taskbarButtonChanged(); break;
        case 5: _t->taskbarTimeoutChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LaunchFeedbackSettings::*)()>(_a, &LaunchFeedbackSettings::blinkingChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (LaunchFeedbackSettings::*)()>(_a, &LaunchFeedbackSettings::bouncingChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (LaunchFeedbackSettings::*)()>(_a, &LaunchFeedbackSettings::cursorTimeoutChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (LaunchFeedbackSettings::*)()>(_a, &LaunchFeedbackSettings::busyCursorChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (LaunchFeedbackSettings::*)()>(_a, &LaunchFeedbackSettings::taskbarButtonChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (LaunchFeedbackSettings::*)()>(_a, &LaunchFeedbackSettings::taskbarTimeoutChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->blinking(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isBlinkingImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultBlinkingValue(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->bouncing(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isBouncingImmutable(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->defaultBouncingValue(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->cursorTimeout(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isCursorTimeoutImmutable(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->defaultCursorTimeoutValue(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->busyCursor(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isBusyCursorImmutable(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->defaultBusyCursorValue(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->taskbarButton(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isTaskbarButtonImmutable(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->defaultTaskbarButtonValue(); break;
        case 15: *reinterpret_cast<int*>(_v) = _t->taskbarTimeout(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isTaskbarTimeoutImmutable(); break;
        case 17: *reinterpret_cast<int*>(_v) = _t->defaultTaskbarTimeoutValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBlinking(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setBouncing(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setCursorTimeout(*reinterpret_cast<int*>(_v)); break;
        case 9: _t->setBusyCursor(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setTaskbarButton(*reinterpret_cast<bool*>(_v)); break;
        case 15: _t->setTaskbarTimeout(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *LaunchFeedbackSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LaunchFeedbackSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22LaunchFeedbackSettingsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int LaunchFeedbackSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void LaunchFeedbackSettings::blinkingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void LaunchFeedbackSettings::bouncingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void LaunchFeedbackSettings::cursorTimeoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void LaunchFeedbackSettings::busyCursorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void LaunchFeedbackSettings::taskbarButtonChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void LaunchFeedbackSettings::taskbarTimeoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
