// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#include "cursorthemedata.h"

#include "cursorthemesettings.h"
#include "launchfeedbacksettings.h"




CursorThemeData::CursorThemeData(QObject *parent)
: KCModuleData(parent)
, m_cursorThemeSettings(new CursorThemeSettings(this))
, m_launchFeedbackSettings(new LaunchFeedbackSettings(this))

{
autoRegisterSkeletons();
}

CursorThemeSettings *CursorThemeData::cursorThemeSettings() const
{
    return m_cursorThemeSettings;
}

LaunchFeedbackSettings *CursorThemeData::launchFeedbackSettings() const
{
    return m_launchFeedbackSettings;
}





#include "moc_cursorthemedata.cpp"
