// This file is generated by kconfig_compiler_kf6 from lookandfeelsettings.kcfg.
// All changes you do to this file will be lost.

#include "lookandfeelsettings.h"

LookAndFeelSettings::LookAndFeelSettings( )
  : KConfigSkeleton( QStringLiteral( "kdeglobals" ) )
{
  setCurrentGroup( QStringLiteral( "KDE" ) );

  KConfigSkeleton::ItemString  *itemLookAndFeelPackage;
  itemLookAndFeelPackage = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "LookAndFeelPackage" ), mLookAndFeelPackage, QStringLiteral( "org.kde.breeze.desktop" ) );
  itemLookAndFeelPackage->setWriteFlags(KConfigBase::Notify);
  addItem( itemLookAndFeelPackage, QStringLiteral( "lookAndFeelPackage" ) );
  KConfigSkeleton::ItemString  *itemDefaultLightLookAndFeel;
  itemDefaultLightLookAndFeel = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "DefaultLightLookAndFeel" ), mDefaultLightLookAndFeel, QStringLiteral( "org.kde.breeze.desktop" ) );
  itemDefaultLightLookAndFeel->setWriteFlags(KConfigBase::Notify);
  addItem( itemDefaultLightLookAndFeel, QStringLiteral( "defaultLightLookAndFeel" ) );
  KConfigSkeleton::ItemString  *itemDefaultDarkLookAndFeel;
  itemDefaultDarkLookAndFeel = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "DefaultDarkLookAndFeel" ), mDefaultDarkLookAndFeel, QStringLiteral( "org.kde.breezedark.desktop" ) );
  itemDefaultDarkLookAndFeel->setWriteFlags(KConfigBase::Notify);
  addItem( itemDefaultDarkLookAndFeel, QStringLiteral( "defaultDarkLookAndFeel" ) );
  KConfigSkeleton::ItemBool  *itemAutomaticLookAndFeel;
  itemAutomaticLookAndFeel = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AutomaticLookAndFeel" ), mAutomaticLookAndFeel, false );
  itemAutomaticLookAndFeel->setWriteFlags(KConfigBase::Notify);
  addItem( itemAutomaticLookAndFeel, QStringLiteral( "automaticLookAndFeel" ) );
  KConfigSkeleton::ItemBool  *itemAutomaticLookAndFeelOnIdle;
  itemAutomaticLookAndFeelOnIdle = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AutomaticLookAndFeelOnIdle" ), mAutomaticLookAndFeelOnIdle, true );
  itemAutomaticLookAndFeelOnIdle->setWriteFlags(KConfigBase::Notify);
  addItem( itemAutomaticLookAndFeelOnIdle, QStringLiteral( "automaticLookAndFeelOnIdle" ) );
  KConfigSkeleton::ItemUInt  *itemAutomaticLookAndFeelIdleInterval;
  itemAutomaticLookAndFeelIdleInterval = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "AutomaticLookAndFeelIdleInterval" ), mAutomaticLookAndFeelIdleInterval, 5 );
  itemAutomaticLookAndFeelIdleInterval->setWriteFlags(KConfigBase::Notify);
  addItem( itemAutomaticLookAndFeelIdleInterval, QStringLiteral( "automaticLookAndFeelIdleInterval" ) );
}

LookAndFeelSettings::~LookAndFeelSettings()
{
}

