// This file is generated by kconfig_compiler_kf6 from soundthemesettings.kcfg.
// All changes you do to this file will be lost.

#include "soundthemesettings.h"

SoundThemeSettings::SoundThemeSettings( QObject *parent )
  : KConfigSkeleton( QStringLiteral( "kdeglobals" ) )
{
  setParent(parent);
  KConfigCompilerSignallingItem::NotifyFunction notifyFunction = static_cast<KConfigCompilerSignallingItem::NotifyFunction>(&SoundThemeSettings::itemChanged);

  setCurrentGroup( QStringLiteral( "Sounds" ) );

  KConfigCompilerSignallingItem  *itemTheme;
  KConfigSkeleton::ItemString  *innerItemTheme;
  innerItemTheme = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Theme" ), mTheme, QStringLiteral( "ocean" ) );
  itemTheme = new KConfigCompilerSignallingItem(innerItemTheme, this, notifyFunction, signalThemeChanged);
  itemTheme->setWriteFlags(KConfigBase::Notify);
  addItem( itemTheme, QStringLiteral( "theme" ) );
  KConfigCompilerSignallingItem  *itemSoundsEnabled;
  KConfigSkeleton::ItemBool  *innerItemSoundsEnabled;
  innerItemSoundsEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Enable" ), mSoundsEnabled, true );
  itemSoundsEnabled = new KConfigCompilerSignallingItem(innerItemSoundsEnabled, this, notifyFunction, signalSoundsEnabledChanged);
  itemSoundsEnabled->setWriteFlags(KConfigBase::Notify);
  addItem( itemSoundsEnabled, QStringLiteral( "soundsEnabled" ) );
}

QString SoundThemeSettings::defaultThemeValue_helper() const
{

  return QStringLiteral( "ocean" );
}

bool SoundThemeSettings::defaultSoundsEnabledValue_helper() const
{

  return true;
}

SoundThemeSettings::~SoundThemeSettings()
{
}


void SoundThemeSettings::itemChanged(quint64 signalFlag) {

  switch (signalFlag) {
  case signalThemeChanged:
    Q_EMIT themeChanged();
    break;
  case signalSoundsEnabledChanged:
    Q_EMIT soundsEnabledChanged();
    break;
  }
}
