#include <QtQml/qqmlprivate.h>
#include <QtCore/qdir.h>
#include <QtCore/qurl.h>
#include <QtCore/qhash.h>
#include <QtCore/qstring.h>

namespace QmlCacheGeneratedCode {
namespace _qt_qml_plasma_applet_org_kde_plasma_notifications_components_ActionContainer_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_notifications_components_Body_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_notifications_components_DraggableFileArea_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_notifications_components_EditContextMenu_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_notifications_components_FooterLoader_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_notifications_components_HeadingButtons_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_notifications_components_Icon_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_notifications_components_JobDetails_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_notifications_components_JobIconItem_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_notifications_components_JobItem_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_notifications_components_ModelInterface_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_notifications_components_NotificationHeader_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_notifications_components_NotificationReplyField_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_notifications_components_SpeedChart_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_notifications_components_Summary_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_notifications_components_ThumbnailStrip_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_notifications_delegates_BaseDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_notifications_delegates_DelegateHistoryGrouped_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_notifications_delegates_DelegateHistory_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_notifications_delegates_DelegatePopup_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_notifications_global_Globals_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_notifications_global_PulseAudio_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_notifications_CompactRepresentation_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_notifications_DraggableDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_notifications_FullRepresentation_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_notifications_main_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_plasma_applet_org_kde_plasma_notifications_NotificationPopup_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}

}
namespace {
struct Registry {
    Registry();
    ~Registry();
    QHash<QString, const QQmlPrivate::CachedQmlUnit*> resourcePathToCachedUnit;
    static const QQmlPrivate::CachedQmlUnit *lookupCachedUnit(const QUrl &url);
};

Q_GLOBAL_STATIC(Registry, unitRegistry)


Registry::Registry() {
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/notifications/components/ActionContainer.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_notifications_components_ActionContainer_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/notifications/components/Body.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_notifications_components_Body_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/notifications/components/DraggableFileArea.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_notifications_components_DraggableFileArea_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/notifications/components/EditContextMenu.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_notifications_components_EditContextMenu_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/notifications/components/FooterLoader.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_notifications_components_FooterLoader_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/notifications/components/HeadingButtons.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_notifications_components_HeadingButtons_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/notifications/components/Icon.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_notifications_components_Icon_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/notifications/components/JobDetails.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_notifications_components_JobDetails_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/notifications/components/JobIconItem.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_notifications_components_JobIconItem_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/notifications/components/JobItem.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_notifications_components_JobItem_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/notifications/components/ModelInterface.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_notifications_components_ModelInterface_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/notifications/components/NotificationHeader.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_notifications_components_NotificationHeader_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/notifications/components/NotificationReplyField.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_notifications_components_NotificationReplyField_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/notifications/components/SpeedChart.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_notifications_components_SpeedChart_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/notifications/components/Summary.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_notifications_components_Summary_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/notifications/components/ThumbnailStrip.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_notifications_components_ThumbnailStrip_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/notifications/delegates/BaseDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_notifications_delegates_BaseDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/notifications/delegates/DelegateHistoryGrouped.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_notifications_delegates_DelegateHistoryGrouped_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/notifications/delegates/DelegateHistory.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_notifications_delegates_DelegateHistory_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/notifications/delegates/DelegatePopup.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_notifications_delegates_DelegatePopup_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/notifications/global/Globals.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_notifications_global_Globals_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/notifications/global/PulseAudio.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_notifications_global_PulseAudio_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/notifications/CompactRepresentation.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_notifications_CompactRepresentation_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/notifications/DraggableDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_notifications_DraggableDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/notifications/FullRepresentation.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_notifications_FullRepresentation_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/notifications/main.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_notifications_main_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/plasma/applet/org/kde/plasma/notifications/NotificationPopup.qml"), &QmlCacheGeneratedCode::_qt_qml_plasma_applet_org_kde_plasma_notifications_NotificationPopup_qml::unit);
    QQmlPrivate::RegisterQmlUnitCacheHook registration;
    registration.structVersion = 0;
    registration.lookupCachedQmlUnit = &lookupCachedUnit;
    QQmlPrivate::qmlregister(QQmlPrivate::QmlUnitCacheHookRegistration, &registration);
}

Registry::~Registry() {
    QQmlPrivate::qmlunregister(QQmlPrivate::QmlUnitCacheHookRegistration, quintptr(&lookupCachedUnit));
}

const QQmlPrivate::CachedQmlUnit *Registry::lookupCachedUnit(const QUrl &url) {
    if (url.scheme() != QLatin1String("qrc"))
        return nullptr;
    QString resourcePath = QDir::cleanPath(url.path());
    if (resourcePath.isEmpty())
        return nullptr;
    if (!resourcePath.startsWith(QLatin1Char('/')))
        resourcePath.prepend(QLatin1Char('/'));
    return unitRegistry()->resourcePathToCachedUnit.value(resourcePath, nullptr);
}
}
int QT_MANGLE_NAMESPACE(qInitResources_qmlcache_org_kde_plasma)() {
    ::unitRegistry();
    return 1;
}
Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_qmlcache_org_kde_plasma))
int QT_MANGLE_NAMESPACE(qCleanupResources_qmlcache_org_kde_plasma)() {
    return 1;
}
