// This file is generated by kconfig_compiler_kf6 from regionandlangsettingsbase.kcfg.
// All changes you do to this file will be lost.

#include "regionandlangsettingsbase.h"

RegionAndLangSettingsBase::RegionAndLangSettingsBase( QObject *parent )
  : KConfigSkeleton( QStringLiteral( "plasma-localerc" ) )
{
  setParent(parent);
  KConfigCompilerSignallingItem::NotifyFunction notifyFunction = static_cast<KConfigCompilerSignallingItem::NotifyFunction>(&RegionAndLangSettingsBase::itemChanged);

  setCurrentGroup( QStringLiteral( "Formats" ) );

  KConfigCompilerSignallingItem  *itemLang;
  KConfigSkeleton::ItemString  *innerItemLang;
  innerItemLang = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "LANG" ), mLang );
  itemLang = new KConfigCompilerSignallingItem(innerItemLang, this, notifyFunction, signalLangChanged);
  addItem( itemLang, QStringLiteral( "lang" ) );
  KConfigCompilerSignallingItem  *itemNumeric;
  KConfigSkeleton::ItemString  *innerItemNumeric;
  innerItemNumeric = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "LC_NUMERIC" ), mNumeric, i18n("Inherit Language") );
  itemNumeric = new KConfigCompilerSignallingItem(innerItemNumeric, this, notifyFunction, signalNumericChanged);
  addItem( itemNumeric, QStringLiteral( "numeric" ) );
  KConfigCompilerSignallingItem  *itemTime;
  KConfigSkeleton::ItemString  *innerItemTime;
  innerItemTime = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "LC_TIME" ), mTime, i18n("Inherit Language") );
  itemTime = new KConfigCompilerSignallingItem(innerItemTime, this, notifyFunction, signalTimeChanged);
  addItem( itemTime, QStringLiteral( "time" ) );
  KConfigCompilerSignallingItem  *itemMonetary;
  KConfigSkeleton::ItemString  *innerItemMonetary;
  innerItemMonetary = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "LC_MONETARY" ), mMonetary, i18n("Inherit Language") );
  itemMonetary = new KConfigCompilerSignallingItem(innerItemMonetary, this, notifyFunction, signalMonetaryChanged);
  addItem( itemMonetary, QStringLiteral( "monetary" ) );
  KConfigCompilerSignallingItem  *itemMeasurement;
  KConfigSkeleton::ItemString  *innerItemMeasurement;
  innerItemMeasurement = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "LC_MEASUREMENT" ), mMeasurement, i18n("Inherit Language") );
  itemMeasurement = new KConfigCompilerSignallingItem(innerItemMeasurement, this, notifyFunction, signalMeasurementChanged);
  addItem( itemMeasurement, QStringLiteral( "measurement" ) );
  KConfigCompilerSignallingItem  *itemPaperSize;
  KConfigSkeleton::ItemString  *innerItemPaperSize;
  innerItemPaperSize = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "LC_PAPER" ), mPaperSize, i18n("Inherit Language") );
  itemPaperSize = new KConfigCompilerSignallingItem(innerItemPaperSize, this, notifyFunction, signalPaperSizeChanged);
  addItem( itemPaperSize, QStringLiteral( "paperSize" ) );
  KConfigCompilerSignallingItem  *itemAddress;
  KConfigSkeleton::ItemString  *innerItemAddress;
  innerItemAddress = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "LC_ADDRESS" ), mAddress, i18n("Inherit Language") );
  itemAddress = new KConfigCompilerSignallingItem(innerItemAddress, this, notifyFunction, signalAddressChanged);
  addItem( itemAddress, QStringLiteral( "address" ) );
  KConfigCompilerSignallingItem  *itemNameStyle;
  KConfigSkeleton::ItemString  *innerItemNameStyle;
  innerItemNameStyle = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "LC_NAME" ), mNameStyle, i18n("Inherit Language") );
  itemNameStyle = new KConfigCompilerSignallingItem(innerItemNameStyle, this, notifyFunction, signalNameStyleChanged);
  addItem( itemNameStyle, QStringLiteral( "nameStyle" ) );
  KConfigCompilerSignallingItem  *itemPhoneNumbers;
  KConfigSkeleton::ItemString  *innerItemPhoneNumbers;
  innerItemPhoneNumbers = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "LC_TELEPHONE" ), mPhoneNumbers, i18n("Inherit Language") );
  itemPhoneNumbers = new KConfigCompilerSignallingItem(innerItemPhoneNumbers, this, notifyFunction, signalPhoneNumbersChanged);
  addItem( itemPhoneNumbers, QStringLiteral( "phoneNumbers" ) );
  KConfigCompilerSignallingItem  *itemCtype;
  KConfigSkeleton::ItemString  *innerItemCtype;
  innerItemCtype = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "LC_CTYPE" ), mCtype, i18n("Inherit Language") );
  itemCtype = new KConfigCompilerSignallingItem(innerItemCtype, this, notifyFunction, signalCtypeChanged);
  addItem( itemCtype, QStringLiteral( "ctype" ) );

  setCurrentGroup( QStringLiteral( "Translations" ) );


            QString language = QString::fromLocal8Bit(qgetenv("LANGUAGE"));
        
  KConfigCompilerSignallingItem  *itemLanguage;
  KConfigSkeleton::ItemString  *innerItemLanguage;
  innerItemLanguage = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "LANGUAGE" ), mLanguage, language );
  itemLanguage = new KConfigCompilerSignallingItem(innerItemLanguage, this, notifyFunction, signalLanguageChanged);
  addItem( itemLanguage, QStringLiteral( "language" ) );
}

QString RegionAndLangSettingsBase::defaultNumericValue_helper() const
{

  return i18n("Inherit Language");
}

QString RegionAndLangSettingsBase::defaultTimeValue_helper() const
{

  return i18n("Inherit Language");
}

QString RegionAndLangSettingsBase::defaultMonetaryValue_helper() const
{

  return i18n("Inherit Language");
}

QString RegionAndLangSettingsBase::defaultMeasurementValue_helper() const
{

  return i18n("Inherit Language");
}

QString RegionAndLangSettingsBase::defaultPaperSizeValue_helper() const
{

  return i18n("Inherit Language");
}

QString RegionAndLangSettingsBase::defaultAddressValue_helper() const
{

  return i18n("Inherit Language");
}

QString RegionAndLangSettingsBase::defaultNameStyleValue_helper() const
{

  return i18n("Inherit Language");
}

QString RegionAndLangSettingsBase::defaultPhoneNumbersValue_helper() const
{

  return i18n("Inherit Language");
}

QString RegionAndLangSettingsBase::defaultCtypeValue_helper() const
{

  return i18n("Inherit Language");
}

QString RegionAndLangSettingsBase::defaultLanguageValue_helper() const
{

            QString language = QString::fromLocal8Bit(qgetenv("LANGUAGE"));
        
  return language;
}

RegionAndLangSettingsBase::~RegionAndLangSettingsBase()
{
}


void RegionAndLangSettingsBase::itemChanged(quint64 signalFlag) {

  switch (signalFlag) {
  case signalLangChanged:
    Q_EMIT langChanged();
    break;
  case signalNumericChanged:
    Q_EMIT numericChanged();
    break;
  case signalTimeChanged:
    Q_EMIT timeChanged();
    break;
  case signalMonetaryChanged:
    Q_EMIT monetaryChanged();
    break;
  case signalMeasurementChanged:
    Q_EMIT measurementChanged();
    break;
  case signalPaperSizeChanged:
    Q_EMIT paperSizeChanged();
    break;
  case signalAddressChanged:
    Q_EMIT addressChanged();
    break;
  case signalNameStyleChanged:
    Q_EMIT nameStyleChanged();
    break;
  case signalPhoneNumbersChanged:
    Q_EMIT phoneNumbersChanged();
    break;
  case signalCtypeChanged:
    Q_EMIT ctypeChanged();
    break;
  case signalLanguageChanged:
    Q_EMIT languageChanged();
    break;
  }
}
