// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#ifndef NIGHTLIGHTDATA_H
#define NIGHTLIGHTDATA_H

#include <QObject>

#include "kcmoduledata.h"



class NightLightSettings;


class NightLightData : public KCModuleData
{
    Q_OBJECT

public:
    explicit NightLightData(QObject *parent = nullptr);
    NightLightSettings *settings() const;


private:
    NightLightSettings *m_settings;

};



#endif
