/****************************************************************************
** Meta object code from reading C++ file 'imagebackend.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../plasma-workspace-6.7.1/wallpapers/image/plugin/imagebackend.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'imagebackend.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12ImageBackendE_t {};
} // unnamed namespace

template <> constexpr inline auto ImageBackend::qt_create_metaobjectdata<qt_meta_tag_ZN12ImageBackendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ImageBackend",
        "QML.Element",
        "auto",
        "settingsChanged",
        "",
        "imageChanged",
        "dynamicModeChanged",
        "wallpaperModelChanged",
        "slideFilterModelChanged",
        "renderingModeChanged",
        "slideshowModeChanged",
        "slideshowFoldersFirstChanged",
        "targetSizeChanged",
        "slideTimerChanged",
        "slidePathsChanged",
        "uncheckedSlidesChanged",
        "pauseSlideshowChanged",
        "configMapChanged",
        "loadingChanged",
        "loading",
        "lastFolderChanged",
        "nextSlide",
        "slotSlideModelDataChanged",
        "QModelIndex",
        "topLeft",
        "bottomRight",
        "QList<int>",
        "roles",
        "startSlideshow",
        "backgroundsFound",
        "addSlidePath",
        "QUrl",
        "url",
        "removeSlidePath",
        "path",
        "nameFilters",
        "addUsersWallpaper",
        "makeWallpaperUrl",
        "selectors",
        "configMap",
        "QQmlPropertyMap*",
        "usedInConfig",
        "renderingMode",
        "RenderingMode",
        "slideshowMode",
        "SortingMode::Mode",
        "slideshowFoldersFirst",
        "image",
        "dynamicMode",
        "DynamicMode::Mode",
        "wallpaperModel",
        "QAbstractItemModel*",
        "slideFilterModel",
        "slideTimer",
        "slidePaths",
        "targetSize",
        "QSize",
        "uncheckedSlides",
        "pauseSlideshow",
        "lastFolder",
        "nextSlideAction",
        "QAction*",
        "SingleImage",
        "SlideShow"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'settingsChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'imageChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dynamicModeChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wallpaperModelChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'slideFilterModelChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'renderingModeChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'slideshowModeChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'slideshowFoldersFirstChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'targetSizeChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'slideTimerChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'slidePathsChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'uncheckedSlidesChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pauseSlideshowChanged'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'configMapChanged'
        QtMocHelpers::SignalData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loadingChanged'
        QtMocHelpers::SignalData<void(bool)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Signal 'lastFolderChanged'
        QtMocHelpers::SignalData<void()>(20, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'nextSlide'
        QtMocHelpers::SlotData<void()>(21, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSlideModelDataChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QModelIndex &, const QList<int> &)>(22, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 }, { 0x80000000 | 23, 25 }, { 0x80000000 | 26, 27 },
        }}),
        // Slot 'startSlideshow'
        QtMocHelpers::SlotData<void()>(28, 4, QMC::AccessProtected, QMetaType::Void),
        // Slot 'backgroundsFound'
        QtMocHelpers::SlotData<void()>(29, 4, QMC::AccessProtected, QMetaType::Void),
        // Method 'addSlidePath'
        QtMocHelpers::MethodData<bool(const QUrl &)>(30, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Method 'removeSlidePath'
        QtMocHelpers::MethodData<void(const QString &)>(33, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 34 },
        }}),
        // Method 'nameFilters'
        QtMocHelpers::MethodData<QString() const>(35, 4, QMC::AccessPublic, QMetaType::QString),
        // Method 'addUsersWallpaper'
        QtMocHelpers::MethodData<QString(const QUrl &)>(36, 4, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Method 'makeWallpaperUrl'
        QtMocHelpers::MethodData<QUrl(const QString &, const QStringList &) const>(37, 4, QMC::AccessPublic, 0x80000000 | 31, {{
            { QMetaType::QString, 32 }, { QMetaType::QStringList, 38 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'configMap'
        QtMocHelpers::PropertyData<QQmlPropertyMap*>(39, 0x80000000 | 40, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 13),
        // property 'usedInConfig'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'renderingMode'
        QtMocHelpers::PropertyData<enum RenderingMode>(42, 0x80000000 | 43, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'slideshowMode'
        QtMocHelpers::PropertyData<SortingMode::Mode>(44, 0x80000000 | 45, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'slideshowFoldersFirst'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'image'
        QtMocHelpers::PropertyData<QString>(47, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'dynamicMode'
        QtMocHelpers::PropertyData<DynamicMode::Mode>(48, 0x80000000 | 49, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'wallpaperModel'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(50, 0x80000000 | 51, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'slideFilterModel'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(52, 0x80000000 | 51, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'slideTimer'
        QtMocHelpers::PropertyData<int>(53, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'slidePaths'
        QtMocHelpers::PropertyData<QStringList>(54, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'targetSize'
        QtMocHelpers::PropertyData<QSize>(55, 0x80000000 | 56, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 8),
        // property 'uncheckedSlides'
        QtMocHelpers::PropertyData<QStringList>(57, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'pauseSlideshow'
        QtMocHelpers::PropertyData<bool>(58, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'lastFolder'
        QtMocHelpers::PropertyData<QUrl>(59, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 15),
        // property 'loading'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags, 14),
        // property 'nextSlideAction'
        QtMocHelpers::PropertyData<QAction*>(60, 0x80000000 | 61, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'RenderingMode'
        QtMocHelpers::EnumData<enum RenderingMode>(43, 43, QMC::EnumFlags{}).add({
            {   62, RenderingMode::SingleImage },
            {   63, RenderingMode::SlideShow },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ImageBackend, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN12ImageBackendE[] = {
    QMetaObject::SuperData::link<SortingMode::staticMetaObject>(),
    QMetaObject::SuperData::link<DynamicMode::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject ImageBackend::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ImageBackendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ImageBackendE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN12ImageBackendE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12ImageBackendE_t>.metaTypes,
    nullptr
} };

void ImageBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ImageBackend *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->settingsChanged(); break;
        case 1: _t->imageChanged(); break;
        case 2: _t->dynamicModeChanged(); break;
        case 3: _t->wallpaperModelChanged(); break;
        case 4: _t->slideFilterModelChanged(); break;
        case 5: _t->renderingModeChanged(); break;
        case 6: _t->slideshowModeChanged(); break;
        case 7: _t->slideshowFoldersFirstChanged(); break;
        case 8: _t->targetSizeChanged(); break;
        case 9: _t->slideTimerChanged(); break;
        case 10: _t->slidePathsChanged(); break;
        case 11: _t->uncheckedSlidesChanged(); break;
        case 12: _t->pauseSlideshowChanged(); break;
        case 13: _t->configMapChanged(); break;
        case 14: _t->loadingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->lastFolderChanged(); break;
        case 16: _t->nextSlide(); break;
        case 17: _t->slotSlideModelDataChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[3]))); break;
        case 18: _t->startSlideshow(); break;
        case 19: _t->backgroundsFound(); break;
        case 20: { bool _r = _t->addSlidePath((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 21: _t->removeSlidePath((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 22: { QString _r = _t->nameFilters();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 23: { QString _r = _t->addUsersWallpaper((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 24: { QUrl _r = _t->makeWallpaperUrl((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ImageBackend::*)()>(_a, &ImageBackend::settingsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageBackend::*)()>(_a, &ImageBackend::imageChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageBackend::*)()>(_a, &ImageBackend::dynamicModeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageBackend::*)()>(_a, &ImageBackend::wallpaperModelChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageBackend::*)()>(_a, &ImageBackend::slideFilterModelChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageBackend::*)()>(_a, &ImageBackend::renderingModeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageBackend::*)()>(_a, &ImageBackend::slideshowModeChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageBackend::*)()>(_a, &ImageBackend::slideshowFoldersFirstChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageBackend::*)()>(_a, &ImageBackend::targetSizeChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageBackend::*)()>(_a, &ImageBackend::slideTimerChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageBackend::*)()>(_a, &ImageBackend::slidePathsChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageBackend::*)()>(_a, &ImageBackend::uncheckedSlidesChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageBackend::*)()>(_a, &ImageBackend::pauseSlideshowChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageBackend::*)()>(_a, &ImageBackend::configMapChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageBackend::*)(bool )>(_a, &ImageBackend::loadingChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageBackend::*)()>(_a, &ImageBackend::lastFolderChanged, 15))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 8:
        case 7:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractItemModel* >(); break;
        case 16:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlPropertyMap* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQmlPropertyMap**>(_v) = _t->configMap(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->m_usedInConfig; break;
        case 2: *reinterpret_cast<enum RenderingMode*>(_v) = _t->renderingMode(); break;
        case 3: *reinterpret_cast<SortingMode::Mode*>(_v) = _t->slideshowMode(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->slideshowFoldersFirst(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->image(); break;
        case 6: *reinterpret_cast<DynamicMode::Mode*>(_v) = _t->dynamicMode(); break;
        case 7: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->wallpaperModel(); break;
        case 8: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->slideFilterModel(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->slideTimer(); break;
        case 10: *reinterpret_cast<QStringList*>(_v) = _t->slidePaths(); break;
        case 11: *reinterpret_cast<QSize*>(_v) = _t->targetSize(); break;
        case 12: *reinterpret_cast<QStringList*>(_v) = _t->uncheckedSlides(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->pauseSlideshow(); break;
        case 14: *reinterpret_cast<QUrl*>(_v) = _t->lastFolder(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->loading(); break;
        case 16: *reinterpret_cast<QAction**>(_v) = _t->nextSlideAction(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setConfigMap(*reinterpret_cast<QQmlPropertyMap**>(_v)); break;
        case 1: QtMocHelpers::setProperty(_t->m_usedInConfig, *reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setRenderingMode(*reinterpret_cast<enum RenderingMode*>(_v)); break;
        case 3: _t->setSlideshowMode(*reinterpret_cast<SortingMode::Mode*>(_v)); break;
        case 4: _t->setSlideshowFoldersFirst(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setImage(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setDynamicMode(*reinterpret_cast<DynamicMode::Mode*>(_v)); break;
        case 9: _t->setSlideTimer(*reinterpret_cast<int*>(_v)); break;
        case 10: _t->setSlidePaths(*reinterpret_cast<QStringList*>(_v)); break;
        case 11: _t->setTargetSize(*reinterpret_cast<QSize*>(_v)); break;
        case 12: _t->setUncheckedSlides(*reinterpret_cast<QStringList*>(_v)); break;
        case 13: _t->setPauseSlideshow(*reinterpret_cast<bool*>(_v)); break;
        case 14: _t->setLastFolder(*reinterpret_cast<QUrl*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ImageBackend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ImageBackend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ImageBackendE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QObject::qt_metacast(_clname);
}

int ImageBackend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void ImageBackend::settingsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ImageBackend::imageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ImageBackend::dynamicModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ImageBackend::wallpaperModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ImageBackend::slideFilterModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ImageBackend::renderingModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ImageBackend::slideshowModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void ImageBackend::slideshowFoldersFirstChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void ImageBackend::targetSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void ImageBackend::slideTimerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void ImageBackend::slidePathsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void ImageBackend::uncheckedSlidesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void ImageBackend::pauseSlideshowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void ImageBackend::configMapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void ImageBackend::loadingChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void ImageBackend::lastFolderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}
QT_WARNING_POP
