// This file is generated by kconfig_compiler_kf6 from iconssettingsbase.kcfg.
// All changes you do to this file will be lost.

#include "iconssettingsbase.h"

IconsSettingsBase::IconsSettingsBase( QObject *parent )
  : KConfigSkeleton( QStringLiteral( "kdeglobals" ) )
{
  setParent(parent);
  KConfigCompilerSignallingItem::NotifyFunction notifyFunction = static_cast<KConfigCompilerSignallingItem::NotifyFunction>(&IconsSettingsBase::itemChanged);

  setCurrentGroup( QStringLiteral( "Icons" ) );

  KConfigCompilerSignallingItem  *itemTheme;
  KConfigSkeleton::ItemString  *innerItemTheme;
  innerItemTheme = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Theme" ), mTheme, QStringLiteral( "breeze" ) );
  itemTheme = new KConfigCompilerSignallingItem(innerItemTheme, this, notifyFunction, signalThemeChanged);
  itemTheme->setWriteFlags(KConfigBase::Notify);
  addItem( itemTheme, QStringLiteral( "Theme" ) );
}

QString IconsSettingsBase::defaultThemeValue_helper() const
{

  return QStringLiteral( "breeze" );
}

IconsSettingsBase::~IconsSettingsBase()
{
}


void IconsSettingsBase::itemChanged(quint64 signalFlag) {

  switch (signalFlag) {
  case signalThemeChanged:
    Q_EMIT ThemeChanged();
    break;
  }
}
