/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.gtk.Menus.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef GTKMENUS_INTERFACE_H
#define GTKMENUS_INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>
#include "gdbusmenutypes_p.h"

/*
 * Proxy class for interface org.gtk.Menus
 */
class OrgGtkMenusInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.gtk.Menus"; }

public:
    OrgGtkMenusInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgGtkMenusInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> End(const QList<uint> &groups)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(groups);
        return asyncCallWithArgumentList(QStringLiteral("End"), argumentList);
    }

    inline QDBusPendingReply<GMenuItemList> Start(const QList<uint> &groups)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(groups);
        return asyncCallWithArgumentList(QStringLiteral("Start"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void Changed(GMenuChangeList changes);
};

#endif
