/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was kf6_org.kde.StatusNotifierWatcher.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "statusnotifierwatcheradaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class StatusNotifierWatcherAdaptor
 */

StatusNotifierWatcherAdaptor::StatusNotifierWatcherAdaptor(StatusNotifierWatcher *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

StatusNotifierWatcherAdaptor::~StatusNotifierWatcherAdaptor()
{
    // destructor
}

bool StatusNotifierWatcherAdaptor::isStatusNotifierHostRegistered() const
{
    // get the value of property IsStatusNotifierHostRegistered
    return qvariant_cast< bool >(parent()->property("IsStatusNotifierHostRegistered"));
}

int StatusNotifierWatcherAdaptor::protocolVersion() const
{
    // get the value of property ProtocolVersion
    return qvariant_cast< int >(parent()->property("ProtocolVersion"));
}

QStringList StatusNotifierWatcherAdaptor::registeredStatusNotifierItems() const
{
    // get the value of property RegisteredStatusNotifierItems
    return qvariant_cast< QStringList >(parent()->property("RegisteredStatusNotifierItems"));
}

void StatusNotifierWatcherAdaptor::RegisterStatusNotifierHost(const QString &service)
{
    // handle method call org.kde.StatusNotifierWatcher.RegisterStatusNotifierHost
    parent()->RegisterStatusNotifierHost(service);
}

void StatusNotifierWatcherAdaptor::RegisterStatusNotifierItem(const QString &service)
{
    // handle method call org.kde.StatusNotifierWatcher.RegisterStatusNotifierItem
    parent()->RegisterStatusNotifierItem(service);
}


#include "moc_statusnotifierwatcheradaptor.cpp"
