/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.JobViewV3.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "jobviewv3adaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class JobViewV3Adaptor
 */

JobViewV3Adaptor::JobViewV3Adaptor(NotificationManager::JobPrivate *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

JobViewV3Adaptor::~JobViewV3Adaptor()
{
    // destructor
}

void JobViewV3Adaptor::terminate(uint errorCode, const QString &errorMessage, const QVariantMap &hints)
{
    // handle method call org.kde.JobViewV3.terminate
    parent()->terminate(errorCode, errorMessage, hints);
}

void JobViewV3Adaptor::update(const QVariantMap &properties)
{
    // handle method call org.kde.JobViewV3.update
    parent()->update(properties);
}


#include "moc_jobviewv3adaptor.cpp"
