/****************************************************************************
** Meta object code from reading C++ file 'portalnotificationsadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "portalnotificationsadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'portalnotificationsadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN26PortalNotificationsAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto PortalNotificationsAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN26PortalNotificationsAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PortalNotificationsAdaptor",
        "D-Bus Interface",
        "org.freedesktop.impl.portal.Notification",
        "D-Bus Introspection",
        "  <interface name=\"org.freedesktop.impl.portal.Notification\">\n "
        "   <property access=\"read\" type=\"u\" name=\"version\"/>\n    <m"
        "ethod name=\"AddNotification\">\n      <arg direction=\"in\" type="
        "\"s\" name=\"app_id\"/>\n      <arg direction=\"in\" type=\"s\" na"
        "me=\"id\"/>\n      <arg direction=\"in\" type=\"a{sv}\" name=\"not"
        "ification\"/>\n      <annotation value=\"QVariantMap\" name=\"org."
        "qtproject.QtDBus.QtTypeName.In2\"/>\n    </method>\n    <method na"
        "me=\"RemoveNotification\">\n      <arg direction=\"in\" type=\"s\""
        " name=\"app_id\"/>\n      <arg direction=\"in\" type=\"s\" name=\""
        "id\"/>\n    </method>\n    <signal name=\"ActionInvoked\">\n      "
        "<arg direction=\"out\" type=\"s\" name=\"app_id\"/>\n      <arg di"
        "rection=\"out\" type=\"s\" name=\"id\"/>\n      <arg direction=\"o"
        "ut\" type=\"s\" name=\"action\"/>\n      <arg direction=\"out\" ty"
        "pe=\"av\" name=\"parameter\"/>\n    </signal>\n  </interface>\n",
        "ActionInvoked",
        "",
        "app_id",
        "id",
        "action",
        "QVariantList",
        "parameter",
        "AddNotification",
        "QVariantMap",
        "notification",
        "RemoveNotification",
        "version"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ActionInvoked'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &, const QVariantList &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 }, { QMetaType::QString, 9 }, { 0x80000000 | 10, 11 },
        }}),
        // Slot 'AddNotification'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QVariantMap &)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 }, { 0x80000000 | 13, 14 },
        }}),
        // Slot 'RemoveNotification'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'version'
        QtMocHelpers::PropertyData<uint>(16, QMetaType::UInt, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<PortalNotificationsAdaptor, qt_meta_tag_ZN26PortalNotificationsAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PortalNotificationsAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26PortalNotificationsAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26PortalNotificationsAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN26PortalNotificationsAdaptorE_t>.metaTypes,
    nullptr
} };

void PortalNotificationsAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PortalNotificationsAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ActionInvoked((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[4]))); break;
        case 1: _t->AddNotification((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3]))); break;
        case 2: _t->RemoveNotification((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PortalNotificationsAdaptor::*)(const QString & , const QString & , const QString & , const QVariantList & )>(_a, &PortalNotificationsAdaptor::ActionInvoked, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<uint*>(_v) = _t->version(); break;
        default: break;
        }
    }
}

const QMetaObject *PortalNotificationsAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PortalNotificationsAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26PortalNotificationsAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int PortalNotificationsAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void PortalNotificationsAdaptor::ActionInvoked(const QString & _t1, const QString & _t2, const QString & _t3, const QVariantList & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4);
}
QT_WARNING_POP
