/****************************************************************************
** Meta object code from reading C++ file 'appsmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/applets/kicker/appsmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'appsmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9AppsModelE_t {};
} // unnamed namespace

template <> constexpr inline auto AppsModel::qt_create_metaobjectdata<qt_meta_tag_ZN9AppsModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AppsModel",
        "QML.Element",
        "auto",
        "cleared",
        "",
        "autoPopulateChanged",
        "paginateChanged",
        "pageSizeChanged",
        "flatChanged",
        "sortedChanged",
        "showSeparatorsChanged",
        "showTopLevelItemsChanged",
        "appNameFormatChanged",
        "appletInterfaceChanged",
        "hiddenEntriesChanged",
        "refresh",
        "trigger",
        "row",
        "actionId",
        "QVariant",
        "argument",
        "modelForRow",
        "AbstractModel*",
        "rowForModel",
        "model",
        "autoPopulate",
        "paginate",
        "pageSize",
        "flat",
        "sorted",
        "showSeparators",
        "showTopLevelItems",
        "appNameFormat",
        "appletInterface"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'cleared'
        QtMocHelpers::SignalData<void() const>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoPopulateChanged'
        QtMocHelpers::SignalData<void() const>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'paginateChanged'
        QtMocHelpers::SignalData<void() const>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pageSizeChanged'
        QtMocHelpers::SignalData<void() const>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'flatChanged'
        QtMocHelpers::SignalData<void() const>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sortedChanged'
        QtMocHelpers::SignalData<void() const>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showSeparatorsChanged'
        QtMocHelpers::SignalData<void() const>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showTopLevelItemsChanged'
        QtMocHelpers::SignalData<void() const>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'appNameFormatChanged'
        QtMocHelpers::SignalData<void() const>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'appletInterfaceChanged'
        QtMocHelpers::SignalData<void() const>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hiddenEntriesChanged'
        QtMocHelpers::SignalData<void() const>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'refresh'
        QtMocHelpers::SlotData<void()>(15, 4, QMC::AccessProtected, QMetaType::Void),
        // Method 'trigger'
        QtMocHelpers::MethodData<bool(int, const QString &, const QVariant &)>(16, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 17 }, { QMetaType::QString, 18 }, { 0x80000000 | 19, 20 },
        }}),
        // Method 'modelForRow'
        QtMocHelpers::MethodData<AbstractModel *(int)>(21, 4, QMC::AccessPublic, 0x80000000 | 22, {{
            { QMetaType::Int, 17 },
        }}),
        // Method 'rowForModel'
        QtMocHelpers::MethodData<int(AbstractModel *)>(23, 4, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 22, 24 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'autoPopulate'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'paginate'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'pageSize'
        QtMocHelpers::PropertyData<int>(27, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'flat'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'sorted'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'showSeparators'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'showTopLevelItems'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'appNameFormat'
        QtMocHelpers::PropertyData<int>(32, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'appletInterface'
        QtMocHelpers::PropertyData<QObject*>(33, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<AppsModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AppsModel::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9AppsModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9AppsModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9AppsModelE_t>.metaTypes,
    nullptr
} };

void AppsModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AppsModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->cleared(); break;
        case 1: _t->autoPopulateChanged(); break;
        case 2: _t->paginateChanged(); break;
        case 3: _t->pageSizeChanged(); break;
        case 4: _t->flatChanged(); break;
        case 5: _t->sortedChanged(); break;
        case 6: _t->showSeparatorsChanged(); break;
        case 7: _t->showTopLevelItemsChanged(); break;
        case 8: _t->appNameFormatChanged(); break;
        case 9: _t->appletInterfaceChanged(); break;
        case 10: _t->hiddenEntriesChanged(); break;
        case 11: _t->refresh(); break;
        case 12: { bool _r = _t->trigger((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { AbstractModel* _r = _t->modelForRow((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<AbstractModel**>(_a[0]) = std::move(_r); }  break;
        case 14: { int _r = _t->rowForModel((*reinterpret_cast<std::add_pointer_t<AbstractModel*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AbstractModel* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AppsModel::*)() const>(_a, &AppsModel::cleared, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppsModel::*)() const>(_a, &AppsModel::autoPopulateChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppsModel::*)() const>(_a, &AppsModel::paginateChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppsModel::*)() const>(_a, &AppsModel::pageSizeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppsModel::*)() const>(_a, &AppsModel::flatChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppsModel::*)() const>(_a, &AppsModel::sortedChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppsModel::*)() const>(_a, &AppsModel::showSeparatorsChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppsModel::*)() const>(_a, &AppsModel::showTopLevelItemsChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppsModel::*)() const>(_a, &AppsModel::appNameFormatChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppsModel::*)() const>(_a, &AppsModel::appletInterfaceChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppsModel::*)() const>(_a, &AppsModel::hiddenEntriesChanged, 10))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->autoPopulate(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->paginate(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->pageSize(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->flat(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->sorted(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->showSeparators(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->showTopLevelItems(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->appNameFormat(); break;
        case 8: *reinterpret_cast<QObject**>(_v) = _t->appletInterface(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAutoPopulate(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setPaginate(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setPageSize(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setFlat(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setSorted(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setShowSeparators(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setShowTopLevelItems(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setAppNameFormat(*reinterpret_cast<int*>(_v)); break;
        case 8: _t->setAppletInterface(*reinterpret_cast<QObject**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *AppsModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AppsModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9AppsModelE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return AbstractModel::qt_metacast(_clname);
}

int AppsModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void AppsModel::cleared()const
{
    QMetaObject::activate(const_cast< AppsModel *>(this), &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AppsModel::autoPopulateChanged()const
{
    QMetaObject::activate(const_cast< AppsModel *>(this), &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AppsModel::paginateChanged()const
{
    QMetaObject::activate(const_cast< AppsModel *>(this), &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AppsModel::pageSizeChanged()const
{
    QMetaObject::activate(const_cast< AppsModel *>(this), &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AppsModel::flatChanged()const
{
    QMetaObject::activate(const_cast< AppsModel *>(this), &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void AppsModel::sortedChanged()const
{
    QMetaObject::activate(const_cast< AppsModel *>(this), &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void AppsModel::showSeparatorsChanged()const
{
    QMetaObject::activate(const_cast< AppsModel *>(this), &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void AppsModel::showTopLevelItemsChanged()const
{
    QMetaObject::activate(const_cast< AppsModel *>(this), &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void AppsModel::appNameFormatChanged()const
{
    QMetaObject::activate(const_cast< AppsModel *>(this), &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void AppsModel::appletInterfaceChanged()const
{
    QMetaObject::activate(const_cast< AppsModel *>(this), &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void AppsModel::hiddenEntriesChanged()const
{
    QMetaObject::activate(const_cast< AppsModel *>(this), &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
