/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Shutdown.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "shutdownadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class ShutdownAdaptor
 */

ShutdownAdaptor::ShutdownAdaptor(Shutdown *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

ShutdownAdaptor::~ShutdownAdaptor()
{
    // destructor
}

void ShutdownAdaptor::logout()
{
    // handle method call org.kde.Shutdown.logout
    parent()->logout();
}

void ShutdownAdaptor::logoutAndReboot()
{
    // handle method call org.kde.Shutdown.logoutAndReboot
    parent()->logoutAndReboot();
}

void ShutdownAdaptor::logoutAndShutdown()
{
    // handle method call org.kde.Shutdown.logoutAndShutdown
    parent()->logoutAndShutdown();
}

void ShutdownAdaptor::saveSession()
{
    // handle method call org.kde.Shutdown.saveSession
    parent()->saveSession();
}


#include "moc_shutdownadaptor.cpp"
