// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#ifndef FEEDBACKDATA_H
#define FEEDBACKDATA_H

#include <QObject>

#include "kcmoduledata.h"



class FeedbackSettings;


class FeedbackData : public KCModuleData
{
    Q_OBJECT

public:
    explicit FeedbackData(QObject *parent = nullptr);
    FeedbackSettings *settings() const;


private:
    FeedbackSettings *m_settings;

};



#endif
