/****************************************************************************
** Meta object code from reading C++ file 'mpris2sourcemodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-workspace-6.7.1/libkmpris/mpris2sourcemodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mpris2sourcemodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17Mpris2SourceModelE_t {};
} // unnamed namespace

template <> constexpr inline auto Mpris2SourceModel::qt_create_metaobjectdata<qt_meta_tag_ZN17Mpris2SourceModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Mpris2SourceModel",
        "onServiceOwnerChanged",
        "",
        "serviceName",
        "oldOwner",
        "newOwner",
        "onServiceNamesFetched",
        "QDBusPendingCallWatcher*",
        "watcher",
        "onInitialFetchFinished",
        "PlayerContainer*",
        "container",
        "onInitialFetchFailed",
        "Role",
        "TrackRole",
        "ContainerRole",
        "CanControlRole",
        "CanGoNextRole",
        "CanGoPreviousRole",
        "CanPlayRole",
        "CanPauseRole",
        "CanStopRole",
        "CanSeekRole",
        "LoopStatusRole",
        "PlaybackStatusRole",
        "PositionRole",
        "RateRole",
        "ShuffleRole",
        "VolumeRole",
        "ArtUrlRole",
        "ArtistRole",
        "AlbumRole",
        "LengthRole",
        "CanQuitRole",
        "CanRaiseRole",
        "CanSetFullscreenRole",
        "DesktopEntryRole",
        "IdentityRole",
        "IconNameRole",
        "InstancePidRole",
        "KDEPidRole",
        "IsMultiplexerRole"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'onServiceOwnerChanged'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 }, { QMetaType::QString, 5 },
        }}),
        // Slot 'onServiceNamesFetched'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'onInitialFetchFinished'
        QtMocHelpers::SlotData<void(PlayerContainer *)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'onInitialFetchFailed'
        QtMocHelpers::SlotData<void(PlayerContainer *)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Role'
        QtMocHelpers::EnumData<enum Role>(13, 13, QMC::EnumFlags{}).add({
            {   14, Role::TrackRole },
            {   15, Role::ContainerRole },
            {   16, Role::CanControlRole },
            {   17, Role::CanGoNextRole },
            {   18, Role::CanGoPreviousRole },
            {   19, Role::CanPlayRole },
            {   20, Role::CanPauseRole },
            {   21, Role::CanStopRole },
            {   22, Role::CanSeekRole },
            {   23, Role::LoopStatusRole },
            {   24, Role::PlaybackStatusRole },
            {   25, Role::PositionRole },
            {   26, Role::RateRole },
            {   27, Role::ShuffleRole },
            {   28, Role::VolumeRole },
            {   29, Role::ArtUrlRole },
            {   30, Role::ArtistRole },
            {   31, Role::AlbumRole },
            {   32, Role::LengthRole },
            {   33, Role::CanQuitRole },
            {   34, Role::CanRaiseRole },
            {   35, Role::CanSetFullscreenRole },
            {   36, Role::DesktopEntryRole },
            {   37, Role::IdentityRole },
            {   38, Role::IconNameRole },
            {   39, Role::InstancePidRole },
            {   40, Role::KDEPidRole },
            {   41, Role::IsMultiplexerRole },
        }),
    };
    return QtMocHelpers::metaObjectData<Mpris2SourceModel, qt_meta_tag_ZN17Mpris2SourceModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Mpris2SourceModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17Mpris2SourceModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17Mpris2SourceModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17Mpris2SourceModelE_t>.metaTypes,
    nullptr
} };

void Mpris2SourceModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Mpris2SourceModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->onServiceOwnerChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 1: _t->onServiceNamesFetched((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 2: _t->onInitialFetchFinished((*reinterpret_cast<std::add_pointer_t<PlayerContainer*>>(_a[1]))); break;
        case 3: _t->onInitialFetchFailed((*reinterpret_cast<std::add_pointer_t<PlayerContainer*>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *Mpris2SourceModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Mpris2SourceModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17Mpris2SourceModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int Mpris2SourceModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}
QT_WARNING_POP
