/****************************************************************************
** Meta object code from reading C++ file 'dbusproperties.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/components/dbus/dbusproperties.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbusproperties.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Plasma15DBusPropertyMapE_t {};
} // unnamed namespace

template <> constexpr inline auto Plasma::DBusPropertyMap::qt_create_metaobjectdata<qt_meta_tag_ZN6Plasma15DBusPropertyMapE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Plasma::DBusPropertyMap",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        ""
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DBusPropertyMap, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Plasma::DBusPropertyMap::staticMetaObject = { {
    QMetaObject::SuperData::link<QQmlPropertyMap::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Plasma15DBusPropertyMapE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Plasma15DBusPropertyMapE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Plasma15DBusPropertyMapE_t>.metaTypes,
    nullptr
} };

void Plasma::DBusPropertyMap::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DBusPropertyMap *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Plasma::DBusPropertyMap::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Plasma::DBusPropertyMap::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Plasma15DBusPropertyMapE_t>.strings))
        return static_cast<void*>(this);
    return QQmlPropertyMap::qt_metacast(_clname);
}

int Plasma::DBusPropertyMap::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQmlPropertyMap::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN6Plasma14DBusPropertiesE_t {};
} // unnamed namespace

template <> constexpr inline auto Plasma::DBusProperties::qt_create_metaobjectdata<qt_meta_tag_ZN6Plasma14DBusPropertiesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Plasma::DBusProperties",
        "QML.Element",
        "Properties",
        "busTypeChanged",
        "",
        "serviceChanged",
        "pathChanged",
        "interfaceChanged",
        "propertyMapChanged",
        "propertiesChanged",
        "interfaceName",
        "QVariantMap",
        "changedProperties",
        "invalidatedProperties",
        "refreshed",
        "updateProperties",
        "update",
        "key",
        "updateAll",
        "busType",
        "BusType::Type",
        "service",
        "path",
        "iface",
        "properties",
        "Plasma::DBusPropertyMap*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'busTypeChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'serviceChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pathChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'interfaceChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'propertyMapChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'propertiesChanged'
        QtMocHelpers::SignalData<void(const QString &, const QVariantMap &, const QStringList &)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { 0x80000000 | 11, 12 }, { QMetaType::QStringList, 13 },
        }}),
        // Signal 'refreshed'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateProperties'
        QtMocHelpers::SlotData<void(const QString &, const QVariantMap &, const QStringList &)>(15, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { 0x80000000 | 11, 12 }, { QMetaType::QStringList, 13 },
        }}),
        // Slot 'updateProperties'
        QtMocHelpers::SlotData<void(const QString &, const QVariantMap &)>(15, 4, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { 0x80000000 | 11, 12 },
        }}),
        // Slot 'updateProperties'
        QtMocHelpers::SlotData<void(const QString &)>(15, 4, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'updateProperties'
        QtMocHelpers::SlotData<void()>(15, 4, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Method 'update'
        QtMocHelpers::MethodData<void(const QString &)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Method 'updateAll'
        QtMocHelpers::MethodData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'busType'
        QtMocHelpers::PropertyData<BusType::Type>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'service'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'path'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'iface'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 3),
        // property 'properties'
        QtMocHelpers::PropertyData<Plasma::DBusPropertyMap*>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DBusProperties, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN6Plasma14DBusPropertiesE[] = {
    QMetaObject::SuperData::link<BusType::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject Plasma::DBusProperties::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Plasma14DBusPropertiesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Plasma14DBusPropertiesE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN6Plasma14DBusPropertiesE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Plasma14DBusPropertiesE_t>.metaTypes,
    nullptr
} };

void Plasma::DBusProperties::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DBusProperties *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->busTypeChanged(); break;
        case 1: _t->serviceChanged(); break;
        case 2: _t->pathChanged(); break;
        case 3: _t->interfaceChanged(); break;
        case 4: _t->propertyMapChanged(); break;
        case 5: _t->propertiesChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        case 6: _t->refreshed(); break;
        case 7: _t->updateProperties((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        case 8: _t->updateProperties((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2]))); break;
        case 9: _t->updateProperties((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->updateProperties(); break;
        case 11: _t->update((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->updateAll(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DBusProperties::*)()>(_a, &DBusProperties::busTypeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusProperties::*)()>(_a, &DBusProperties::serviceChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusProperties::*)()>(_a, &DBusProperties::pathChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusProperties::*)()>(_a, &DBusProperties::interfaceChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusProperties::*)()>(_a, &DBusProperties::propertyMapChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusProperties::*)(const QString & , const QVariantMap & , const QStringList & )>(_a, &DBusProperties::propertiesChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusProperties::*)()>(_a, &DBusProperties::refreshed, 6))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Plasma::DBusPropertyMap* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<BusType::Type*>(_v) = _t->busType(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->service(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->path(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->interface(); break;
        case 4: *reinterpret_cast<Plasma::DBusPropertyMap**>(_v) = _t->properties(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBusType(*reinterpret_cast<BusType::Type*>(_v)); break;
        case 1: _t->setService(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setPath(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setInterface(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Plasma::DBusProperties::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Plasma::DBusProperties::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Plasma14DBusPropertiesE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QObject::qt_metacast(_clname);
}

int Plasma::DBusProperties::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void Plasma::DBusProperties::busTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Plasma::DBusProperties::serviceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Plasma::DBusProperties::pathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Plasma::DBusProperties::interfaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Plasma::DBusProperties::propertyMapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Plasma::DBusProperties::propertiesChanged(const QString & _t1, const QVariantMap & _t2, const QStringList & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3);
}

// SIGNAL 6
void Plasma::DBusProperties::refreshed()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
