// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#include "fontsdata.h"

#include "fontssettings.h"
#include "fontsaasettings.h"




FontsData::FontsData(QObject *parent)
: KCModuleData(parent)
, m_fontsSettings(new FontsSettings(this))
, m_fontsAASettings(new FontsAASettings(this))

{
autoRegisterSkeletons();
}

FontsSettings *FontsData::fontsSettings() const
{
    return m_fontsSettings;
}

FontsAASettings *FontsData::fontsAASettings() const
{
    return m_fontsAASettings;
}





#include "moc_fontsdata.cpp"
