// This file is generated by kconfig_compiler_kf6 from terminal_settings.kcfg.
// All changes you do to this file will be lost.
#ifndef TERMINALSETTINGS_H
#define TERMINALSETTINGS_H

#include <qglobal.h>
#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class TerminalSettings : public KConfigSkeleton
{
  public:

    TerminalSettings( QObject *parent = nullptr );
    ~TerminalSettings() override;

    /**
      Set TerminalApplication
    */
    void setTerminalApplication( const QString & v )
    {
      if (!isTerminalApplicationImmutable())
        mTerminalApplication = v;
    }

    /**
      Get TerminalApplication
    */
    QString terminalApplication() const
    {
      return mTerminalApplication;
    }

    /**
      Is TerminalApplication Immutable
    */
    bool isTerminalApplicationImmutable() const
    {
      return isImmutable( QStringLiteral( "terminalApplication" ) );
    }

    /**
      Get TerminalApplication default value
    */
    QString defaultTerminalApplicationValue() const
    {
        return defaultTerminalApplicationValue_helper();
    }

    /**
      Set TerminalService
    */
    void setTerminalService( const QString & v )
    {
      if (!isTerminalServiceImmutable())
        mTerminalService = v;
    }

    /**
      Get TerminalService
    */
    QString terminalService() const
    {
      return mTerminalService;
    }

    /**
      Is TerminalService Immutable
    */
    bool isTerminalServiceImmutable() const
    {
      return isImmutable( QStringLiteral( "terminalService" ) );
    }

    /**
      Get TerminalService default value
    */
    QString defaultTerminalServiceValue() const
    {
        return defaultTerminalServiceValue_helper();
    }

  protected:

    // General
    QString mTerminalApplication;
    QString defaultTerminalApplicationValue_helper() const;
    QString mTerminalService;
    QString defaultTerminalServiceValue_helper() const;
};

#endif

