/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<abstractmodel.h>)
#  include <abstractmodel.h>
#endif
#if __has_include(<appsmodel.h>)
#  include <appsmodel.h>
#endif
#if __has_include(<computermodel.h>)
#  include <computermodel.h>
#endif
#if __has_include(<containmentinterface.h>)
#  include <containmentinterface.h>
#endif
#if __has_include(<dashboardwindow.h>)
#  include <dashboardwindow.h>
#endif
#if __has_include(<draghelper.h>)
#  include <draghelper.h>
#endif
#if __has_include(<funnelmodel.h>)
#  include <funnelmodel.h>
#endif
#if __has_include(<kastatsfavoritesmodel.h>)
#  include <kastatsfavoritesmodel.h>
#endif
#if __has_include(<processrunner.h>)
#  include <processrunner.h>
#endif
#if __has_include(<recentusagemodel.h>)
#  include <recentusagemodel.h>
#endif
#if __has_include(<rootmodel.h>)
#  include <rootmodel.h>
#endif
#if __has_include(<runnermodel.h>)
#  include <runnermodel.h>
#endif
#if __has_include(<simplefavoritesmodel.h>)
#  include <simplefavoritesmodel.h>
#endif
#if __has_include(<submenu.h>)
#  include <submenu.h>
#endif
#if __has_include(<systemmodel.h>)
#  include <systemmodel.h>
#endif
#if __has_include(<systemsettings.h>)
#  include <systemsettings.h>
#endif
#if __has_include(<wheelinterceptor.h>)
#  include <wheelinterceptor.h>
#endif
#if __has_include(<windowsystem.h>)
#  include <windowsystem.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_plasma_private_kicker()
{
    qmlRegisterModule("org.kde.plasma.private.kicker", 0, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<AbstractModel>("org.kde.plasma.private.kicker", 0);
    qmlRegisterTypesAndRevisions<AppsModel>("org.kde.plasma.private.kicker", 0);
    qmlRegisterTypesAndRevisions<ComputerModel>("org.kde.plasma.private.kicker", 0);
    qmlRegisterTypesAndRevisions<ContainmentInterface>("org.kde.plasma.private.kicker", 0);
    qmlRegisterEnum<ContainmentInterface::Target>("ContainmentInterface::Target");
    qmlRegisterTypesAndRevisions<DashboardWindow>("org.kde.plasma.private.kicker", 0);
    qmlRegisterAnonymousType<QQuickWindow, 254>("org.kde.plasma.private.kicker", 0);
    qmlRegisterAnonymousType<QWindow, 254>("org.kde.plasma.private.kicker", 0);
    qmlRegisterTypesAndRevisions<DragHelper>("org.kde.plasma.private.kicker", 0);
    QMetaType::fromType<ForwardingModel *>().id();
    qmlRegisterTypesAndRevisions<FunnelModel>("org.kde.plasma.private.kicker", 0);
    qmlRegisterTypesAndRevisions<KAStatsFavoritesModel>("org.kde.plasma.private.kicker", 0);
    QMetaType::fromType<PlaceholderModel *>().id();
    qmlRegisterTypesAndRevisions<ProcessRunner>("org.kde.plasma.private.kicker", 0);
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    qmlRegisterTypesAndRevisions<RecentUsageModel>("org.kde.plasma.private.kicker", 0);
    qmlRegisterEnum<RecentUsageModel::IncludeUsage>("RecentUsageModel::IncludeUsage");
    qmlRegisterEnum<RecentUsageModel::Ordering>("RecentUsageModel::Ordering");
    qmlRegisterTypesAndRevisions<RootModel>("org.kde.plasma.private.kicker", 0);
    qmlRegisterTypesAndRevisions<RunnerModel>("org.kde.plasma.private.kicker", 0);
    qmlRegisterTypesAndRevisions<SimpleFavoritesModel>("org.kde.plasma.private.kicker", 0);
    qmlRegisterTypesAndRevisions<SubMenu>("org.kde.plasma.private.kicker", 0);
    qmlRegisterTypesAndRevisions<SystemModel>("org.kde.plasma.private.kicker", 0);
    qmlRegisterTypesAndRevisions<SystemSettings>("org.kde.plasma.private.kicker", 0);
    qmlRegisterTypesAndRevisions<WheelInterceptor>("org.kde.plasma.private.kicker", 0);
    qmlRegisterAnonymousType<QQuickItem, 254>("org.kde.plasma.private.kicker", 0);
    qmlRegisterTypesAndRevisions<WindowSystem>("org.kde.plasma.private.kicker", 0);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.plasma.private.kicker", 0, 1);
}

static const QQmlModuleRegistration orgkdeplasmaprivatekickerRegistration("org.kde.plasma.private.kicker", qml_register_types_org_kde_plasma_private_kicker);
