/****************************************************************************
** Meta object code from reading C++ file 'statusnotifieritem_interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "statusnotifieritem_interface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'statusnotifieritem_interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24OrgKdeStatusNotifierItemE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgKdeStatusNotifierItem::qt_create_metaobjectdata<qt_meta_tag_ZN24OrgKdeStatusNotifierItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgKdeStatusNotifierItem",
        "NewAttentionIcon",
        "",
        "NewIcon",
        "NewMenu",
        "NewOverlayIcon",
        "NewStatus",
        "status",
        "NewTitle",
        "NewToolTip",
        "Activate",
        "QDBusPendingReply<>",
        "x",
        "y",
        "ContextMenu",
        "ProvideXdgActivationToken",
        "token",
        "Scroll",
        "delta",
        "orientation",
        "SecondaryActivate",
        "AttentionIconName",
        "AttentionIconPixmap",
        "KDbusImageVector",
        "AttentionMovieName",
        "Category",
        "IconName",
        "IconPixmap",
        "IconThemePath",
        "Id",
        "ItemIsMenu",
        "Menu",
        "QDBusObjectPath",
        "OverlayIconName",
        "OverlayIconPixmap",
        "Status",
        "Title",
        "ToolTip",
        "KDbusToolTipStruct",
        "WindowId"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'NewAttentionIcon'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'NewIcon'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'NewMenu'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'NewOverlayIcon'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'NewStatus'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'NewTitle'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'NewToolTip'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Activate'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int, int)>(10, 2, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::Int, 12 }, { QMetaType::Int, 13 },
        }}),
        // Slot 'ContextMenu'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int, int)>(14, 2, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::Int, 12 }, { QMetaType::Int, 13 },
        }}),
        // Slot 'ProvideXdgActivationToken'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(15, 2, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::QString, 16 },
        }}),
        // Slot 'Scroll'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int, const QString &)>(17, 2, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::Int, 18 }, { QMetaType::QString, 19 },
        }}),
        // Slot 'SecondaryActivate'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int, int)>(20, 2, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::Int, 12 }, { QMetaType::Int, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'AttentionIconName'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'AttentionIconPixmap'
        QtMocHelpers::PropertyData<KDbusImageVector>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'AttentionMovieName'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Category'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'IconName'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'IconPixmap'
        QtMocHelpers::PropertyData<KDbusImageVector>(27, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'IconThemePath'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Id'
        QtMocHelpers::PropertyData<QString>(29, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'ItemIsMenu'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'Menu'
        QtMocHelpers::PropertyData<QDBusObjectPath>(31, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'OverlayIconName'
        QtMocHelpers::PropertyData<QString>(33, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'OverlayIconPixmap'
        QtMocHelpers::PropertyData<KDbusImageVector>(34, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'Status'
        QtMocHelpers::PropertyData<QString>(35, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Title'
        QtMocHelpers::PropertyData<QString>(36, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'ToolTip'
        QtMocHelpers::PropertyData<KDbusToolTipStruct>(37, 0x80000000 | 38, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'WindowId'
        QtMocHelpers::PropertyData<int>(39, QMetaType::Int, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgKdeStatusNotifierItem, qt_meta_tag_ZN24OrgKdeStatusNotifierItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgKdeStatusNotifierItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24OrgKdeStatusNotifierItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24OrgKdeStatusNotifierItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24OrgKdeStatusNotifierItemE_t>.metaTypes,
    nullptr
} };

void OrgKdeStatusNotifierItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgKdeStatusNotifierItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->NewAttentionIcon(); break;
        case 1: _t->NewIcon(); break;
        case 2: _t->NewMenu(); break;
        case 3: _t->NewOverlayIcon(); break;
        case 4: _t->NewStatus((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->NewTitle(); break;
        case 6: _t->NewToolTip(); break;
        case 7: { QDBusPendingReply<> _r = _t->Activate((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<> _r = _t->ContextMenu((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<> _r = _t->ProvideXdgActivationToken((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<> _r = _t->Scroll((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<> _r = _t->SecondaryActivate((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgKdeStatusNotifierItem::*)()>(_a, &OrgKdeStatusNotifierItem::NewAttentionIcon, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeStatusNotifierItem::*)()>(_a, &OrgKdeStatusNotifierItem::NewIcon, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeStatusNotifierItem::*)()>(_a, &OrgKdeStatusNotifierItem::NewMenu, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeStatusNotifierItem::*)()>(_a, &OrgKdeStatusNotifierItem::NewOverlayIcon, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeStatusNotifierItem::*)(const QString & )>(_a, &OrgKdeStatusNotifierItem::NewStatus, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeStatusNotifierItem::*)()>(_a, &OrgKdeStatusNotifierItem::NewTitle, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeStatusNotifierItem::*)()>(_a, &OrgKdeStatusNotifierItem::NewToolTip, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->attentionIconName(); break;
        case 1: *reinterpret_cast<KDbusImageVector*>(_v) = _t->attentionIconPixmap(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->attentionMovieName(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->category(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->iconName(); break;
        case 5: *reinterpret_cast<KDbusImageVector*>(_v) = _t->iconPixmap(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->iconThemePath(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->id(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->itemIsMenu(); break;
        case 9: *reinterpret_cast<QDBusObjectPath*>(_v) = _t->menu(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->overlayIconName(); break;
        case 11: *reinterpret_cast<KDbusImageVector*>(_v) = _t->overlayIconPixmap(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->status(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        case 14: *reinterpret_cast<KDbusToolTipStruct*>(_v) = _t->toolTip(); break;
        case 15: *reinterpret_cast<int*>(_v) = _t->windowId(); break;
        default: break;
        }
    }
}

const QMetaObject *OrgKdeStatusNotifierItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgKdeStatusNotifierItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24OrgKdeStatusNotifierItemE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgKdeStatusNotifierItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void OrgKdeStatusNotifierItem::NewAttentionIcon()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void OrgKdeStatusNotifierItem::NewIcon()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void OrgKdeStatusNotifierItem::NewMenu()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void OrgKdeStatusNotifierItem::NewOverlayIcon()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void OrgKdeStatusNotifierItem::NewStatus(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void OrgKdeStatusNotifierItem::NewTitle()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void OrgKdeStatusNotifierItem::NewToolTip()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
