/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<keyboardlayout.h>)
#  include <keyboardlayout.h>
#endif
#if __has_include(<layoutnames.h>)
#  include <layoutnames.h>
#endif
#if __has_include(<virtualkeyboard.h>)
#  include <virtualkeyboard.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_plasma_workspace_keyboardlayout()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<KeyboardLayout>("org.kde.plasma.workspace.keyboardlayout", 1);
    qmlRegisterTypesAndRevisions<KwinVirtualKeyboardInterface>("org.kde.plasma.workspace.keyboardlayout", 1);
    qmlRegisterEnum<KwinVirtualKeyboardInterface::VirtualKeyboardVisibility>("KwinVirtualKeyboardInterface::VirtualKeyboardVisibility");
    qmlRegisterTypesAndRevisions<LayoutNames>("org.kde.plasma.workspace.keyboardlayout", 1);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.plasma.workspace.keyboardlayout", 1, 0);
}

static const QQmlModuleRegistration orgkdeplasmaworkspacekeyboardlayoutRegistration("org.kde.plasma.workspace.keyboardlayout", qml_register_types_org_kde_plasma_workspace_keyboardlayout);
