// This file is generated by kconfig_compiler_kf6 from eventsettings.kcfg.
// All changes you do to this file will be lost.

#include "eventsettings.h"

using namespace NotificationManager;

EventSettings::EventSettings( KSharedConfig::Ptr config, const QString & eventId, QObject *parent )
  : KConfigSkeleton( std::move( config ) )
  , mParameventId(eventId)
{
  setParent(parent);
  setCurrentGroup( QStringLiteral( "Event/%1" ).arg( mParameventId ) );

  KConfigSkeleton::ItemString  *itemName;
  itemName = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Name" ), mName );
  addItem( itemName, QStringLiteral( "name" ) );
  KConfigSkeleton::ItemString  *itemComment;
  itemComment = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Comment" ), mComment );
  addItem( itemComment, QStringLiteral( "comment" ) );
  KConfigSkeleton::ItemString  *itemIconName;
  itemIconName = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "IconName" ), mIconName );
  addItem( itemIconName, QStringLiteral( "iconName" ) );
  KConfigSkeleton::ItemString  *itemContext;
  itemContext = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Context" ), mContext );
  addItem( itemContext, QStringLiteral( "context" ) );
  KConfigSkeleton::ItemString  *itemUrgency;
  itemUrgency = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Urgency" ), mUrgency );
  addItem( itemUrgency, QStringLiteral( "urgency" ) );
  KConfigSkeleton::ItemString  *itemAction;
  itemAction = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Action" ), mAction );
  addItem( itemAction, QStringLiteral( "action" ) );
  KConfigSkeleton::ItemString  *itemSound;
  itemSound = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Sound" ), mSound );
  addItem( itemSound, QStringLiteral( "sound" ) );
}

EventSettings::~EventSettings()
{
}

