// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#ifndef ICONSDATA_H
#define ICONSDATA_H

#include <QObject>

#include "kcmoduledata.h"



class IconsSettings;


class IconsData : public KCModuleData
{
    Q_OBJECT

public:
    explicit IconsData(QObject *parent = nullptr);
    IconsSettings *settings() const;


private:
    IconsSettings *m_settings;

};



#endif
