/****************************************************************************
** Meta object code from reading C++ file 'donotdisturbsettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../donotdisturbsettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'donotdisturbsettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19NotificationManager20DoNotDisturbSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto NotificationManager::DoNotDisturbSettings::qt_create_metaobjectdata<qt_meta_tag_ZN19NotificationManager20DoNotDisturbSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NotificationManager::DoNotDisturbSettings",
        "UntilChanged",
        "",
        "WhenScreensMirroredChanged",
        "WhenScreenSharingChanged",
        "WhenFullscreenChanged",
        "NotificationSoundsMutedChanged",
        "until",
        "isUntilImmutable",
        "whenScreensMirrored",
        "isWhenScreensMirroredImmutable",
        "defaultWhenScreensMirroredValue",
        "whenScreenSharing",
        "isWhenScreenSharingImmutable",
        "defaultWhenScreenSharingValue",
        "whenFullscreen",
        "isWhenFullscreenImmutable",
        "defaultWhenFullscreenValue",
        "notificationSoundsMuted",
        "isNotificationSoundsMutedImmutable",
        "defaultNotificationSoundsMutedValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'UntilChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'WhenScreensMirroredChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'WhenScreenSharingChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'WhenFullscreenChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'NotificationSoundsMutedChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'until'
        QtMocHelpers::PropertyData<QDateTime>(7, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isUntilImmutable'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'whenScreensMirrored'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isWhenScreensMirroredImmutable'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultWhenScreensMirroredValue'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'whenScreenSharing'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isWhenScreenSharingImmutable'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultWhenScreenSharingValue'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'whenFullscreen'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isWhenFullscreenImmutable'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultWhenFullscreenValue'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'notificationSoundsMuted'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isNotificationSoundsMutedImmutable'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNotificationSoundsMutedValue'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DoNotDisturbSettings, qt_meta_tag_ZN19NotificationManager20DoNotDisturbSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject NotificationManager::DoNotDisturbSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationManager20DoNotDisturbSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationManager20DoNotDisturbSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19NotificationManager20DoNotDisturbSettingsE_t>.metaTypes,
    nullptr
} };

void NotificationManager::DoNotDisturbSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DoNotDisturbSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->UntilChanged(); break;
        case 1: _t->WhenScreensMirroredChanged(); break;
        case 2: _t->WhenScreenSharingChanged(); break;
        case 3: _t->WhenFullscreenChanged(); break;
        case 4: _t->NotificationSoundsMutedChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DoNotDisturbSettings::*)()>(_a, &DoNotDisturbSettings::UntilChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DoNotDisturbSettings::*)()>(_a, &DoNotDisturbSettings::WhenScreensMirroredChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DoNotDisturbSettings::*)()>(_a, &DoNotDisturbSettings::WhenScreenSharingChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DoNotDisturbSettings::*)()>(_a, &DoNotDisturbSettings::WhenFullscreenChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DoNotDisturbSettings::*)()>(_a, &DoNotDisturbSettings::NotificationSoundsMutedChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QDateTime*>(_v) = _t->until(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isUntilImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->whenScreensMirrored(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isWhenScreensMirroredImmutable(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->defaultWhenScreensMirroredValue(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->whenScreenSharing(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isWhenScreenSharingImmutable(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->defaultWhenScreenSharingValue(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->whenFullscreen(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isWhenFullscreenImmutable(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->defaultWhenFullscreenValue(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->notificationSoundsMuted(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->isNotificationSoundsMutedImmutable(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->defaultNotificationSoundsMutedValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setUntil(*reinterpret_cast<QDateTime*>(_v)); break;
        case 2: _t->setWhenScreensMirrored(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setWhenScreenSharing(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setWhenFullscreen(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setNotificationSoundsMuted(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *NotificationManager::DoNotDisturbSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NotificationManager::DoNotDisturbSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationManager20DoNotDisturbSettingsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int NotificationManager::DoNotDisturbSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void NotificationManager::DoNotDisturbSettings::UntilChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void NotificationManager::DoNotDisturbSettings::WhenScreensMirroredChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void NotificationManager::DoNotDisturbSettings::WhenScreenSharingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void NotificationManager::DoNotDisturbSettings::WhenFullscreenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void NotificationManager::DoNotDisturbSettings::NotificationSoundsMutedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
