/****************************************************************************
** Meta object code from reading C++ file 'componentchooser.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/kcms/componentchooser/componentchooser.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'componentchooser.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7PairQmlE_t {};
} // unnamed namespace

template <> constexpr inline auto PairQml::qt_create_metaobjectdata<qt_meta_tag_ZN7PairQmlE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PairQml",
        "first",
        "QVariant",
        "second"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'first'
        QtMocHelpers::PropertyData<QVariant>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant | QMC::Final),
        // property 'second'
        QtMocHelpers::PropertyData<QVariant>(3, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant | QMC::Final),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PairQml, qt_meta_tag_ZN7PairQmlE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PairQml::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7PairQmlE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7PairQmlE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7PairQmlE_t>.metaTypes,
    nullptr
} };

void PairQml::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<PairQml *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QVariant*>(_v) = _t->first; break;
        case 1: *reinterpret_cast<QVariant*>(_v) = _t->second; break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN16ComponentChooserE_t {};
} // unnamed namespace

template <> constexpr inline auto ComponentChooser::qt_create_metaobjectdata<qt_meta_tag_ZN16ComponentChooserE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ComponentChooser",
        "indexChanged",
        "",
        "isDefaultsChanged",
        "isSaveNeededChanged",
        "modelChanged",
        "onSaved",
        "currentStorageId",
        "applicationName",
        "applicationIcon",
        "select",
        "index",
        "saveAssociationUnsuportedMimeTypes",
        "saveMimeTypesNotAssociated",
        "applications",
        "ApplicationModel*",
        "isDefaults",
        "unsupportedMimeTypes",
        "mimeTypesNotAssociated",
        "QList<PairQml>",
        "isSaveNeeded"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'indexChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isDefaultsChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isSaveNeededChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modelChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onSaved'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'currentStorageId'
        QtMocHelpers::MethodData<QString() const>(7, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'applicationName'
        QtMocHelpers::MethodData<QString() const>(8, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'applicationIcon'
        QtMocHelpers::MethodData<QString() const>(9, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'select'
        QtMocHelpers::MethodData<void(int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Method 'saveAssociationUnsuportedMimeTypes'
        QtMocHelpers::MethodData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'saveMimeTypesNotAssociated'
        QtMocHelpers::MethodData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'applications'
        QtMocHelpers::PropertyData<ApplicationModel*>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'index'
        QtMocHelpers::PropertyData<int>(11, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'isDefaults'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'unsupportedMimeTypes'
        QtMocHelpers::PropertyData<QStringList>(17, QMetaType::QStringList, QMC::DefaultPropertyFlags, 3),
        // property 'mimeTypesNotAssociated'
        QtMocHelpers::PropertyData<QList<PairQml>>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'isSaveNeeded'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ComponentChooser, qt_meta_tag_ZN16ComponentChooserE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ComponentChooser::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ComponentChooserE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ComponentChooserE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16ComponentChooserE_t>.metaTypes,
    nullptr
} };

void ComponentChooser::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ComponentChooser *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->indexChanged(); break;
        case 1: _t->isDefaultsChanged(); break;
        case 2: _t->isSaveNeededChanged(); break;
        case 3: _t->modelChanged(); break;
        case 4: _t->onSaved(); break;
        case 5: { QString _r = _t->currentStorageId();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 6: { QString _r = _t->applicationName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 7: { QString _r = _t->applicationIcon();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->select((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->saveAssociationUnsuportedMimeTypes(); break;
        case 10: _t->saveMimeTypesNotAssociated(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ComponentChooser::*)()>(_a, &ComponentChooser::indexChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ComponentChooser::*)()>(_a, &ComponentChooser::isDefaultsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ComponentChooser::*)()>(_a, &ComponentChooser::isSaveNeededChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ComponentChooser::*)()>(_a, &ComponentChooser::modelChanged, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ApplicationModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<ApplicationModel**>(_v) = _t->m_model; break;
        case 1: *reinterpret_cast<int*>(_v) = _t->m_index; break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isDefaults(); break;
        case 3: *reinterpret_cast<QStringList*>(_v) = _t->unsupportedMimeTypes(); break;
        case 4: *reinterpret_cast<QList<PairQml>*>(_v) = _t->mimeTypesNotAssociated(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isSaveNeeded(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1:
            if (QtMocHelpers::setProperty(_t->m_index, *reinterpret_cast<int*>(_v)))
                Q_EMIT _t->indexChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *ComponentChooser::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ComponentChooser::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ComponentChooserE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ComponentChooser::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void ComponentChooser::indexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ComponentChooser::isDefaultsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ComponentChooser::isSaveNeededChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ComponentChooser::modelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
