// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "logging.h"


Q_LOGGING_CATEGORY(LOOKANDFEELAUTOSWITCHER, "org.kde.plasma.lookandfeelautoswitcher", QtWarningMsg)

