/****************************************************************************
** Meta object code from reading C++ file 'runnermodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/applets/kicker/runnermodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'runnermodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11RunnerModelE_t {};
} // unnamed namespace

template <> constexpr inline auto RunnerModel::qt_create_metaobjectdata<qt_meta_tag_ZN11RunnerModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "RunnerModel",
        "QML.Element",
        "auto",
        "countChanged",
        "",
        "favoritesModelChanged",
        "appletInterfaceChanged",
        "runnersChanged",
        "queryChanged",
        "queryFinished",
        "queryingChanged",
        "mergeResultsChanged",
        "resultsPresentChanged",
        "requestUpdateQuery",
        "query",
        "anyRunnerFinished",
        "startQuery",
        "modelForRow",
        "RunnerMatchesModel*",
        "row",
        "clear",
        "count",
        "favoritesModel",
        "AbstractModel*",
        "appletInterface",
        "runners",
        "mergeResults",
        "querying",
        "resultsPresent"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'countChanged'
        QtMocHelpers::SignalData<void() const>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'favoritesModelChanged'
        QtMocHelpers::SignalData<void() const>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'appletInterfaceChanged'
        QtMocHelpers::SignalData<void() const>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'runnersChanged'
        QtMocHelpers::SignalData<void() const>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'queryChanged'
        QtMocHelpers::SignalData<void() const>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'queryFinished'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'queryingChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mergeResultsChanged'
        QtMocHelpers::SignalData<void() const>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resultsPresentChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestUpdateQuery'
        QtMocHelpers::SignalData<void(const QString &)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Signal 'anyRunnerFinished'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'startQuery'
        QtMocHelpers::SlotData<void()>(16, 4, QMC::AccessPrivate, QMetaType::Void),
        // Method 'modelForRow'
        QtMocHelpers::MethodData<RunnerMatchesModel *(int)>(17, 4, QMC::AccessPublic, 0x80000000 | 18, {{
            { QMetaType::Int, 19 },
        }}),
        // Method 'clear'
        QtMocHelpers::MethodData<void()>(20, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'count'
        QtMocHelpers::PropertyData<int>(21, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'favoritesModel'
        QtMocHelpers::PropertyData<AbstractModel*>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'appletInterface'
        QtMocHelpers::PropertyData<QObject*>(24, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'runners'
        QtMocHelpers::PropertyData<QStringList>(25, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'query'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'mergeResults'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'querying'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'resultsPresent'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags, 8),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<RunnerModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject RunnerModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11RunnerModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11RunnerModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11RunnerModelE_t>.metaTypes,
    nullptr
} };

void RunnerModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RunnerModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->countChanged(); break;
        case 1: _t->favoritesModelChanged(); break;
        case 2: _t->appletInterfaceChanged(); break;
        case 3: _t->runnersChanged(); break;
        case 4: _t->queryChanged(); break;
        case 5: _t->queryFinished(); break;
        case 6: _t->queryingChanged(); break;
        case 7: _t->mergeResultsChanged(); break;
        case 8: _t->resultsPresentChanged(); break;
        case 9: _t->requestUpdateQuery((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->anyRunnerFinished(); break;
        case 11: _t->startQuery(); break;
        case 12: { RunnerMatchesModel* _r = _t->modelForRow((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<RunnerMatchesModel**>(_a[0]) = std::move(_r); }  break;
        case 13: _t->clear(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (RunnerModel::*)() const>(_a, &RunnerModel::countChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (RunnerModel::*)() const>(_a, &RunnerModel::favoritesModelChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (RunnerModel::*)() const>(_a, &RunnerModel::appletInterfaceChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (RunnerModel::*)() const>(_a, &RunnerModel::runnersChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (RunnerModel::*)() const>(_a, &RunnerModel::queryChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (RunnerModel::*)()>(_a, &RunnerModel::queryFinished, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (RunnerModel::*)()>(_a, &RunnerModel::queryingChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (RunnerModel::*)() const>(_a, &RunnerModel::mergeResultsChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (RunnerModel::*)()>(_a, &RunnerModel::resultsPresentChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (RunnerModel::*)(const QString & )>(_a, &RunnerModel::requestUpdateQuery, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (RunnerModel::*)()>(_a, &RunnerModel::anyRunnerFinished, 10))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< AbstractModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->count(); break;
        case 1: *reinterpret_cast<AbstractModel**>(_v) = _t->favoritesModel(); break;
        case 2: *reinterpret_cast<QObject**>(_v) = _t->appletInterface(); break;
        case 3: *reinterpret_cast<QStringList*>(_v) = _t->runners(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->query(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->mergeResults(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->querying(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->resultsPresent(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setFavoritesModel(*reinterpret_cast<AbstractModel**>(_v)); break;
        case 2: _t->setAppletInterface(*reinterpret_cast<QObject**>(_v)); break;
        case 3: _t->setRunners(*reinterpret_cast<QStringList*>(_v)); break;
        case 4: _t->setQuery(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setMergeResults(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *RunnerModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RunnerModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11RunnerModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int RunnerModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void RunnerModel::countChanged()const
{
    QMetaObject::activate(const_cast< RunnerModel *>(this), &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void RunnerModel::favoritesModelChanged()const
{
    QMetaObject::activate(const_cast< RunnerModel *>(this), &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void RunnerModel::appletInterfaceChanged()const
{
    QMetaObject::activate(const_cast< RunnerModel *>(this), &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void RunnerModel::runnersChanged()const
{
    QMetaObject::activate(const_cast< RunnerModel *>(this), &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void RunnerModel::queryChanged()const
{
    QMetaObject::activate(const_cast< RunnerModel *>(this), &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void RunnerModel::queryFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void RunnerModel::queryingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void RunnerModel::mergeResultsChanged()const
{
    QMetaObject::activate(const_cast< RunnerModel *>(this), &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void RunnerModel::resultsPresentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void RunnerModel::requestUpdateQuery(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void RunnerModel::anyRunnerFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
