/****************************************************************************
** Meta object code from reading C++ file 'historymodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-workspace-6.7.1/klipper/historymodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'historymodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12HistoryModelE_t {};
} // unnamed namespace

template <> constexpr inline auto HistoryModel::qt_create_metaobjectdata<qt_meta_tag_ZN12HistoryModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "HistoryModel",
        "changed",
        "",
        "isTop",
        "actionInvoked",
        "std::shared_ptr<const HistoryItem>",
        "item",
        "checkClipData",
        "QClipboard::Mode",
        "mode",
        "const QMimeData*",
        "data",
        "slotIgnored",
        "slotReceivedEmptyClipboard",
        "RoleType",
        "HistoryItemConstPtrRole",
        "UuidRole",
        "TypeRole",
        "TypeIntRole",
        "ImageUrlRole",
        "ImageSizeRole",
        "StarredRole"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'changed'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'actionInvoked'
        QtMocHelpers::SignalData<void(const std::shared_ptr<const HistoryItem> &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'checkClipData'
        QtMocHelpers::SlotData<void(QClipboard::Mode, const QMimeData *)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 10, 11 },
        }}),
        // Slot 'slotIgnored'
        QtMocHelpers::SlotData<void(QClipboard::Mode)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'slotReceivedEmptyClipboard'
        QtMocHelpers::SlotData<void(QClipboard::Mode)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'RoleType'
        QtMocHelpers::EnumData<enum RoleType>(14, 14, QMC::EnumFlags{}).add({
            {   15, RoleType::HistoryItemConstPtrRole },
            {   16, RoleType::UuidRole },
            {   17, RoleType::TypeRole },
            {   18, RoleType::TypeIntRole },
            {   19, RoleType::ImageUrlRole },
            {   20, RoleType::ImageSizeRole },
            {   21, RoleType::StarredRole },
        }),
    };
    return QtMocHelpers::metaObjectData<HistoryModel, qt_meta_tag_ZN12HistoryModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject HistoryModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12HistoryModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12HistoryModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12HistoryModelE_t>.metaTypes,
    nullptr
} };

void HistoryModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<HistoryModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changed((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->changed(); break;
        case 2: _t->actionInvoked((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<const HistoryItem>>>(_a[1]))); break;
        case 3: _t->checkClipData((*reinterpret_cast<std::add_pointer_t<QClipboard::Mode>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const QMimeData*>>(_a[2]))); break;
        case 4: _t->slotIgnored((*reinterpret_cast<std::add_pointer_t<QClipboard::Mode>>(_a[1]))); break;
        case 5: _t->slotReceivedEmptyClipboard((*reinterpret_cast<std::add_pointer_t<QClipboard::Mode>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (HistoryModel::*)(bool )>(_a, &HistoryModel::changed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (HistoryModel::*)(const std::shared_ptr<const HistoryItem> & )>(_a, &HistoryModel::actionInvoked, 2))
            return;
    }
}

const QMetaObject *HistoryModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *HistoryModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12HistoryModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int HistoryModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void HistoryModel::changed(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 2
void HistoryModel::actionInvoked(const std::shared_ptr<const HistoryItem> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
