/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.secretprompter.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "secretprompteradaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class SecretprompterAdaptor
 */

SecretprompterAdaptor::SecretprompterAdaptor(KSecretPrompter *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

SecretprompterAdaptor::~SecretprompterAdaptor()
{
    // destructor
}

void SecretprompterAdaptor::CreateCollectionPrompt(const QDBusObjectPath &request, const QString &window_id, const QString &activation_token, const QString &collection_name)
{
    // handle method call org.kde.secretprompter.CreateCollectionPrompt
    parent()->CreateCollectionPrompt(request, window_id, activation_token, collection_name);
}

void SecretprompterAdaptor::UnlockCollectionPrompt(const QDBusObjectPath &request, const QString &window_id, const QString &activation_token, const QString &collection_name)
{
    // handle method call org.kde.secretprompter.UnlockCollectionPrompt
    parent()->UnlockCollectionPrompt(request, window_id, activation_token, collection_name);
}


#include "moc_secretprompteradaptor.cpp"
