/****************************************************************************
** Meta object code from reading C++ file 'containment.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-workspace-6.7.1/shell/scripting/containment.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'containment.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18WorkspaceScripting11ContainmentE_t {};
} // unnamed namespace

template <> constexpr inline auto WorkspaceScripting::Containment::qt_create_metaobjectdata<qt_meta_tag_ZN18WorkspaceScripting11ContainmentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WorkspaceScripting::Containment",
        "remove",
        "",
        "showConfigurationInterface",
        "widgetById",
        "QJSValue",
        "paramId",
        "addWidget",
        "v",
        "x",
        "y",
        "w",
        "h",
        "QVariantList",
        "args",
        "widgets",
        "widgetType",
        "version",
        "configKeys",
        "configGroups",
        "globalConfigKeys",
        "globalConfigGroups",
        "currentConfigGroup",
        "wallpaperPlugin",
        "wallpaperMode",
        "locked",
        "type",
        "formFactor",
        "widgetIds",
        "QList<int>",
        "screen",
        "id"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'remove'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showConfigurationInterface'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'widgetById'
        QtMocHelpers::MethodData<QJSValue(const QJSValue &) const>(4, 2, QMC::AccessPublic, 0x80000000 | 5, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Method 'widgetById'
        QtMocHelpers::MethodData<QJSValue() const>(4, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 5),
        // Method 'addWidget'
        QtMocHelpers::MethodData<QJSValue(const QJSValue &, qreal, qreal, qreal, qreal, const QVariantList &)>(7, 2, QMC::AccessPublic, 0x80000000 | 5, {{
            { 0x80000000 | 5, 8 }, { QMetaType::QReal, 9 }, { QMetaType::QReal, 10 }, { QMetaType::QReal, 11 },
            { QMetaType::QReal, 12 }, { 0x80000000 | 13, 14 },
        }}),
        // Method 'addWidget'
        QtMocHelpers::MethodData<QJSValue(const QJSValue &, qreal, qreal, qreal, qreal)>(7, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 5, {{
            { 0x80000000 | 5, 8 }, { QMetaType::QReal, 9 }, { QMetaType::QReal, 10 }, { QMetaType::QReal, 11 },
            { QMetaType::QReal, 12 },
        }}),
        // Method 'addWidget'
        QtMocHelpers::MethodData<QJSValue(const QJSValue &, qreal, qreal, qreal)>(7, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 5, {{
            { 0x80000000 | 5, 8 }, { QMetaType::QReal, 9 }, { QMetaType::QReal, 10 }, { QMetaType::QReal, 11 },
        }}),
        // Method 'addWidget'
        QtMocHelpers::MethodData<QJSValue(const QJSValue &, qreal, qreal)>(7, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 5, {{
            { 0x80000000 | 5, 8 }, { QMetaType::QReal, 9 }, { QMetaType::QReal, 10 },
        }}),
        // Method 'addWidget'
        QtMocHelpers::MethodData<QJSValue(const QJSValue &, qreal)>(7, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 5, {{
            { 0x80000000 | 5, 8 }, { QMetaType::QReal, 9 },
        }}),
        // Method 'addWidget'
        QtMocHelpers::MethodData<QJSValue(const QJSValue &)>(7, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 5, {{
            { 0x80000000 | 5, 8 },
        }}),
        // Method 'addWidget'
        QtMocHelpers::MethodData<QJSValue()>(7, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 5),
        // Method 'widgets'
        QtMocHelpers::MethodData<QJSValue(const QString &) const>(15, 2, QMC::AccessPublic, 0x80000000 | 5, {{
            { QMetaType::QString, 16 },
        }}),
        // Method 'widgets'
        QtMocHelpers::MethodData<QJSValue() const>(15, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 5),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'version'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'configKeys'
        QtMocHelpers::PropertyData<QStringList>(18, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'configGroups'
        QtMocHelpers::PropertyData<QStringList>(19, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'globalConfigKeys'
        QtMocHelpers::PropertyData<QStringList>(20, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'globalConfigGroups'
        QtMocHelpers::PropertyData<QStringList>(21, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'currentConfigGroup'
        QtMocHelpers::PropertyData<QStringList>(22, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'wallpaperPlugin'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'wallpaperMode'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'locked'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'type'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'formFactor'
        QtMocHelpers::PropertyData<QString>(27, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'widgetIds'
        QtMocHelpers::PropertyData<QList<int>>(28, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'screen'
        QtMocHelpers::PropertyData<int>(30, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'id'
        QtMocHelpers::PropertyData<int>(31, QMetaType::Int, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Containment, qt_meta_tag_ZN18WorkspaceScripting11ContainmentE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WorkspaceScripting::Containment::staticMetaObject = { {
    QMetaObject::SuperData::link<Applet::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18WorkspaceScripting11ContainmentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18WorkspaceScripting11ContainmentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18WorkspaceScripting11ContainmentE_t>.metaTypes,
    nullptr
} };

void WorkspaceScripting::Containment::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Containment *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->remove(); break;
        case 1: _t->showConfigurationInterface(); break;
        case 2: { QJSValue _r = _t->widgetById((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 3: { QJSValue _r = _t->widgetById();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 4: { QJSValue _r = _t->addWidget((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 5: { QJSValue _r = _t->addWidget((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 6: { QJSValue _r = _t->addWidget((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 7: { QJSValue _r = _t->addWidget((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 8: { QJSValue _r = _t->addWidget((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 9: { QJSValue _r = _t->addWidget((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 10: { QJSValue _r = _t->addWidget();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 11: { QJSValue _r = _t->widgets((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 12: { QJSValue _r = _t->widgets();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 11:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<int> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->version(); break;
        case 1: *reinterpret_cast<QStringList*>(_v) = _t->configKeys(); break;
        case 2: *reinterpret_cast<QStringList*>(_v) = _t->configGroups(); break;
        case 3: *reinterpret_cast<QStringList*>(_v) = _t->globalConfigKeys(); break;
        case 4: *reinterpret_cast<QStringList*>(_v) = _t->globalConfigGroups(); break;
        case 5: *reinterpret_cast<QStringList*>(_v) = _t->currentConfigGroup(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->wallpaperPlugin(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->wallpaperMode(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->locked(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->type(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->formFactor(); break;
        case 11: *reinterpret_cast<QList<int>*>(_v) = _t->widgetIds(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->screen(); break;
        case 13: *reinterpret_cast<int*>(_v) = _t->id(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 5: _t->setCurrentConfigGroup(*reinterpret_cast<QStringList*>(_v)); break;
        case 6: _t->setWallpaperPlugin(*reinterpret_cast<QString*>(_v)); break;
        case 7: _t->setWallpaperMode(*reinterpret_cast<QString*>(_v)); break;
        case 8: _t->setLocked(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setScreen(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *WorkspaceScripting::Containment::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WorkspaceScripting::Containment::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18WorkspaceScripting11ContainmentE_t>.strings))
        return static_cast<void*>(this);
    return Applet::qt_metacast(_clname);
}

int WorkspaceScripting::Containment::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Applet::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}
QT_WARNING_POP
