/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.krunner.App.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef KRUNNER_INTERFACE_H
#define KRUNNER_INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.krunner.App
 */
class OrgKdeKrunnerAppInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.krunner.App"; }

public:
    OrgKdeKrunnerAppInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeKrunnerAppInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> display()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("display"), argumentList);
    }

    inline QDBusPendingReply<> displaySingleRunner(const QString &runnerName)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(runnerName);
        return asyncCallWithArgumentList(QStringLiteral("displaySingleRunner"), argumentList);
    }

    inline QDBusPendingReply<> displayWithClipboardContents()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("displayWithClipboardContents"), argumentList);
    }

    inline QDBusPendingReply<> query(const QString &term)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(term);
        return asyncCallWithArgumentList(QStringLiteral("query"), argumentList);
    }

    inline QDBusPendingReply<> querySingleRunner(const QString &runnerName, const QString &term)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(runnerName) << QVariant::fromValue(term);
        return asyncCallWithArgumentList(QStringLiteral("querySingleRunner"), argumentList);
    }

    inline QDBusPendingReply<> toggleDisplay()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("toggleDisplay"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace kde {
    namespace krunner {
      using App = ::OrgKdeKrunnerAppInterface;
    }
  }
}

#endif
