/****************************************************************************
** Meta object code from reading C++ file 'fontinstadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "fontinstadaptor.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fontinstadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15FontinstAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto FontinstAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN15FontinstAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FontinstAdaptor",
        "D-Bus Interface",
        "org.kde.fontinst",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.fontinst\">\n    <signal name=\"fontLi"
        "st\">\n      <arg direction=\"out\" type=\"i\" name=\"pid\"/>\n   "
        "   <arg direction=\"out\" type=\"a(ba(sa(utba(ssi))))\" name=\"fam"
        "ilies\"/>\n      <annotation value=\"const QList&lt;KFI::Families&"
        "gt; &amp;\" name=\"org.qtproject.QtDBus.QtTypeName.Out1\"/>\n    <"
        "/signal>\n    <signal name=\"status\">\n      <arg direction=\"out"
        "\" type=\"i\" name=\"pid\"/>\n      <arg direction=\"out\" type=\""
        "i\" name=\"value\"/>\n    </signal>\n    <signal name=\"fontStat\""
        ">\n      <arg direction=\"out\" type=\"i\" name=\"pid\"/>\n      <"
        "arg direction=\"out\" type=\"(sa(utba(ssi)))\" name=\"family\"/>\n"
        "      <annotation value=\"const KFI::Family &amp;\" name=\"org.qtp"
        "roject.QtDBus.QtTypeName.Out1\"/>\n    </signal>\n    <signal name"
        "=\"fontsAdded\">\n      <arg direction=\"out\" type=\"(ba(sa(utba("
        "ssi))))\" name=\"families\"/>\n      <annotation value=\"const KFI"
        "::Families &amp;\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>"
        "\n    </signal>\n    <signal name=\"fontsRemoved\">\n      <arg di"
        "rection=\"out\" type=\"(ba(sa(utba(ssi))))\" name=\"families\"/>\n"
        "      <annotation value=\"const KFI::Families &amp;\" name=\"org.q"
        "tproject.QtDBus.QtTypeName.Out0\"/>\n    </signal>\n    <method na"
        "me=\"list\">\n      <arg direction=\"in\" type=\"i\" name=\"folder"
        "s\"/>\n      <arg direction=\"in\" type=\"i\" name=\"pid\"/>\n    "
        "  <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.No"
        "Reply\"/>\n    </method>\n    <method name=\"statFont\">\n      <a"
        "nnotation value=\"KFI::Family\" name=\"org.qtproject.QtDBus.QtType"
        "Name.In0\"/>\n      <arg direction=\"in\" type=\"s\" name=\"name\""
        "/>\n      <arg direction=\"in\" type=\"i\" name=\"folders\"/>\n   "
        "   <arg direction=\"in\" type=\"i\" name=\"pid\"/>\n      <annotat"
        "ion value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
        "    </method>\n    <method name=\"install\">\n      <arg direction"
        "=\"in\" type=\"s\" name=\"file\"/>\n      <arg direction=\"in\" ty"
        "pe=\"b\" name=\"createAfm\"/>\n      <arg direction=\"in\" type=\""
        "b\" name=\"toSystem\"/>\n      <arg direction=\"in\" type=\"i\" na"
        "me=\"pid\"/>\n      <arg direction=\"in\" type=\"b\" name=\"checkC"
        "onfig\"/>\n      <annotation value=\"true\" name=\"org.freedesktop"
        ".DBus.Method.NoReply\"/>\n    </method>\n    <method name=\"uninst"
        "all\">\n      <arg direction=\"in\" type=\"s\" name=\"family\"/>\n"
        "      <arg direction=\"in\" type=\"u\" name=\"style\"/>\n      <ar"
        "g direction=\"in\" type=\"b\" name=\"fromSystem\"/>\n      <arg di"
        "rection=\"in\" type=\"i\" name=\"pid\"/>\n      <arg direction=\"i"
        "n\" type=\"b\" name=\"checkConfig\"/>\n      <annotation value=\"t"
        "rue\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n    </method"
        ">\n    <method name=\"uninstall\">\n      <arg direction=\"in\" ty"
        "pe=\"s\" name=\"name\"/>\n      <arg direction=\"in\" type=\"b\" n"
        "ame=\"fromSystem\"/>\n      <arg direction=\"in\" type=\"i\" name="
        "\"pid\"/>\n      <arg direction=\"in\" type=\"b\" name=\"checkConf"
        "ig\"/>\n      <annotation value=\"true\" name=\"org.freedesktop.DB"
        "us.Method.NoReply\"/>\n    </method>\n    <method name=\"move\">\n"
        "      <arg direction=\"in\" type=\"s\" name=\"family\"/>\n      <a"
        "rg direction=\"in\" type=\"u\" name=\"style\"/>\n      <arg direct"
        "ion=\"in\" type=\"b\" name=\"toSystem\"/>\n      <arg direction=\""
        "in\" type=\"i\" name=\"pid\"/>\n      <arg direction=\"in\" type=\""
        "b\" name=\"checkConfig\"/>\n      <annotation value=\"true\" name="
        "\"org.freedesktop.DBus.Method.NoReply\"/>\n    </method>\n    <met"
        "hod name=\"enable\">\n      <arg direction=\"in\" type=\"s\" name="
        "\"family\"/>\n      <arg direction=\"in\" type=\"u\" name=\"style\""
        "/>\n      <arg direction=\"in\" type=\"b\" name=\"inSystem\"/>\n  "
        "    <arg direction=\"in\" type=\"i\" name=\"pid\"/>\n      <arg di"
        "rection=\"in\" type=\"b\" name=\"checkConfig\"/>\n      <annotatio"
        "n value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n "
        "   </method>\n    <method name=\"disable\">\n      <arg direction="
        "\"in\" type=\"s\" name=\"family\"/>\n      <arg direction=\"in\" t"
        "ype=\"u\" name=\"style\"/>\n      <arg direction=\"in\" type=\"b\""
        " name=\"inSystem\"/>\n      <arg direction=\"in\" type=\"i\" name="
        "\"pid\"/>\n      <arg direction=\"in\" type=\"b\" name=\"checkConf"
        "ig\"/>\n      <annotation value=\"true\" name=\"org.freedesktop.DB"
        "us.Method.NoReply\"/>\n    </method>\n    <method name=\"removeFil"
        "e\">\n      <arg direction=\"in\" type=\"s\" name=\"family\"/>\n  "
        "    <arg direction=\"in\" type=\"u\" name=\"style\"/>\n      <arg "
        "direction=\"in\" type=\"s\" name=\"file\"/>\n      <arg direction="
        "\"in\" type=\"b\" name=\"fromSystem\"/>\n      <arg direction=\"in"
        "\" type=\"i\" name=\"pid\"/>\n      <arg direction=\"in\" type=\"b"
        "\" name=\"checkConfig\"/>\n      <annotation value=\"true\" name=\""
        "org.freedesktop.DBus.Method.NoReply\"/>\n    </method>\n    <metho"
        "d name=\"reconfigure\">\n      <arg direction=\"in\" type=\"i\" na"
        "me=\"pid\"/>\n      <arg direction=\"in\" type=\"b\" name=\"force\""
        "/>\n      <annotation value=\"true\" name=\"org.freedesktop.DBus.M"
        "ethod.NoReply\"/>\n    </method>\n    <method name=\"saveDisabled\""
        "/>\n    <method name=\"folderName\">\n      <arg direction=\"in\" "
        "type=\"b\" name=\"sys\"/>\n      <arg direction=\"out\" type=\"s\""
        "/>\n    </method>\n  </interface>\n",
        "fontList",
        "",
        "pid",
        "QList<KFI::Families>",
        "families",
        "fontStat",
        "KFI::Family",
        "family",
        "fontsAdded",
        "KFI::Families",
        "fontsRemoved",
        "status",
        "value",
        "disable",
        "Q_NOREPLY",
        "style",
        "inSystem",
        "checkConfig",
        "enable",
        "folderName",
        "sys",
        "install",
        "file",
        "createAfm",
        "toSystem",
        "list",
        "folders",
        "move",
        "reconfigure",
        "force",
        "removeFile",
        "fromSystem",
        "saveDisabled",
        "statFont",
        "name",
        "uninstall"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'fontList'
        QtMocHelpers::SignalData<void(int, const QList<KFI::Families> &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Signal 'fontStat'
        QtMocHelpers::SignalData<void(int, const KFI::Family &)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 }, { 0x80000000 | 11, 12 },
        }}),
        // Signal 'fontsAdded'
        QtMocHelpers::SignalData<void(const KFI::Families &)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 9 },
        }}),
        // Signal 'fontsRemoved'
        QtMocHelpers::SignalData<void(const KFI::Families &)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 9 },
        }}),
        // Signal 'status'
        QtMocHelpers::SignalData<void(int, int)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 }, { QMetaType::Int, 17 },
        }}),
        // Slot 'disable'
        QtMocHelpers::SlotData<void(const QString &, uint, bool, int, bool)>(18, 19, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::UInt, 20 }, { QMetaType::Bool, 21 }, { QMetaType::Int, 7 },
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'enable'
        QtMocHelpers::SlotData<void(const QString &, uint, bool, int, bool)>(23, 19, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::UInt, 20 }, { QMetaType::Bool, 21 }, { QMetaType::Int, 7 },
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'folderName'
        QtMocHelpers::SlotData<QString(bool)>(24, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'install'
        QtMocHelpers::SlotData<void(const QString &, bool, bool, int, bool)>(26, 19, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 27 }, { QMetaType::Bool, 28 }, { QMetaType::Bool, 29 }, { QMetaType::Int, 7 },
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'list'
        QtMocHelpers::SlotData<void(int, int)>(30, 19, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 31 }, { QMetaType::Int, 7 },
        }}),
        // Slot 'move'
        QtMocHelpers::SlotData<void(const QString &, uint, bool, int, bool)>(32, 19, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::UInt, 20 }, { QMetaType::Bool, 29 }, { QMetaType::Int, 7 },
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'reconfigure'
        QtMocHelpers::SlotData<void(int, bool)>(33, 19, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 }, { QMetaType::Bool, 34 },
        }}),
        // Slot 'removeFile'
        QtMocHelpers::SlotData<void(const QString &, uint, const QString &, bool, int, bool)>(35, 19, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::UInt, 20 }, { QMetaType::QString, 27 }, { QMetaType::Bool, 36 },
            { QMetaType::Int, 7 }, { QMetaType::Bool, 22 },
        }}),
        // Slot 'saveDisabled'
        QtMocHelpers::SlotData<void()>(37, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'statFont'
        QtMocHelpers::SlotData<void(const QString &, int, int)>(38, 19, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 39 }, { QMetaType::Int, 31 }, { QMetaType::Int, 7 },
        }}),
        // Slot 'uninstall'
        QtMocHelpers::SlotData<void(const QString &, bool, int, bool)>(40, 19, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 39 }, { QMetaType::Bool, 36 }, { QMetaType::Int, 7 }, { QMetaType::Bool, 22 },
        }}),
        // Slot 'uninstall'
        QtMocHelpers::SlotData<void(const QString &, uint, bool, int, bool)>(40, 19, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::UInt, 20 }, { QMetaType::Bool, 36 }, { QMetaType::Int, 7 },
            { QMetaType::Bool, 22 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<FontinstAdaptor, qt_meta_tag_ZN15FontinstAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject FontinstAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15FontinstAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15FontinstAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15FontinstAdaptorE_t>.metaTypes,
    nullptr
} };

void FontinstAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FontinstAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->fontList((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<KFI::Families>>>(_a[2]))); break;
        case 1: _t->fontStat((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KFI::Family>>(_a[2]))); break;
        case 2: _t->fontsAdded((*reinterpret_cast<std::add_pointer_t<KFI::Families>>(_a[1]))); break;
        case 3: _t->fontsRemoved((*reinterpret_cast<std::add_pointer_t<KFI::Families>>(_a[1]))); break;
        case 4: _t->status((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 5: _t->disable((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 6: _t->enable((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 7: { QString _r = _t->folderName((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->install((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 9: _t->list((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 10: _t->move((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 11: _t->reconfigure((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 12: _t->removeFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6]))); break;
        case 13: _t->saveDisabled(); break;
        case 14: _t->statFont((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 15: _t->uninstall((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 16: _t->uninstall((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FontinstAdaptor::*)(int , const QList<KFI::Families> & )>(_a, &FontinstAdaptor::fontList, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FontinstAdaptor::*)(int , const KFI::Family & )>(_a, &FontinstAdaptor::fontStat, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FontinstAdaptor::*)(const KFI::Families & )>(_a, &FontinstAdaptor::fontsAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FontinstAdaptor::*)(const KFI::Families & )>(_a, &FontinstAdaptor::fontsRemoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FontinstAdaptor::*)(int , int )>(_a, &FontinstAdaptor::status, 4))
            return;
    }
}

const QMetaObject *FontinstAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FontinstAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15FontinstAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int FontinstAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void FontinstAdaptor::fontList(int _t1, const QList<KFI::Families> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void FontinstAdaptor::fontStat(int _t1, const KFI::Family & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void FontinstAdaptor::fontsAdded(const KFI::Families & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void FontinstAdaptor::fontsRemoved(const KFI::Families & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void FontinstAdaptor::status(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}
QT_WARNING_POP
