/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kuiserver.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "kuiserveradaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class KuiserverAdaptor
 */

KuiserverAdaptor::KuiserverAdaptor(NotificationManager::JobsModelPrivate *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

KuiserverAdaptor::~KuiserverAdaptor()
{
    // destructor
}

void KuiserverAdaptor::emitJobUrlsChanged()
{
    // handle method call org.kde.kuiserver.emitJobUrlsChanged
    parent()->emitJobUrlsChanged();
}

void KuiserverAdaptor::registerService(const QString &service, const QString &objectPath)
{
    // handle method call org.kde.kuiserver.registerService
    parent()->registerService(service, objectPath);
}

QStringList KuiserverAdaptor::registeredJobContacts()
{
    // handle method call org.kde.kuiserver.registeredJobContacts
    return parent()->registeredJobContacts();
}

bool KuiserverAdaptor::requiresJobTracker()
{
    // handle method call org.kde.kuiserver.requiresJobTracker
    return parent()->requiresJobTracker();
}


#include "moc_kuiserveradaptor.cpp"
