/****************************************************************************
** Meta object code from reading C++ file 'jobviewv2adaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "jobviewv2adaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'jobviewv2adaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16JobViewV2AdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto JobViewV2Adaptor::qt_create_metaobjectdata<qt_meta_tag_ZN16JobViewV2AdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "JobViewV2Adaptor",
        "D-Bus Interface",
        "org.kde.JobViewV2",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.JobViewV2\">\n    <method name=\"termi"
        "nate\">\n      <arg direction=\"in\" type=\"s\" name=\"errorMessag"
        "e\"/>\n      <annotation value=\"true\" name=\"org.freedesktop.DBu"
        "s.Method.NoReply\"/>\n    </method>\n    <method name=\"setSuspend"
        "ed\">\n      <arg direction=\"in\" type=\"b\" name=\"suspended\"/>"
        "\n      <annotation value=\"true\" name=\"org.freedesktop.DBus.Met"
        "hod.NoReply\"/>\n    </method>\n    <method name=\"setTotalAmount\""
        ">\n      <arg direction=\"in\" type=\"t\" name=\"amount\"/>\n     "
        " <arg direction=\"in\" type=\"s\" name=\"unit\"/>\n      <annotati"
        "on value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
        "    </method>\n    <method name=\"setProcessedAmount\">\n      <ar"
        "g direction=\"in\" type=\"t\" name=\"amount\"/>\n      <arg direct"
        "ion=\"in\" type=\"s\" name=\"unit\"/>\n      <annotation value=\"t"
        "rue\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n    </method"
        ">\n    <method name=\"setPercent\">\n      <arg direction=\"in\" t"
        "ype=\"u\" name=\"percent\"/>\n      <annotation value=\"true\" nam"
        "e=\"org.freedesktop.DBus.Method.NoReply\"/>\n    </method>\n    <m"
        "ethod name=\"setSpeed\">\n      <arg direction=\"in\" type=\"t\" n"
        "ame=\"bytesPerSecond\"/>\n      <annotation value=\"true\" name=\""
        "org.freedesktop.DBus.Method.NoReply\"/>\n    </method>\n    <metho"
        "d name=\"setInfoMessage\">\n      <arg direction=\"in\" type=\"s\""
        " name=\"message\"/>\n      <annotation value=\"true\" name=\"org.f"
        "reedesktop.DBus.Method.NoReply\"/>\n    </method>\n    <method nam"
        "e=\"setDescriptionField\">\n      <arg direction=\"in\" type=\"u\""
        " name=\"number\"/>\n      <arg direction=\"in\" type=\"s\" name=\""
        "name\"/>\n      <arg direction=\"in\" type=\"s\" name=\"value\"/>\n"
        "      <arg direction=\"out\" type=\"b\" name=\"res\"/>\n    </meth"
        "od>\n    <method name=\"clearDescriptionField\">\n      <arg direc"
        "tion=\"in\" type=\"u\" name=\"number\"/>\n      <annotation value="
        "\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n    </met"
        "hod>\n    <method name=\"setDestUrl\">\n      <arg direction=\"in\""
        " type=\"v\" name=\"destUrl\"/>\n      <annotation value=\"true\" n"
        "ame=\"org.freedesktop.DBus.Method.NoReply\"/>\n    </method>\n    "
        "<method name=\"setError\">\n      <arg direction=\"in\" type=\"u\""
        " name=\"errorCode\"/>\n      <annotation value=\"true\" name=\"org"
        ".freedesktop.DBus.Method.NoReply\"/>\n    </method>\n    <signal n"
        "ame=\"suspendRequested\"/>\n    <signal name=\"resumeRequested\"/>"
        "\n    <signal name=\"cancelRequested\"/>\n  </interface>\n",
        "cancelRequested",
        "",
        "resumeRequested",
        "suspendRequested",
        "clearDescriptionField",
        "Q_NOREPLY",
        "number",
        "setDescriptionField",
        "name",
        "value",
        "setDestUrl",
        "QDBusVariant",
        "destUrl",
        "setError",
        "errorCode",
        "setInfoMessage",
        "message",
        "setPercent",
        "percent",
        "setProcessedAmount",
        "amount",
        "unit",
        "setSpeed",
        "bytesPerSecond",
        "setSuspended",
        "suspended",
        "setTotalAmount",
        "terminate",
        "errorMessage"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'cancelRequested'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resumeRequested'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'suspendRequested'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearDescriptionField'
        QtMocHelpers::SlotData<void(uint)>(9, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 11 },
        }}),
        // Slot 'setDescriptionField'
        QtMocHelpers::SlotData<bool(uint, const QString &, const QString &)>(12, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::UInt, 11 }, { QMetaType::QString, 13 }, { QMetaType::QString, 14 },
        }}),
        // Slot 'setDestUrl'
        QtMocHelpers::SlotData<void(const QDBusVariant &)>(15, 10, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'setError'
        QtMocHelpers::SlotData<void(uint)>(18, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 19 },
        }}),
        // Slot 'setInfoMessage'
        QtMocHelpers::SlotData<void(const QString &)>(20, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'setPercent'
        QtMocHelpers::SlotData<void(uint)>(22, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 23 },
        }}),
        // Slot 'setProcessedAmount'
        QtMocHelpers::SlotData<void(qulonglong, const QString &)>(24, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 25 }, { QMetaType::QString, 26 },
        }}),
        // Slot 'setSpeed'
        QtMocHelpers::SlotData<void(qulonglong)>(27, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 28 },
        }}),
        // Slot 'setSuspended'
        QtMocHelpers::SlotData<void(bool)>(29, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 30 },
        }}),
        // Slot 'setTotalAmount'
        QtMocHelpers::SlotData<void(qulonglong, const QString &)>(31, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 25 }, { QMetaType::QString, 26 },
        }}),
        // Slot 'terminate'
        QtMocHelpers::SlotData<void(const QString &)>(32, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 33 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<JobViewV2Adaptor, qt_meta_tag_ZN16JobViewV2AdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject JobViewV2Adaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16JobViewV2AdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16JobViewV2AdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16JobViewV2AdaptorE_t>.metaTypes,
    nullptr
} };

void JobViewV2Adaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<JobViewV2Adaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->cancelRequested(); break;
        case 1: _t->resumeRequested(); break;
        case 2: _t->suspendRequested(); break;
        case 3: _t->clearDescriptionField((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 4: { bool _r = _t->setDescriptionField((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->setDestUrl((*reinterpret_cast<std::add_pointer_t<QDBusVariant>>(_a[1]))); break;
        case 6: _t->setError((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 7: _t->setInfoMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->setPercent((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 9: _t->setProcessedAmount((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 10: _t->setSpeed((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 11: _t->setSuspended((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->setTotalAmount((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 13: _t->terminate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (JobViewV2Adaptor::*)()>(_a, &JobViewV2Adaptor::cancelRequested, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (JobViewV2Adaptor::*)()>(_a, &JobViewV2Adaptor::resumeRequested, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (JobViewV2Adaptor::*)()>(_a, &JobViewV2Adaptor::suspendRequested, 2))
            return;
    }
}

const QMetaObject *JobViewV2Adaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *JobViewV2Adaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16JobViewV2AdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int JobViewV2Adaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void JobViewV2Adaptor::cancelRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void JobViewV2Adaptor::resumeRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void JobViewV2Adaptor::suspendRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
