// This file is generated by kconfig_compiler_kf6 from fontsaasettingsbase.kcfg.
// All changes you do to this file will be lost.

#include "fontsaasettingsbase.h"

FontsAASettingsBase::FontsAASettingsBase( QObject *parent )
  : KConfigSkeleton( QStringLiteral( "kcmfonts" ) )
{
  setParent(parent);
  KConfigCompilerSignallingItem::NotifyFunction notifyFunction = static_cast<KConfigCompilerSignallingItem::NotifyFunction>(&FontsAASettingsBase::itemChanged);

  setCurrentGroup( QStringLiteral( "General" ) );

  KConfigCompilerSignallingItem  *itemForceFontDPI;
  KConfigSkeleton::ItemUInt  *innerItemForceFontDPI;
  innerItemForceFontDPI = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "forceFontDPI" ), mForceFontDPI, 0 );
  itemForceFontDPI = new KConfigCompilerSignallingItem(innerItemForceFontDPI, this, notifyFunction, signalForceFontDPIChanged);
  itemForceFontDPI->setWriteFlags(KConfigBase::Notify);
  addItem( itemForceFontDPI, QStringLiteral( "forceFontDPI" ) );
}

uint FontsAASettingsBase::defaultForceFontDPIValue_helper() const
{

  return 0;
}

FontsAASettingsBase::~FontsAASettingsBase()
{
}


void FontsAASettingsBase::itemChanged(quint64 signalFlag) {

  switch (signalFlag) {
  case signalForceFontDPIChanged:
    Q_EMIT forceFontDPIChanged();
    break;
  }
}
