/****************************************************************************
** Meta object code from reading C++ file 'secretprompteradaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "secretprompteradaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'secretprompteradaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21SecretprompterAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto SecretprompterAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN21SecretprompterAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SecretprompterAdaptor",
        "D-Bus Interface",
        "org.kde.secretprompter",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.secretprompter\">\n    <method name=\""
        "UnlockCollectionPrompt\">\n      <arg direction=\"in\" type=\"o\" "
        "name=\"request\"/>\n      <arg direction=\"in\" type=\"s\" name=\""
        "window_id\"/>\n      <arg direction=\"in\" type=\"s\" name=\"activ"
        "ation_token\"/>\n      <arg direction=\"in\" type=\"s\" name=\"col"
        "lection_name\"/>\n    </method>\n    <method name=\"CreateCollecti"
        "onPrompt\">\n      <arg direction=\"in\" type=\"o\" name=\"request"
        "\"/>\n      <arg direction=\"in\" type=\"s\" name=\"window_id\"/>\n"
        "      <arg direction=\"in\" type=\"s\" name=\"activation_token\"/>"
        "\n      <arg direction=\"in\" type=\"s\" name=\"collection_name\"/"
        ">\n    </method>\n  </interface>\n",
        "CreateCollectionPrompt",
        "",
        "QDBusObjectPath",
        "request",
        "window_id",
        "activation_token",
        "collection_name",
        "UnlockCollectionPrompt"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'CreateCollectionPrompt'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QString &, const QString &, const QString &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::QString, 9 }, { QMetaType::QString, 10 }, { QMetaType::QString, 11 },
        }}),
        // Slot 'UnlockCollectionPrompt'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QString &, const QString &, const QString &)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::QString, 9 }, { QMetaType::QString, 10 }, { QMetaType::QString, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<SecretprompterAdaptor, qt_meta_tag_ZN21SecretprompterAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject SecretprompterAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21SecretprompterAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21SecretprompterAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21SecretprompterAdaptorE_t>.metaTypes,
    nullptr
} };

void SecretprompterAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SecretprompterAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->CreateCollectionPrompt((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 1: _t->UnlockCollectionPrompt((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        default: ;
        }
    }
}

const QMetaObject *SecretprompterAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SecretprompterAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21SecretprompterAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int SecretprompterAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}
QT_WARNING_POP
