// This file is autogenerated. Changes will be overwritten.
#include "EJRQKI7XPS/moc_badgesettings.cpp"
#include "EJRQKI7XPS/moc_behaviorsettings.cpp"
#include "EJRQKI7XPS/moc_donotdisturbsettings.cpp"
#include "EJRQKI7XPS/moc_jobsettings.cpp"
#include "EJRQKI7XPS/moc_notificationsettings.cpp"
#include "EWIEGA46WW/moc_fullscreentracker_p.cpp"
#include "EWIEGA46WW/moc_notificationsmodel.cpp"
#include "EWIEGA46WW/moc_portalnotificationsmodel.cpp"
