// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "containmentlayoutmanager_debug.h"


Q_LOGGING_CATEGORY(CONTAINMENTLAYOUTMANAGER_DEBUG, "org.kde.plasma.containmentlayoutmanager", QtInfoMsg)

