/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kappmenu.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef APPMENUADAPTOR_H
#define APPMENUADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "appmenu_dbus.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.kappmenu
 */
class AppmenuAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.kappmenu")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.kappmenu\">\n"
"    <method name=\"showMenu\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"x\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"y\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"service\"/>\n"
"      <arg direction=\"in\" type=\"o\" name=\"objectPath\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"actionId\"/>\n"
"    </method>\n"
"    <method name=\"reconfigure\"/>\n"
"    <signal name=\"reconfigured\"/>\n"
"    <signal name=\"showRequest\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"service\"/>\n"
"      <arg direction=\"out\" type=\"o\" name=\"objectPath\"/>\n"
"      <arg direction=\"out\" type=\"i\" name=\"actionId\"/>\n"
"    </signal>\n"
"    <signal name=\"menuShown\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"service\"/>\n"
"      <arg direction=\"out\" type=\"o\" name=\"objectPath\"/>\n"
"    </signal>\n"
"    <signal name=\"menuHidden\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"service\"/>\n"
"      <arg direction=\"out\" type=\"o\" name=\"objectPath\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    AppmenuAdaptor(AppmenuDBus *parent);
    ~AppmenuAdaptor() override;

    inline AppmenuDBus *parent() const
    { return static_cast<AppmenuDBus *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void reconfigure();
    void showMenu(int x, int y, const QString &service, const QDBusObjectPath &objectPath, int actionId);
Q_SIGNALS: // SIGNALS
    void menuHidden(const QString &service, const QDBusObjectPath &objectPath);
    void menuShown(const QString &service, const QDBusObjectPath &objectPath);
    void reconfigured();
    void showRequest(const QString &service, const QDBusObjectPath &objectPath, int actionId);
};

#endif
