/****************************************************************************
** Meta object code from reading C++ file 'plasma_wallpaper_imageplugin_static_plasma_wallpaper_image.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../plasma_wallpaper_imageplugin_static_plasma_wallpaper_image.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'plasma_wallpaper_imageplugin_static_plasma_wallpaper_image.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN29MaximizedWindowMonitorForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto MaximizedWindowMonitorForeign::qt_create_metaobjectdata<qt_meta_tag_ZN29MaximizedWindowMonitorForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MaximizedWindowMonitorForeign",
        "QML.Foreign",
        "MaximizedWindowMonitor",
        "QML.Element"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    2 },
    });
    return QtMocHelpers::metaObjectData<MaximizedWindowMonitorForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject MaximizedWindowMonitorForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29MaximizedWindowMonitorForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29MaximizedWindowMonitorForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN29MaximizedWindowMonitorForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN17MediaProxyForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto MediaProxyForeign::qt_create_metaobjectdata<qt_meta_tag_ZN17MediaProxyForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MediaProxyForeign",
        "QML.Foreign",
        "MediaProxy",
        "QML.Element"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    2 },
    });
    return QtMocHelpers::metaObjectData<MediaProxyForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject MediaProxyForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17MediaProxyForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17MediaProxyForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17MediaProxyForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN23DayNightSnapshotForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto DayNightSnapshotForeign::qt_create_metaobjectdata<qt_meta_tag_ZN23DayNightSnapshotForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DayNightSnapshotForeign",
        "QML.Foreign",
        "DayNightSnapshot",
        "QML.Element",
        "dayNightSnapshot"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<DayNightSnapshotForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DayNightSnapshotForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23DayNightSnapshotForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23DayNightSnapshotForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23DayNightSnapshotForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN24DayNightWallpaperForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto DayNightWallpaperForeign::qt_create_metaobjectdata<qt_meta_tag_ZN24DayNightWallpaperForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DayNightWallpaperForeign",
        "QML.Foreign",
        "DayNightWallpaper",
        "QML.Element"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    2 },
    });
    return QtMocHelpers::metaObjectData<DayNightWallpaperForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DayNightWallpaperForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24DayNightWallpaperForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24DayNightWallpaperForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24DayNightWallpaperForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN19ImageBackendForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto ImageBackendForeign::qt_create_metaobjectdata<qt_meta_tag_ZN19ImageBackendForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ImageBackendForeign",
        "QML.Foreign",
        "ImageBackend",
        "QML.Element"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    2 },
    });
    return QtMocHelpers::metaObjectData<ImageBackendForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ImageBackendForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19ImageBackendForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19ImageBackendForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19ImageBackendForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN21TransientImageForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto TransientImageForeign::qt_create_metaobjectdata<qt_meta_tag_ZN21TransientImageForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TransientImageForeign",
        "QML.Foreign",
        "TransientImage",
        "QML.Element"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    2 },
    });
    return QtMocHelpers::metaObjectData<TransientImageForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject TransientImageForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21TransientImageForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21TransientImageForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21TransientImageForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN21BackgroundTypeForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto BackgroundTypeForeign::qt_create_metaobjectdata<qt_meta_tag_ZN21BackgroundTypeForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BackgroundTypeForeign",
        "QML.Foreign",
        "BackgroundType",
        "QML.ForeignIsNamespace",
        "true",
        "QML.Element"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    2 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN21BackgroundTypeForeignE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN21BackgroundTypeForeignE =
    BackgroundTypeForeign::qt_create_metaobjectdata<qt_meta_tag_ZN21BackgroundTypeForeignE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN21BackgroundTypeForeignE =
    qt_staticMetaObjectContent_ZN21BackgroundTypeForeignE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN21BackgroundTypeForeignE =
    qt_staticMetaObjectContent_ZN21BackgroundTypeForeignE.relocatingData;

Q_CONSTINIT const QMetaObject BackgroundTypeForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN21BackgroundTypeForeignE.stringdata,
    qt_staticMetaObjectStaticContent_ZN21BackgroundTypeForeignE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN21BackgroundTypeForeignE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN18DynamicModeForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto DynamicModeForeign::qt_create_metaobjectdata<qt_meta_tag_ZN18DynamicModeForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DynamicModeForeign",
        "QML.Foreign",
        "DynamicMode",
        "QML.ForeignIsNamespace",
        "true",
        "QML.Element"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    2 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN18DynamicModeForeignE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN18DynamicModeForeignE =
    DynamicModeForeign::qt_create_metaobjectdata<qt_meta_tag_ZN18DynamicModeForeignE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN18DynamicModeForeignE =
    qt_staticMetaObjectContent_ZN18DynamicModeForeignE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN18DynamicModeForeignE =
    qt_staticMetaObjectContent_ZN18DynamicModeForeignE.relocatingData;

Q_CONSTINIT const QMetaObject DynamicModeForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN18DynamicModeForeignE.stringdata,
    qt_staticMetaObjectStaticContent_ZN18DynamicModeForeignE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN18DynamicModeForeignE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN18SortingModeForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto SortingModeForeign::qt_create_metaobjectdata<qt_meta_tag_ZN18SortingModeForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SortingModeForeign",
        "QML.Foreign",
        "SortingMode",
        "QML.ForeignIsNamespace",
        "true",
        "QML.Element"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    2 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN18SortingModeForeignE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN18SortingModeForeignE =
    SortingModeForeign::qt_create_metaobjectdata<qt_meta_tag_ZN18SortingModeForeignE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN18SortingModeForeignE =
    qt_staticMetaObjectContent_ZN18SortingModeForeignE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN18SortingModeForeignE =
    qt_staticMetaObjectContent_ZN18SortingModeForeignE.relocatingData;

Q_CONSTINIT const QMetaObject SortingModeForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN18SortingModeForeignE.stringdata,
    qt_staticMetaObjectStaticContent_ZN18SortingModeForeignE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN18SortingModeForeignE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN15ProviderForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto ProviderForeign::qt_create_metaobjectdata<qt_meta_tag_ZN15ProviderForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ProviderForeign",
        "QML.Foreign",
        "Provider",
        "QML.ForeignIsNamespace",
        "true",
        "QML.Element"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    2 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN15ProviderForeignE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN15ProviderForeignE =
    ProviderForeign::qt_create_metaobjectdata<qt_meta_tag_ZN15ProviderForeignE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN15ProviderForeignE =
    qt_staticMetaObjectContent_ZN15ProviderForeignE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN15ProviderForeignE =
    qt_staticMetaObjectContent_ZN15ProviderForeignE.relocatingData;

Q_CONSTINIT const QMetaObject ProviderForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN15ProviderForeignE.stringdata,
    qt_staticMetaObjectStaticContent_ZN15ProviderForeignE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN15ProviderForeignE.metaTypes,
    nullptr
} };

QT_WARNING_POP
