/****************************************************************************
** Meta object code from reading C++ file 'kcm.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/kcms/notifications/kcm.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcm.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KCMNotificationsE_t {};
} // unnamed namespace

template <> constexpr inline auto KCMNotifications::qt_create_metaobjectdata<qt_meta_tag_ZN16KCMNotificationsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KCMNotifications",
        "toggleDoNotDisturbShortcutChanged",
        "",
        "navigateToComponent",
        "desktopEntry",
        "notifyRcName",
        "eventId",
        "isDefaultsBehaviorSettingsChanged",
        "load",
        "save",
        "defaults",
        "onDefaultsIndicatorsVisibleChanged",
        "updateModelIsDefaultStatus",
        "QModelIndex",
        "index",
        "parseArguments",
        "QVariantList",
        "args",
        "soundsLocation",
        "QUrl",
        "playSound",
        "soundName",
        "behaviorSettings",
        "NotificationManager::BehaviorSettings*",
        "plasmaWorkspaceNotifyRcName",
        "sourcesModel",
        "SourcesModel*",
        "filteredModel",
        "FilterProxyModel*",
        "dndSettings",
        "NotificationManager::DoNotDisturbSettings*",
        "notificationSettings",
        "NotificationManager::NotificationSettings*",
        "jobSettings",
        "NotificationManager::JobSettings*",
        "badgeSettings",
        "NotificationManager::BadgeSettings*",
        "isDefaultsBehaviorSettings",
        "toggleDoNotDisturbShortcut",
        "QKeySequence"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'toggleDoNotDisturbShortcutChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'navigateToComponent'
        QtMocHelpers::SignalData<void(const QString &, const QString, const QString)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 }, { QMetaType::QString, 5 }, { QMetaType::QString, 6 },
        }}),
        // Signal 'isDefaultsBehaviorSettingsChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'load'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'defaults'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onDefaultsIndicatorsVisibleChanged'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateModelIsDefaultStatus'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'parseArguments'
        QtMocHelpers::SlotData<void(const QVariantList &)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Method 'soundsLocation'
        QtMocHelpers::MethodData<QUrl()>(18, 2, QMC::AccessPublic, 0x80000000 | 19),
        // Method 'playSound'
        QtMocHelpers::MethodData<void(const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Method 'behaviorSettings'
        QtMocHelpers::MethodData<NotificationManager::BehaviorSettings *(const QModelIndex &)>(22, 2, QMC::AccessPublic, 0x80000000 | 23, {{
            { 0x80000000 | 13, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'plasmaWorkspaceNotifyRcName'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sourcesModel'
        QtMocHelpers::PropertyData<SourcesModel*>(25, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'filteredModel'
        QtMocHelpers::PropertyData<FilterProxyModel*>(27, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'dndSettings'
        QtMocHelpers::PropertyData<NotificationManager::DoNotDisturbSettings*>(29, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'notificationSettings'
        QtMocHelpers::PropertyData<NotificationManager::NotificationSettings*>(31, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'jobSettings'
        QtMocHelpers::PropertyData<NotificationManager::JobSettings*>(33, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'badgeSettings'
        QtMocHelpers::PropertyData<NotificationManager::BadgeSettings*>(35, 0x80000000 | 36, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'isDefaultsBehaviorSettings'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'toggleDoNotDisturbShortcut'
        QtMocHelpers::PropertyData<QKeySequence>(38, 0x80000000 | 39, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KCMNotifications, qt_meta_tag_ZN16KCMNotificationsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KCMNotifications::staticMetaObject = { {
    QMetaObject::SuperData::link<KQuickManagedConfigModule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KCMNotificationsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KCMNotificationsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KCMNotificationsE_t>.metaTypes,
    nullptr
} };

void KCMNotifications::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KCMNotifications *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->toggleDoNotDisturbShortcutChanged(); break;
        case 1: _t->navigateToComponent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 2: _t->isDefaultsBehaviorSettingsChanged(); break;
        case 3: _t->load(); break;
        case 4: _t->save(); break;
        case 5: _t->defaults(); break;
        case 6: _t->onDefaultsIndicatorsVisibleChanged(); break;
        case 7: _t->updateModelIsDefaultStatus((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 8: _t->parseArguments((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1]))); break;
        case 9: { QUrl _r = _t->soundsLocation();
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->playSound((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: { NotificationManager::BehaviorSettings* _r = _t->behaviorSettings((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])));
            if (_a[0]) *reinterpret_cast<NotificationManager::BehaviorSettings**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KCMNotifications::*)()>(_a, &KCMNotifications::toggleDoNotDisturbShortcutChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMNotifications::*)(const QString & , const QString , const QString )>(_a, &KCMNotifications::navigateToComponent, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMNotifications::*)()>(_a, &KCMNotifications::isDefaultsBehaviorSettingsChanged, 2))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< FilterProxyModel* >(); break;
        case 6:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NotificationManager::BadgeSettings* >(); break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NotificationManager::DoNotDisturbSettings* >(); break;
        case 5:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NotificationManager::JobSettings* >(); break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NotificationManager::NotificationSettings* >(); break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< SourcesModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->plasmaWorkspaceNotifyRcName(); break;
        case 1: *reinterpret_cast<SourcesModel**>(_v) = _t->sourcesModel(); break;
        case 2: *reinterpret_cast<FilterProxyModel**>(_v) = _t->filteredModel(); break;
        case 3: *reinterpret_cast<NotificationManager::DoNotDisturbSettings**>(_v) = _t->dndSettings(); break;
        case 4: *reinterpret_cast<NotificationManager::NotificationSettings**>(_v) = _t->notificationSettings(); break;
        case 5: *reinterpret_cast<NotificationManager::JobSettings**>(_v) = _t->jobSettings(); break;
        case 6: *reinterpret_cast<NotificationManager::BadgeSettings**>(_v) = _t->badgeSettings(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isDefaultsBehaviorSettings(); break;
        case 8: *reinterpret_cast<QKeySequence*>(_v) = _t->toggleDoNotDisturbShortcut(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 8: _t->setToggleDoNotDisturbShortcut(*reinterpret_cast<QKeySequence*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KCMNotifications::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KCMNotifications::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KCMNotificationsE_t>.strings))
        return static_cast<void*>(this);
    return KQuickManagedConfigModule::qt_metacast(_clname);
}

int KCMNotifications::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KQuickManagedConfigModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void KCMNotifications::toggleDoNotDisturbShortcutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KCMNotifications::navigateToComponent(const QString & _t1, const QString _t2, const QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void KCMNotifications::isDefaultsBehaviorSettingsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
