/********************************************************************************
** Form generated from reading UI file 'preview.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREVIEW_H
#define UI_PREVIEW_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_preview
{
public:
    QGridLayout *gridLayout;
    QLabel *label;
    QPushButton *pushButton;
    QSpacerItem *spacerItem;
    QSpacerItem *horizontalSpacer;
    QFrame *frame;
    QGridLayout *gridLayout1;
    QWidget *selectionWidget;
    QHBoxLayout *hboxLayout;
    QLabel *labelSelection0;
    QLabel *labelSelection3;
    QLabel *labelSelection4;
    QLabel *labelSelection2;
    QLabel *labelSelection1;
    QLabel *labelSelection5;
    QLabel *labelSelection6;
    QLabel *labelSelection7;
    QSpacerItem *spacerItem1;
    QWidget *viewWidget;
    QHBoxLayout *hboxLayout1;
    QLabel *labelView0;
    QLabel *labelView3;
    QLabel *labelView4;
    QLabel *labelView2;
    QLabel *labelView1;
    QLabel *labelView5;
    QLabel *labelView6;
    QLabel *labelView7;
    QSpacerItem *spacerItem2;

    void setupUi(QFrame *preview)
    {
        if (preview->objectName().isEmpty())
            preview->setObjectName("preview");
        preview->resize(467, 116);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(preview->sizePolicy().hasHeightForWidth());
        preview->setSizePolicy(sizePolicy);
        preview->setFrameShape(QFrame::StyledPanel);
        preview->setFrameShadow(QFrame::Sunken);
        gridLayout = new QGridLayout(preview);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(preview);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 1, 1, 1);

        pushButton = new QPushButton(preview);
        pushButton->setObjectName("pushButton");

        gridLayout->addWidget(pushButton, 1, 1, 1, 1);

        spacerItem = new QSpacerItem(4, 51, QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem, 0, 3, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 0, 1, 1);

        frame = new QFrame(preview);
        frame->setObjectName("frame");
        frame->setAutoFillBackground(true);
        frame->setFrameShape(QFrame::StyledPanel);
        frame->setFrameShadow(QFrame::Sunken);
        gridLayout1 = new QGridLayout(frame);
        gridLayout1->setSpacing(0);
        gridLayout1->setObjectName("gridLayout1");
        gridLayout1->setContentsMargins(0, 0, 0, 0);
        selectionWidget = new QWidget(frame);
        selectionWidget->setObjectName("selectionWidget");
        selectionWidget->setAutoFillBackground(true);
        hboxLayout = new QHBoxLayout(selectionWidget);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(2, 2, 2, 2);
        labelSelection0 = new QLabel(selectionWidget);
        labelSelection0->setObjectName("labelSelection0");

        hboxLayout->addWidget(labelSelection0);

        labelSelection3 = new QLabel(selectionWidget);
        labelSelection3->setObjectName("labelSelection3");
        QFont font;
        font.setUnderline(true);
        labelSelection3->setFont(font);

        hboxLayout->addWidget(labelSelection3);

        labelSelection4 = new QLabel(selectionWidget);
        labelSelection4->setObjectName("labelSelection4");
        labelSelection4->setFont(font);

        hboxLayout->addWidget(labelSelection4);

        labelSelection2 = new QLabel(selectionWidget);
        labelSelection2->setObjectName("labelSelection2");

        hboxLayout->addWidget(labelSelection2);

        labelSelection1 = new QLabel(selectionWidget);
        labelSelection1->setObjectName("labelSelection1");

        hboxLayout->addWidget(labelSelection1);

        labelSelection5 = new QLabel(selectionWidget);
        labelSelection5->setObjectName("labelSelection5");

        hboxLayout->addWidget(labelSelection5);

        labelSelection6 = new QLabel(selectionWidget);
        labelSelection6->setObjectName("labelSelection6");

        hboxLayout->addWidget(labelSelection6);

        labelSelection7 = new QLabel(selectionWidget);
        labelSelection7->setObjectName("labelSelection7");

        hboxLayout->addWidget(labelSelection7);


        gridLayout1->addWidget(selectionWidget, 1, 0, 1, 1);

        spacerItem1 = new QSpacerItem(141, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        gridLayout1->addItem(spacerItem1, 2, 0, 1, 2);

        viewWidget = new QWidget(frame);
        viewWidget->setObjectName("viewWidget");
        hboxLayout1 = new QHBoxLayout(viewWidget);
        hboxLayout1->setObjectName("hboxLayout1");
        hboxLayout1->setContentsMargins(2, 2, 2, 2);
        labelView0 = new QLabel(viewWidget);
        labelView0->setObjectName("labelView0");

        hboxLayout1->addWidget(labelView0);

        labelView3 = new QLabel(viewWidget);
        labelView3->setObjectName("labelView3");
        labelView3->setFont(font);

        hboxLayout1->addWidget(labelView3);

        labelView4 = new QLabel(viewWidget);
        labelView4->setObjectName("labelView4");
        labelView4->setFont(font);

        hboxLayout1->addWidget(labelView4);

        labelView2 = new QLabel(viewWidget);
        labelView2->setObjectName("labelView2");

        hboxLayout1->addWidget(labelView2);

        labelView1 = new QLabel(viewWidget);
        labelView1->setObjectName("labelView1");

        hboxLayout1->addWidget(labelView1);

        labelView5 = new QLabel(viewWidget);
        labelView5->setObjectName("labelView5");

        hboxLayout1->addWidget(labelView5);

        labelView6 = new QLabel(viewWidget);
        labelView6->setObjectName("labelView6");

        hboxLayout1->addWidget(labelView6);

        labelView7 = new QLabel(viewWidget);
        labelView7->setObjectName("labelView7");

        hboxLayout1->addWidget(labelView7);


        gridLayout1->addWidget(viewWidget, 0, 0, 1, 1);


        gridLayout->addWidget(frame, 0, 2, 3, 1);

        spacerItem2 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        gridLayout->addItem(spacerItem2, 2, 1, 1, 1);


        retranslateUi(preview);

        QMetaObject::connectSlotsByName(preview);
    } // setupUi

    void retranslateUi(QFrame *preview)
    {
#if QT_CONFIG(tooltip)
        label->setToolTip(tr2i18n("Window text on Window Background", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Window text", "color-kcm-preview"));
#if QT_CONFIG(tooltip)
        pushButton->setToolTip(tr2i18n("Button text on Button Background", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButton->setText(tr2i18n("Push Button", "color-kcm-preview"));
#if QT_CONFIG(tooltip)
        labelSelection0->setToolTip(tr2i18n("Selection Normal Text against Selection Normal Background", nullptr));
#endif // QT_CONFIG(tooltip)
        labelSelection0->setText(tr2i18n("Selected text", "color-kcm-preview"));
#if QT_CONFIG(tooltip)
        labelSelection3->setToolTip(tr2i18n("Selection Link Text against Selection Normal Background", nullptr));
#endif // QT_CONFIG(tooltip)
        labelSelection3->setText(tr2i18n("link", "color-kcm-preview"));
#if QT_CONFIG(tooltip)
        labelSelection4->setToolTip(tr2i18n("Selection Visited Text against Selection Normal Background", nullptr));
#endif // QT_CONFIG(tooltip)
        labelSelection4->setText(tr2i18n("visited", "color-kcm-preview"));
#if QT_CONFIG(tooltip)
        labelSelection2->setToolTip(tr2i18n("Selection Active Text against Selection Normal Background", nullptr));
#endif // QT_CONFIG(tooltip)
        labelSelection2->setText(tr2i18n("a", "color-kcm-preview"));
#if QT_CONFIG(tooltip)
        labelSelection1->setToolTip(tr2i18n("Selection Inactive Text against Selection Normal Background", nullptr));
#endif // QT_CONFIG(tooltip)
        labelSelection1->setText(tr2i18n("i", "color-kcm-preview"));
#if QT_CONFIG(tooltip)
        labelSelection5->setToolTip(tr2i18n("Selection Negative Text against Selection Normal Background", nullptr));
#endif // QT_CONFIG(tooltip)
        labelSelection5->setText(tr2i18n("!", "color-kcm-preview"));
#if QT_CONFIG(tooltip)
        labelSelection6->setToolTip(tr2i18n("Selection Neutral Text against Selection Normal Background", nullptr));
#endif // QT_CONFIG(tooltip)
        labelSelection6->setText(tr2i18n("=", "color-kcm-preview"));
#if QT_CONFIG(tooltip)
        labelSelection7->setToolTip(tr2i18n("Selection Positive Text against Selection Normal Background", nullptr));
#endif // QT_CONFIG(tooltip)
        labelSelection7->setText(tr2i18n("+", "color-kcm-preview"));
#if QT_CONFIG(tooltip)
        labelView0->setToolTip(tr2i18n("View Normal Text against View Normal Background", nullptr));
#endif // QT_CONFIG(tooltip)
        labelView0->setText(tr2i18n("Normal text", "color-kcm-preview"));
#if QT_CONFIG(tooltip)
        labelView3->setToolTip(tr2i18n("View Link Text against View Normal Background", nullptr));
#endif // QT_CONFIG(tooltip)
        labelView3->setText(tr2i18n("link", "color-kcm-preview"));
#if QT_CONFIG(tooltip)
        labelView4->setToolTip(tr2i18n("View Visited Text against View Normal Background", nullptr));
#endif // QT_CONFIG(tooltip)
        labelView4->setText(tr2i18n("visited", "color-kcm-preview"));
#if QT_CONFIG(tooltip)
        labelView2->setToolTip(tr2i18n("View Active Text against View Normal Background", nullptr));
#endif // QT_CONFIG(tooltip)
        labelView2->setText(tr2i18n("a", "color-kcm-preview"));
#if QT_CONFIG(tooltip)
        labelView1->setToolTip(tr2i18n("View Inactive Text against View Normal Background", nullptr));
#endif // QT_CONFIG(tooltip)
        labelView1->setText(tr2i18n("i", "color-kcm-preview"));
#if QT_CONFIG(tooltip)
        labelView5->setToolTip(tr2i18n("View Negative Text against View Normal Background", nullptr));
#endif // QT_CONFIG(tooltip)
        labelView5->setText(tr2i18n("!", "color-kcm-preview"));
#if QT_CONFIG(tooltip)
        labelView6->setToolTip(tr2i18n("View Neutral Text against View Normal Background", nullptr));
#endif // QT_CONFIG(tooltip)
        labelView6->setText(tr2i18n("=", "color-kcm-preview"));
#if QT_CONFIG(tooltip)
        labelView7->setToolTip(tr2i18n("View Positive Text against View Normal Background", nullptr));
#endif // QT_CONFIG(tooltip)
        labelView7->setText(tr2i18n("+", "color-kcm-preview"));
        (void)preview;
    } // retranslateUi

};

namespace Ui {
    class preview: public Ui_preview {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PREVIEW_H

