// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#include "nightlightdata.h"

#include "nightlightsettings.h"




NightLightData::NightLightData(QObject *parent)
: KCModuleData(parent)
, m_settings(new NightLightSettings(this))

{
autoRegisterSkeletons();
}

NightLightSettings *NightLightData::settings() const
{
    return m_settings;
}





#include "moc_nightlightdata.cpp"
