/****************************************************************************
** Meta object code from reading C++ file 'trianglemousefilter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/components/trianglemousefilter/trianglemousefilter.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'trianglemousefilter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19TriangleMouseFilterE_t {};
} // unnamed namespace

template <> constexpr inline auto TriangleMouseFilter::qt_create_metaobjectdata<qt_meta_tag_ZN19TriangleMouseFilterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TriangleMouseFilter",
        "QML.Element",
        "auto",
        "filterTimoutChanged",
        "",
        "edgeChanged",
        "edgeLineChanged",
        "activeChanged",
        "blockFirstEnterChanged",
        "secondaryPointChanged",
        "active",
        "filterTimeOut",
        "edge",
        "Qt::Edge",
        "edgeLine",
        "QList<int>",
        "blockFirstEnter",
        "secondaryPoint",
        "QPointF"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'filterTimoutChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'edgeChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'edgeLineChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'blockFirstEnterChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'secondaryPointChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'active'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 3),
        // property 'filterTimeOut'
        QtMocHelpers::PropertyData<int>(11, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'edge'
        QtMocHelpers::PropertyData<Qt::Edge>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 1),
        // property 'edgeLine'
        QtMocHelpers::PropertyData<QList<int>>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 2),
        // property 'blockFirstEnter'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 4),
        // property 'secondaryPoint'
        QtMocHelpers::PropertyData<QPointF>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 5),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<TriangleMouseFilter, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject TriangleMouseFilter::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19TriangleMouseFilterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19TriangleMouseFilterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19TriangleMouseFilterE_t>.metaTypes,
    nullptr
} };

void TriangleMouseFilter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TriangleMouseFilter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->filterTimoutChanged(); break;
        case 1: _t->edgeChanged(); break;
        case 2: _t->edgeLineChanged(); break;
        case 3: _t->activeChanged(); break;
        case 4: _t->blockFirstEnterChanged(); break;
        case 5: _t->secondaryPointChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TriangleMouseFilter::*)()>(_a, &TriangleMouseFilter::filterTimoutChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TriangleMouseFilter::*)()>(_a, &TriangleMouseFilter::edgeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TriangleMouseFilter::*)()>(_a, &TriangleMouseFilter::edgeLineChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TriangleMouseFilter::*)()>(_a, &TriangleMouseFilter::activeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TriangleMouseFilter::*)()>(_a, &TriangleMouseFilter::blockFirstEnterChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TriangleMouseFilter::*)()>(_a, &TriangleMouseFilter::secondaryPointChanged, 5))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<int> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->m_active; break;
        case 1: *reinterpret_cast<int*>(_v) = _t->m_filterTimeout; break;
        case 2: *reinterpret_cast<Qt::Edge*>(_v) = _t->m_edge; break;
        case 3: *reinterpret_cast<QList<int>*>(_v) = _t->m_edgeLine; break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->m_blockFirstEnter; break;
        case 5: *reinterpret_cast<QPointF*>(_v) = _t->m_secondaryPoint; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->m_active, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->activeChanged();
            break;
        case 1:
            if (QtMocHelpers::setProperty(_t->m_filterTimeout, *reinterpret_cast<int*>(_v)))
                Q_EMIT _t->filterTimoutChanged();
            break;
        case 2:
            if (QtMocHelpers::setProperty(_t->m_edge, *reinterpret_cast<Qt::Edge*>(_v)))
                Q_EMIT _t->edgeChanged();
            break;
        case 3:
            if (QtMocHelpers::setProperty(_t->m_edgeLine, *reinterpret_cast<QList<int>*>(_v)))
                Q_EMIT _t->edgeLineChanged();
            break;
        case 4:
            if (QtMocHelpers::setProperty(_t->m_blockFirstEnter, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->blockFirstEnterChanged();
            break;
        case 5:
            if (QtMocHelpers::setProperty(_t->m_secondaryPoint, *reinterpret_cast<QPointF*>(_v)))
                Q_EMIT _t->secondaryPointChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *TriangleMouseFilter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TriangleMouseFilter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19TriangleMouseFilterE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int TriangleMouseFilter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void TriangleMouseFilter::filterTimoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TriangleMouseFilter::edgeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void TriangleMouseFilter::edgeLineChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void TriangleMouseFilter::activeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void TriangleMouseFilter::blockFirstEnterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void TriangleMouseFilter::secondaryPointChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
