// This file is generated by kconfig_compiler_kf6 from launchfeedbacksettings.kcfg.
// All changes you do to this file will be lost.

#include "launchfeedbacksettings.h"

LaunchFeedbackSettings::LaunchFeedbackSettings( QObject *parent )
  : KConfigSkeleton( QStringLiteral( "klaunchrc" ) )
{
  setParent(parent);
  KConfigCompilerSignallingItem::NotifyFunction notifyFunction = static_cast<KConfigCompilerSignallingItem::NotifyFunction>(&LaunchFeedbackSettings::itemChanged);

  setCurrentGroup( QStringLiteral( "BusyCursorSettings" ) );

  KConfigCompilerSignallingItem  *itemBlinking;
  KConfigSkeleton::ItemBool  *innerItemBlinking;
  innerItemBlinking = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Blinking" ), mBlinking, false );
  itemBlinking = new KConfigCompilerSignallingItem(innerItemBlinking, this, notifyFunction, signalBlinkingChanged);
  itemBlinking->setWriteFlags(KConfigBase::Notify);
  addItem( itemBlinking, QStringLiteral( "blinking" ) );
  KConfigCompilerSignallingItem  *itemBouncing;
  KConfigSkeleton::ItemBool  *innerItemBouncing;
  innerItemBouncing = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Bouncing" ), mBouncing, true );
  itemBouncing = new KConfigCompilerSignallingItem(innerItemBouncing, this, notifyFunction, signalBouncingChanged);
  itemBouncing->setWriteFlags(KConfigBase::Notify);
  addItem( itemBouncing, QStringLiteral( "bouncing" ) );
  KConfigCompilerSignallingItem  *itemCursorTimeout;
  KConfigSkeleton::ItemInt  *innerItemCursorTimeout;
  innerItemCursorTimeout = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "Timeout" ), mCursorTimeout, 5 );
  itemCursorTimeout = new KConfigCompilerSignallingItem(innerItemCursorTimeout, this, notifyFunction, signalCursorTimeoutChanged);
  itemCursorTimeout->setWriteFlags(KConfigBase::Notify);
  addItem( itemCursorTimeout, QStringLiteral( "cursorTimeout" ) );

  setCurrentGroup( QStringLiteral( "FeedbackStyle" ) );

  KConfigCompilerSignallingItem  *itemBusyCursor;
  KConfigSkeleton::ItemBool  *innerItemBusyCursor;
  innerItemBusyCursor = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "BusyCursor" ), mBusyCursor, true );
  itemBusyCursor = new KConfigCompilerSignallingItem(innerItemBusyCursor, this, notifyFunction, signalBusyCursorChanged);
  itemBusyCursor->setWriteFlags(KConfigBase::Notify);
  addItem( itemBusyCursor, QStringLiteral( "busyCursor" ) );
  KConfigCompilerSignallingItem  *itemTaskbarButton;
  KConfigSkeleton::ItemBool  *innerItemTaskbarButton;
  innerItemTaskbarButton = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TaskbarButton" ), mTaskbarButton, true );
  itemTaskbarButton = new KConfigCompilerSignallingItem(innerItemTaskbarButton, this, notifyFunction, signalTaskbarButtonChanged);
  itemTaskbarButton->setWriteFlags(KConfigBase::Notify);
  addItem( itemTaskbarButton, QStringLiteral( "taskbarButton" ) );

  setCurrentGroup( QStringLiteral( "TaskbarButtonSettings" ) );

  KConfigCompilerSignallingItem  *itemTaskbarTimeout;
  KConfigSkeleton::ItemInt  *innerItemTaskbarTimeout;
  innerItemTaskbarTimeout = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "Timeout" ), mTaskbarTimeout, 5 );
  itemTaskbarTimeout = new KConfigCompilerSignallingItem(innerItemTaskbarTimeout, this, notifyFunction, signalTaskbarTimeoutChanged);
  itemTaskbarTimeout->setWriteFlags(KConfigBase::Notify);
  addItem( itemTaskbarTimeout, QStringLiteral( "taskbarTimeout" ) );
}

bool LaunchFeedbackSettings::defaultBlinkingValue_helper() const
{

  return false;
}

bool LaunchFeedbackSettings::defaultBouncingValue_helper() const
{

  return true;
}

int LaunchFeedbackSettings::defaultCursorTimeoutValue_helper() const
{

  return 5;
}

bool LaunchFeedbackSettings::defaultBusyCursorValue_helper() const
{

  return true;
}

bool LaunchFeedbackSettings::defaultTaskbarButtonValue_helper() const
{

  return true;
}

int LaunchFeedbackSettings::defaultTaskbarTimeoutValue_helper() const
{

  return 5;
}

LaunchFeedbackSettings::~LaunchFeedbackSettings()
{
}


void LaunchFeedbackSettings::itemChanged(quint64 signalFlag) {

  switch (signalFlag) {
  case signalBlinkingChanged:
    Q_EMIT blinkingChanged();
    break;
  case signalBouncingChanged:
    Q_EMIT bouncingChanged();
    break;
  case signalCursorTimeoutChanged:
    Q_EMIT cursorTimeoutChanged();
    break;
  case signalBusyCursorChanged:
    Q_EMIT busyCursorChanged();
    break;
  case signalTaskbarButtonChanged:
    Q_EMIT taskbarButtonChanged();
    break;
  case signalTaskbarTimeoutChanged:
    Q_EMIT taskbarTimeoutChanged();
    break;
  }
}
