/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<dbusconnection.h>)
#  include <dbusconnection.h>
#endif
#if __has_include(<dbuserror.h>)
#  include <dbuserror.h>
#endif
#if __has_include(<dbusmessage.h>)
#  include <dbusmessage.h>
#endif
#if __has_include(<dbuspendingreply.h>)
#  include <dbuspendingreply.h>
#endif
#if __has_include(<dbusproperties.h>)
#  include <dbusproperties.h>
#endif
#if __has_include(<dbusservicewatcher.h>)
#  include <dbusservicewatcher.h>
#endif
#if __has_include(<dbussignalwatcher.h>)
#  include <dbussignalwatcher.h>
#endif
#if __has_include(<dbustype.h>)
#  include <dbustype.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_plasma_workspace_dbus()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &BusType::staticMetaObject;},
            "BusType");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&BusType::staticMetaObject, "org.kde.plasma.workspace.dbus", 1, nullptr, &BusType::staticMetaObject, nullptr);
    qmlRegisterEnum<BusType::Type>("BusType::Type");
    qmlRegisterTypesAndRevisions<DBusServiceWatcher>("org.kde.plasma.workspace.dbus", 1);
    qmlRegisterTypesAndRevisions<Plasma::DBus::BOOL>("org.kde.plasma.workspace.dbus", 1);
    qmlRegisterTypesAndRevisions<Plasma::DBus::BYTE>("org.kde.plasma.workspace.dbus", 1);
    qmlRegisterTypesAndRevisions<Plasma::DBus::DICT>("org.kde.plasma.workspace.dbus", 1);
    qmlRegisterTypesAndRevisions<Plasma::DBus::DOUBLE>("org.kde.plasma.workspace.dbus", 1);
    qmlRegisterTypesAndRevisions<Plasma::DBus::INT16>("org.kde.plasma.workspace.dbus", 1);
    qmlRegisterTypesAndRevisions<Plasma::DBus::INT32>("org.kde.plasma.workspace.dbus", 1);
    qmlRegisterTypesAndRevisions<Plasma::DBus::INT64>("org.kde.plasma.workspace.dbus", 1);
    qmlRegisterTypesAndRevisions<Plasma::DBus::OBJECTPATH>("org.kde.plasma.workspace.dbus", 1);
    qmlRegisterTypesAndRevisions<Plasma::DBus::SIGNATURE>("org.kde.plasma.workspace.dbus", 1);
    qmlRegisterTypesAndRevisions<Plasma::DBus::STRING>("org.kde.plasma.workspace.dbus", 1);
    qmlRegisterTypesAndRevisions<Plasma::DBus::UINT16>("org.kde.plasma.workspace.dbus", 1);
    qmlRegisterTypesAndRevisions<Plasma::DBus::UINT32>("org.kde.plasma.workspace.dbus", 1);
    qmlRegisterTypesAndRevisions<Plasma::DBus::UINT64>("org.kde.plasma.workspace.dbus", 1);
    qmlRegisterTypesAndRevisions<Plasma::DBus::VARIANT>("org.kde.plasma.workspace.dbus", 1);
    QMetaType::fromType<Plasma::DBusConnection *>().id();
    qmlRegisterTypesAndRevisions<Plasma::DBusError>("org.kde.plasma.workspace.dbus", 1);
    qmlRegisterTypesAndRevisions<Plasma::DBusMessage>("org.kde.plasma.workspace.dbus", 1);
    qmlRegisterTypesAndRevisions<Plasma::DBusPendingReply>("org.kde.plasma.workspace.dbus", 1);
    qmlRegisterTypesAndRevisions<Plasma::DBusProperties>("org.kde.plasma.workspace.dbus", 1);
    qmlRegisterTypesAndRevisions<Plasma::DBusPropertyMap>("org.kde.plasma.workspace.dbus", 1);
    qmlRegisterTypesAndRevisions<Plasma::DBusSignalWatcher>("org.kde.plasma.workspace.dbus", 1);
    qmlRegisterTypesAndRevisions<Plasma::SessionBusConnection>("org.kde.plasma.workspace.dbus", 1);
    qmlRegisterTypesAndRevisions<Plasma::SystemBusConnection>("org.kde.plasma.workspace.dbus", 1);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.plasma.workspace.dbus", 1, 0);
}

static const QQmlModuleRegistration orgkdeplasmaworkspacedbusRegistration("org.kde.plasma.workspace.dbus", qml_register_types_org_kde_plasma_workspace_dbus);
