/****************************************************************************
** Meta object code from reading C++ file 'job.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-workspace-6.7.1/libnotificationmanager/job.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'job.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19NotificationManager3JobE_t {};
} // unnamed namespace

template <> constexpr inline auto NotificationManager::Job::qt_create_metaobjectdata<qt_meta_tag_ZN19NotificationManager3JobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NotificationManager::Job",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Can only access Job via JobDetailsRole of JobsModel",
        "updatedChanged",
        "",
        "summaryChanged",
        "textChanged",
        "stateChanged",
        "Notifications::JobState",
        "jobState",
        "percentageChanged",
        "percentage",
        "errorChanged",
        "error",
        "errorTextChanged",
        "errorText",
        "destUrlChanged",
        "effectiveDestUrlChanged",
        "speedChanged",
        "elapsedTimeChanged",
        "processedBytesChanged",
        "processedFilesChanged",
        "processedDirectoriesChanged",
        "processedItemsChanged",
        "processedAmountChanged",
        "totalBytesChanged",
        "totalFilesChanged",
        "totalDirectoriesChanged",
        "totalItemsChanged",
        "totalAmountChanged",
        "descriptionLabel1Changed",
        "descriptionValue1Changed",
        "descriptionLabel2Changed",
        "descriptionValue2Changed",
        "descriptionUrlChanged",
        "hasDetailsChanged",
        "expiredChanged",
        "dismissedChanged",
        "suspend",
        "resume",
        "kill",
        "summary",
        "text",
        "desktopEntry",
        "applicationName",
        "applicationIconName",
        "state",
        "suspendable",
        "killable",
        "destUrl",
        "QUrl",
        "speed",
        "elapsedTime",
        "processedBytes",
        "processedFiles",
        "processedDirectories",
        "processedItems",
        "totalBytes",
        "totalFiles",
        "totalDirectories",
        "totalItems",
        "descriptionLabel1",
        "descriptionValue1",
        "descriptionLabel2",
        "descriptionValue2",
        "hasDetails",
        "descriptionUrl",
        "effectiveDestUrl"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'updatedChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'summaryChanged'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textChanged'
        QtMocHelpers::SignalData<void()>(10, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void(Notifications::JobState)>(11, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'percentageChanged'
        QtMocHelpers::SignalData<void(int)>(14, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Signal 'errorChanged'
        QtMocHelpers::SignalData<void(int)>(16, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Signal 'errorTextChanged'
        QtMocHelpers::SignalData<void(const QString &)>(18, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Signal 'destUrlChanged'
        QtMocHelpers::SignalData<void()>(20, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'effectiveDestUrlChanged'
        QtMocHelpers::SignalData<void()>(21, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'speedChanged'
        QtMocHelpers::SignalData<void()>(22, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'elapsedTimeChanged'
        QtMocHelpers::SignalData<void()>(23, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'processedBytesChanged'
        QtMocHelpers::SignalData<void()>(24, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'processedFilesChanged'
        QtMocHelpers::SignalData<void()>(25, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'processedDirectoriesChanged'
        QtMocHelpers::SignalData<void()>(26, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'processedItemsChanged'
        QtMocHelpers::SignalData<void()>(27, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'processedAmountChanged'
        QtMocHelpers::SignalData<void()>(28, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'totalBytesChanged'
        QtMocHelpers::SignalData<void()>(29, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'totalFilesChanged'
        QtMocHelpers::SignalData<void()>(30, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'totalDirectoriesChanged'
        QtMocHelpers::SignalData<void()>(31, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'totalItemsChanged'
        QtMocHelpers::SignalData<void()>(32, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'totalAmountChanged'
        QtMocHelpers::SignalData<void()>(33, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'descriptionLabel1Changed'
        QtMocHelpers::SignalData<void()>(34, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'descriptionValue1Changed'
        QtMocHelpers::SignalData<void()>(35, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'descriptionLabel2Changed'
        QtMocHelpers::SignalData<void()>(36, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'descriptionValue2Changed'
        QtMocHelpers::SignalData<void()>(37, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'descriptionUrlChanged'
        QtMocHelpers::SignalData<void()>(38, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hasDetailsChanged'
        QtMocHelpers::SignalData<void()>(39, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'expiredChanged'
        QtMocHelpers::SignalData<void()>(40, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dismissedChanged'
        QtMocHelpers::SignalData<void()>(41, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'suspend'
        QtMocHelpers::MethodData<void()>(42, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'resume'
        QtMocHelpers::MethodData<void()>(43, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'kill'
        QtMocHelpers::MethodData<void()>(44, 8, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'summary'
        QtMocHelpers::PropertyData<QString>(45, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'text'
        QtMocHelpers::PropertyData<QString>(46, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'desktopEntry'
        QtMocHelpers::PropertyData<QString>(47, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'applicationName'
        QtMocHelpers::PropertyData<QString>(48, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'applicationIconName'
        QtMocHelpers::PropertyData<QString>(49, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'state'
        QtMocHelpers::PropertyData<Notifications::JobState>(50, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'percentage'
        QtMocHelpers::PropertyData<int>(15, QMetaType::Int, QMC::DefaultPropertyFlags, 4),
        // property 'error'
        QtMocHelpers::PropertyData<int>(17, QMetaType::Int, QMC::DefaultPropertyFlags, 5),
        // property 'suspendable'
        QtMocHelpers::PropertyData<bool>(51, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'killable'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'destUrl'
        QtMocHelpers::PropertyData<QUrl>(53, 0x80000000 | 54, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 7),
        // property 'speed'
        QtMocHelpers::PropertyData<qulonglong>(55, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 9),
        // property 'elapsedTime'
        QtMocHelpers::PropertyData<qulonglong>(56, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 10),
        // property 'processedBytes'
        QtMocHelpers::PropertyData<qulonglong>(57, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 11),
        // property 'processedFiles'
        QtMocHelpers::PropertyData<qulonglong>(58, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 12),
        // property 'processedDirectories'
        QtMocHelpers::PropertyData<qulonglong>(59, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 13),
        // property 'processedItems'
        QtMocHelpers::PropertyData<qulonglong>(60, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 14),
        // property 'totalBytes'
        QtMocHelpers::PropertyData<qulonglong>(61, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 16),
        // property 'totalFiles'
        QtMocHelpers::PropertyData<qulonglong>(62, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 17),
        // property 'totalDirectories'
        QtMocHelpers::PropertyData<qulonglong>(63, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 18),
        // property 'totalItems'
        QtMocHelpers::PropertyData<qulonglong>(64, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 19),
        // property 'descriptionLabel1'
        QtMocHelpers::PropertyData<QString>(65, QMetaType::QString, QMC::DefaultPropertyFlags, 21),
        // property 'descriptionValue1'
        QtMocHelpers::PropertyData<QString>(66, QMetaType::QString, QMC::DefaultPropertyFlags, 22),
        // property 'descriptionLabel2'
        QtMocHelpers::PropertyData<QString>(67, QMetaType::QString, QMC::DefaultPropertyFlags, 23),
        // property 'descriptionValue2'
        QtMocHelpers::PropertyData<QString>(68, QMetaType::QString, QMC::DefaultPropertyFlags, 24),
        // property 'hasDetails'
        QtMocHelpers::PropertyData<bool>(69, QMetaType::Bool, QMC::DefaultPropertyFlags, 26),
        // property 'descriptionUrl'
        QtMocHelpers::PropertyData<QUrl>(70, 0x80000000 | 54, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 25),
        // property 'effectiveDestUrl'
        QtMocHelpers::PropertyData<QUrl>(71, 0x80000000 | 54, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 8),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<Job, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN19NotificationManager3JobE[] = {
    QMetaObject::SuperData::link<NotificationManager::Notifications::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject NotificationManager::Job::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationManager3JobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationManager3JobE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN19NotificationManager3JobE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19NotificationManager3JobE_t>.metaTypes,
    nullptr
} };

void NotificationManager::Job::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Job *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->updatedChanged(); break;
        case 1: _t->summaryChanged(); break;
        case 2: _t->textChanged(); break;
        case 3: _t->stateChanged((*reinterpret_cast<std::add_pointer_t<Notifications::JobState>>(_a[1]))); break;
        case 4: _t->percentageChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->errorChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->errorTextChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->destUrlChanged(); break;
        case 8: _t->effectiveDestUrlChanged(); break;
        case 9: _t->speedChanged(); break;
        case 10: _t->elapsedTimeChanged(); break;
        case 11: _t->processedBytesChanged(); break;
        case 12: _t->processedFilesChanged(); break;
        case 13: _t->processedDirectoriesChanged(); break;
        case 14: _t->processedItemsChanged(); break;
        case 15: _t->processedAmountChanged(); break;
        case 16: _t->totalBytesChanged(); break;
        case 17: _t->totalFilesChanged(); break;
        case 18: _t->totalDirectoriesChanged(); break;
        case 19: _t->totalItemsChanged(); break;
        case 20: _t->totalAmountChanged(); break;
        case 21: _t->descriptionLabel1Changed(); break;
        case 22: _t->descriptionValue1Changed(); break;
        case 23: _t->descriptionLabel2Changed(); break;
        case 24: _t->descriptionValue2Changed(); break;
        case 25: _t->descriptionUrlChanged(); break;
        case 26: _t->hasDetailsChanged(); break;
        case 27: _t->expiredChanged(); break;
        case 28: _t->dismissedChanged(); break;
        case 29: _t->suspend(); break;
        case 30: _t->resume(); break;
        case 31: _t->kill(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Job::*)()>(_a, &Job::updatedChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Job::*)()>(_a, &Job::summaryChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Job::*)()>(_a, &Job::textChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Job::*)(Notifications::JobState )>(_a, &Job::stateChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Job::*)(int )>(_a, &Job::percentageChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Job::*)(int )>(_a, &Job::errorChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Job::*)(const QString & )>(_a, &Job::errorTextChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Job::*)()>(_a, &Job::destUrlChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Job::*)()>(_a, &Job::effectiveDestUrlChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Job::*)()>(_a, &Job::speedChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Job::*)()>(_a, &Job::elapsedTimeChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Job::*)()>(_a, &Job::processedBytesChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Job::*)()>(_a, &Job::processedFilesChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Job::*)()>(_a, &Job::processedDirectoriesChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Job::*)()>(_a, &Job::processedItemsChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Job::*)()>(_a, &Job::processedAmountChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Job::*)()>(_a, &Job::totalBytesChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (Job::*)()>(_a, &Job::totalFilesChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (Job::*)()>(_a, &Job::totalDirectoriesChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (Job::*)()>(_a, &Job::totalItemsChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (Job::*)()>(_a, &Job::totalAmountChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (Job::*)()>(_a, &Job::descriptionLabel1Changed, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (Job::*)()>(_a, &Job::descriptionValue1Changed, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (Job::*)()>(_a, &Job::descriptionLabel2Changed, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (Job::*)()>(_a, &Job::descriptionValue2Changed, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (Job::*)()>(_a, &Job::descriptionUrlChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (Job::*)()>(_a, &Job::hasDetailsChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (Job::*)()>(_a, &Job::expiredChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (Job::*)()>(_a, &Job::dismissedChanged, 28))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->summary(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->text(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->desktopEntry(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->applicationName(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->applicationIconName(); break;
        case 5: *reinterpret_cast<Notifications::JobState*>(_v) = _t->state(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->percentage(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->error(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->suspendable(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->killable(); break;
        case 10: *reinterpret_cast<QUrl*>(_v) = _t->destUrl(); break;
        case 11: *reinterpret_cast<qulonglong*>(_v) = _t->speed(); break;
        case 12: *reinterpret_cast<qulonglong*>(_v) = _t->elapsedTime(); break;
        case 13: *reinterpret_cast<qulonglong*>(_v) = _t->processedBytes(); break;
        case 14: *reinterpret_cast<qulonglong*>(_v) = _t->processedFiles(); break;
        case 15: *reinterpret_cast<qulonglong*>(_v) = _t->processedDirectories(); break;
        case 16: *reinterpret_cast<qulonglong*>(_v) = _t->processedItems(); break;
        case 17: *reinterpret_cast<qulonglong*>(_v) = _t->totalBytes(); break;
        case 18: *reinterpret_cast<qulonglong*>(_v) = _t->totalFiles(); break;
        case 19: *reinterpret_cast<qulonglong*>(_v) = _t->totalDirectories(); break;
        case 20: *reinterpret_cast<qulonglong*>(_v) = _t->totalItems(); break;
        case 21: *reinterpret_cast<QString*>(_v) = _t->descriptionLabel1(); break;
        case 22: *reinterpret_cast<QString*>(_v) = _t->descriptionValue1(); break;
        case 23: *reinterpret_cast<QString*>(_v) = _t->descriptionLabel2(); break;
        case 24: *reinterpret_cast<QString*>(_v) = _t->descriptionValue2(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->hasDetails(); break;
        case 26: *reinterpret_cast<QUrl*>(_v) = _t->descriptionUrl(); break;
        case 27: *reinterpret_cast<QUrl*>(_v) = _t->effectiveDestUrl(); break;
        default: break;
        }
    }
}

const QMetaObject *NotificationManager::Job::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NotificationManager::Job::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationManager3JobE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int NotificationManager::Job::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 32;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    return _id;
}

// SIGNAL 0
void NotificationManager::Job::updatedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void NotificationManager::Job::summaryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void NotificationManager::Job::textChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void NotificationManager::Job::stateChanged(Notifications::JobState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void NotificationManager::Job::percentageChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void NotificationManager::Job::errorChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void NotificationManager::Job::errorTextChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void NotificationManager::Job::destUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void NotificationManager::Job::effectiveDestUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void NotificationManager::Job::speedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void NotificationManager::Job::elapsedTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void NotificationManager::Job::processedBytesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void NotificationManager::Job::processedFilesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void NotificationManager::Job::processedDirectoriesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void NotificationManager::Job::processedItemsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void NotificationManager::Job::processedAmountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void NotificationManager::Job::totalBytesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void NotificationManager::Job::totalFilesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void NotificationManager::Job::totalDirectoriesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void NotificationManager::Job::totalItemsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void NotificationManager::Job::totalAmountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void NotificationManager::Job::descriptionLabel1Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void NotificationManager::Job::descriptionValue1Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void NotificationManager::Job::descriptionLabel2Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void NotificationManager::Job::descriptionValue2Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void NotificationManager::Job::descriptionUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void NotificationManager::Job::hasDetailsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void NotificationManager::Job::expiredChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void NotificationManager::Job::dismissedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}
QT_WARNING_POP
