/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.fontinst.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "fontinstadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class FontinstAdaptor
 */

FontinstAdaptor::FontinstAdaptor(KFI::FontInst *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

FontinstAdaptor::~FontinstAdaptor()
{
    // destructor
}

void FontinstAdaptor::disable(const QString &family, uint style, bool inSystem, int pid, bool checkConfig)
{
    // handle method call org.kde.fontinst.disable
    parent()->disable(family, style, inSystem, pid, checkConfig);
}

void FontinstAdaptor::enable(const QString &family, uint style, bool inSystem, int pid, bool checkConfig)
{
    // handle method call org.kde.fontinst.enable
    parent()->enable(family, style, inSystem, pid, checkConfig);
}

QString FontinstAdaptor::folderName(bool sys)
{
    // handle method call org.kde.fontinst.folderName
    return parent()->folderName(sys);
}

void FontinstAdaptor::install(const QString &file, bool createAfm, bool toSystem, int pid, bool checkConfig)
{
    // handle method call org.kde.fontinst.install
    parent()->install(file, createAfm, toSystem, pid, checkConfig);
}

void FontinstAdaptor::list(int folders, int pid)
{
    // handle method call org.kde.fontinst.list
    parent()->list(folders, pid);
}

void FontinstAdaptor::move(const QString &family, uint style, bool toSystem, int pid, bool checkConfig)
{
    // handle method call org.kde.fontinst.move
    parent()->move(family, style, toSystem, pid, checkConfig);
}

void FontinstAdaptor::reconfigure(int pid, bool force)
{
    // handle method call org.kde.fontinst.reconfigure
    parent()->reconfigure(pid, force);
}

void FontinstAdaptor::removeFile(const QString &family, uint style, const QString &file, bool fromSystem, int pid, bool checkConfig)
{
    // handle method call org.kde.fontinst.removeFile
    parent()->removeFile(family, style, file, fromSystem, pid, checkConfig);
}

void FontinstAdaptor::saveDisabled()
{
    // handle method call org.kde.fontinst.saveDisabled
    parent()->saveDisabled();
}

void FontinstAdaptor::statFont(const QString &name, int folders, int pid)
{
    // handle method call org.kde.fontinst.statFont
    parent()->statFont(name, folders, pid);
}

void FontinstAdaptor::uninstall(const QString &name, bool fromSystem, int pid, bool checkConfig)
{
    // handle method call org.kde.fontinst.uninstall
    parent()->uninstall(name, fromSystem, pid, checkConfig);
}

void FontinstAdaptor::uninstall(const QString &family, uint style, bool fromSystem, int pid, bool checkConfig)
{
    // handle method call org.kde.fontinst.uninstall
    parent()->uninstall(family, style, fromSystem, pid, checkConfig);
}


#include "moc_fontinstadaptor.cpp"
