// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#ifndef CURSORTHEMEDATA_H
#define CURSORTHEMEDATA_H

#include <QObject>

#include "kcmoduledata.h"



class CursorThemeSettings;
class LaunchFeedbackSettings;


class CursorThemeData : public KCModuleData
{
    Q_OBJECT

public:
    explicit CursorThemeData(QObject *parent = nullptr);
    CursorThemeSettings *cursorThemeSettings() const;
LaunchFeedbackSettings *launchFeedbackSettings() const;


private:
    CursorThemeSettings *m_cursorThemeSettings;
LaunchFeedbackSettings *m_launchFeedbackSettings;

};



#endif
