/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<mpris2model.h>)
#  include <mpris2model.h>
#endif
#if __has_include(<multiplexermodel.h>)
#  include <multiplexermodel.h>
#endif
#if __has_include(<playercontainer.h>)
#  include <playercontainer.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_plasma_private_mpris()
{
    qmlRegisterModule("org.kde.plasma.private.mpris", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    QMetaType::fromType<AbstractPlayerContainer *>().id();
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &LoopStatus::staticMetaObject;},
            "LoopStatus");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&LoopStatus::staticMetaObject, "org.kde.plasma.private.mpris", 254, nullptr, &LoopStatus::staticMetaObject, nullptr);
    qmlRegisterEnum<LoopStatus::Status>("LoopStatus::Status");
    qmlRegisterTypesAndRevisions<Mpris2Model>("org.kde.plasma.private.mpris", 254);
    qmlRegisterTypesAndRevisions<MultiplexerModel>("org.kde.plasma.private.mpris", 254);
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &PlaybackStatus::staticMetaObject;},
            "PlaybackStatus");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&PlaybackStatus::staticMetaObject, "org.kde.plasma.private.mpris", 254, nullptr, &PlaybackStatus::staticMetaObject, nullptr);
    qmlRegisterEnum<PlaybackStatus::Status>("PlaybackStatus::Status");
    qmlRegisterTypesAndRevisions<PlayerContainer>("org.kde.plasma.private.mpris", 254);
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    QMetaType::fromType<QConcatenateTablesProxyModel *>().id();
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &ShuffleStatus::staticMetaObject;},
            "ShuffleStatus");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&ShuffleStatus::staticMetaObject, "org.kde.plasma.private.mpris", 254, nullptr, &ShuffleStatus::staticMetaObject, nullptr);
    qmlRegisterEnum<ShuffleStatus::Status>("ShuffleStatus::Status");
    QT_WARNING_POP
    qmlRegisterModule("org.kde.plasma.private.mpris", 254, 254);
}

static const QQmlModuleRegistration orgkdeplasmaprivatemprisRegistration("org.kde.plasma.private.mpris", qml_register_types_org_kde_plasma_private_mpris);
