// This file is generated by kconfig_compiler_kf6 from badgesettings.kcfg.
// All changes you do to this file will be lost.

#include "badgesettings.h"

using namespace NotificationManager;

BadgeSettings::BadgeSettings( QObject *parent )
  : KConfigSkeleton( QStringLiteral( "plasmanotifyrc" ) )
{
  setParent(parent);
  KConfigCompilerSignallingItem::NotifyFunction notifyFunction = static_cast<KConfigCompilerSignallingItem::NotifyFunction>(&BadgeSettings::itemChanged);

  setCurrentGroup( QStringLiteral( "Badges" ) );

  KConfigCompilerSignallingItem  *itemInTaskManager;
  KConfigSkeleton::ItemBool  *innerItemInTaskManager;
  innerItemInTaskManager = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "InTaskManager" ), mInTaskManager, true );
  itemInTaskManager = new KConfigCompilerSignallingItem(innerItemInTaskManager, this, notifyFunction, signalInTaskManagerChanged);
  itemInTaskManager->setWriteFlags(KConfigBase::Notify);
  addItem( itemInTaskManager, QStringLiteral( "InTaskManager" ) );
}

bool BadgeSettings::defaultInTaskManagerValue_helper() const
{

  return true;
}

BadgeSettings::~BadgeSettings()
{
}


void BadgeSettings::itemChanged(quint64 signalFlag) {

  switch (signalFlag) {
  case signalInTaskManagerChanged:
    Q_EMIT InTaskManagerChanged();
    break;
  }
}
