/****************************************************************************
** Meta object code from reading C++ file 'fprint_device_interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "fprint_device_interface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fprint_device_interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN35NetReactivatedFprintDeviceInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto NetReactivatedFprintDeviceInterface::qt_create_metaobjectdata<qt_meta_tag_ZN35NetReactivatedFprintDeviceInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NetReactivatedFprintDeviceInterface",
        "EnrollStatus",
        "",
        "result",
        "done",
        "VerifyFingerSelected",
        "finger_name",
        "VerifyStatus",
        "Claim",
        "QDBusPendingReply<>",
        "username",
        "DeleteEnrolledFinger",
        "DeleteEnrolledFingers",
        "DeleteEnrolledFingers2",
        "EnrollStart",
        "EnrollStop",
        "ListEnrolledFingers",
        "QDBusPendingReply<QStringList>",
        "Release",
        "VerifyStart",
        "VerifyStop",
        "name"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'EnrollStatus'
        QtMocHelpers::SignalData<void(const QString &, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Bool, 4 },
        }}),
        // Signal 'VerifyFingerSelected'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'VerifyStatus'
        QtMocHelpers::SignalData<void(const QString &, bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Bool, 4 },
        }}),
        // Slot 'Claim'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(8, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'DeleteEnrolledFinger'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(11, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'DeleteEnrolledFingers'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(12, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'DeleteEnrolledFingers2'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(13, 2, QMC::AccessPublic, 0x80000000 | 9),
        // Slot 'EnrollStart'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(14, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'EnrollStop'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(15, 2, QMC::AccessPublic, 0x80000000 | 9),
        // Slot 'ListEnrolledFingers'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>(const QString &)>(16, 2, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'Release'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(18, 2, QMC::AccessPublic, 0x80000000 | 9),
        // Slot 'VerifyStart'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(19, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'VerifyStop'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(20, 2, QMC::AccessPublic, 0x80000000 | 9),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetReactivatedFprintDeviceInterface, qt_meta_tag_ZN35NetReactivatedFprintDeviceInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject NetReactivatedFprintDeviceInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN35NetReactivatedFprintDeviceInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN35NetReactivatedFprintDeviceInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN35NetReactivatedFprintDeviceInterfaceE_t>.metaTypes,
    nullptr
} };

void NetReactivatedFprintDeviceInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetReactivatedFprintDeviceInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->EnrollStatus((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 1: _t->VerifyFingerSelected((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->VerifyStatus((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 3: { QDBusPendingReply<> _r = _t->Claim((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<> _r = _t->DeleteEnrolledFinger((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<> _r = _t->DeleteEnrolledFingers((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<> _r = _t->DeleteEnrolledFingers2();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<> _r = _t->EnrollStart((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<> _r = _t->EnrollStop();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<QStringList> _r = _t->ListEnrolledFingers((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<> _r = _t->Release();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<> _r = _t->VerifyStart((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<> _r = _t->VerifyStop();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NetReactivatedFprintDeviceInterface::*)(const QString & , bool )>(_a, &NetReactivatedFprintDeviceInterface::EnrollStatus, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetReactivatedFprintDeviceInterface::*)(const QString & )>(_a, &NetReactivatedFprintDeviceInterface::VerifyFingerSelected, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetReactivatedFprintDeviceInterface::*)(const QString & , bool )>(_a, &NetReactivatedFprintDeviceInterface::VerifyStatus, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        default: break;
        }
    }
}

const QMetaObject *NetReactivatedFprintDeviceInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NetReactivatedFprintDeviceInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN35NetReactivatedFprintDeviceInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int NetReactivatedFprintDeviceInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void NetReactivatedFprintDeviceInterface::EnrollStatus(const QString & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void NetReactivatedFprintDeviceInterface::VerifyFingerSelected(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void NetReactivatedFprintDeviceInterface::VerifyStatus(const QString & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}
QT_WARNING_POP
