/****************************************************************************
** Meta object code from reading C++ file 'user_interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "user_interface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'user_interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN35OrgFreedesktopAccountsUserInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgFreedesktopAccountsUserInterface::qt_create_metaobjectdata<qt_meta_tag_ZN35OrgFreedesktopAccountsUserInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgFreedesktopAccountsUserInterface",
        "Changed",
        "",
        "SetAccountType",
        "QDBusPendingReply<>",
        "accountType",
        "SetAutomaticLogin",
        "enabled",
        "SetEmail",
        "email",
        "SetHomeDirectory",
        "homedir",
        "SetIconFile",
        "filename",
        "SetLanguage",
        "language",
        "SetLocation",
        "location",
        "SetLocked",
        "locked",
        "SetPassword",
        "password",
        "hint",
        "SetPasswordMode",
        "mode",
        "SetRealName",
        "name",
        "SetShell",
        "shell",
        "SetUserName",
        "SetXSession",
        "x_session",
        "AccountType",
        "AutomaticLogin",
        "Email",
        "HomeDirectory",
        "IconFile",
        "Language",
        "LocalAccount",
        "Location",
        "Locked",
        "LoginFrequency",
        "PasswordHint",
        "PasswordMode",
        "RealName",
        "Shell",
        "SystemAccount",
        "Uid",
        "UserName",
        "XSession"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Changed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'SetAccountType'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int)>(3, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'SetAutomaticLogin'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(6, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::Bool, 7 },
        }}),
        // Slot 'SetEmail'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(8, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'SetHomeDirectory'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(10, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'SetIconFile'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(12, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'SetLanguage'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(14, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'SetLocation'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(16, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'SetLocked'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(18, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::Bool, 19 },
        }}),
        // Slot 'SetPassword'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(20, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::QString, 21 }, { QMetaType::QString, 22 },
        }}),
        // Slot 'SetPasswordMode'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int)>(23, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::Int, 24 },
        }}),
        // Slot 'SetRealName'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(25, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'SetShell'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(27, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'SetUserName'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(29, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'SetXSession'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(30, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::QString, 31 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'AccountType'
        QtMocHelpers::PropertyData<int>(32, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'AutomaticLogin'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'Email'
        QtMocHelpers::PropertyData<QString>(34, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'HomeDirectory'
        QtMocHelpers::PropertyData<QString>(35, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'IconFile'
        QtMocHelpers::PropertyData<QString>(36, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Language'
        QtMocHelpers::PropertyData<QString>(37, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'LocalAccount'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'Location'
        QtMocHelpers::PropertyData<QString>(39, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Locked'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'LoginFrequency'
        QtMocHelpers::PropertyData<qulonglong>(41, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'PasswordHint'
        QtMocHelpers::PropertyData<QString>(42, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'PasswordMode'
        QtMocHelpers::PropertyData<int>(43, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'RealName'
        QtMocHelpers::PropertyData<QString>(44, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Shell'
        QtMocHelpers::PropertyData<QString>(45, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'SystemAccount'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'Uid'
        QtMocHelpers::PropertyData<qulonglong>(47, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'UserName'
        QtMocHelpers::PropertyData<QString>(48, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'XSession'
        QtMocHelpers::PropertyData<QString>(49, QMetaType::QString, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgFreedesktopAccountsUserInterface, qt_meta_tag_ZN35OrgFreedesktopAccountsUserInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgFreedesktopAccountsUserInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN35OrgFreedesktopAccountsUserInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN35OrgFreedesktopAccountsUserInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN35OrgFreedesktopAccountsUserInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgFreedesktopAccountsUserInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopAccountsUserInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Changed(); break;
        case 1: { QDBusPendingReply<> _r = _t->SetAccountType((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<> _r = _t->SetAutomaticLogin((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<> _r = _t->SetEmail((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<> _r = _t->SetHomeDirectory((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<> _r = _t->SetIconFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<> _r = _t->SetLanguage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<> _r = _t->SetLocation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<> _r = _t->SetLocked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<> _r = _t->SetPassword((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<> _r = _t->SetPasswordMode((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<> _r = _t->SetRealName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<> _r = _t->SetShell((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<> _r = _t->SetUserName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<> _r = _t->SetXSession((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAccountsUserInterface::*)()>(_a, &OrgFreedesktopAccountsUserInterface::Changed, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->accountType(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->automaticLogin(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->email(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->homeDirectory(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->iconFile(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->language(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->localAccount(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->location(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->locked(); break;
        case 9: *reinterpret_cast<qulonglong*>(_v) = _t->loginFrequency(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->passwordHint(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->passwordMode(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->realName(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->shell(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->systemAccount(); break;
        case 15: *reinterpret_cast<qulonglong*>(_v) = _t->uid(); break;
        case 16: *reinterpret_cast<QString*>(_v) = _t->userName(); break;
        case 17: *reinterpret_cast<QString*>(_v) = _t->xSession(); break;
        default: break;
        }
    }
}

const QMetaObject *OrgFreedesktopAccountsUserInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopAccountsUserInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN35OrgFreedesktopAccountsUserInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopAccountsUserInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void OrgFreedesktopAccountsUserInterface::Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
