/****************************************************************************
** Meta object code from reading C++ file 'notificationsettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../notificationsettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'notificationsettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19NotificationManager20NotificationSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto NotificationManager::NotificationSettings::qt_create_metaobjectdata<qt_meta_tag_ZN19NotificationManager20NotificationSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NotificationManager::NotificationSettings",
        "CriticalInDndModeChanged",
        "",
        "LowPriorityPopupsChanged",
        "LowPriorityHistoryChanged",
        "PopupPositionChanged",
        "PopupTimeoutChanged",
        "ShowPopupTimeoutChanged",
        "criticalInDndMode",
        "isCriticalInDndModeImmutable",
        "defaultCriticalInDndModeValue",
        "lowPriorityPopups",
        "isLowPriorityPopupsImmutable",
        "defaultLowPriorityPopupsValue",
        "lowPriorityHistory",
        "isLowPriorityHistoryImmutable",
        "defaultLowPriorityHistoryValue",
        "popupPosition",
        "isPopupPositionImmutable",
        "defaultPopupPositionValue",
        "popupTimeout",
        "isPopupTimeoutImmutable",
        "defaultPopupTimeoutValue",
        "showPopupTimeout",
        "isShowPopupTimeoutImmutable",
        "defaultShowPopupTimeoutValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'CriticalInDndModeChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LowPriorityPopupsChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LowPriorityHistoryChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PopupPositionChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PopupTimeoutChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowPopupTimeoutChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'criticalInDndMode'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isCriticalInDndModeImmutable'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCriticalInDndModeValue'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lowPriorityPopups'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isLowPriorityPopupsImmutable'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLowPriorityPopupsValue'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lowPriorityHistory'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isLowPriorityHistoryImmutable'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLowPriorityHistoryValue'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'popupPosition'
        QtMocHelpers::PropertyData<int>(17, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isPopupPositionImmutable'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultPopupPositionValue'
        QtMocHelpers::PropertyData<int>(19, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'popupTimeout'
        QtMocHelpers::PropertyData<int>(20, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isPopupTimeoutImmutable'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultPopupTimeoutValue'
        QtMocHelpers::PropertyData<int>(22, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showPopupTimeout'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isShowPopupTimeoutImmutable'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowPopupTimeoutValue'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NotificationSettings, qt_meta_tag_ZN19NotificationManager20NotificationSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject NotificationManager::NotificationSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationManager20NotificationSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationManager20NotificationSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19NotificationManager20NotificationSettingsE_t>.metaTypes,
    nullptr
} };

void NotificationManager::NotificationSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NotificationSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->CriticalInDndModeChanged(); break;
        case 1: _t->LowPriorityPopupsChanged(); break;
        case 2: _t->LowPriorityHistoryChanged(); break;
        case 3: _t->PopupPositionChanged(); break;
        case 4: _t->PopupTimeoutChanged(); break;
        case 5: _t->ShowPopupTimeoutChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NotificationSettings::*)()>(_a, &NotificationSettings::CriticalInDndModeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationSettings::*)()>(_a, &NotificationSettings::LowPriorityPopupsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationSettings::*)()>(_a, &NotificationSettings::LowPriorityHistoryChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationSettings::*)()>(_a, &NotificationSettings::PopupPositionChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationSettings::*)()>(_a, &NotificationSettings::PopupTimeoutChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationSettings::*)()>(_a, &NotificationSettings::ShowPopupTimeoutChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->criticalInDndMode(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isCriticalInDndModeImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultCriticalInDndModeValue(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->lowPriorityPopups(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isLowPriorityPopupsImmutable(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->defaultLowPriorityPopupsValue(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->lowPriorityHistory(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isLowPriorityHistoryImmutable(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->defaultLowPriorityHistoryValue(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->popupPosition(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isPopupPositionImmutable(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->defaultPopupPositionValue(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->popupTimeout(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isPopupTimeoutImmutable(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->defaultPopupTimeoutValue(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->showPopupTimeout(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isShowPopupTimeoutImmutable(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->defaultShowPopupTimeoutValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCriticalInDndMode(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setLowPriorityPopups(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setLowPriorityHistory(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setPopupPosition(*reinterpret_cast<int*>(_v)); break;
        case 12: _t->setPopupTimeout(*reinterpret_cast<int*>(_v)); break;
        case 15: _t->setShowPopupTimeout(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *NotificationManager::NotificationSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NotificationManager::NotificationSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationManager20NotificationSettingsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int NotificationManager::NotificationSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void NotificationManager::NotificationSettings::CriticalInDndModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void NotificationManager::NotificationSettings::LowPriorityPopupsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void NotificationManager::NotificationSettings::LowPriorityHistoryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void NotificationManager::NotificationSettings::PopupPositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void NotificationManager::NotificationSettings::PopupTimeoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void NotificationManager::NotificationSettings::ShowPopupTimeoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
