/****************************************************************************
** Meta object code from reading C++ file 'devicefiltercontrol.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/applets/devicenotifier/devicefiltercontrol.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QProperty>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'devicefiltercontrol.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19DeviceFilterControlE_t {};
} // unnamed namespace

template <> constexpr inline auto DeviceFilterControl::qt_create_metaobjectdata<qt_meta_tag_ZN19DeviceFilterControlE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DeviceFilterControl",
        "QML.Element",
        "auto",
        "lastUdiChanged",
        "",
        "lastDescriptionChanged",
        "lastIconChanged",
        "lastDeviceAddedChanged",
        "deviceCountChanged",
        "unmountableCountChanged",
        "onDeviceAdded",
        "QModelIndex",
        "parent",
        "first",
        "last",
        "onDeviceRemoved",
        "onModelReset",
        "onDeviceActionUnmountableChanged",
        "udi",
        "status",
        "unmountAllRemovables",
        "dismissUsbDeviceAddedNotification",
        "isVisible",
        "filterType",
        "DevicesType",
        "deviceCount",
        "qsizetype",
        "unmountableCount",
        "lastUdi",
        "lastDescription",
        "lastIcon",
        "lastDeviceAdded",
        "All",
        "Removable",
        "Unremovable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'lastUdiChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastDescriptionChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastIconChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastDeviceAddedChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'deviceCountChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'unmountableCountChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onDeviceAdded'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(10, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { QMetaType::Int, 13 }, { QMetaType::Int, 14 },
        }}),
        // Slot 'onDeviceRemoved'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(15, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { QMetaType::Int, 13 }, { QMetaType::Int, 14 },
        }}),
        // Slot 'onModelReset'
        QtMocHelpers::SlotData<void()>(16, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onDeviceActionUnmountableChanged'
        QtMocHelpers::SlotData<void(const QString &, bool)>(17, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 18 }, { QMetaType::Bool, 19 },
        }}),
        // Method 'unmountAllRemovables'
        QtMocHelpers::MethodData<void()>(20, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'dismissUsbDeviceAddedNotification'
        QtMocHelpers::MethodData<void()>(21, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'isVisible'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'filterType'
        QtMocHelpers::PropertyData<enum DevicesType>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'deviceCount'
        QtMocHelpers::PropertyData<qsizetype>(25, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Bindable, 4),
        // property 'unmountableCount'
        QtMocHelpers::PropertyData<qsizetype>(27, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Bindable, 5),
        // property 'lastUdi'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Bindable, 0),
        // property 'lastDescription'
        QtMocHelpers::PropertyData<QString>(29, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Bindable, 1),
        // property 'lastIcon'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Bindable, 2),
        // property 'lastDeviceAdded'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 3),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'DevicesType'
        QtMocHelpers::EnumData<enum DevicesType>(24, 24, QMC::EnumFlags{}).add({
            {   32, DevicesType::All },
            {   33, DevicesType::Removable },
            {   34, DevicesType::Unremovable },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DeviceFilterControl, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DeviceFilterControl::staticMetaObject = { {
    QMetaObject::SuperData::link<QSortFilterProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DeviceFilterControlE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DeviceFilterControlE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19DeviceFilterControlE_t>.metaTypes,
    nullptr
} };

void DeviceFilterControl::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeviceFilterControl *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->lastUdiChanged(); break;
        case 1: _t->lastDescriptionChanged(); break;
        case 2: _t->lastIconChanged(); break;
        case 3: _t->lastDeviceAddedChanged(); break;
        case 4: _t->deviceCountChanged(); break;
        case 5: _t->unmountableCountChanged(); break;
        case 6: _t->onDeviceAdded((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 7: _t->onDeviceRemoved((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 8: _t->onModelReset(); break;
        case 9: _t->onDeviceActionUnmountableChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 10: _t->unmountAllRemovables(); break;
        case 11: _t->dismissUsbDeviceAddedNotification(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DeviceFilterControl::*)()>(_a, &DeviceFilterControl::lastUdiChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceFilterControl::*)()>(_a, &DeviceFilterControl::lastDescriptionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceFilterControl::*)()>(_a, &DeviceFilterControl::lastIconChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceFilterControl::*)()>(_a, &DeviceFilterControl::lastDeviceAddedChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceFilterControl::*)()>(_a, &DeviceFilterControl::deviceCountChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceFilterControl::*)()>(_a, &DeviceFilterControl::unmountableCountChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isVisible(); break;
        case 1: *reinterpret_cast<enum DevicesType*>(_v) = _t->filterType(); break;
        case 2: *reinterpret_cast<qsizetype*>(_v) = _t->bindableDeviceCount().value(); break;
        case 3: *reinterpret_cast<qsizetype*>(_v) = _t->bindableUnmountableCount().value(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->bindableLastUdi().value(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->bindableLastDescription().value(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->bindableLastIcon().value(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->bindableLastDeviceAdded().value(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setIsVisible(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setFilterType(*reinterpret_cast<enum DevicesType*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::BindableProperty) {
        switch (_id) {
        case 2: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableDeviceCount(); break;
        case 3: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableUnmountableCount(); break;
        case 4: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableLastUdi(); break;
        case 5: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableLastDescription(); break;
        case 6: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableLastIcon(); break;
        case 7: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableLastDeviceAdded(); break;
        default: break;
        }
    }
}

const QMetaObject *DeviceFilterControl::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeviceFilterControl::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DeviceFilterControlE_t>.strings))
        return static_cast<void*>(this);
    return QSortFilterProxyModel::qt_metacast(_clname);
}

int DeviceFilterControl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSortFilterProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void DeviceFilterControl::lastUdiChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DeviceFilterControl::lastDescriptionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DeviceFilterControl::lastIconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DeviceFilterControl::lastDeviceAddedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DeviceFilterControl::deviceCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DeviceFilterControl::unmountableCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
