/****************************************************************************
** Meta object code from reading C++ file 'scriptengine_v1.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-workspace-6.7.1/shell/scripting/scriptengine_v1.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'scriptengine_v1.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18WorkspaceScripting12ScriptEngine2V1E_t {};
} // unnamed namespace

template <> constexpr inline auto WorkspaceScripting::ScriptEngine::V1::qt_create_metaobjectdata<qt_meta_tag_ZN18WorkspaceScripting12ScriptEngine2V1E_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WorkspaceScripting::ScriptEngine::V1",
        "print",
        "",
        "QJSValue",
        "param",
        "getApiVersion",
        "desktopById",
        "id",
        "desktopsForActivity",
        "desktopForScreen",
        "screen",
        "screenForConnector",
        "createActivity",
        "nameParam",
        "plugin",
        "setCurrentActivity",
        "setActivityName",
        "idParam",
        "activityName",
        "currentActivity",
        "activities",
        "loadSerializedLayout",
        "data",
        "panelById",
        "desktops",
        "panels",
        "fileExists",
        "path",
        "loadTemplate",
        "layout",
        "applicationExists",
        "application",
        "defaultApplication",
        "storageId",
        "applicationPath",
        "userDataPath",
        "type",
        "knownWallpaperPlugins",
        "formFactor",
        "setImmutability",
        "immutability",
        "createContainment",
        "defautPlugin",
        "newPanel",
        "configFile",
        "config",
        "group",
        "gridUnit"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'print'
        QtMocHelpers::SignalData<void(const QJSValue &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Method 'getApiVersion'
        QtMocHelpers::MethodData<QJSValue(const QJSValue &)>(5, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Method 'desktopById'
        QtMocHelpers::MethodData<QJSValue(const QJSValue &) const>(6, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { 0x80000000 | 3, 7 },
        }}),
        // Method 'desktopById'
        QtMocHelpers::MethodData<QJSValue() const>(6, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3),
        // Method 'desktopsForActivity'
        QtMocHelpers::MethodData<QJSValue(const QJSValue &) const>(8, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { 0x80000000 | 3, 7 },
        }}),
        // Method 'desktopsForActivity'
        QtMocHelpers::MethodData<QJSValue() const>(8, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3),
        // Method 'desktopForScreen'
        QtMocHelpers::MethodData<QJSValue(const QJSValue &) const>(9, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { 0x80000000 | 3, 10 },
        }}),
        // Method 'desktopForScreen'
        QtMocHelpers::MethodData<QJSValue() const>(9, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3),
        // Method 'screenForConnector'
        QtMocHelpers::MethodData<QJSValue(const QJSValue &) const>(11, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Method 'screenForConnector'
        QtMocHelpers::MethodData<QJSValue() const>(11, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3),
        // Method 'createActivity'
        QtMocHelpers::MethodData<QJSValue(const QJSValue &, const QString &)>(12, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { 0x80000000 | 3, 13 }, { QMetaType::QString, 14 },
        }}),
        // Method 'createActivity'
        QtMocHelpers::MethodData<QJSValue(const QJSValue &)>(12, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3, {{
            { 0x80000000 | 3, 13 },
        }}),
        // Method 'createActivity'
        QtMocHelpers::MethodData<QJSValue()>(12, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3),
        // Method 'setCurrentActivity'
        QtMocHelpers::MethodData<QJSValue(const QJSValue &)>(15, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { 0x80000000 | 3, 7 },
        }}),
        // Method 'setCurrentActivity'
        QtMocHelpers::MethodData<QJSValue()>(15, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3),
        // Method 'setActivityName'
        QtMocHelpers::MethodData<QJSValue(const QJSValue &, const QJSValue &)>(16, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { 0x80000000 | 3, 17 }, { 0x80000000 | 3, 13 },
        }}),
        // Method 'setActivityName'
        QtMocHelpers::MethodData<QJSValue(const QJSValue &)>(16, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3, {{
            { 0x80000000 | 3, 17 },
        }}),
        // Method 'setActivityName'
        QtMocHelpers::MethodData<QJSValue()>(16, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3),
        // Method 'activityName'
        QtMocHelpers::MethodData<QJSValue(const QJSValue &) const>(18, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { 0x80000000 | 3, 17 },
        }}),
        // Method 'activityName'
        QtMocHelpers::MethodData<QJSValue() const>(18, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3),
        // Method 'currentActivity'
        QtMocHelpers::MethodData<QString() const>(19, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'activities'
        QtMocHelpers::MethodData<QJSValue() const>(20, 2, QMC::AccessPublic, 0x80000000 | 3),
        // Method 'loadSerializedLayout'
        QtMocHelpers::MethodData<QJSValue(const QJSValue &)>(21, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { 0x80000000 | 3, 22 },
        }}),
        // Method 'loadSerializedLayout'
        QtMocHelpers::MethodData<QJSValue()>(21, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3),
        // Method 'panelById'
        QtMocHelpers::MethodData<QJSValue(const QJSValue &) const>(23, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { 0x80000000 | 3, 17 },
        }}),
        // Method 'panelById'
        QtMocHelpers::MethodData<QJSValue() const>(23, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3),
        // Method 'desktops'
        QtMocHelpers::MethodData<QJSValue() const>(24, 2, QMC::AccessPublic, 0x80000000 | 3),
        // Method 'panels'
        QtMocHelpers::MethodData<QJSValue() const>(25, 2, QMC::AccessPublic, 0x80000000 | 3),
        // Method 'fileExists'
        QtMocHelpers::MethodData<bool(const QString &) const>(26, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 27 },
        }}),
        // Method 'fileExists'
        QtMocHelpers::MethodData<bool() const>(26, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool),
        // Method 'loadTemplate'
        QtMocHelpers::MethodData<bool(const QString &)>(28, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 29 },
        }}),
        // Method 'loadTemplate'
        QtMocHelpers::MethodData<bool()>(28, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool),
        // Method 'applicationExists'
        QtMocHelpers::MethodData<bool(const QString &) const>(30, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 31 },
        }}),
        // Method 'applicationExists'
        QtMocHelpers::MethodData<bool() const>(30, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool),
        // Method 'defaultApplication'
        QtMocHelpers::MethodData<QJSValue(const QString &, bool) const>(32, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { QMetaType::QString, 31 }, { QMetaType::Bool, 33 },
        }}),
        // Method 'defaultApplication'
        QtMocHelpers::MethodData<QJSValue(const QString &) const>(32, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3, {{
            { QMetaType::QString, 31 },
        }}),
        // Method 'defaultApplication'
        QtMocHelpers::MethodData<QJSValue() const>(32, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3),
        // Method 'applicationPath'
        QtMocHelpers::MethodData<QJSValue(const QString &) const>(34, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { QMetaType::QString, 31 },
        }}),
        // Method 'applicationPath'
        QtMocHelpers::MethodData<QJSValue() const>(34, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3),
        // Method 'userDataPath'
        QtMocHelpers::MethodData<QJSValue(const QString &, const QString &) const>(35, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { QMetaType::QString, 36 }, { QMetaType::QString, 27 },
        }}),
        // Method 'userDataPath'
        QtMocHelpers::MethodData<QJSValue(const QString &) const>(35, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3, {{
            { QMetaType::QString, 36 },
        }}),
        // Method 'userDataPath'
        QtMocHelpers::MethodData<QJSValue() const>(35, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3),
        // Method 'knownWallpaperPlugins'
        QtMocHelpers::MethodData<QJSValue(const QString &) const>(37, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { QMetaType::QString, 38 },
        }}),
        // Method 'knownWallpaperPlugins'
        QtMocHelpers::MethodData<QJSValue() const>(37, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3),
        // Method 'setImmutability'
        QtMocHelpers::MethodData<void(const QString &)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 40 },
        }}),
        // Method 'setImmutability'
        QtMocHelpers::MethodData<void()>(39, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Method 'immutability'
        QtMocHelpers::MethodData<QString() const>(40, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'createContainment'
        QtMocHelpers::MethodData<QJSValue(const QString &, const QString &, const QString &)>(41, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { QMetaType::QString, 36 }, { QMetaType::QString, 42 }, { QMetaType::QString, 14 },
        }}),
        // Method 'createContainment'
        QtMocHelpers::MethodData<QJSValue(const QString &, const QString &)>(41, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3, {{
            { QMetaType::QString, 36 }, { QMetaType::QString, 42 },
        }}),
        // Method 'newPanel'
        QtMocHelpers::MethodData<QJSValue(const QString &)>(43, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { QMetaType::QString, 14 },
        }}),
        // Method 'newPanel'
        QtMocHelpers::MethodData<QJSValue()>(43, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3),
        // Method 'configFile'
        QtMocHelpers::MethodData<QJSValue(const QJSValue &, const QString &)>(44, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { 0x80000000 | 3, 45 }, { QMetaType::QString, 46 },
        }}),
        // Method 'configFile'
        QtMocHelpers::MethodData<QJSValue(const QJSValue &)>(44, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3, {{
            { 0x80000000 | 3, 45 },
        }}),
        // Method 'configFile'
        QtMocHelpers::MethodData<QJSValue()>(44, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'gridUnit'
        QtMocHelpers::PropertyData<int>(47, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<V1, qt_meta_tag_ZN18WorkspaceScripting12ScriptEngine2V1E_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WorkspaceScripting::ScriptEngine::V1::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18WorkspaceScripting12ScriptEngine2V1E_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18WorkspaceScripting12ScriptEngine2V1E_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18WorkspaceScripting12ScriptEngine2V1E_t>.metaTypes,
    nullptr
} };

void WorkspaceScripting::ScriptEngine::V1::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<V1 *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->print((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1]))); break;
        case 1: { QJSValue _r = _t->getApiVersion((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 2: { QJSValue _r = _t->desktopById((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 3: { QJSValue _r = _t->desktopById();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 4: { QJSValue _r = _t->desktopsForActivity((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 5: { QJSValue _r = _t->desktopsForActivity();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 6: { QJSValue _r = _t->desktopForScreen((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 7: { QJSValue _r = _t->desktopForScreen();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 8: { QJSValue _r = _t->screenForConnector((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 9: { QJSValue _r = _t->screenForConnector();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 10: { QJSValue _r = _t->createActivity((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 11: { QJSValue _r = _t->createActivity((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 12: { QJSValue _r = _t->createActivity();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 13: { QJSValue _r = _t->setCurrentActivity((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 14: { QJSValue _r = _t->setCurrentActivity();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 15: { QJSValue _r = _t->setActivityName((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 16: { QJSValue _r = _t->setActivityName((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 17: { QJSValue _r = _t->setActivityName();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 18: { QJSValue _r = _t->activityName((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 19: { QJSValue _r = _t->activityName();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 20: { QString _r = _t->currentActivity();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 21: { QJSValue _r = _t->activities();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 22: { QJSValue _r = _t->loadSerializedLayout((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 23: { QJSValue _r = _t->loadSerializedLayout();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 24: { QJSValue _r = _t->panelById((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 25: { QJSValue _r = _t->panelById();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 26: { QJSValue _r = _t->desktops();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 27: { QJSValue _r = _t->panels();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 28: { bool _r = _t->fileExists((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 29: { bool _r = _t->fileExists();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 30: { bool _r = _t->loadTemplate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 31: { bool _r = _t->loadTemplate();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 32: { bool _r = _t->applicationExists((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 33: { bool _r = _t->applicationExists();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 34: { QJSValue _r = _t->defaultApplication((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 35: { QJSValue _r = _t->defaultApplication((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 36: { QJSValue _r = _t->defaultApplication();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 37: { QJSValue _r = _t->applicationPath((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 38: { QJSValue _r = _t->applicationPath();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 39: { QJSValue _r = _t->userDataPath((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 40: { QJSValue _r = _t->userDataPath((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 41: { QJSValue _r = _t->userDataPath();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 42: { QJSValue _r = _t->knownWallpaperPlugins((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 43: { QJSValue _r = _t->knownWallpaperPlugins();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 44: _t->setImmutability((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 45: _t->setImmutability(); break;
        case 46: { QString _r = _t->immutability();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 47: { QJSValue _r = _t->createContainment((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 48: { QJSValue _r = _t->createContainment((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 49: { QJSValue _r = _t->newPanel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 50: { QJSValue _r = _t->newPanel();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 51: { QJSValue _r = _t->configFile((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 52: { QJSValue _r = _t->configFile((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 53: { QJSValue _r = _t->configFile();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 51:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 52:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (V1::*)(const QJSValue & )>(_a, &V1::print, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->gridUnit(); break;
        default: break;
        }
    }
}

const QMetaObject *WorkspaceScripting::ScriptEngine::V1::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WorkspaceScripting::ScriptEngine::V1::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18WorkspaceScripting12ScriptEngine2V1E_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int WorkspaceScripting::ScriptEngine::V1::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 54)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 54;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 54)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 54;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void WorkspaceScripting::ScriptEngine::V1::print(const QJSValue & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
