// This file is generated by kconfig_compiler_kf6 from fontsaasettingsbase.kcfg.
// All changes you do to this file will be lost.
#ifndef FONTSAASETTINGSBASE_H
#define FONTSAASETTINGSBASE_H

#include <qglobal.h>
#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class FontsAASettingsBase : public KConfigSkeleton
{
  Q_OBJECT
  public:

    FontsAASettingsBase( QObject *parent = nullptr );
    ~FontsAASettingsBase() override;

    /**
      Set Force font DPI on X11
    */
    void setForceFontDPI( uint v )
    {
      if (v != mForceFontDPI && !isForceFontDPIImmutable()) {
        mForceFontDPI = v;
        Q_EMIT forceFontDPIChanged();
      }
    }

    Q_PROPERTY(uint forceFontDPI READ forceFontDPI WRITE setForceFontDPI NOTIFY forceFontDPIChanged)
    Q_PROPERTY(bool isForceFontDPIImmutable READ isForceFontDPIImmutable CONSTANT)
    Q_PROPERTY(uint defaultForceFontDPIValue READ defaultForceFontDPIValue CONSTANT)
    /**
      Get Force font DPI on X11
    */
    uint forceFontDPI() const
    {
      return mForceFontDPI;
    }

    /**
      Is Force font DPI on X11 Immutable
    */
    bool isForceFontDPIImmutable() const
    {
      return isImmutable( QStringLiteral( "forceFontDPI" ) );
    }

    /**
      Get Force font DPI on X11 default value
    */
    uint defaultForceFontDPIValue() const
    {
        return defaultForceFontDPIValue_helper();
    }


    enum {
      signalForceFontDPIChanged = 1
    };

  Q_SIGNALS:
    void forceFontDPIChanged();

  private:
    void itemChanged(quint64 signalFlag);

  protected:

    // General
    uint mForceFontDPI;
    uint defaultForceFontDPIValue_helper() const;
};

#endif

