// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "statusnotifierwatcher_debug.h"


Q_LOGGING_CATEGORY(STATUSNOTIFIERITEMWATCHER, "org.kde.plasma.statusnotifierwatcher", QtInfoMsg)

