/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.plasmashell.accentColor.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef ACCENTCOLOR_SERVICE_ADAPTOR_H
#define ACCENTCOLOR_SERVICE_ADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "accentColorService/accentColorService.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.plasmashell.accentColor
 */
class AccentColorServiceAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.plasmashell.accentColor")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.plasmashell.accentColor\">\n"
"    <method name=\"setAccentColor\">\n"
"      <arg direction=\"in\" type=\"u\" name=\"accentColor\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    AccentColorServiceAdaptor(AccentColorService *parent);
    ~AccentColorServiceAdaptor() override;

    inline AccentColorService *parent() const
    { return static_cast<AccentColorService *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void setAccentColor(uint accentColor);
Q_SIGNALS: // SIGNALS
};

#endif
