/****************************************************************************
** Meta object code from reading C++ file 'transientimage.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../plasma-workspace-6.7.1/wallpapers/image/plugin/transientimage.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'transientimage.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN29TransientImageTextureProviderE_t {};
} // unnamed namespace

template <> constexpr inline auto TransientImageTextureProvider::qt_create_metaobjectdata<qt_meta_tag_ZN29TransientImageTextureProviderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TransientImageTextureProvider"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TransientImageTextureProvider, qt_meta_tag_ZN29TransientImageTextureProviderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TransientImageTextureProvider::staticMetaObject = { {
    QMetaObject::SuperData::link<QSGTextureProvider::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29TransientImageTextureProviderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29TransientImageTextureProviderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN29TransientImageTextureProviderE_t>.metaTypes,
    nullptr
} };

void TransientImageTextureProvider::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TransientImageTextureProvider *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *TransientImageTextureProvider::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TransientImageTextureProvider::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29TransientImageTextureProviderE_t>.strings))
        return static_cast<void*>(this);
    return QSGTextureProvider::qt_metacast(_clname);
}

int TransientImageTextureProvider::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSGTextureProvider::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN20TransientImageReaderE_t {};
} // unnamed namespace

template <> constexpr inline auto TransientImageReader::qt_create_metaobjectdata<qt_meta_tag_ZN20TransientImageReaderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TransientImageReader",
        "finished",
        "",
        "QImage",
        "image"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'finished'
        QtMocHelpers::SignalData<void(const QImage &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TransientImageReader, qt_meta_tag_ZN20TransientImageReaderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TransientImageReader::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20TransientImageReaderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20TransientImageReaderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20TransientImageReaderE_t>.metaTypes,
    nullptr
} };

void TransientImageReader::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TransientImageReader *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->finished((*reinterpret_cast<std::add_pointer_t<QImage>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TransientImageReader::*)(const QImage & )>(_a, &TransientImageReader::finished, 0))
            return;
    }
}

const QMetaObject *TransientImageReader::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TransientImageReader::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20TransientImageReaderE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int TransientImageReader::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void TransientImageReader::finished(const QImage & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN14TransientImageE_t {};
} // unnamed namespace

template <> constexpr inline auto TransientImage::qt_create_metaobjectdata<qt_meta_tag_ZN14TransientImageE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TransientImage",
        "QML.Element",
        "auto",
        "sourceSizeChanged",
        "",
        "sourceChanged",
        "statusChanged",
        "fillModeChanged",
        "status",
        "Status",
        "source",
        "QUrl",
        "fillMode",
        "FillMode",
        "Null",
        "Ready",
        "Loading",
        "Error",
        "Stretch",
        "PreserveAspectFit",
        "PreserveAspectCrop",
        "Tile",
        "TileVertically",
        "TileHorizontally",
        "Pad"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sourceSizeChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sourceChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fillModeChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'status'
        QtMocHelpers::PropertyData<enum Status>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'source'
        QtMocHelpers::PropertyData<QUrl>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'fillMode'
        QtMocHelpers::PropertyData<enum FillMode>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Status'
        QtMocHelpers::EnumData<enum Status>(9, 9, QMC::EnumFlags{}).add({
            {   14, Status::Null },
            {   15, Status::Ready },
            {   16, Status::Loading },
            {   17, Status::Error },
        }),
        // enum 'FillMode'
        QtMocHelpers::EnumData<enum FillMode>(13, 13, QMC::EnumFlags{}).add({
            {   18, FillMode::Stretch },
            {   19, FillMode::PreserveAspectFit },
            {   20, FillMode::PreserveAspectCrop },
            {   21, FillMode::Tile },
            {   22, FillMode::TileVertically },
            {   23, FillMode::TileHorizontally },
            {   24, FillMode::Pad },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<TransientImage, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject TransientImage::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14TransientImageE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14TransientImageE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14TransientImageE_t>.metaTypes,
    nullptr
} };

void TransientImage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TransientImage *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sourceSizeChanged(); break;
        case 1: _t->sourceChanged(); break;
        case 2: _t->statusChanged(); break;
        case 3: _t->fillModeChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TransientImage::*)()>(_a, &TransientImage::sourceSizeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransientImage::*)()>(_a, &TransientImage::sourceChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransientImage::*)()>(_a, &TransientImage::statusChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransientImage::*)()>(_a, &TransientImage::fillModeChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum Status*>(_v) = _t->status(); break;
        case 1: *reinterpret_cast<QUrl*>(_v) = _t->source(); break;
        case 2: *reinterpret_cast<enum FillMode*>(_v) = _t->fillMode(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setSource(*reinterpret_cast<QUrl*>(_v)); break;
        case 2: _t->setFillMode(*reinterpret_cast<enum FillMode*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *TransientImage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TransientImage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14TransientImageE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int TransientImage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void TransientImage::sourceSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TransientImage::sourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void TransientImage::statusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void TransientImage::fillModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
