/****************************************************************************
** Meta object code from reading C++ file 'KCmFontInst.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../plasma-workspace-6.7.1/kcms/kfontinst/kcmfontinst/KCmFontInst.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#include <QtCore/QSet>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'KCmFontInst.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3KFI12CKCmFontInstE_t {};
} // unnamed namespace

template <> constexpr inline auto KFI::CKCmFontInst::qt_create_metaobjectdata<qt_meta_tag_ZN3KFI12CKCmFontInstE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KFI::CKCmFontInst",
        "previewMenu",
        "",
        "QPoint",
        "pos",
        "splitterMoved",
        "fontsSelected",
        "QModelIndexList",
        "list",
        "groupSelected",
        "QModelIndex",
        "index",
        "addFonts",
        "deleteFonts",
        "moveFonts",
        "zipGroup",
        "enableFonts",
        "disableFonts",
        "addGroup",
        "removeGroup",
        "enableGroup",
        "disableGroup",
        "changeText",
        "duplicateFonts",
        "downloadFonts",
        "QList<KNSCore::Entry>",
        "changedEntries",
        "print",
        "printGroup",
        "listingPercent",
        "p",
        "refreshFontList",
        "refreshFamilies",
        "showInfo",
        "info",
        "setStatusBar",
        "QSet<QUrl>",
        "src"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'previewMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'splitterMoved'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'fontsSelected'
        QtMocHelpers::SlotData<void(const QModelIndexList &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'groupSelected'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'addFonts'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'deleteFonts'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'moveFonts'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zipGroup'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'enableFonts'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'disableFonts'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addGroup'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'removeGroup'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'enableGroup'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'disableGroup'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'changeText'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'duplicateFonts'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'downloadFonts'
        QtMocHelpers::SlotData<void(const QList<KNSCore::Entry> &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Slot 'print'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'printGroup'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'listingPercent'
        QtMocHelpers::SlotData<void(int)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 30 },
        }}),
        // Slot 'refreshFontList'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'refreshFamilies'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showInfo'
        QtMocHelpers::SlotData<void(const QString &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 34 },
        }}),
        // Slot 'setStatusBar'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addFonts'
        QtMocHelpers::SlotData<void(const QSet<QUrl> &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CKCmFontInst, qt_meta_tag_ZN3KFI12CKCmFontInstE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KFI::CKCmFontInst::staticMetaObject = { {
    QMetaObject::SuperData::link<KCModule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3KFI12CKCmFontInstE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3KFI12CKCmFontInstE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3KFI12CKCmFontInstE_t>.metaTypes,
    nullptr
} };

void KFI::CKCmFontInst::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CKCmFontInst *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->previewMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 1: _t->splitterMoved(); break;
        case 2: _t->fontsSelected((*reinterpret_cast<std::add_pointer_t<QModelIndexList>>(_a[1]))); break;
        case 3: _t->groupSelected((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 4: _t->addFonts(); break;
        case 5: _t->deleteFonts(); break;
        case 6: _t->moveFonts(); break;
        case 7: _t->zipGroup(); break;
        case 8: _t->enableFonts(); break;
        case 9: _t->disableFonts(); break;
        case 10: _t->addGroup(); break;
        case 11: _t->removeGroup(); break;
        case 12: _t->enableGroup(); break;
        case 13: _t->disableGroup(); break;
        case 14: _t->changeText(); break;
        case 15: _t->duplicateFonts(); break;
        case 16: _t->downloadFonts((*reinterpret_cast<std::add_pointer_t<QList<KNSCore::Entry>>>(_a[1]))); break;
        case 17: _t->print(); break;
        case 18: _t->printGroup(); break;
        case 19: _t->listingPercent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->refreshFontList(); break;
        case 21: _t->refreshFamilies(); break;
        case 22: _t->showInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 23: _t->setStatusBar(); break;
        case 24: _t->addFonts((*reinterpret_cast<std::add_pointer_t<QSet<QUrl>>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QModelIndexList >(); break;
            }
            break;
        }
    }
}

const QMetaObject *KFI::CKCmFontInst::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KFI::CKCmFontInst::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3KFI12CKCmFontInstE_t>.strings))
        return static_cast<void*>(this);
    return KCModule::qt_metacast(_clname);
}

int KFI::CKCmFontInst::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KCModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    return _id;
}
QT_WARNING_POP
