/****************************************************************************
** Meta object code from reading C++ file 'settingtype.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/kcms/region_language/settingtype.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'settingtype.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17KCM_RegionAndLangE_t {};
} // unnamed namespace

template <> constexpr inline auto KCM_RegionAndLang::qt_create_metaobjectdata<qt_meta_tag_ZN17KCM_RegionAndLangE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KCM_RegionAndLang",
        "SettingType",
        "Lang",
        "Numeric",
        "Time",
        "Currency",
        "Measurement",
        "PaperSize",
        "Address",
        "NameStyle",
        "PhoneNumbers",
        "BinaryDialect",
        "Language"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'SettingType'
        QtMocHelpers::EnumData<SettingType>(1, 1, QMC::EnumFlags{}).add({
            {    2, SettingType::Lang },
            {    3, SettingType::Numeric },
            {    4, SettingType::Time },
            {    5, SettingType::Currency },
            {    6, SettingType::Measurement },
            {    7, SettingType::PaperSize },
            {    8, SettingType::Address },
            {    9, SettingType::NameStyle },
            {   10, SettingType::PhoneNumbers },
            {   11, SettingType::BinaryDialect },
            {   12, SettingType::Language },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN17KCM_RegionAndLangE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN17KCM_RegionAndLangE =
    KCM_RegionAndLang::qt_create_metaobjectdata<qt_meta_tag_ZN17KCM_RegionAndLangE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN17KCM_RegionAndLangE =
    qt_staticMetaObjectContent_ZN17KCM_RegionAndLangE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN17KCM_RegionAndLangE =
    qt_staticMetaObjectContent_ZN17KCM_RegionAndLangE.relocatingData;

Q_CONSTINIT const QMetaObject KCM_RegionAndLang::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN17KCM_RegionAndLangE.stringdata,
    qt_staticMetaObjectStaticContent_ZN17KCM_RegionAndLangE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN17KCM_RegionAndLangE.metaTypes,
    nullptr
} };

QT_WARNING_POP
