/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.notificationmanager.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef NOTIFICATIONMANAGERADAPTOR_H
#define NOTIFICATIONMANAGERADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "server_p.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.NotificationManager
 */
class NotificationManagerAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.NotificationManager")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.NotificationManager\">\n"
"    <method name=\"RegisterWatcher\"/>\n"
"    <method name=\"UnRegisterWatcher\"/>\n"
"    <method name=\"InvokeAction\">\n"
"      <arg direction=\"in\" type=\"u\" name=\"id\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"action_key\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    NotificationManagerAdaptor(NotificationManager::ServerPrivate *parent);
    ~NotificationManagerAdaptor() override;

    inline NotificationManager::ServerPrivate *parent() const
    { return static_cast<NotificationManager::ServerPrivate *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void InvokeAction(uint id, const QString &action_key);
    void RegisterWatcher();
    void UnRegisterWatcher();
Q_SIGNALS: // SIGNALS
};

#endif
