/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.fontinst.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef FONTINSTADAPTOR_H
#define FONTINSTADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "FontInst.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.fontinst
 */
class FontinstAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.fontinst")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.fontinst\">\n"
"    <signal name=\"fontList\">\n"
"      <arg direction=\"out\" type=\"i\" name=\"pid\"/>\n"
"      <arg direction=\"out\" type=\"a(ba(sa(utba(ssi))))\" name=\"families\"/>\n"
"      <annotation value=\"const QList&lt;KFI::Families&gt; &amp;\" name=\"org.qtproject.QtDBus.QtTypeName.Out1\"/>\n"
"    </signal>\n"
"    <signal name=\"status\">\n"
"      <arg direction=\"out\" type=\"i\" name=\"pid\"/>\n"
"      <arg direction=\"out\" type=\"i\" name=\"value\"/>\n"
"    </signal>\n"
"    <signal name=\"fontStat\">\n"
"      <arg direction=\"out\" type=\"i\" name=\"pid\"/>\n"
"      <arg direction=\"out\" type=\"(sa(utba(ssi)))\" name=\"family\"/>\n"
"      <annotation value=\"const KFI::Family &amp;\" name=\"org.qtproject.QtDBus.QtTypeName.Out1\"/>\n"
"    </signal>\n"
"    <signal name=\"fontsAdded\">\n"
"      <arg direction=\"out\" type=\"(ba(sa(utba(ssi))))\" name=\"families\"/>\n"
"      <annotation value=\"const KFI::Families &amp;\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </signal>\n"
"    <signal name=\"fontsRemoved\">\n"
"      <arg direction=\"out\" type=\"(ba(sa(utba(ssi))))\" name=\"families\"/>\n"
"      <annotation value=\"const KFI::Families &amp;\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </signal>\n"
"    <method name=\"list\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"folders\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"pid\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"statFont\">\n"
"      <annotation value=\"KFI::Family\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"folders\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"pid\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"install\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"file\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"createAfm\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"toSystem\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"pid\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"checkConfig\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"uninstall\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"family\"/>\n"
"      <arg direction=\"in\" type=\"u\" name=\"style\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"fromSystem\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"pid\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"checkConfig\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"uninstall\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"fromSystem\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"pid\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"checkConfig\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"move\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"family\"/>\n"
"      <arg direction=\"in\" type=\"u\" name=\"style\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"toSystem\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"pid\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"checkConfig\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"enable\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"family\"/>\n"
"      <arg direction=\"in\" type=\"u\" name=\"style\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"inSystem\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"pid\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"checkConfig\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"disable\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"family\"/>\n"
"      <arg direction=\"in\" type=\"u\" name=\"style\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"inSystem\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"pid\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"checkConfig\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"removeFile\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"family\"/>\n"
"      <arg direction=\"in\" type=\"u\" name=\"style\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"file\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"fromSystem\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"pid\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"checkConfig\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"reconfigure\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"pid\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"force\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"saveDisabled\"/>\n"
"    <method name=\"folderName\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"sys\"/>\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    FontinstAdaptor(KFI::FontInst *parent);
    ~FontinstAdaptor() override;

    inline KFI::FontInst *parent() const
    { return static_cast<KFI::FontInst *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    Q_NOREPLY void disable(const QString &family, uint style, bool inSystem, int pid, bool checkConfig);
    Q_NOREPLY void enable(const QString &family, uint style, bool inSystem, int pid, bool checkConfig);
    QString folderName(bool sys);
    Q_NOREPLY void install(const QString &file, bool createAfm, bool toSystem, int pid, bool checkConfig);
    Q_NOREPLY void list(int folders, int pid);
    Q_NOREPLY void move(const QString &family, uint style, bool toSystem, int pid, bool checkConfig);
    Q_NOREPLY void reconfigure(int pid, bool force);
    Q_NOREPLY void removeFile(const QString &family, uint style, const QString &file, bool fromSystem, int pid, bool checkConfig);
    void saveDisabled();
    Q_NOREPLY void statFont(const QString &name, int folders, int pid);
    Q_NOREPLY void uninstall(const QString &name, bool fromSystem, int pid, bool checkConfig);
    Q_NOREPLY void uninstall(const QString &family, uint style, bool fromSystem, int pid, bool checkConfig);
Q_SIGNALS: // SIGNALS
    void fontList(int pid, const QList<KFI::Families> & families);
    void fontStat(int pid, const KFI::Family & family);
    void fontsAdded(const KFI::Families & families);
    void fontsRemoved(const KFI::Families & families);
    void status(int pid, int value);
};

#endif
