/****************************************************************************
** Meta object code from reading C++ file 'kcm_componentchooser.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/kcms/componentchooser/kcm_componentchooser.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcm_componentchooser.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19KcmComponentChooserE_t {};
} // unnamed namespace

template <> constexpr inline auto KcmComponentChooser::qt_create_metaobjectdata<qt_meta_tag_ZN19KcmComponentChooserE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KcmComponentChooser",
        "browsers",
        "ComponentChooser*",
        "calendar",
        "emailClients",
        "terminalEmulators",
        "fileManagers",
        "geoUriHandlers",
        "telUriHandlers",
        "textEditors",
        "imageViewers",
        "musicPlayers",
        "videoPlayers",
        "pdfViewers",
        "archiveManagers"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'browsers'
        QtMocHelpers::PropertyData<ComponentChooser*>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'calendar'
        QtMocHelpers::PropertyData<ComponentChooser*>(3, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'emailClients'
        QtMocHelpers::PropertyData<ComponentChooser*>(4, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'terminalEmulators'
        QtMocHelpers::PropertyData<ComponentChooser*>(5, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'fileManagers'
        QtMocHelpers::PropertyData<ComponentChooser*>(6, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'geoUriHandlers'
        QtMocHelpers::PropertyData<ComponentChooser*>(7, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'telUriHandlers'
        QtMocHelpers::PropertyData<ComponentChooser*>(8, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'textEditors'
        QtMocHelpers::PropertyData<ComponentChooser*>(9, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'imageViewers'
        QtMocHelpers::PropertyData<ComponentChooser*>(10, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'musicPlayers'
        QtMocHelpers::PropertyData<ComponentChooser*>(11, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'videoPlayers'
        QtMocHelpers::PropertyData<ComponentChooser*>(12, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'pdfViewers'
        QtMocHelpers::PropertyData<ComponentChooser*>(13, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'archiveManagers'
        QtMocHelpers::PropertyData<ComponentChooser*>(14, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KcmComponentChooser, qt_meta_tag_ZN19KcmComponentChooserE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KcmComponentChooser::staticMetaObject = { {
    QMetaObject::SuperData::link<KQuickManagedConfigModule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19KcmComponentChooserE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19KcmComponentChooserE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19KcmComponentChooserE_t>.metaTypes,
    nullptr
} };

void KcmComponentChooser::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KcmComponentChooser *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 12:
        case 11:
        case 10:
        case 9:
        case 8:
        case 7:
        case 6:
        case 5:
        case 4:
        case 3:
        case 2:
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ComponentChooser* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<ComponentChooser**>(_v) = _t->browsers(); break;
        case 1: *reinterpret_cast<ComponentChooser**>(_v) = _t->calendar(); break;
        case 2: *reinterpret_cast<ComponentChooser**>(_v) = _t->emailClients(); break;
        case 3: *reinterpret_cast<ComponentChooser**>(_v) = _t->terminalEmulators(); break;
        case 4: *reinterpret_cast<ComponentChooser**>(_v) = _t->fileManagers(); break;
        case 5: *reinterpret_cast<ComponentChooser**>(_v) = _t->geoUriHandlers(); break;
        case 6: *reinterpret_cast<ComponentChooser**>(_v) = _t->telUriHandlers(); break;
        case 7: *reinterpret_cast<ComponentChooser**>(_v) = _t->textEditors(); break;
        case 8: *reinterpret_cast<ComponentChooser**>(_v) = _t->imageViewers(); break;
        case 9: *reinterpret_cast<ComponentChooser**>(_v) = _t->musicPlayers(); break;
        case 10: *reinterpret_cast<ComponentChooser**>(_v) = _t->videoPlayers(); break;
        case 11: *reinterpret_cast<ComponentChooser**>(_v) = _t->pdfViewers(); break;
        case 12: *reinterpret_cast<ComponentChooser**>(_v) = _t->archiveManagers(); break;
        default: break;
        }
    }
}

const QMetaObject *KcmComponentChooser::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KcmComponentChooser::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19KcmComponentChooserE_t>.strings))
        return static_cast<void*>(this);
    return KQuickManagedConfigModule::qt_metacast(_clname);
}

int KcmComponentChooser::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KQuickManagedConfigModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}
QT_WARNING_POP
