/****************************************************************************
** Meta object code from reading C++ file 'virtualdesktopinfo.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-workspace-6.7.1/libtaskmanager/virtualdesktopinfo.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'virtualdesktopinfo.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11TaskManager18VirtualDesktopInfoE_t {};
} // unnamed namespace

template <> constexpr inline auto TaskManager::VirtualDesktopInfo::qt_create_metaobjectdata<qt_meta_tag_ZN11TaskManager18VirtualDesktopInfoE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TaskManager::VirtualDesktopInfo",
        "QML.Element",
        "auto",
        "currentDesktopChanged",
        "",
        "currentDesktopForScreenChanged",
        "screenName",
        "numberOfDesktopsChanged",
        "desktopIdsChanged",
        "desktopNamesChanged",
        "desktopPositionsChanged",
        "desktopLayoutRowsChanged",
        "navigationWrappingAroundChanged",
        "currentDesktopByScreenName",
        "QVariant",
        "currentDesktopByScreenGeometry",
        "QRect",
        "screenGeometry",
        "currentDesktop",
        "numberOfDesktops",
        "desktopIds",
        "QVariantList",
        "desktopNames",
        "desktopLayoutRows",
        "navigationWrappingAround"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentDesktopChanged'
        QtMocHelpers::SignalData<void() const>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentDesktopForScreenChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(5, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'numberOfDesktopsChanged'
        QtMocHelpers::SignalData<void() const>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'desktopIdsChanged'
        QtMocHelpers::SignalData<void() const>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'desktopNamesChanged'
        QtMocHelpers::SignalData<void() const>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'desktopPositionsChanged'
        QtMocHelpers::SignalData<void() const>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'desktopLayoutRowsChanged'
        QtMocHelpers::SignalData<void() const>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'navigationWrappingAroundChanged'
        QtMocHelpers::SignalData<void() const>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'currentDesktopByScreenName'
        QtMocHelpers::MethodData<QVariant(const QString &) const>(13, 4, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QString, 6 },
        }}),
        // Method 'currentDesktopByScreenGeometry'
        QtMocHelpers::MethodData<QVariant(const QRect &) const>(15, 4, QMC::AccessPublic, 0x80000000 | 14, {{
            { 0x80000000 | 16, 17 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'currentDesktop'
        QtMocHelpers::PropertyData<QVariant>(18, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'numberOfDesktops'
        QtMocHelpers::PropertyData<int>(19, QMetaType::Int, QMC::DefaultPropertyFlags, 2),
        // property 'desktopIds'
        QtMocHelpers::PropertyData<QVariantList>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'desktopNames'
        QtMocHelpers::PropertyData<QStringList>(22, QMetaType::QStringList, QMC::DefaultPropertyFlags, 4),
        // property 'desktopLayoutRows'
        QtMocHelpers::PropertyData<int>(23, QMetaType::Int, QMC::DefaultPropertyFlags, 6),
        // property 'navigationWrappingAround'
        QtMocHelpers::PropertyData<int>(24, QMetaType::Int, QMC::DefaultPropertyFlags, 7),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<VirtualDesktopInfo, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject TaskManager::VirtualDesktopInfo::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11TaskManager18VirtualDesktopInfoE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11TaskManager18VirtualDesktopInfoE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11TaskManager18VirtualDesktopInfoE_t>.metaTypes,
    nullptr
} };

void TaskManager::VirtualDesktopInfo::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<VirtualDesktopInfo *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentDesktopChanged(); break;
        case 1: _t->currentDesktopForScreenChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->numberOfDesktopsChanged(); break;
        case 3: _t->desktopIdsChanged(); break;
        case 4: _t->desktopNamesChanged(); break;
        case 5: _t->desktopPositionsChanged(); break;
        case 6: _t->desktopLayoutRowsChanged(); break;
        case 7: _t->navigationWrappingAroundChanged(); break;
        case 8: { QVariant _r = _t->currentDesktopByScreenName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 9: { QVariant _r = _t->currentDesktopByScreenGeometry((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (VirtualDesktopInfo::*)() const>(_a, &VirtualDesktopInfo::currentDesktopChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (VirtualDesktopInfo::*)(const QString & ) const>(_a, &VirtualDesktopInfo::currentDesktopForScreenChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (VirtualDesktopInfo::*)() const>(_a, &VirtualDesktopInfo::numberOfDesktopsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (VirtualDesktopInfo::*)() const>(_a, &VirtualDesktopInfo::desktopIdsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (VirtualDesktopInfo::*)() const>(_a, &VirtualDesktopInfo::desktopNamesChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (VirtualDesktopInfo::*)() const>(_a, &VirtualDesktopInfo::desktopPositionsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (VirtualDesktopInfo::*)() const>(_a, &VirtualDesktopInfo::desktopLayoutRowsChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (VirtualDesktopInfo::*)() const>(_a, &VirtualDesktopInfo::navigationWrappingAroundChanged, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QVariant*>(_v) = _t->currentDesktop(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->numberOfDesktops(); break;
        case 2: *reinterpret_cast<QVariantList*>(_v) = _t->desktopIds(); break;
        case 3: *reinterpret_cast<QStringList*>(_v) = _t->desktopNames(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->desktopLayoutRows(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->navigationWrappingAround(); break;
        default: break;
        }
    }
}

const QMetaObject *TaskManager::VirtualDesktopInfo::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TaskManager::VirtualDesktopInfo::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11TaskManager18VirtualDesktopInfoE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int TaskManager::VirtualDesktopInfo::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void TaskManager::VirtualDesktopInfo::currentDesktopChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::VirtualDesktopInfo *>(this), &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TaskManager::VirtualDesktopInfo::currentDesktopForScreenChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< TaskManager::VirtualDesktopInfo *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void TaskManager::VirtualDesktopInfo::numberOfDesktopsChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::VirtualDesktopInfo *>(this), &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void TaskManager::VirtualDesktopInfo::desktopIdsChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::VirtualDesktopInfo *>(this), &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void TaskManager::VirtualDesktopInfo::desktopNamesChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::VirtualDesktopInfo *>(this), &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void TaskManager::VirtualDesktopInfo::desktopPositionsChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::VirtualDesktopInfo *>(this), &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void TaskManager::VirtualDesktopInfo::desktopLayoutRowsChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::VirtualDesktopInfo *>(this), &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void TaskManager::VirtualDesktopInfo::navigationWrappingAroundChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::VirtualDesktopInfo *>(this), &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
