/********************************************************************************
** Form generated from reading UI file 'freespacenotifier_prefs_base.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FREESPACENOTIFIER_PREFS_BASE_H
#define UI_FREESPACENOTIFIER_PREFS_BASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_freespacenotifier_prefs_base
{
public:
    QGridLayout *gridLayout;
    QCheckBox *kcfg_enableNotification;
    QLabel *label_minimumSpace;
    QSpinBox *kcfg_minimumSpace;
    QLabel *label_minimumSpacePercentage;
    QSpinBox *kcfg_minimumSpacePercentage;
    QLabel *label_info;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *freespacenotifier_prefs_base)
    {
        if (freespacenotifier_prefs_base->objectName().isEmpty())
            freespacenotifier_prefs_base->setObjectName("freespacenotifier_prefs_base");
        freespacenotifier_prefs_base->resize(320, 250);
        gridLayout = new QGridLayout(freespacenotifier_prefs_base);
        gridLayout->setObjectName("gridLayout");
        kcfg_enableNotification = new QCheckBox(freespacenotifier_prefs_base);
        kcfg_enableNotification->setObjectName("kcfg_enableNotification");
        kcfg_enableNotification->setChecked(true);

        gridLayout->addWidget(kcfg_enableNotification, 0, 0, 1, 2);

        label_minimumSpace = new QLabel(freespacenotifier_prefs_base);
        label_minimumSpace->setObjectName("label_minimumSpace");
        label_minimumSpace->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_minimumSpace, 1, 0, 1, 1);

        kcfg_minimumSpace = new QSpinBox(freespacenotifier_prefs_base);
        kcfg_minimumSpace->setObjectName("kcfg_minimumSpace");

        gridLayout->addWidget(kcfg_minimumSpace, 1, 1, 1, 1);

        label_minimumSpacePercentage = new QLabel(freespacenotifier_prefs_base);
        label_minimumSpacePercentage->setObjectName("label_minimumSpacePercentage");
        label_minimumSpacePercentage->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_minimumSpacePercentage, 2, 0, 1, 1);

        kcfg_minimumSpacePercentage = new QSpinBox(freespacenotifier_prefs_base);
        kcfg_minimumSpacePercentage->setObjectName("kcfg_minimumSpacePercentage");
        kcfg_minimumSpacePercentage->setMinimum(0);
        kcfg_minimumSpacePercentage->setMaximum(100);

        gridLayout->addWidget(kcfg_minimumSpacePercentage, 2, 1, 1, 1);

        label_info = new QLabel(freespacenotifier_prefs_base);
        label_info->setObjectName("label_info");
        label_info->setWordWrap(true);

        gridLayout->addWidget(label_info, 3, 0, 1, 2);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 4, 0, 1, 2);


        retranslateUi(freespacenotifier_prefs_base);
        QObject::connect(kcfg_enableNotification, &QCheckBox::toggled, kcfg_minimumSpace, &QSpinBox::setEnabled);
        QObject::connect(kcfg_enableNotification, &QCheckBox::toggled, label_minimumSpace, &QLabel::setEnabled);
        QObject::connect(kcfg_enableNotification, &QCheckBox::toggled, kcfg_minimumSpacePercentage, &QSpinBox::setEnabled);
        QObject::connect(kcfg_enableNotification, &QCheckBox::toggled, label_minimumSpacePercentage, &QLabel::setEnabled);

        QMetaObject::connectSlotsByName(freespacenotifier_prefs_base);
    } // setupUi

    void retranslateUi(QWidget *freespacenotifier_prefs_base)
    {
        kcfg_enableNotification->setText(tr2i18n("Enable low disk space warning", nullptr));
        label_minimumSpace->setText(tr2i18n("Warn when free space is below:", nullptr));
        kcfg_minimumSpace->setSuffix(tr2i18n(" MiB", nullptr));
        label_minimumSpacePercentage->setText(tr2i18n("And when free space is under:", nullptr));
        kcfg_minimumSpacePercentage->setSuffix(tr2i18n("%", nullptr));
        label_info->setText(tr2i18n("The system will notify you if the free space drops below the specified MiB and the specified percentage of available space.", nullptr));
        (void)freespacenotifier_prefs_base;
    } // retranslateUi

};

namespace Ui {
    class freespacenotifier_prefs_base: public Ui_freespacenotifier_prefs_base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FREESPACENOTIFIER_PREFS_BASE_H

