// /qt/qml/org/kde/plasma/workspace/components/BatteryIcon.qml
#include <QtQml/qqmlprivate.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qobject.h>
#include <QtCore/qstring.h>
#include <QtCore/qstringlist.h>
#include <QtCore/qtimezone.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <QtQml/qqmlcomponent.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmllist.h>
#include <type_traits>
namespace QmlCacheGeneratedCode {
namespace _qt_qml_org_kde_plasma_workspace_components_BatteryIcon_qml {
extern const unsigned char qmlData alignas(16) [];
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x49,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x34,0x15,0x0,0x0,0x6d,0x9a,0x56,0x52,
0x89,0x63,0x80,0xc9,0x21,0x62,0x87,0x40,
0x62,0x4b,0x85,0x4a,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0x42,0x0,0x0,0x0,0x40,0x8,0x0,0x0,
0xa,0x0,0x0,0x0,0xc8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,
0x24,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x50,0x11,0x0,0x0,
0x80,0x1,0x0,0x0,0xf0,0x1,0x0,0x0,
0x40,0x2,0x0,0x0,0x90,0x2,0x0,0x0,
0x50,0x5,0x0,0x0,0xa0,0x5,0x0,0x0,
0x8,0x6,0x0,0x0,0x68,0x6,0x0,0x0,
0xb8,0x6,0x0,0x0,0xf0,0x7,0x0,0x0,
0x53,0x0,0x0,0x0,0x60,0x0,0x0,0x0,
0x53,0x0,0x0,0x0,0x70,0x0,0x0,0x0,
0x77,0x1,0x0,0x0,0x53,0x0,0x0,0x0,
0xd0,0x0,0x0,0x0,0xb3,0x1,0x0,0x0,
0x40,0x1,0x0,0x0,0x53,0x0,0x0,0x0,
0xb0,0x0,0x0,0x0,0x53,0x0,0x0,0x0,
0xa0,0x0,0x0,0x0,0x53,0x0,0x0,0x0,
0xc0,0x0,0x0,0x0,0x53,0x0,0x0,0x0,
0xc0,0x0,0x0,0x0,0x53,0x0,0x0,0x0,
0x80,0x0,0x0,0x0,0x53,0x0,0x0,0x0,
0xc0,0x0,0x0,0x0,0xe0,0x2,0x0,0x0,
0x53,0x0,0x0,0x0,0xc0,0x0,0x0,0x0,
0x3,0x3,0x0,0x0,0x53,0x0,0x0,0x0,
0x90,0x0,0x0,0x0,0xc7,0x1,0x0,0x0,
0x53,0x0,0x0,0x0,0xd0,0x0,0x0,0x0,
0x53,0x0,0x0,0x0,0x90,0x0,0x0,0x0,
0xc7,0x1,0x0,0x0,0x53,0x0,0x0,0x0,
0xb0,0x0,0x0,0x0,0x3,0x3,0x0,0x0,
0x44,0x0,0x0,0x0,0x27,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0xa,0x0,0x0,0x0,
0x1d,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1d,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x0,0x3c,0x1,
0x50,0xc,0x2e,0x2,0x3c,0x3,0x18,0x9,
0xb4,0x4,0x1,0x9,0x4c,0x2,0x12,0x1e,
0x18,0x7,0x2e,0x5,0x3c,0x6,0x50,0x4,
0x12,0x1f,0x4c,0x2,0x12,0x0,0x80,0x7,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x8,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x1e,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1e,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x7,0x3c,0x8,
0x74,0x18,0x6,0x2,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x16,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x1f,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1f,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x9,0x3c,0xa,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0xa8,0x1,0x0,0x0,0xdc,0x0,0x0,0x0,
0x17,0x0,0x0,0x0,0x1,0x0,0x1,0x0,
0x38,0x0,0x0,0x0,0x15,0x0,0x0,0x0,
0x40,0x0,0x0,0x0,0x0,0x0,0x1e,0x0,
0xff,0xff,0xff,0xff,0xc,0x0,0x0,0x0,
0x21,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x8,0x0,0x1,0x0,0x0,0x0,
0x19,0x0,0x0,0x0,0x9,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x24,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0xc,0x0,0x0,0x0,
0x25,0x0,0x0,0x0,0x3,0x0,0x0,0x0,
0x17,0x0,0x0,0x0,0x28,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x1a,0x0,0x0,0x0,
0x29,0x0,0x0,0x0,0x5,0x0,0x0,0x0,
0x20,0x0,0x0,0x0,0x2a,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x29,0x0,0x0,0x0,
0x2b,0x0,0x0,0x0,0x9,0x0,0x0,0x0,
0x2f,0x0,0x0,0x0,0x2c,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x38,0x0,0x0,0x0,
0x2d,0x0,0x0,0x0,0xd,0x0,0x0,0x0,
0x3e,0x0,0x0,0x0,0x2e,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x47,0x0,0x0,0x0,
0x2f,0x0,0x0,0x0,0x11,0x0,0x0,0x0,
0x4d,0x0,0x0,0x0,0x30,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x53,0x0,0x0,0x0,
0x31,0x0,0x0,0x0,0x15,0x0,0x0,0x0,
0x59,0x0,0x0,0x0,0x32,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x5f,0x0,0x0,0x0,
0x33,0x0,0x0,0x0,0x19,0x0,0x0,0x0,
0x65,0x0,0x0,0x0,0x34,0x0,0x0,0x0,
0x1c,0x0,0x0,0x0,0x6b,0x0,0x0,0x0,
0x35,0x0,0x0,0x0,0x1d,0x0,0x0,0x0,
0x71,0x0,0x0,0x0,0x36,0x0,0x0,0x0,
0x20,0x0,0x0,0x0,0x77,0x0,0x0,0x0,
0x37,0x0,0x0,0x0,0x21,0x0,0x0,0x0,
0x7d,0x0,0x0,0x0,0x38,0x0,0x0,0x0,
0x24,0x0,0x0,0x0,0x83,0x0,0x0,0x0,
0x39,0x0,0x0,0x0,0x25,0x0,0x0,0x0,
0x89,0x0,0x0,0x0,0x3a,0x0,0x0,0x0,
0x28,0x0,0x0,0x0,0x8f,0x0,0x0,0x0,
0x3b,0x0,0x0,0x0,0x29,0x0,0x0,0x0,
0x95,0x0,0x0,0x0,0x3c,0x0,0x0,0x0,
0x2c,0x0,0x0,0x0,0x9b,0x0,0x0,0x0,
0x3e,0x0,0x0,0x0,0x2f,0x0,0x0,0x0,
0x9f,0x0,0x0,0x0,0x41,0x0,0x0,0x0,
0x30,0x0,0x0,0x0,0xa5,0x0,0x0,0x0,
0x42,0x0,0x0,0x0,0x33,0x0,0x0,0x0,
0xb3,0x0,0x0,0x0,0x45,0x0,0x0,0x0,
0x34,0x0,0x0,0x0,0xc0,0x0,0x0,0x0,
0x46,0x0,0x0,0x0,0x37,0x0,0x0,0x0,
0xd6,0x0,0x0,0x0,0x49,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0xd9,0x0,0x0,0x0,
0x4a,0x0,0x0,0x0,0x38,0x0,0x0,0x0,
0x2e,0xb,0x3c,0xc,0x50,0x11,0x2e,0xd,
0x3c,0xe,0x50,0xb,0x12,0x20,0x18,0x9,
0x2e,0xf,0x3c,0x10,0x80,0x9,0x2,0xe,
0x18,0x8,0x10,0x5f,0x66,0x6,0x50,0x9,
0x12,0x21,0x18,0x8,0x4d,0x76,0x0,0x0,
0x0,0x10,0x55,0x66,0x6,0x50,0x9,0x12,
0x22,0x18,0x8,0x4d,0x67,0x0,0x0,0x0,
0x10,0x4b,0x66,0x6,0x50,0x9,0x12,0x23,
0x18,0x8,0x4d,0x58,0x0,0x0,0x0,0x10,
0x41,0x66,0x6,0x50,0x6,0x12,0x24,0x18,
0x8,0x4c,0x4c,0x10,0x37,0x66,0x6,0x50,
0x6,0x12,0x25,0x18,0x8,0x4c,0x40,0x10,
0x2d,0x66,0x6,0x50,0x6,0x12,0x26,0x18,
0x8,0x4c,0x34,0x10,0x23,0x66,0x6,0x50,
0x6,0x12,0x27,0x18,0x8,0x4c,0x28,0x10,
0x19,0x66,0x6,0x50,0x6,0x12,0x28,0x18,
0x8,0x4c,0x1c,0x10,0xf,0x66,0x6,0x50,
0x6,0x12,0x29,0x18,0x8,0x4c,0x10,0x10,
0x5,0x64,0x6,0x50,0x6,0x12,0x2a,0x18,
0x8,0x4c,0x4,0x12,0x2b,0x18,0x8,0x2e,
0x11,0x3c,0x12,0x50,0xe,0x16,0x8,0xc2,
0x2c,0x18,0x9,0x12,0x2d,0x80,0x9,0x18,
0x8,0xc2,0x2c,0x2e,0x13,0x3c,0x14,0x3c,
0x15,0x18,0x9,0x6,0x64,0x9,0x50,0x16,
0x16,0x8,0xc2,0x2c,0x18,0xa,0x12,0x2f,
0x18,0xb,0x2e,0x16,0x3c,0x17,0x80,0xb,
0x80,0xa,0x18,0x8,0xc2,0x2c,0x16,0x8,
0x2,0x16,0x7,0x2,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x5,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x1c,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1c,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x18,0x18,0x6,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x1d,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0xa,0x0,0x0,0x0,
0x51,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x51,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x19,0x3c,0x1a,
0x18,0x9,0xb4,0x1b,0x1,0x9,0x18,0x7,
0x2e,0x1c,0x3c,0x1d,0x50,0x4,0x12,0x1f,
0x4c,0x2,0x12,0x0,0x80,0x7,0x18,0x6,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x13,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0xa,0x0,0x0,0x0,
0x52,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x52,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x1e,0x3c,0x1f,
0x18,0x9,0xb4,0x20,0x1,0x9,0x18,0x7,
0x12,0x0,0x6e,0x7,0x18,0x6,0x2,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x16,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x53,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x53,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x21,0x3c,0x22,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0xd0,0x0,0x0,0x0,0x59,0x0,0x0,0x0,
0x1c,0x0,0x0,0x0,0x1,0x0,0x1,0x0,
0x38,0x0,0x0,0x0,0x15,0x0,0x0,0x0,
0x40,0x0,0x0,0x0,0x0,0x0,0xc,0x0,
0xff,0xff,0xff,0xff,0x8,0x0,0x0,0x0,
0x55,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x8,0x0,0x0,0x0,0x0,0x0,
0x1d,0x0,0x0,0x0,0x15,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x56,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x38,0x0,0x0,0x0,
0x58,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0x3b,0x0,0x0,0x0,0x5a,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x3e,0x0,0x0,0x0,
0x5c,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0x41,0x0,0x0,0x0,0x5e,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x44,0x0,0x0,0x0,
0x60,0x0,0x0,0x0,0x6,0x0,0x0,0x0,
0x47,0x0,0x0,0x0,0x62,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x4a,0x0,0x0,0x0,
0x64,0x0,0x0,0x0,0x8,0x0,0x0,0x0,
0x4d,0x0,0x0,0x0,0x66,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x50,0x0,0x0,0x0,
0x68,0x0,0x0,0x0,0xa,0x0,0x0,0x0,
0x53,0x0,0x0,0x0,0x6a,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x56,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0xb,0x0,0x0,0x0,
0x12,0x31,0x6c,0x6,0x4e,0x32,0x12,0x32,
0x6c,0x6,0x4e,0x2f,0x12,0x33,0x6c,0x6,
0x4e,0x2c,0x12,0x34,0x6c,0x6,0x4e,0x29,
0x12,0x35,0x6c,0x6,0x4e,0x26,0x12,0x36,
0x6c,0x6,0x4e,0x23,0x12,0x37,0x6c,0x6,
0x4e,0x20,0x12,0x38,0x6c,0x6,0x4e,0x1d,
0x12,0x39,0x6c,0x6,0x4e,0x1a,0x4c,0x1b,
0x12,0x3a,0x2,0x12,0x3b,0x2,0x12,0x3c,
0x2,0x12,0x3c,0x2,0x12,0x3d,0x2,0x12,
0x3e,0x2,0x12,0x3f,0x2,0x12,0x40,0x2,
0x12,0x41,0x2,0x12,0x0,0x2,0x16,0x7,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x5,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x50,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x50,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x23,0x18,0x6,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x48,0x9,0x0,0x0,0x50,0x9,0x0,0x0,
0x68,0x9,0x0,0x0,0x80,0x9,0x0,0x0,
0xa8,0x9,0x0,0x0,0xb8,0x9,0x0,0x0,
0xc8,0x9,0x0,0x0,0xe8,0x9,0x0,0x0,
0x0,0xa,0x0,0x0,0x18,0xa,0x0,0x0,
0x38,0xa,0x0,0x0,0x68,0xa,0x0,0x0,
0x80,0xa,0x0,0x0,0xb0,0xa,0x0,0x0,
0xd8,0xa,0x0,0x0,0xf8,0xa,0x0,0x0,
0x10,0xb,0x0,0x0,0x20,0xb,0x0,0x0,
0x50,0xb,0x0,0x0,0x68,0xb,0x0,0x0,
0x98,0xb,0x0,0x0,0xb0,0xb,0x0,0x0,
0xe8,0xb,0x0,0x0,0x18,0xc,0x0,0x0,
0x38,0xc,0x0,0x0,0x50,0xc,0x0,0x0,
0x58,0xc,0x0,0x0,0x68,0xc,0x0,0x0,
0x98,0xc,0x0,0x0,0xc0,0xc,0x0,0x0,
0xc8,0xc,0x0,0x0,0xf0,0xc,0x0,0x0,
0x8,0xd,0x0,0x0,0x30,0xd,0x0,0x0,
0x50,0xd,0x0,0x0,0x70,0xd,0x0,0x0,
0x90,0xd,0x0,0x0,0xb0,0xd,0x0,0x0,
0xd0,0xd,0x0,0x0,0xf0,0xd,0x0,0x0,
0x10,0xe,0x0,0x0,0x30,0xe,0x0,0x0,
0x50,0xe,0x0,0x0,0x70,0xe,0x0,0x0,
0x90,0xe,0x0,0x0,0xa0,0xe,0x0,0x0,
0xb8,0xe,0x0,0x0,0xd0,0xe,0x0,0x0,
0xe8,0xe,0x0,0x0,0x0,0xf,0x0,0x0,
0x10,0xf,0x0,0x0,0x28,0xf,0x0,0x0,
0x38,0xf,0x0,0x0,0x48,0xf,0x0,0x0,
0x58,0xf,0x0,0x0,0x78,0xf,0x0,0x0,
0x90,0xf,0x0,0x0,0xa8,0xf,0x0,0x0,
0xc0,0xf,0x0,0x0,0xf0,0xf,0x0,0x0,
0x28,0x10,0x0,0x0,0x48,0x10,0x0,0x0,
0x68,0x10,0x0,0x0,0x98,0x10,0x0,0x0,
0xe8,0x10,0x0,0x0,0x20,0x11,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x4b,0x0,0x69,0x0,
0x72,0x0,0x69,0x0,0x67,0x0,0x61,0x0,
0x6d,0x0,0x69,0x0,0x0,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x6f,0x0,0x72,0x0,
0x67,0x0,0x2e,0x0,0x6b,0x0,0x64,0x0,
0x65,0x0,0x2e,0x0,0x6b,0x0,0x69,0x0,
0x72,0x0,0x69,0x0,0x67,0x0,0x61,0x0,
0x6d,0x0,0x69,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x49,0x0,0x74,0x0,
0x65,0x0,0x6d,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x72,0x0,0x6f,0x0,
0x6f,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x68,0x0,0x61,0x0,
0x73,0x0,0x42,0x0,0x61,0x0,0x74,0x0,
0x74,0x0,0x65,0x0,0x72,0x0,0x79,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x70,0x0,0x65,0x0,
0x72,0x0,0x63,0x0,0x65,0x0,0x6e,0x0,
0x74,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x70,0x0,0x6c,0x0,
0x75,0x0,0x67,0x0,0x67,0x0,0x65,0x0,
0x64,0x0,0x49,0x0,0x6e,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x62,0x0,0x61,0x0,
0x74,0x0,0x74,0x0,0x65,0x0,0x72,0x0,
0x79,0x0,0x54,0x0,0x79,0x0,0x70,0x0,
0x65,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x69,0x0,0x73,0x0,
0x53,0x0,0x6f,0x0,0x6d,0x0,0x65,0x0,
0x68,0x0,0x6f,0x0,0x77,0x0,0x46,0x0,
0x75,0x0,0x6c,0x0,0x6c,0x0,0x79,0x0,
0x43,0x0,0x68,0x0,0x61,0x0,0x72,0x0,
0x67,0x0,0x65,0x0,0x64,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x61,0x0,0x63,0x0,
0x74,0x0,0x69,0x0,0x76,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x70,0x0,0x6f,0x0,
0x77,0x0,0x65,0x0,0x72,0x0,0x50,0x0,
0x72,0x0,0x6f,0x0,0x66,0x0,0x69,0x0,
0x6c,0x0,0x65,0x0,0x49,0x0,0x63,0x0,
0x6f,0x0,0x6e,0x0,0x4e,0x0,0x61,0x0,
0x6d,0x0,0x65,0x0,0x0,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x70,0x0,0x72,0x0,
0x65,0x0,0x66,0x0,0x65,0x0,0x72,0x0,
0x53,0x0,0x79,0x0,0x6d,0x0,0x62,0x0,
0x6f,0x0,0x6c,0x0,0x69,0x0,0x63,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x4b,0x0,0x69,0x0,
0x72,0x0,0x69,0x0,0x67,0x0,0x61,0x0,
0x6d,0x0,0x69,0x0,0x2e,0x0,0x49,0x0,
0x63,0x0,0x6f,0x0,0x6e,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x61,0x0,0x6e,0x0,
0x63,0x0,0x68,0x0,0x6f,0x0,0x72,0x0,
0x73,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x66,0x0,0x69,0x0,
0x6c,0x0,0x6c,0x0,0x0,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x66,0x0,0x69,0x0,0x6c,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x73,0x0,0x6f,0x0,
0x75,0x0,0x72,0x0,0x63,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x73,0x0,0x6f,0x0,0x75,0x0,
0x72,0x0,0x63,0x0,0x65,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x76,0x0,0x69,0x0,
0x73,0x0,0x69,0x0,0x62,0x0,0x6c,0x0,
0x65,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x16,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x76,0x0,0x69,0x0,0x73,0x0,
0x69,0x0,0x62,0x0,0x6c,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x61,0x0,0x63,0x0,0x74,0x0,
0x69,0x0,0x76,0x0,0x65,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x66,0x0,0x69,0x0,
0x6c,0x0,0x6c,0x0,0x45,0x0,0x6c,0x0,
0x65,0x0,0x6d,0x0,0x65,0x0,0x6e,0x0,
0x74,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x73,0x0,0x74,0x0,
0x72,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x70,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x69,0x0,0x6e,0x0,
0x74,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x12,0x0,0x0,0x0,0x6f,0x0,0x74,0x0,
0x68,0x0,0x65,0x0,0x72,0x0,0x42,0x0,
0x61,0x0,0x74,0x0,0x74,0x0,0x65,0x0,
0x72,0x0,0x69,0x0,0x65,0x0,0x73,0x0,
0x49,0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x65,0x0,0x6c,0x0,
0x65,0x0,0x6d,0x0,0x65,0x0,0x6e,0x0,
0x74,0x0,0x46,0x0,0x6f,0x0,0x72,0x0,
0x54,0x0,0x79,0x0,0x70,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x74,0x0,0x0,0x0,
0xf,0x0,0x0,0x0,0x62,0x0,0x61,0x0,
0x74,0x0,0x74,0x0,0x65,0x0,0x72,0x0,
0x79,0x0,0x2d,0x0,0x6d,0x0,0x69,0x0,
0x73,0x0,0x73,0x0,0x69,0x0,0x6e,0x0,
0x67,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x2d,0x0,0x73,0x0,
0x79,0x0,0x6d,0x0,0x62,0x0,0x6f,0x0,
0x6c,0x0,0x69,0x0,0x63,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x62,0x0,0x61,0x0,
0x74,0x0,0x74,0x0,0x65,0x0,0x72,0x0,
0x79,0x0,0x2d,0x0,0x70,0x0,0x72,0x0,
0x6f,0x0,0x66,0x0,0x69,0x0,0x6c,0x0,
0x65,0x0,0x2d,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x62,0x0,0x61,0x0,
0x74,0x0,0x74,0x0,0x65,0x0,0x72,0x0,
0x79,0x0,0x2d,0x0,0x31,0x0,0x30,0x0,
0x30,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x62,0x0,0x61,0x0,
0x74,0x0,0x74,0x0,0x65,0x0,0x72,0x0,
0x79,0x0,0x2d,0x0,0x30,0x0,0x39,0x0,
0x30,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x62,0x0,0x61,0x0,
0x74,0x0,0x74,0x0,0x65,0x0,0x72,0x0,
0x79,0x0,0x2d,0x0,0x30,0x0,0x38,0x0,
0x30,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x62,0x0,0x61,0x0,
0x74,0x0,0x74,0x0,0x65,0x0,0x72,0x0,
0x79,0x0,0x2d,0x0,0x30,0x0,0x37,0x0,
0x30,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x62,0x0,0x61,0x0,
0x74,0x0,0x74,0x0,0x65,0x0,0x72,0x0,
0x79,0x0,0x2d,0x0,0x30,0x0,0x36,0x0,
0x30,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x62,0x0,0x61,0x0,
0x74,0x0,0x74,0x0,0x65,0x0,0x72,0x0,
0x79,0x0,0x2d,0x0,0x30,0x0,0x35,0x0,
0x30,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x62,0x0,0x61,0x0,
0x74,0x0,0x74,0x0,0x65,0x0,0x72,0x0,
0x79,0x0,0x2d,0x0,0x30,0x0,0x34,0x0,
0x30,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x62,0x0,0x61,0x0,
0x74,0x0,0x74,0x0,0x65,0x0,0x72,0x0,
0x79,0x0,0x2d,0x0,0x30,0x0,0x33,0x0,
0x30,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x62,0x0,0x61,0x0,
0x74,0x0,0x74,0x0,0x65,0x0,0x72,0x0,
0x79,0x0,0x2d,0x0,0x30,0x0,0x32,0x0,
0x30,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x62,0x0,0x61,0x0,
0x74,0x0,0x74,0x0,0x65,0x0,0x72,0x0,
0x79,0x0,0x2d,0x0,0x30,0x0,0x31,0x0,
0x30,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x62,0x0,0x61,0x0,
0x74,0x0,0x74,0x0,0x65,0x0,0x72,0x0,
0x79,0x0,0x2d,0x0,0x30,0x0,0x30,0x0,
0x30,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x6e,0x0,0x61,0x0,
0x6d,0x0,0x65,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x2d,0x0,0x63,0x0,
0x68,0x0,0x61,0x0,0x72,0x0,0x67,0x0,
0x69,0x0,0x6e,0x0,0x67,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x6c,0x0,0x65,0x0,
0x6e,0x0,0x67,0x0,0x74,0x0,0x68,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x2d,0x0,0x70,0x0,
0x72,0x0,0x6f,0x0,0x66,0x0,0x69,0x0,
0x6c,0x0,0x65,0x0,0x2d,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x70,0x0,0x61,0x0,
0x72,0x0,0x65,0x0,0x6e,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x4d,0x0,0x6f,0x0,
0x75,0x0,0x73,0x0,0x65,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x4b,0x0,0x65,0x0,
0x79,0x0,0x62,0x0,0x6f,0x0,0x61,0x0,
0x72,0x0,0x64,0x0,0x0,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x50,0x0,0x64,0x0,
0x61,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x50,0x0,0x68,0x0,
0x6f,0x0,0x6e,0x0,0x65,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x55,0x0,0x70,0x0,
0x73,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x47,0x0,0x61,0x0,
0x6d,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,
0x49,0x0,0x6e,0x0,0x70,0x0,0x75,0x0,
0x74,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x42,0x0,0x6c,0x0,
0x75,0x0,0x65,0x0,0x74,0x0,0x6f,0x0,
0x6f,0x0,0x74,0x0,0x68,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x48,0x0,0x65,0x0,
0x61,0x0,0x64,0x0,0x70,0x0,0x68,0x0,
0x6f,0x0,0x6e,0x0,0x65,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x48,0x0,0x65,0x0,
0x61,0x0,0x64,0x0,0x73,0x0,0x65,0x0,
0x74,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x69,0x0,0x6e,0x0,
0x70,0x0,0x75,0x0,0x74,0x0,0x2d,0x0,
0x6d,0x0,0x6f,0x0,0x75,0x0,0x73,0x0,
0x65,0x0,0x2d,0x0,0x62,0x0,0x61,0x0,
0x74,0x0,0x74,0x0,0x65,0x0,0x72,0x0,
0x79,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x16,0x0,0x0,0x0,0x69,0x0,0x6e,0x0,
0x70,0x0,0x75,0x0,0x74,0x0,0x2d,0x0,
0x6b,0x0,0x65,0x0,0x79,0x0,0x62,0x0,
0x6f,0x0,0x61,0x0,0x72,0x0,0x64,0x0,
0x2d,0x0,0x62,0x0,0x61,0x0,0x74,0x0,
0x74,0x0,0x65,0x0,0x72,0x0,0x79,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x70,0x0,0x68,0x0,
0x6f,0x0,0x6e,0x0,0x65,0x0,0x2d,0x0,
0x62,0x0,0x61,0x0,0x74,0x0,0x74,0x0,
0x65,0x0,0x72,0x0,0x79,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x62,0x0,0x61,0x0,
0x74,0x0,0x74,0x0,0x65,0x0,0x72,0x0,
0x79,0x0,0x2d,0x0,0x75,0x0,0x70,0x0,
0x73,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x69,0x0,0x6e,0x0,
0x70,0x0,0x75,0x0,0x74,0x0,0x2d,0x0,
0x67,0x0,0x61,0x0,0x6d,0x0,0x69,0x0,
0x6e,0x0,0x67,0x0,0x2d,0x0,0x62,0x0,
0x61,0x0,0x74,0x0,0x74,0x0,0x65,0x0,
0x72,0x0,0x79,0x0,0x0,0x0,0x0,0x0,
0x24,0x0,0x0,0x0,0x70,0x0,0x72,0x0,
0x65,0x0,0x66,0x0,0x65,0x0,0x72,0x0,
0x65,0x0,0x6e,0x0,0x63,0x0,0x65,0x0,
0x73,0x0,0x2d,0x0,0x73,0x0,0x79,0x0,
0x73,0x0,0x74,0x0,0x65,0x0,0x6d,0x0,
0x2d,0x0,0x62,0x0,0x6c,0x0,0x75,0x0,
0x65,0x0,0x74,0x0,0x6f,0x0,0x6f,0x0,
0x74,0x0,0x68,0x0,0x2d,0x0,0x62,0x0,
0x61,0x0,0x74,0x0,0x74,0x0,0x65,0x0,
0x72,0x0,0x79,0x0,0x0,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x61,0x0,0x75,0x0,
0x64,0x0,0x69,0x0,0x6f,0x0,0x2d,0x0,
0x68,0x0,0x65,0x0,0x61,0x0,0x64,0x0,
0x70,0x0,0x68,0x0,0x6f,0x0,0x6e,0x0,
0x65,0x0,0x73,0x0,0x2d,0x0,0x62,0x0,
0x61,0x0,0x74,0x0,0x74,0x0,0x65,0x0,
0x72,0x0,0x79,0x0,0x0,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x61,0x0,0x75,0x0,
0x64,0x0,0x69,0x0,0x6f,0x0,0x2d,0x0,
0x68,0x0,0x65,0x0,0x61,0x0,0x64,0x0,
0x73,0x0,0x65,0x0,0x74,0x0,0x2d,0x0,
0x62,0x0,0x61,0x0,0x74,0x0,0x74,0x0,
0x65,0x0,0x72,0x0,0x79,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x38,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x8,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x1,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0xa,0x0,0x10,0x0,0xff,0xff,0x0,0x0,
0x4c,0x0,0x0,0x0,0x94,0x1,0x0,0x0,
0x4c,0x2,0x0,0x0,0xbc,0x2,0x0,0x0,
0x74,0x3,0x0,0x0,0x4,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x8,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0xb4,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb4,0x0,0x0,0x0,0xb4,0x0,0x0,0x0,
0x0,0x0,0x6,0x0,0xb4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x44,0x1,0x0,0x0,
0xc,0x0,0x10,0x0,0xd,0x0,0x50,0x0,
0x44,0x1,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x1,0x0,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x3,0x0,0x0,0x20,
0xf,0x0,0x50,0x0,0x7,0x0,0x0,0x0,
0x2,0x0,0x0,0x20,0x10,0x0,0x50,0x0,
0x8,0x0,0x0,0x0,0x3,0x0,0x0,0x20,
0x11,0x0,0x50,0x0,0x9,0x0,0x0,0x0,
0x5,0x0,0x0,0x20,0x12,0x0,0x50,0x0,
0xa,0x0,0x0,0x0,0x3,0x0,0x0,0x20,
0x13,0x0,0x50,0x0,0xb,0x0,0x0,0x0,
0x3,0x0,0x0,0x20,0x14,0x0,0x50,0x0,
0xc,0x0,0x0,0x0,0x5,0x0,0x0,0x20,
0x15,0x0,0x50,0x0,0xd,0x0,0x0,0x0,
0x3,0x0,0x0,0x20,0x16,0x0,0x50,0x0,
0xd,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x16,0x0,0x30,0x1,0x16,0x0,0x30,0x2,
0xc,0x0,0x0,0x0,0x0,0x0,0x3,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x15,0x0,0x50,0x1,0x15,0x0,0xb0,0x2,
0xb,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x14,0x0,0x30,0x1,0x14,0x0,0xb0,0x1,
0xa,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x13,0x0,0x30,0x1,0x13,0x0,0xa0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x8,0x0,
0x1,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1b,0x0,0x50,0x0,0x1b,0x0,0x50,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x8,0x0,
0x3,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4e,0x0,0x50,0x0,0x4e,0x0,0x50,0x0,
0x0,0x0,0x0,0x0,0xe,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x1,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x58,0x0,0x0,0x0,
0x58,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x58,0x0,0x0,0x0,0x58,0x0,0x0,0x0,
0x0,0x0,0x4,0x0,0x58,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xb8,0x0,0x0,0x0,
0x1b,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0xb8,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb8,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0xb,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1f,0x0,0x90,0x0,
0x1f,0x0,0x10,0x1,0x14,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1e,0x0,0x90,0x0,
0x1e,0x0,0x20,0x1,0x12,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1d,0x0,0x90,0x0,
0x1d,0x0,0x10,0x1,0xf,0x0,0x0,0x0,
0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1c,0x0,0x90,0x0,
0x1c,0x0,0x10,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x1,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6c,0x0,0x0,0x0,
0x1c,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x4,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1c,0x0,0x10,0x1,0x1c,0x0,0x70,0x1,
0x0,0x0,0x0,0x0,0xe,0x0,0x0,0x0,
0x1b,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x1,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x58,0x0,0x0,0x0,
0x58,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x58,0x0,0x0,0x0,0x58,0x0,0x0,0x0,
0x0,0x0,0x4,0x0,0x58,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xb8,0x0,0x0,0x0,
0x4e,0x0,0x50,0x0,0x4f,0x0,0x90,0x0,
0xb8,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb8,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0xb,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x7,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x53,0x0,0x90,0x0,
0x53,0x0,0x10,0x1,0x14,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x6,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x52,0x0,0x90,0x0,
0x52,0x0,0x20,0x1,0x12,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x5,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x51,0x0,0x90,0x0,
0x51,0x0,0x10,0x1,0xf,0x0,0x0,0x0,
0x0,0x0,0xa,0x0,0x4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x50,0x0,0x90,0x0,
0x50,0x0,0x10,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x1,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6c,0x0,0x0,0x0,
0x50,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x9,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x50,0x0,0x10,0x1,0x50,0x0,0x70,0x1,
0x0,0x0,0x0,0x0
};
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[] = {
{ 0, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<QVariant>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for source at line 29, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
    aotContext->mark(v2_22, markStack);
    aotContext->mark(v2_34, markStack);
    aotContext->mark(v2_6, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QObject *v2_22 = nullptr;
QObject *v2_6 = nullptr;
QString c2_34;
QString c7_32;
QString c7_34;
QString v2_12;
QString v2_18;
QString v2_28;
QString v2_32;
QString v7_20;
QVariant v2_34;
bool v2_24;
bool v2_2;
int v2_8;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(0, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QVariant *>(argv[0]) = QVariant();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(1, s.v2_0, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(1, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QVariant *>(argv[0]) = QVariant();
}
return;
}
}
{
}
// generate_JumpFalse
if (!s.v2_2) {
    goto label_0;
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
while (!aotContext->loadContextIdLookup(2, &s.v2_6)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
aotContext->initLoadContextIdLookup(2);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QVariant *>(argv[0]) = QVariant();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
while (!aotContext->getObjectLookup(3, s.v2_6, &s.v2_8)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
aotContext->initGetObjectLookup(3, s.v2_6);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QVariant *>(argv[0]) = QVariant();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_CallQmlContextPropertyLookup
{
QString callResult;
const auto doCall = [&]() {
    void *args[] = {&callResult, &s.v2_8};
    return aotContext->callQmlContextPropertyLookup(4, args, 1);
};
const auto doInit = [&]() {
    aotContext->initCallQmlContextPropertyLookup(4, 3);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QVariant *>(argv[0]) = QVariant();
}
return;
}
}
s.v2_12 = std::move(callResult);
aotContext->setImplicitDestructible(s.v2_12);
}
{
}
// generate_Jump
{
s.v7_20 = s.v2_12;
    goto label_1;
}
label_0:;
// generate_LoadRuntimeString
s.v2_18 = QStringLiteral("battery-missing");
{
s.v7_20 = s.v2_18;
}
label_1:;
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(24);
#endif
while (!aotContext->loadContextIdLookup(5, &s.v2_22)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(24);
#endif
aotContext->initLoadContextIdLookup(5);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QVariant *>(argv[0]) = QVariant();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(26);
#endif
while (!aotContext->getObjectLookup(6, s.v2_22, &s.v2_24)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(26);
#endif
aotContext->initGetObjectLookup(6, s.v2_22);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QVariant *>(argv[0]) = QVariant();
}
return;
}
}
{
}
// generate_JumpFalse
if (!s.v2_24) {
s.c7_32 = s.v7_20;
    goto label_2;
}
{
}
// generate_LoadRuntimeString
s.v2_28 = QStringLiteral("-symbolic");
{
}
// generate_Jump
{
s.c2_34 = s.v2_28;
s.c7_34 = s.v7_20;
    goto label_3;
}
label_2:;
// generate_LoadRuntimeString
s.v2_32 = QStringLiteral("");
{
s.c2_34 = s.v2_32;
s.c7_34 = s.c7_32;
}
label_3:;
// generate_Add
s.v2_34 = QVariant::fromValue(QString(s.c7_34 + s.c2_34));
{
}
{
}
// generate_Ret
if (argv[0]) {
    if (!s.v2_34.isValid())
        aotContext->setReturnValueUndefined();
    *static_cast<QVariant *>(argv[0]) = std::move(s.v2_34);
}
return;
}
 },{ 1, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<bool>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for visible at line 30, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
bool v2_2;
bool v2_4;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(7, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(7);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = bool();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(8, s.v2_0, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(8, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = bool();
}
return;
}
}
{
}
// generate_UNot
s.v2_4 = !s.v2_2;
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = s.v2_4;
}
return;
}
 },{ 2, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<bool>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for active at line 31, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
bool v2_2;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(9, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(9);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = bool();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(10, s.v2_0, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(10, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = bool();
}
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = s.v2_2;
}
return;
}
 },{ 3, 1, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<QString>();
    argTypes[1] = QMetaType::fromType<int>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// fillElement at line 33, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
    aotContext->mark(v2_159, markStack);
    aotContext->mark(v2_16, markStack);
    aotContext->mark(v2_179, markStack);
    aotContext->mark(v2_202, markStack);
    aotContext->mark(v2_6, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QObject *v2_159 = nullptr;
QObject *v2_16 = nullptr;
QObject *v2_179 = nullptr;
QObject *v2_202 = nullptr;
QObject *v2_6 = nullptr;
QString c8_159;
QString c8_179;
QString v2_101;
QString v2_113;
QString v2_125;
QString v2_12;
QString v2_137;
QString v2_149;
QString v2_155;
QString v2_171;
QString v2_173;
QString v2_181;
QString v2_18;
QString v2_198;
QString v2_204;
QString v2_206;
QString v2_208;
QString v2_20;
QString v2_214;
QString v2_32;
QString v2_47;
QString v2_62;
QString v2_77;
QString v2_89;
bool v2_109;
bool v2_121;
bool v2_133;
bool v2_145;
bool v2_161;
bool v2_188;
bool v2_28;
bool v2_2;
bool v2_43;
bool v2_58;
bool v2_73;
bool v2_85;
bool v2_8;
bool v2_97;
double v2_183;
double v2_187;
int a1 = (*static_cast<int*>(argv[1]));
int v2_107;
int v2_119;
int v2_131;
int v2_143;
int v2_26;
int v2_41;
int v2_56;
int v2_71;
int v2_83;
int v2_95;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(11, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(11);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(12, s.v2_0, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(12, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_JumpFalse
if (!s.v2_2) {
    goto label_0;
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
while (!aotContext->loadContextIdLookup(13, &s.v2_6)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
aotContext->initLoadContextIdLookup(13);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_GetLookup
{
QString retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
while (!aotContext->getObjectLookup(14, s.v2_6, &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
aotContext->initGetObjectLookup(14, s.v2_6);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
s.v2_8 = QJSPrimitiveValue(std::move(retrieved)).toBoolean();
}
{
}
// generate_JumpFalse
if (!s.v2_8) {
    goto label_0;
}
{
}
// generate_LoadRuntimeString
s.v2_12 = QStringLiteral("battery-profile-");
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
while (!aotContext->loadContextIdLookup(15, &s.v2_16)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
aotContext->initLoadContextIdLookup(15);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(20);
#endif
while (!aotContext->getObjectLookup(16, s.v2_16, &s.v2_18)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(20);
#endif
aotContext->initGetObjectLookup(16, s.v2_16);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_Add
s.v2_20 = QString(std::move(s.v2_12) + std::move(s.v2_18));
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = std::move(s.v2_20);
}
return;
label_0:;
{
}
{
}
// generate_LoadInt
s.v2_26 = 95;
{
}
// generate_CmpGe
s.v2_28 = s.a1 >= s.v2_26;
{
}
// generate_JumpFalse
if (!s.v2_28) {
    goto label_1;
}
{
}
// generate_LoadRuntimeString
s.v2_32 = QStringLiteral("battery-100");
{
}
// generate_StoreReg
{
}
// generate_Jump
{
s.c8_159 = s.v2_32;
    goto label_2;
}
label_1:;
// generate_LoadInt
s.v2_41 = 85;
{
}
// generate_CmpGe
s.v2_43 = s.a1 >= s.v2_41;
{
}
// generate_JumpFalse
if (!s.v2_43) {
    goto label_3;
}
{
}
// generate_LoadRuntimeString
s.v2_47 = QStringLiteral("battery-090");
{
}
// generate_StoreReg
{
}
// generate_Jump
{
s.c8_159 = s.v2_47;
    goto label_2;
}
label_3:;
// generate_LoadInt
s.v2_56 = 75;
{
}
// generate_CmpGe
s.v2_58 = s.a1 >= s.v2_56;
{
}
// generate_JumpFalse
if (!s.v2_58) {
    goto label_4;
}
{
}
// generate_LoadRuntimeString
s.v2_62 = QStringLiteral("battery-080");
{
}
// generate_StoreReg
{
}
// generate_Jump
{
s.c8_159 = s.v2_62;
    goto label_2;
}
label_4:;
// generate_LoadInt
s.v2_71 = 65;
{
}
// generate_CmpGe
s.v2_73 = s.a1 >= s.v2_71;
{
}
// generate_JumpFalse
if (!s.v2_73) {
    goto label_5;
}
{
}
// generate_LoadRuntimeString
s.v2_77 = QStringLiteral("battery-070");
{
}
// generate_StoreReg
{
}
// generate_Jump
{
s.c8_159 = s.v2_77;
    goto label_2;
}
label_5:;
// generate_LoadInt
s.v2_83 = 55;
{
}
// generate_CmpGe
s.v2_85 = s.a1 >= s.v2_83;
{
}
// generate_JumpFalse
if (!s.v2_85) {
    goto label_6;
}
{
}
// generate_LoadRuntimeString
s.v2_89 = QStringLiteral("battery-060");
{
}
// generate_StoreReg
{
}
// generate_Jump
{
s.c8_159 = s.v2_89;
    goto label_2;
}
label_6:;
// generate_LoadInt
s.v2_95 = 45;
{
}
// generate_CmpGe
s.v2_97 = s.a1 >= s.v2_95;
{
}
// generate_JumpFalse
if (!s.v2_97) {
    goto label_7;
}
{
}
// generate_LoadRuntimeString
s.v2_101 = QStringLiteral("battery-050");
{
}
// generate_StoreReg
{
}
// generate_Jump
{
s.c8_159 = s.v2_101;
    goto label_2;
}
label_7:;
// generate_LoadInt
s.v2_107 = 35;
{
}
// generate_CmpGe
s.v2_109 = s.a1 >= s.v2_107;
{
}
// generate_JumpFalse
if (!s.v2_109) {
    goto label_8;
}
{
}
// generate_LoadRuntimeString
s.v2_113 = QStringLiteral("battery-040");
{
}
// generate_StoreReg
{
}
// generate_Jump
{
s.c8_159 = s.v2_113;
    goto label_2;
}
label_8:;
// generate_LoadInt
s.v2_119 = 25;
{
}
// generate_CmpGe
s.v2_121 = s.a1 >= s.v2_119;
{
}
// generate_JumpFalse
if (!s.v2_121) {
    goto label_9;
}
{
}
// generate_LoadRuntimeString
s.v2_125 = QStringLiteral("battery-030");
{
}
// generate_StoreReg
{
}
// generate_Jump
{
s.c8_159 = s.v2_125;
    goto label_2;
}
label_9:;
// generate_LoadInt
s.v2_131 = 15;
{
}
// generate_CmpGe
s.v2_133 = s.a1 >= s.v2_131;
{
}
// generate_JumpFalse
if (!s.v2_133) {
    goto label_10;
}
{
}
// generate_LoadRuntimeString
s.v2_137 = QStringLiteral("battery-020");
{
}
// generate_StoreReg
{
}
// generate_Jump
{
s.c8_159 = s.v2_137;
    goto label_2;
}
label_10:;
// generate_LoadInt
s.v2_143 = 5;
{
}
// generate_CmpGt
s.v2_145 = s.a1 > s.v2_143;
{
}
// generate_JumpFalse
if (!s.v2_145) {
    goto label_11;
}
{
}
// generate_LoadRuntimeString
s.v2_149 = QStringLiteral("battery-010");
{
}
// generate_StoreReg
{
}
// generate_Jump
{
s.c8_159 = s.v2_149;
    goto label_2;
}
label_11:;
// generate_LoadRuntimeString
s.v2_155 = QStringLiteral("battery-000");
{
}
// generate_StoreReg
{
s.c8_159 = s.v2_155;
}
label_2:;
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(161);
#endif
while (!aotContext->loadContextIdLookup(17, &s.v2_159)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(161);
#endif
aotContext->initLoadContextIdLookup(17);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(163);
#endif
while (!aotContext->getObjectLookup(18, s.v2_159, &s.v2_161)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(163);
#endif
aotContext->initGetObjectLookup(18, s.v2_159);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_JumpFalse
if (!s.v2_161) {
s.c8_179 = s.c8_159;
    goto label_12;
}
{
}
// generate_LoadReg
{
}
{
}
// generate_StoreReg
{
}
// generate_LoadRuntimeString
s.v2_171 = QStringLiteral("-charging");
{
}
// generate_Add
s.v2_173 = QString(s.c8_159 + std::move(s.v2_171));
{
}
// generate_StoreReg
{
}
{
s.c8_179 = s.v2_173;
}
label_12:;
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(181);
#endif
while (!aotContext->loadContextIdLookup(19, &s.v2_179)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(181);
#endif
aotContext->initLoadContextIdLookup(19);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(183);
#endif
while (!aotContext->getObjectLookup(20, s.v2_179, &s.v2_181)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(183);
#endif
aotContext->initGetObjectLookup(20, s.v2_179);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_GetLookup
{
qlonglong retrieved;
retrieved = s.v2_181.length();
s.v2_183 = double(std::move(retrieved));
}
{
}
// generate_StoreReg
{
}
// generate_LoadZero
s.v2_187 = double(0);
{
}
// generate_CmpGt
s.v2_188 = s.v2_183 > s.v2_187;
{
}
// generate_JumpFalse
if (!s.v2_188) {
s.v2_214 = s.c8_179;
    goto label_13;
}
{
}
// generate_LoadReg
{
}
{
}
// generate_StoreReg
{
}
// generate_LoadRuntimeString
s.v2_198 = QStringLiteral("-profile-");
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(204);
#endif
while (!aotContext->loadContextIdLookup(22, &s.v2_202)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(204);
#endif
aotContext->initLoadContextIdLookup(22);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(206);
#endif
while (!aotContext->getObjectLookup(23, s.v2_202, &s.v2_204)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(206);
#endif
aotContext->initGetObjectLookup(23, s.v2_202);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_Add
s.v2_206 = QString(std::move(s.v2_198) + std::move(s.v2_204));
{
}
// generate_Add
s.v2_208 = QString(s.c8_179 + std::move(s.v2_206));
{
}
// generate_StoreReg
{
}
{
s.v2_214 = s.v2_208;
}
label_13:;
// generate_LoadReg
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = std::move(s.v2_214);
}
return;
}
 },{ 4, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("QQuickItem*"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for fill at line 28, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(24, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadScopeObjectPropertyLookup(24);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QObject * *>(argv[0]) = nullptr;
}
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QObject * *>(argv[0]) = s.v2_0;
}
return;
}
 },{ 5, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<QVariant>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for source at line 81, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
    aotContext->mark(v2_12, markStack);
    aotContext->mark(v2_24, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QObject *v2_12 = nullptr;
QString c2_24;
QString v2_18;
QString v2_22;
QString v2_2;
QString v2_6;
QVariant v2_24;
bool v2_14;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(25, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(25);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QVariant *>(argv[0]) = QVariant();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(26, s.v2_0, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(26, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QVariant *>(argv[0]) = QVariant();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_CallQmlContextPropertyLookup
{
QString callResult;
const auto doCall = [&]() {
    void *args[] = {&callResult, &s.v2_2};
    return aotContext->callQmlContextPropertyLookup(27, args, 1);
};
const auto doInit = [&]() {
    aotContext->initCallQmlContextPropertyLookup(27, 3);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QVariant *>(argv[0]) = QVariant();
}
return;
}
}
s.v2_6 = std::move(callResult);
aotContext->setImplicitDestructible(s.v2_6);
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
while (!aotContext->loadContextIdLookup(28, &s.v2_12)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
aotContext->initLoadContextIdLookup(28);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QVariant *>(argv[0]) = QVariant();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
while (!aotContext->getObjectLookup(29, s.v2_12, &s.v2_14)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
aotContext->initGetObjectLookup(29, s.v2_12);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QVariant *>(argv[0]) = QVariant();
}
return;
}
}
{
}
// generate_JumpFalse
if (!s.v2_14) {
    goto label_0;
}
{
}
// generate_LoadRuntimeString
s.v2_18 = QStringLiteral("-symbolic");
{
}
// generate_Jump
{
s.c2_24 = s.v2_18;
    goto label_1;
}
label_0:;
// generate_LoadRuntimeString
s.v2_22 = QStringLiteral("");
{
s.c2_24 = s.v2_22;
}
label_1:;
// generate_Add
s.v2_24 = QVariant::fromValue(QString(s.v2_6 + s.c2_24));
{
}
{
}
// generate_Ret
if (argv[0]) {
    if (!s.v2_24.isValid())
        aotContext->setReturnValueUndefined();
    *static_cast<QVariant *>(argv[0]) = std::move(s.v2_24);
}
return;
}
 },{ 6, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<bool>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for visible at line 82, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QString v2_12;
QString v2_2;
QString v2_6;
bool v2_14;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(30, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(30);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = bool();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(31, s.v2_0, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(31, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = bool();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_CallQmlContextPropertyLookup
{
QString callResult;
const auto doCall = [&]() {
    void *args[] = {&callResult, &s.v2_2};
    return aotContext->callQmlContextPropertyLookup(32, args, 1);
};
const auto doInit = [&]() {
    aotContext->initCallQmlContextPropertyLookup(32, 3);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = bool();
}
return;
}
}
s.v2_6 = std::move(callResult);
aotContext->setImplicitDestructible(s.v2_6);
}
{
}
// generate_StoreReg
{
}
// generate_LoadRuntimeString
s.v2_12 = QStringLiteral("");
{
}
// generate_CmpStrictNotEqual
s.v2_14 = s.v2_6 != s.v2_12;
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = s.v2_14;
}
return;
}
 },{ 7, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<bool>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for active at line 83, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
bool v2_2;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(33, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(33);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = bool();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(34, s.v2_0, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(34, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = bool();
}
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = s.v2_2;
}
return;
}
 },{ 8, 1, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<QString>();
    argTypes[1] = QMetaType::fromType<QString>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// elementForType at line 85, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QString a1 = (*static_cast<QString*>(argv[1]));
QString v2_0;
QString v2_12;
QString v2_18;
QString v2_24;
QString v2_30;
QString v2_36;
QString v2_42;
QString v2_48;
QString v2_56;
QString v2_59;
QString v2_62;
QString v2_65;
QString v2_68;
QString v2_6;
QString v2_71;
QString v2_74;
QString v2_77;
QString v2_80;
QString v2_83;
bool v2_14;
bool v2_20;
bool v2_26;
bool v2_2;
bool v2_32;
bool v2_38;
bool v2_44;
bool v2_50;
bool v2_8;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadRuntimeString
s.v2_0 = QStringLiteral("Mouse");
{
}
// generate_CmpStrictEqual
s.v2_2 = s.a1 == s.v2_0;
{
}
// generate_JumpTrue
if (s.v2_2) {
    goto label_0;
}
{
}
// generate_LoadRuntimeString
s.v2_6 = QStringLiteral("Keyboard");
{
}
// generate_CmpStrictEqual
s.v2_8 = s.a1 == s.v2_6;
{
}
// generate_JumpTrue
if (s.v2_8) {
    goto label_1;
}
{
}
// generate_LoadRuntimeString
s.v2_12 = QStringLiteral("Pda");
{
}
// generate_CmpStrictEqual
s.v2_14 = s.a1 == s.v2_12;
{
}
// generate_JumpTrue
if (s.v2_14) {
    goto label_2;
}
{
}
// generate_LoadRuntimeString
s.v2_18 = QStringLiteral("Phone");
{
}
// generate_CmpStrictEqual
s.v2_20 = s.a1 == s.v2_18;
{
}
// generate_JumpTrue
if (s.v2_20) {
    goto label_3;
}
{
}
// generate_LoadRuntimeString
s.v2_24 = QStringLiteral("Ups");
{
}
// generate_CmpStrictEqual
s.v2_26 = s.a1 == s.v2_24;
{
}
// generate_JumpTrue
if (s.v2_26) {
    goto label_4;
}
{
}
// generate_LoadRuntimeString
s.v2_30 = QStringLiteral("GamingInput");
{
}
// generate_CmpStrictEqual
s.v2_32 = s.a1 == s.v2_30;
{
}
// generate_JumpTrue
if (s.v2_32) {
    goto label_5;
}
{
}
// generate_LoadRuntimeString
s.v2_36 = QStringLiteral("Bluetooth");
{
}
// generate_CmpStrictEqual
s.v2_38 = s.a1 == s.v2_36;
{
}
// generate_JumpTrue
if (s.v2_38) {
    goto label_6;
}
{
}
// generate_LoadRuntimeString
s.v2_42 = QStringLiteral("Headphone");
{
}
// generate_CmpStrictEqual
s.v2_44 = s.a1 == s.v2_42;
{
}
// generate_JumpTrue
if (s.v2_44) {
    goto label_7;
}
{
}
// generate_LoadRuntimeString
s.v2_48 = QStringLiteral("Headset");
{
}
// generate_CmpStrictEqual
s.v2_50 = s.a1 == s.v2_48;
{
}
// generate_JumpTrue
if (s.v2_50) {
    goto label_8;
}
{
}
// generate_Jump
{
    goto label_9;
}
label_0:;
// generate_LoadRuntimeString
s.v2_56 = QStringLiteral("input-mouse-battery");
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = std::move(s.v2_56);
}
return;
label_1:;
// generate_LoadRuntimeString
s.v2_59 = QStringLiteral("input-keyboard-battery");
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = std::move(s.v2_59);
}
return;
label_2:;
// generate_LoadRuntimeString
s.v2_62 = QStringLiteral("phone-battery");
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = std::move(s.v2_62);
}
return;
label_3:;
// generate_LoadRuntimeString
s.v2_65 = QStringLiteral("phone-battery");
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = std::move(s.v2_65);
}
return;
label_4:;
// generate_LoadRuntimeString
s.v2_68 = QStringLiteral("battery-ups");
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = std::move(s.v2_68);
}
return;
label_5:;
// generate_LoadRuntimeString
s.v2_71 = QStringLiteral("input-gaming-battery");
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = std::move(s.v2_71);
}
return;
label_6:;
// generate_LoadRuntimeString
s.v2_74 = QStringLiteral("preferences-system-bluetooth-battery");
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = std::move(s.v2_74);
}
return;
label_7:;
// generate_LoadRuntimeString
s.v2_77 = QStringLiteral("audio-headphones-battery");
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = std::move(s.v2_77);
}
return;
label_8:;
// generate_LoadRuntimeString
s.v2_80 = QStringLiteral("audio-headset-battery");
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = std::move(s.v2_80);
}
return;
label_9:;
// generate_LoadRuntimeString
s.v2_83 = QStringLiteral("");
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = std::move(s.v2_83);
}
return;
}
 },{ 9, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("QQuickItem*"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for fill at line 80, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(35, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadScopeObjectPropertyLookup(35);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QObject * *>(argv[0]) = nullptr;
}
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QObject * *>(argv[0]) = s.v2_0;
}
return;
}
 },{ 0, 0, nullptr, nullptr }};
}
}
