// This file is generated by kconfig_compiler_kf6 from feedbacksettings.kcfg.
// All changes you do to this file will be lost.

#include "feedbacksettings.h"

FeedbackSettings::FeedbackSettings( QObject *parent )
  : KConfigSkeleton( QStringLiteral( "PlasmaUserFeedback" ) )
{
  setParent(parent);
  KConfigCompilerSignallingItem::NotifyFunction notifyFunction = static_cast<KConfigCompilerSignallingItem::NotifyFunction>(&FeedbackSettings::itemChanged);

  setCurrentGroup( QStringLiteral( "Global" ) );

  KConfigCompilerSignallingItem  *itemFeedbackLevel;
  KConfigSkeleton::ItemInt  *innerItemFeedbackLevel;
  innerItemFeedbackLevel = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "FeedbackLevel" ), mFeedbackLevel, KUserFeedback::Provider::NoTelemetry );
  itemFeedbackLevel = new KConfigCompilerSignallingItem(innerItemFeedbackLevel, this, notifyFunction, signalFeedbackLevelChanged);
  addItem( itemFeedbackLevel, QStringLiteral( "feedbackLevel" ) );
}

int FeedbackSettings::defaultFeedbackLevelValue_helper() const
{

  return KUserFeedback::Provider::NoTelemetry;
}

FeedbackSettings::~FeedbackSettings()
{
}


void FeedbackSettings::itemChanged(quint64 signalFlag) {

  switch (signalFlag) {
  case signalFeedbackLevelChanged:
    Q_EMIT feedbackLevelChanged();
    break;
  }
}
