/****************************************************************************
** Meta object code from reading C++ file 'abstracttasksmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-workspace-6.7.1/libtaskmanager/abstracttasksmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'abstracttasksmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11TaskManager18AbstractTasksModelE_t {};
} // unnamed namespace

template <> constexpr inline auto TaskManager::AbstractTasksModel::qt_create_metaobjectdata<qt_meta_tag_ZN11TaskManager18AbstractTasksModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TaskManager::AbstractTasksModel",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "AdditionalRoles",
        "AppId",
        "AppName",
        "GenericName",
        "LauncherUrl",
        "LauncherUrlWithoutIcon",
        "WinIdList",
        "MimeType",
        "MimeData",
        "IsWindow",
        "IsStartup",
        "IsLauncher",
        "HasLauncher",
        "IsGroupParent",
        "ChildCount",
        "IsGroupable",
        "IsActive",
        "IsClosable",
        "IsMovable",
        "IsResizable",
        "IsMaximizable",
        "IsMaximized",
        "IsMinimizable",
        "IsMinimized",
        "IsKeepAbove",
        "IsKeepBelow",
        "IsFullScreenable",
        "IsFullScreen",
        "IsShadeable",
        "IsShaded",
        "IsVirtualDesktopsChangeable",
        "VirtualDesktops",
        "IsOnAllVirtualDesktops",
        "Geometry",
        "ScreenGeometry",
        "Activities",
        "IsDemandingAttention",
        "SkipTaskbar",
        "SkipPager",
        "AppPid",
        "StackingOrder",
        "LastActivated",
        "ApplicationMenuServiceName",
        "ApplicationMenuObjectPath",
        "IsHidden",
        "CanLaunchNewInstance",
        "HasNoBorder",
        "CanSetNoBorder",
        "IsExcludedFromCapture"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'AdditionalRoles'
        QtMocHelpers::EnumData<enum AdditionalRoles>(7, 7, QMC::EnumFlags{}).add({
            {    8, AdditionalRoles::AppId },
            {    9, AdditionalRoles::AppName },
            {   10, AdditionalRoles::GenericName },
            {   11, AdditionalRoles::LauncherUrl },
            {   12, AdditionalRoles::LauncherUrlWithoutIcon },
            {   13, AdditionalRoles::WinIdList },
            {   14, AdditionalRoles::MimeType },
            {   15, AdditionalRoles::MimeData },
            {   16, AdditionalRoles::IsWindow },
            {   17, AdditionalRoles::IsStartup },
            {   18, AdditionalRoles::IsLauncher },
            {   19, AdditionalRoles::HasLauncher },
            {   20, AdditionalRoles::IsGroupParent },
            {   21, AdditionalRoles::ChildCount },
            {   22, AdditionalRoles::IsGroupable },
            {   23, AdditionalRoles::IsActive },
            {   24, AdditionalRoles::IsClosable },
            {   25, AdditionalRoles::IsMovable },
            {   26, AdditionalRoles::IsResizable },
            {   27, AdditionalRoles::IsMaximizable },
            {   28, AdditionalRoles::IsMaximized },
            {   29, AdditionalRoles::IsMinimizable },
            {   30, AdditionalRoles::IsMinimized },
            {   31, AdditionalRoles::IsKeepAbove },
            {   32, AdditionalRoles::IsKeepBelow },
            {   33, AdditionalRoles::IsFullScreenable },
            {   34, AdditionalRoles::IsFullScreen },
            {   35, AdditionalRoles::IsShadeable },
            {   36, AdditionalRoles::IsShaded },
            {   37, AdditionalRoles::IsVirtualDesktopsChangeable },
            {   38, AdditionalRoles::VirtualDesktops },
            {   39, AdditionalRoles::IsOnAllVirtualDesktops },
            {   40, AdditionalRoles::Geometry },
            {   41, AdditionalRoles::ScreenGeometry },
            {   42, AdditionalRoles::Activities },
            {   43, AdditionalRoles::IsDemandingAttention },
            {   44, AdditionalRoles::SkipTaskbar },
            {   45, AdditionalRoles::SkipPager },
            {   46, AdditionalRoles::AppPid },
            {   47, AdditionalRoles::StackingOrder },
            {   48, AdditionalRoles::LastActivated },
            {   49, AdditionalRoles::ApplicationMenuServiceName },
            {   50, AdditionalRoles::ApplicationMenuObjectPath },
            {   51, AdditionalRoles::IsHidden },
            {   52, AdditionalRoles::CanLaunchNewInstance },
            {   53, AdditionalRoles::HasNoBorder },
            {   54, AdditionalRoles::CanSetNoBorder },
            {   55, AdditionalRoles::IsExcludedFromCapture },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<AbstractTasksModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject TaskManager::AbstractTasksModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11TaskManager18AbstractTasksModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11TaskManager18AbstractTasksModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11TaskManager18AbstractTasksModelE_t>.metaTypes,
    nullptr
} };

void TaskManager::AbstractTasksModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractTasksModel *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *TaskManager::AbstractTasksModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TaskManager::AbstractTasksModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11TaskManager18AbstractTasksModelE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "AbstractTasksModelIface"))
        return static_cast< AbstractTasksModelIface*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int TaskManager::AbstractTasksModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
