/****************************************************************************
** Meta object code from reading C++ file 'jobviewv3adaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "jobviewv3adaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'jobviewv3adaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16JobViewV3AdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto JobViewV3Adaptor::qt_create_metaobjectdata<qt_meta_tag_ZN16JobViewV3AdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "JobViewV3Adaptor",
        "D-Bus Interface",
        "org.kde.JobViewV3",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.JobViewV3\">\n    <method name=\"termi"
        "nate\">\n      <arg direction=\"in\" type=\"u\" name=\"errorCode\""
        "/>\n      <arg direction=\"in\" type=\"s\" name=\"errorMessage\"/>"
        "\n      <arg direction=\"in\" type=\"a{sv}\" name=\"hints\"/>\n   "
        "   <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.N"
        "oReply\"/>\n      <annotation value=\"QVariantMap\" name=\"org.qtp"
        "roject.QtDBus.QtTypeName.In2\"/>\n    </method>\n    <method name="
        "\"update\">\n      <arg direction=\"in\" type=\"a{sv}\" name=\"pro"
        "perties\"/>\n      <annotation value=\"true\" name=\"org.freedeskt"
        "op.DBus.Method.NoReply\"/>\n      <annotation value=\"QVariantMap\""
        " name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n    </method>\n  "
        "  <signal name=\"updateRequested\"/>\n    <signal name=\"suspendRe"
        "quested\"/>\n    <signal name=\"resumeRequested\"/>\n    <signal n"
        "ame=\"cancelRequested\"/>\n  </interface>\n",
        "cancelRequested",
        "",
        "resumeRequested",
        "suspendRequested",
        "updateRequested",
        "terminate",
        "Q_NOREPLY",
        "errorCode",
        "errorMessage",
        "QVariantMap",
        "hints",
        "update",
        "properties"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'cancelRequested'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resumeRequested'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'suspendRequested'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateRequested'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'terminate'
        QtMocHelpers::SlotData<void(uint, const QString &, const QVariantMap &)>(10, 11, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 12 }, { QMetaType::QString, 13 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'update'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(16, 11, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 17 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<JobViewV3Adaptor, qt_meta_tag_ZN16JobViewV3AdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject JobViewV3Adaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16JobViewV3AdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16JobViewV3AdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16JobViewV3AdaptorE_t>.metaTypes,
    nullptr
} };

void JobViewV3Adaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<JobViewV3Adaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->cancelRequested(); break;
        case 1: _t->resumeRequested(); break;
        case 2: _t->suspendRequested(); break;
        case 3: _t->updateRequested(); break;
        case 4: _t->terminate((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3]))); break;
        case 5: _t->update((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (JobViewV3Adaptor::*)()>(_a, &JobViewV3Adaptor::cancelRequested, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (JobViewV3Adaptor::*)()>(_a, &JobViewV3Adaptor::resumeRequested, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (JobViewV3Adaptor::*)()>(_a, &JobViewV3Adaptor::suspendRequested, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (JobViewV3Adaptor::*)()>(_a, &JobViewV3Adaptor::updateRequested, 3))
            return;
    }
}

const QMetaObject *JobViewV3Adaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *JobViewV3Adaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16JobViewV3AdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int JobViewV3Adaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void JobViewV3Adaptor::cancelRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void JobViewV3Adaptor::resumeRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void JobViewV3Adaptor::suspendRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void JobViewV3Adaptor::updateRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
