/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.KSMServerInterface.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "ksmserverinterfaceadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class KSMServerInterfaceAdaptor
 */

KSMServerInterfaceAdaptor::KSMServerInterfaceAdaptor(KSMServer *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

KSMServerInterfaceAdaptor::~KSMServerInterfaceAdaptor()
{
    // destructor
}

bool KSMServerInterfaceAdaptor::closeSession()
{
    // handle method call org.kde.KSMServerInterface.closeSession
    return parent()->closeSession();
}

QString KSMServerInterfaceAdaptor::currentSession()
{
    // handle method call org.kde.KSMServerInterface.currentSession
    return parent()->currentSession();
}

bool KSMServerInterfaceAdaptor::isShuttingDown()
{
    // handle method call org.kde.KSMServerInterface.isShuttingDown
    return parent()->isShuttingDown();
}

void KSMServerInterfaceAdaptor::resetLogout()
{
    // handle method call org.kde.KSMServerInterface.resetLogout
    parent()->resetLogout();
}

void KSMServerInterfaceAdaptor::restoreSession()
{
    // handle method call org.kde.KSMServerInterface.restoreSession
    parent()->restoreSession();
}

void KSMServerInterfaceAdaptor::saveCurrentSession()
{
    // handle method call org.kde.KSMServerInterface.saveCurrentSession
    parent()->saveCurrentSession();
}

void KSMServerInterfaceAdaptor::saveCurrentSessionAs(const QString &in0)
{
    // handle method call org.kde.KSMServerInterface.saveCurrentSessionAs
    parent()->saveCurrentSessionAs(in0);
}

QStringList KSMServerInterfaceAdaptor::sessionList()
{
    // handle method call org.kde.KSMServerInterface.sessionList
    return parent()->sessionList();
}


#include "moc_ksmserverinterfaceadaptor.cpp"
