/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.JobViewV3.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef JOBVIEWV3ADAPTOR_H
#define JOBVIEWV3ADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "job_p.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.JobViewV3
 */
class JobViewV3Adaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.JobViewV3")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.JobViewV3\">\n"
"    <method name=\"terminate\">\n"
"      <arg direction=\"in\" type=\"u\" name=\"errorCode\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"errorMessage\"/>\n"
"      <arg direction=\"in\" type=\"a{sv}\" name=\"hints\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.In2\"/>\n"
"    </method>\n"
"    <method name=\"update\">\n"
"      <arg direction=\"in\" type=\"a{sv}\" name=\"properties\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"    </method>\n"
"    <signal name=\"updateRequested\"/>\n"
"    <signal name=\"suspendRequested\"/>\n"
"    <signal name=\"resumeRequested\"/>\n"
"    <signal name=\"cancelRequested\"/>\n"
"  </interface>\n"
        "")
public:
    JobViewV3Adaptor(NotificationManager::JobPrivate *parent);
    ~JobViewV3Adaptor() override;

    inline NotificationManager::JobPrivate *parent() const
    { return static_cast<NotificationManager::JobPrivate *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    Q_NOREPLY void terminate(uint errorCode, const QString &errorMessage, const QVariantMap &hints);
    Q_NOREPLY void update(const QVariantMap &properties);
Q_SIGNALS: // SIGNALS
    void cancelRequested();
    void resumeRequested();
    void suspendRequested();
    void updateRequested();
};

#endif
