// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#include "colorsdata.h"

#include "colorssettings.h"




ColorsData::ColorsData(QObject *parent)
: KCModuleData(parent)
, m_settings(new ColorsSettings(this))

{
autoRegisterSkeletons();
}

ColorsSettings *ColorsData::settings() const
{
    return m_settings;
}





#include "moc_colorsdata.cpp"
