/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.JobViewServerV2.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef JOBVIEWSERVERV2ADAPTOR_H
#define JOBVIEWSERVERV2ADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "jobsmodel_p.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.JobViewServerV2
 */
class JobViewServerV2Adaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.JobViewServerV2")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.JobViewServerV2\">\n"
"    <method name=\"requestView\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"desktopEntry\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"capabilities\"/>\n"
"      <arg direction=\"in\" type=\"a{sv}\" name=\"hints\"/>\n"
"      <arg direction=\"out\" type=\"o\" name=\"trackerPath\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.In2\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    JobViewServerV2Adaptor(NotificationManager::JobsModelPrivate *parent);
    ~JobViewServerV2Adaptor() override;

    inline NotificationManager::JobsModelPrivate *parent() const
    { return static_cast<NotificationManager::JobsModelPrivate *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    QDBusObjectPath requestView(const QString &desktopEntry, int capabilities, const QVariantMap &hints);
Q_SIGNALS: // SIGNALS
};

#endif
