/****************************************************************************
** Meta object code from reading C++ file 'fingerprintmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../plasma-workspace-6.7.1/kcms/users/src/fingerprintmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fingerprintmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6FingerE_t {};
} // unnamed namespace

template <> constexpr inline auto Finger::qt_create_metaobjectdata<qt_meta_tag_ZN6FingerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Finger",
        "internalName",
        "friendlyName"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'internalName'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'friendlyName'
        QtMocHelpers::PropertyData<QString>(2, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Finger, qt_meta_tag_ZN6FingerE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Finger::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6FingerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6FingerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6FingerE_t>.metaTypes,
    nullptr
} };

void Finger::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Finger *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->internalName(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->friendlyName(); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN16FingerprintModelE_t {};
} // unnamed namespace

template <> constexpr inline auto FingerprintModel::qt_create_metaobjectdata<qt_meta_tag_ZN16FingerprintModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FingerprintModel",
        "currentErrorChanged",
        "",
        "enrollFeedbackChanged",
        "enrolledFingerprintsChanged",
        "devicesFoundChanged",
        "currentlyEnrollingChanged",
        "enrollProgressChanged",
        "dialogStateChanged",
        "scanComplete",
        "scanSuccess",
        "scanFailure",
        "handleEnrollCompleted",
        "handleEnrollStagePassed",
        "handleEnrollRetryStage",
        "feedback",
        "handleEnrollFailed",
        "error",
        "switchUser",
        "username",
        "startEnrolling",
        "finger",
        "stopEnrolling",
        "deleteFingerprint",
        "scanType",
        "FprintDevice::ScanType",
        "currentError",
        "enrollFeedback",
        "enrolledFingerprints",
        "QVariantList",
        "availableFingersToEnroll",
        "unavailableFingersToEnroll",
        "deviceFound",
        "currentlyEnrolling",
        "enrollProgress",
        "dialogState",
        "DialogState",
        "FingerprintList",
        "PickFinger",
        "Enrolling",
        "EnrollComplete"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentErrorChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enrollFeedbackChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enrolledFingerprintsChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'devicesFoundChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentlyEnrollingChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enrollProgressChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dialogStateChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scanComplete'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scanSuccess'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scanFailure'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleEnrollCompleted'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleEnrollStagePassed'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleEnrollRetryStage'
        QtMocHelpers::SlotData<void(const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'handleEnrollFailed'
        QtMocHelpers::SlotData<void(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Method 'switchUser'
        QtMocHelpers::MethodData<void(const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Method 'startEnrolling'
        QtMocHelpers::MethodData<void(const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Method 'stopEnrolling'
        QtMocHelpers::MethodData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'deleteFingerprint'
        QtMocHelpers::MethodData<void(const QString &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'scanType'
        QtMocHelpers::PropertyData<FprintDevice::ScanType>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'currentError'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'enrollFeedback'
        QtMocHelpers::PropertyData<QString>(27, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'enrolledFingerprints'
        QtMocHelpers::PropertyData<QVariantList>(28, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'availableFingersToEnroll'
        QtMocHelpers::PropertyData<QVariantList>(30, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'unavailableFingersToEnroll'
        QtMocHelpers::PropertyData<QVariantList>(31, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'deviceFound'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'currentlyEnrolling'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
        // property 'enrollProgress'
        QtMocHelpers::PropertyData<double>(34, QMetaType::Double, QMC::DefaultPropertyFlags, 5),
        // property 'dialogState'
        QtMocHelpers::PropertyData<enum DialogState>(35, 0x80000000 | 36, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'DialogState'
        QtMocHelpers::EnumData<enum DialogState>(36, 36, QMC::EnumFlags{}).add({
            {   37, DialogState::FingerprintList },
            {   38, DialogState::PickFinger },
            {   39, DialogState::Enrolling },
            {   40, DialogState::EnrollComplete },
        }),
    };
    return QtMocHelpers::metaObjectData<FingerprintModel, qt_meta_tag_ZN16FingerprintModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN16FingerprintModelE[] = {
    QMetaObject::SuperData::link<FprintDevice::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject FingerprintModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16FingerprintModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16FingerprintModelE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN16FingerprintModelE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16FingerprintModelE_t>.metaTypes,
    nullptr
} };

void FingerprintModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FingerprintModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentErrorChanged(); break;
        case 1: _t->enrollFeedbackChanged(); break;
        case 2: _t->enrolledFingerprintsChanged(); break;
        case 3: _t->devicesFoundChanged(); break;
        case 4: _t->currentlyEnrollingChanged(); break;
        case 5: _t->enrollProgressChanged(); break;
        case 6: _t->dialogStateChanged(); break;
        case 7: _t->scanComplete(); break;
        case 8: _t->scanSuccess(); break;
        case 9: _t->scanFailure(); break;
        case 10: _t->handleEnrollCompleted(); break;
        case 11: _t->handleEnrollStagePassed(); break;
        case 12: _t->handleEnrollRetryStage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->handleEnrollFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->switchUser((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->startEnrolling((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->stopEnrolling(); break;
        case 17: _t->deleteFingerprint((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FingerprintModel::*)()>(_a, &FingerprintModel::currentErrorChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FingerprintModel::*)()>(_a, &FingerprintModel::enrollFeedbackChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FingerprintModel::*)()>(_a, &FingerprintModel::enrolledFingerprintsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FingerprintModel::*)()>(_a, &FingerprintModel::devicesFoundChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FingerprintModel::*)()>(_a, &FingerprintModel::currentlyEnrollingChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FingerprintModel::*)()>(_a, &FingerprintModel::enrollProgressChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (FingerprintModel::*)()>(_a, &FingerprintModel::dialogStateChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (FingerprintModel::*)()>(_a, &FingerprintModel::scanComplete, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (FingerprintModel::*)()>(_a, &FingerprintModel::scanSuccess, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (FingerprintModel::*)()>(_a, &FingerprintModel::scanFailure, 9))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<FprintDevice::ScanType*>(_v) = _t->scanType(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->currentError(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->enrollFeedback(); break;
        case 3: *reinterpret_cast<QVariantList*>(_v) = _t->enrolledFingerprints(); break;
        case 4: *reinterpret_cast<QVariantList*>(_v) = _t->availableFingersToEnroll(); break;
        case 5: *reinterpret_cast<QVariantList*>(_v) = _t->unavailableFingersToEnroll(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->deviceFound(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->currentlyEnrolling(); break;
        case 8: *reinterpret_cast<double*>(_v) = _t->enrollProgress(); break;
        case 9: *reinterpret_cast<enum DialogState*>(_v) = _t->dialogState(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setCurrentError(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setEnrollFeedback(*reinterpret_cast<QString*>(_v)); break;
        case 9: _t->setDialogState(*reinterpret_cast<enum DialogState*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *FingerprintModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FingerprintModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16FingerprintModelE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int FingerprintModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void FingerprintModel::currentErrorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void FingerprintModel::enrollFeedbackChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void FingerprintModel::enrolledFingerprintsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void FingerprintModel::devicesFoundChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void FingerprintModel::currentlyEnrollingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void FingerprintModel::enrollProgressChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void FingerprintModel::dialogStateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void FingerprintModel::scanComplete()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void FingerprintModel::scanSuccess()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void FingerprintModel::scanFailure()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
