/****************************************************************************
** Meta object code from reading C++ file 'kcmcursortheme.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/kcms/cursortheme/kcmcursortheme.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcmcursortheme.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17CursorThemeConfigE_t {};
} // unnamed namespace

template <> constexpr inline auto CursorThemeConfig::qt_create_metaobjectdata<qt_meta_tag_ZN17CursorThemeConfigE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CursorThemeConfig",
        "canInstallChanged",
        "",
        "canResizeChanged",
        "canConfigureChanged",
        "downloadingFileChanged",
        "preferredSizeChanged",
        "themeApplied",
        "showSuccessMessage",
        "message",
        "showInfoMessage",
        "showErrorMessage",
        "ghnsEntryChanged",
        "KNSCore::Entry",
        "entry",
        "installThemeFromFile",
        "QUrl",
        "url",
        "updateSizeComboBox",
        "cursorSizeIndex",
        "cursorSize",
        "cursorSizeFromIndex",
        "index",
        "iconSizeFromIndex",
        "QSize",
        "cursorThemeIndex",
        "cursorTheme",
        "cursorThemeFromIndex",
        "cursorThemeSettings",
        "CursorThemeSettings*",
        "launchFeedbackSettings",
        "LaunchFeedbackSettings*",
        "canInstall",
        "canResize",
        "canConfigure",
        "cursorsModel",
        "QAbstractItemModel*",
        "sizesModel",
        "downloadingFile",
        "preferredSize"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'canInstallChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canResizeChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canConfigureChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'downloadingFileChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'preferredSizeChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'themeApplied'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showSuccessMessage'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'showInfoMessage'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'showErrorMessage'
        QtMocHelpers::SignalData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'ghnsEntryChanged'
        QtMocHelpers::SlotData<void(const KNSCore::Entry &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'installThemeFromFile'
        QtMocHelpers::SlotData<void(const QUrl &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'updateSizeComboBox'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'cursorSizeIndex'
        QtMocHelpers::MethodData<int(int) const>(19, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 20 },
        }}),
        // Method 'cursorSizeFromIndex'
        QtMocHelpers::MethodData<int(int)>(21, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 22 },
        }}),
        // Method 'iconSizeFromIndex'
        QtMocHelpers::MethodData<QSize(int)>(23, 2, QMC::AccessPublic, 0x80000000 | 24, {{
            { QMetaType::Int, 22 },
        }}),
        // Method 'cursorThemeIndex'
        QtMocHelpers::MethodData<int(const QString &) const>(25, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 26 },
        }}),
        // Method 'cursorThemeFromIndex'
        QtMocHelpers::MethodData<QString(int) const>(27, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 22 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'cursorThemeSettings'
        QtMocHelpers::PropertyData<CursorThemeSettings*>(28, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'launchFeedbackSettings'
        QtMocHelpers::PropertyData<LaunchFeedbackSettings*>(30, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'canInstall'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'canResize'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'canConfigure'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'cursorsModel'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(35, 0x80000000 | 36, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'sizesModel'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(37, 0x80000000 | 36, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'downloadingFile'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'preferredSize'
        QtMocHelpers::PropertyData<int>(39, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CursorThemeConfig, qt_meta_tag_ZN17CursorThemeConfigE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CursorThemeConfig::staticMetaObject = { {
    QMetaObject::SuperData::link<KQuickManagedConfigModule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17CursorThemeConfigE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17CursorThemeConfigE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17CursorThemeConfigE_t>.metaTypes,
    nullptr
} };

void CursorThemeConfig::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CursorThemeConfig *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->canInstallChanged(); break;
        case 1: _t->canResizeChanged(); break;
        case 2: _t->canConfigureChanged(); break;
        case 3: _t->downloadingFileChanged(); break;
        case 4: _t->preferredSizeChanged(); break;
        case 5: _t->themeApplied(); break;
        case 6: _t->showSuccessMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->showInfoMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->showErrorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->ghnsEntryChanged((*reinterpret_cast<std::add_pointer_t<KNSCore::Entry>>(_a[1]))); break;
        case 10: _t->installThemeFromFile((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 11: _t->updateSizeComboBox(); break;
        case 12: { int _r = _t->cursorSizeIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 13: { int _r = _t->cursorSizeFromIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 14: { QSize _r = _t->iconSizeFromIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QSize*>(_a[0]) = std::move(_r); }  break;
        case 15: { int _r = _t->cursorThemeIndex((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 16: { QString _r = _t->cursorThemeFromIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CursorThemeConfig::*)()>(_a, &CursorThemeConfig::canInstallChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CursorThemeConfig::*)()>(_a, &CursorThemeConfig::canResizeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CursorThemeConfig::*)()>(_a, &CursorThemeConfig::canConfigureChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CursorThemeConfig::*)()>(_a, &CursorThemeConfig::downloadingFileChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CursorThemeConfig::*)()>(_a, &CursorThemeConfig::preferredSizeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CursorThemeConfig::*)()>(_a, &CursorThemeConfig::themeApplied, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (CursorThemeConfig::*)(const QString & )>(_a, &CursorThemeConfig::showSuccessMessage, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (CursorThemeConfig::*)(const QString & )>(_a, &CursorThemeConfig::showInfoMessage, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (CursorThemeConfig::*)(const QString & )>(_a, &CursorThemeConfig::showErrorMessage, 8))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< CursorThemeSettings* >(); break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< LaunchFeedbackSettings* >(); break;
        case 6:
        case 5:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractItemModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<CursorThemeSettings**>(_v) = _t->cursorThemeSettings(); break;
        case 1: *reinterpret_cast<LaunchFeedbackSettings**>(_v) = _t->launchFeedbackSettings(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->canInstall(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->canResize(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->canConfigure(); break;
        case 5: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->cursorsModel(); break;
        case 6: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->sizesModel(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->downloadingFile(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->preferredSize(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setCanInstall(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setCanResize(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setCanConfigure(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setPreferredSize(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *CursorThemeConfig::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CursorThemeConfig::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17CursorThemeConfigE_t>.strings))
        return static_cast<void*>(this);
    return KQuickManagedConfigModule::qt_metacast(_clname);
}

int CursorThemeConfig::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KQuickManagedConfigModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void CursorThemeConfig::canInstallChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void CursorThemeConfig::canResizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void CursorThemeConfig::canConfigureChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void CursorThemeConfig::downloadingFileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void CursorThemeConfig::preferredSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void CursorThemeConfig::themeApplied()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void CursorThemeConfig::showSuccessMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void CursorThemeConfig::showInfoMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void CursorThemeConfig::showErrorMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}
QT_WARNING_POP
