// This file is generated by kconfig_compiler_kf6 from lookandfeelautoswitcherstate.kcfg.
// All changes you do to this file will be lost.

#include "lookandfeelautoswitcherstate.h"

LookAndFeelAutoSwitcherState::LookAndFeelAutoSwitcherState( )
  : KConfigSkeleton( KSharedConfig::openStateConfig(QStringLiteral( "lookandfeelautoswitcherstaterc") ) )
{
  setCurrentGroup( QStringLiteral( "DarkLightCycle" ) );

  KConfigSkeleton::ItemString  *itemSerializedSchedule;
  itemSerializedSchedule = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "SerializedSchedule" ), mSerializedSchedule );
  addItem( itemSerializedSchedule, QStringLiteral( "SerializedSchedule" ) );
}

LookAndFeelAutoSwitcherState::~LookAndFeelAutoSwitcherState()
{
}

