/****************************************************************************
** Meta object code from reading C++ file 'settings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-workspace-6.7.1/libnotificationmanager/settings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'settings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19NotificationManager8SettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto NotificationManager::Settings::qt_create_metaobjectdata<qt_meta_tag_ZN19NotificationManager8SettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NotificationManager::Settings",
        "QML.Element",
        "auto",
        "settingsChanged",
        "",
        "liveChanged",
        "dirtyChanged",
        "knownApplicationsChanged",
        "notificationsInhibitedByApplicationChanged",
        "notificationsInhibitedByApplication",
        "notificationInhibitionApplicationsChanged",
        "screensMirroredChanged",
        "fullscreenFocusedChanged",
        "applicationBehavior",
        "NotificationBehaviors",
        "desktopEntry",
        "setApplicationBehavior",
        "behaviors",
        "serviceBehavior",
        "setServiceBehavior",
        "registerKnownApplication",
        "forgetKnownApplication",
        "load",
        "save",
        "defaults",
        "revokeApplicationInhibitions",
        "criticalPopupsInDoNotDisturbMode",
        "lowPriorityPopups",
        "lowPriorityHistory",
        "popupPosition",
        "PopupPosition",
        "popupTimeout",
        "showPopupTimeout",
        "jobsInNotifications",
        "permanentJobPopups",
        "badgesInTaskManager",
        "knownApplications",
        "popupBlacklistedApplications",
        "popupBlacklistedServices",
        "doNotDisturbPopupWhitelistedApplications",
        "doNotDisturbPopupWhitelistedServices",
        "historyBlacklistedApplications",
        "historyBlacklistedServices",
        "badgeBlacklistedApplications",
        "notificationsInhibitedUntil",
        "notificationInhibitionApplications",
        "notificationInhibitionReasons",
        "inhibitNotificationsWhenScreensMirrored",
        "screensMirrored",
        "inhibitNotificationsWhenScreenSharing",
        "inhibitNotificationsWhenFullscreen",
        "fullscreenFocused",
        "notificationSoundsInhibited",
        "live",
        "dirty",
        "CloseToWidget",
        "TopLeft",
        "TopCenter",
        "TopRight",
        "BottomLeft",
        "BottomCenter",
        "BottomRight",
        "NotificationBehavior",
        "ShowPopups",
        "ShowPopupsInDoNotDisturbMode",
        "ShowInHistory",
        "ShowBadges"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'settingsChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'liveChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dirtyChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'knownApplicationsChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'notificationsInhibitedByApplicationChanged'
        QtMocHelpers::SignalData<void(bool)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Signal 'notificationInhibitionApplicationsChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'screensMirroredChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fullscreenFocusedChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'applicationBehavior'
        QtMocHelpers::MethodData<NotificationBehaviors(const QString &) const>(13, 4, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QString, 15 },
        }}),
        // Method 'setApplicationBehavior'
        QtMocHelpers::MethodData<void(const QString &, NotificationBehaviors)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 }, { 0x80000000 | 14, 17 },
        }}),
        // Method 'serviceBehavior'
        QtMocHelpers::MethodData<NotificationBehaviors(const QString &) const>(18, 4, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QString, 15 },
        }}),
        // Method 'setServiceBehavior'
        QtMocHelpers::MethodData<void(const QString &, NotificationBehaviors)>(19, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 }, { 0x80000000 | 14, 17 },
        }}),
        // Method 'registerKnownApplication'
        QtMocHelpers::MethodData<void(const QString &)>(20, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Method 'forgetKnownApplication'
        QtMocHelpers::MethodData<void(const QString &)>(21, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Method 'load'
        QtMocHelpers::MethodData<void()>(22, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'save'
        QtMocHelpers::MethodData<void()>(23, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'defaults'
        QtMocHelpers::MethodData<void()>(24, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'revokeApplicationInhibitions'
        QtMocHelpers::MethodData<void()>(25, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'criticalPopupsInDoNotDisturbMode'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'lowPriorityPopups'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'lowPriorityHistory'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'popupPosition'
        QtMocHelpers::PropertyData<enum PopupPosition>(29, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'popupTimeout'
        QtMocHelpers::PropertyData<int>(31, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet, 0),
        // property 'showPopupTimeout'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'jobsInNotifications'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'permanentJobPopups'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'badgesInTaskManager'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'knownApplications'
        QtMocHelpers::PropertyData<QStringList>(36, QMetaType::QStringList, QMC::DefaultPropertyFlags, 3),
        // property 'popupBlacklistedApplications'
        QtMocHelpers::PropertyData<QStringList>(37, QMetaType::QStringList, QMC::DefaultPropertyFlags, 0),
        // property 'popupBlacklistedServices'
        QtMocHelpers::PropertyData<QStringList>(38, QMetaType::QStringList, QMC::DefaultPropertyFlags, 0),
        // property 'doNotDisturbPopupWhitelistedApplications'
        QtMocHelpers::PropertyData<QStringList>(39, QMetaType::QStringList, QMC::DefaultPropertyFlags, 0),
        // property 'doNotDisturbPopupWhitelistedServices'
        QtMocHelpers::PropertyData<QStringList>(40, QMetaType::QStringList, QMC::DefaultPropertyFlags, 0),
        // property 'historyBlacklistedApplications'
        QtMocHelpers::PropertyData<QStringList>(41, QMetaType::QStringList, QMC::DefaultPropertyFlags, 0),
        // property 'historyBlacklistedServices'
        QtMocHelpers::PropertyData<QStringList>(42, QMetaType::QStringList, QMC::DefaultPropertyFlags, 0),
        // property 'badgeBlacklistedApplications'
        QtMocHelpers::PropertyData<QStringList>(43, QMetaType::QStringList, QMC::DefaultPropertyFlags, 0),
        // property 'notificationsInhibitedUntil'
        QtMocHelpers::PropertyData<QDateTime>(44, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet, 0),
        // property 'notificationsInhibitedByApplication'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
        // property 'notificationInhibitionApplications'
        QtMocHelpers::PropertyData<QStringList>(45, QMetaType::QStringList, QMC::DefaultPropertyFlags, 5),
        // property 'notificationInhibitionReasons'
        QtMocHelpers::PropertyData<QStringList>(46, QMetaType::QStringList, QMC::DefaultPropertyFlags, 5),
        // property 'inhibitNotificationsWhenScreensMirrored'
        QtMocHelpers::PropertyData<bool>(47, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'screensMirrored'
        QtMocHelpers::PropertyData<bool>(48, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'inhibitNotificationsWhenScreenSharing'
        QtMocHelpers::PropertyData<bool>(49, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'inhibitNotificationsWhenFullscreen'
        QtMocHelpers::PropertyData<bool>(50, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'fullscreenFocused'
        QtMocHelpers::PropertyData<bool>(51, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'notificationSoundsInhibited'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'live'
        QtMocHelpers::PropertyData<bool>(53, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'dirty'
        QtMocHelpers::PropertyData<bool>(54, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'PopupPosition'
        QtMocHelpers::EnumData<enum PopupPosition>(30, 30, QMC::EnumFlags{}).add({
            {   55, PopupPosition::CloseToWidget },
            {   56, PopupPosition::TopLeft },
            {   57, PopupPosition::TopCenter },
            {   58, PopupPosition::TopRight },
            {   59, PopupPosition::BottomLeft },
            {   60, PopupPosition::BottomCenter },
            {   61, PopupPosition::BottomRight },
        }),
        // enum 'NotificationBehavior'
        QtMocHelpers::EnumData<enum NotificationBehavior>(62, 62, QMC::EnumFlags{}).add({
            {   63, NotificationBehavior::ShowPopups },
            {   64, NotificationBehavior::ShowPopupsInDoNotDisturbMode },
            {   65, NotificationBehavior::ShowInHistory },
            {   66, NotificationBehavior::ShowBadges },
        }),
        // flag 'NotificationBehaviors'
        QtMocHelpers::EnumData<NotificationBehaviors>(14, 62, QMC::EnumIsFlag).add({
            {   63, NotificationBehavior::ShowPopups },
            {   64, NotificationBehavior::ShowPopupsInDoNotDisturbMode },
            {   65, NotificationBehavior::ShowInHistory },
            {   66, NotificationBehavior::ShowBadges },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Settings, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject NotificationManager::Settings::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationManager8SettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationManager8SettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19NotificationManager8SettingsE_t>.metaTypes,
    nullptr
} };

void NotificationManager::Settings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Settings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->settingsChanged(); break;
        case 1: _t->liveChanged(); break;
        case 2: _t->dirtyChanged(); break;
        case 3: _t->knownApplicationsChanged(); break;
        case 4: _t->notificationsInhibitedByApplicationChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->notificationInhibitionApplicationsChanged(); break;
        case 6: _t->screensMirroredChanged(); break;
        case 7: _t->fullscreenFocusedChanged(); break;
        case 8: { NotificationBehaviors _r = _t->applicationBehavior((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<NotificationBehaviors*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->setApplicationBehavior((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<NotificationBehaviors>>(_a[2]))); break;
        case 10: { NotificationBehaviors _r = _t->serviceBehavior((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<NotificationBehaviors*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->setServiceBehavior((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<NotificationBehaviors>>(_a[2]))); break;
        case 12: _t->registerKnownApplication((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->forgetKnownApplication((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->load(); break;
        case 15: _t->save(); break;
        case 16: _t->defaults(); break;
        case 17: _t->revokeApplicationInhibitions(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::settingsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::liveChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::dirtyChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::knownApplicationsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)(bool )>(_a, &Settings::notificationsInhibitedByApplicationChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::notificationInhibitionApplicationsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::screensMirroredChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::fullscreenFocusedChanged, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->criticalPopupsInDoNotDisturbMode(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->lowPriorityPopups(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->lowPriorityHistory(); break;
        case 3: *reinterpret_cast<enum PopupPosition*>(_v) = _t->popupPosition(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->popupTimeout(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->showPopupTimeout(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->jobsInNotifications(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->permanentJobPopups(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->badgesInTaskManager(); break;
        case 9: *reinterpret_cast<QStringList*>(_v) = _t->knownApplications(); break;
        case 10: *reinterpret_cast<QStringList*>(_v) = _t->popupBlacklistedApplications(); break;
        case 11: *reinterpret_cast<QStringList*>(_v) = _t->popupBlacklistedServices(); break;
        case 12: *reinterpret_cast<QStringList*>(_v) = _t->doNotDisturbPopupWhitelistedApplications(); break;
        case 13: *reinterpret_cast<QStringList*>(_v) = _t->doNotDisturbPopupWhitelistedServices(); break;
        case 14: *reinterpret_cast<QStringList*>(_v) = _t->historyBlacklistedApplications(); break;
        case 15: *reinterpret_cast<QStringList*>(_v) = _t->historyBlacklistedServices(); break;
        case 16: *reinterpret_cast<QStringList*>(_v) = _t->badgeBlacklistedApplications(); break;
        case 17: *reinterpret_cast<QDateTime*>(_v) = _t->notificationsInhibitedUntil(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->notificationsInhibitedByApplication(); break;
        case 19: *reinterpret_cast<QStringList*>(_v) = _t->notificationInhibitionApplications(); break;
        case 20: *reinterpret_cast<QStringList*>(_v) = _t->notificationInhibitionReasons(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->inhibitNotificationsWhenScreensMirrored(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->screensMirrored(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->inhibitNotificationsWhenScreenSharing(); break;
        case 24: *reinterpret_cast<bool*>(_v) = _t->inhibitNotificationsWhenFullscreen(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->fullscreenFocused(); break;
        case 26: *reinterpret_cast<bool*>(_v) = _t->notificationSoundsInhibited(); break;
        case 27: *reinterpret_cast<bool*>(_v) = _t->live(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->dirty(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCriticalPopupsInDoNotDisturbMode(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setLowPriorityPopups(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setLowPriorityHistory(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setPopupPosition(*reinterpret_cast<enum PopupPosition*>(_v)); break;
        case 4: _t->setPopupTimeout(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setShowPopupTimeout(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setJobsInNotifications(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setPermanentJobPopups(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setBadgesInTaskManager(*reinterpret_cast<bool*>(_v)); break;
        case 17: _t->setNotificationsInhibitedUntil(*reinterpret_cast<QDateTime*>(_v)); break;
        case 21: _t->setInhibitNotificationsWhenScreensMirrored(*reinterpret_cast<bool*>(_v)); break;
        case 22: _t->setScreensMirrored(*reinterpret_cast<bool*>(_v)); break;
        case 23: _t->setInhibitNotificationsWhenScreenSharing(*reinterpret_cast<bool*>(_v)); break;
        case 24: _t->setInhibitNotificationsWhenFullscreen(*reinterpret_cast<bool*>(_v)); break;
        case 25: _t->setFullscreenFocused(*reinterpret_cast<bool*>(_v)); break;
        case 26: _t->setNotificationSoundsInhibited(*reinterpret_cast<bool*>(_v)); break;
        case 27: _t->setLive(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 4: _t->resetPopupTimeout(); break;
        case 17: _t->resetNotificationsInhibitedUntil(); break;
        default: break;
        }
    }
}

const QMetaObject *NotificationManager::Settings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NotificationManager::Settings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationManager8SettingsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int NotificationManager::Settings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    return _id;
}

// SIGNAL 0
void NotificationManager::Settings::settingsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void NotificationManager::Settings::liveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void NotificationManager::Settings::dirtyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void NotificationManager::Settings::knownApplicationsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void NotificationManager::Settings::notificationsInhibitedByApplicationChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void NotificationManager::Settings::notificationInhibitionApplicationsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void NotificationManager::Settings::screensMirroredChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void NotificationManager::Settings::fullscreenFocusedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
