/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<actionsinfo.h>)
#  include <actionsinfo.h>
#endif
#if __has_include(<devicefiltercontrol.h>)
#  include <devicefiltercontrol.h>
#endif
#if __has_include(<stateinfo.h>)
#  include <stateinfo.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_plasma_applet_org_kde_plasma_devicenotifier()
{
    qmlRegisterModule("plasma.applet.org.kde.plasma.devicenotifier", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<ActionsInfo>("plasma.applet.org.kde.plasma.devicenotifier", 254);
    qmlRegisterEnum<ActionsInfo::ActionInfo>("ActionsInfo::ActionInfo");
    qmlRegisterTypesAndRevisions<DeviceFilterControl>("plasma.applet.org.kde.plasma.devicenotifier", 254);
    qmlRegisterEnum<DeviceFilterControl::DevicesType>("DeviceFilterControl::DevicesType");
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    QMetaType::fromType<QAbstractProxyModel *>().id();
    QMetaType::fromType<QSortFilterProxyModel *>().id();
    qmlRegisterTypesAndRevisions<StateInfo>("plasma.applet.org.kde.plasma.devicenotifier", 254);
    qmlRegisterEnum<StateInfo::State>("StateInfo::State");
    QT_WARNING_POP
    qmlRegisterModule("plasma.applet.org.kde.plasma.devicenotifier", 254, 254);
}

static const QQmlModuleRegistration plasmaappletorgkdeplasmadevicenotifierRegistration("plasma.applet.org.kde.plasma.devicenotifier", qml_register_types_plasma_applet_org_kde_plasma_devicenotifier);
