// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#include "iconsdata.h"

#include "iconssettings.h"




IconsData::IconsData(QObject *parent)
: KCModuleData(parent)
, m_settings(new IconsSettings(this))

{
autoRegisterSkeletons();
}

IconsSettings *IconsData::settings() const
{
    return m_settings;
}





#include "moc_iconsdata.cpp"
