/****************************************************************************
** Meta object code from reading C++ file 'kcm_soundtheme.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/kcms/soundtheme/kcm_soundtheme.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcm_soundtheme.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9ThemeInfoE_t {};
} // unnamed namespace

template <> constexpr inline auto ThemeInfo::qt_create_metaobjectdata<qt_meta_tag_ZN9ThemeInfoE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ThemeInfo",
        "QML.Element",
        "anonymous",
        "id",
        "name",
        "comment",
        "inherits",
        "directories",
        "hidden",
        "example"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'id'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'comment'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'inherits'
        QtMocHelpers::PropertyData<QStringList>(6, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'directories'
        QtMocHelpers::PropertyData<QStringList>(7, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hidden'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'example'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ThemeInfo, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ThemeInfo::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9ThemeInfoE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9ThemeInfoE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9ThemeInfoE_t>.metaTypes,
    nullptr
} };

void ThemeInfo::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ThemeInfo *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->id; break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->name; break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->comment; break;
        case 3: *reinterpret_cast<QStringList*>(_v) = _t->inherits; break;
        case 4: *reinterpret_cast<QStringList*>(_v) = _t->directories; break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isHidden; break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->example; break;
        default: break;
        }
    }
}

const QMetaObject *ThemeInfo::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ThemeInfo::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9ThemeInfoE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ThemeInfo::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN13KCMSoundThemeE_t {};
} // unnamed namespace

template <> constexpr inline auto KCMSoundTheme::qt_create_metaobjectdata<qt_meta_tag_ZN13KCMSoundThemeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KCMSoundTheme",
        "themesLoaded",
        "",
        "themeChanged",
        "playingChanged",
        "showSuccessMessage",
        "message",
        "showErrorMessage",
        "cancelSound",
        "onPlayingFinished",
        "indexOf",
        "themeId",
        "nameFor",
        "playSound",
        "soundList",
        "installThemeFromFile",
        "QUrl",
        "url",
        "errorString",
        "errorCode",
        "settings",
        "SoundThemeSettings*",
        "themes",
        "QList<ThemeInfo*>",
        "currentIndex",
        "playingTheme",
        "playingSound"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'themesLoaded'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'themeChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playingChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showSuccessMessage'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'showErrorMessage'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'cancelSound'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onPlayingFinished'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'indexOf'
        QtMocHelpers::MethodData<int(const QString &) const>(10, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 11 },
        }}),
        // Method 'nameFor'
        QtMocHelpers::MethodData<QString(const QString &) const>(12, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 11 },
        }}),
        // Method 'playSound'
        QtMocHelpers::MethodData<int(const QString &, const QStringList &)>(13, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 11 }, { QMetaType::QStringList, 14 },
        }}),
        // Method 'installThemeFromFile'
        QtMocHelpers::MethodData<void(const QUrl &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Method 'errorString'
        QtMocHelpers::MethodData<QString(int)>(18, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 19 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'settings'
        QtMocHelpers::PropertyData<SoundThemeSettings*>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'themes'
        QtMocHelpers::PropertyData<QList<ThemeInfo*>>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 0),
        // property 'currentIndex'
        QtMocHelpers::PropertyData<int>(24, QMetaType::Int, QMC::DefaultPropertyFlags, 1),
        // property 'playingTheme'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 2),
        // property 'playingSound'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KCMSoundTheme, qt_meta_tag_ZN13KCMSoundThemeE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KCMSoundTheme::staticMetaObject = { {
    QMetaObject::SuperData::link<KQuickManagedConfigModule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KCMSoundThemeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KCMSoundThemeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KCMSoundThemeE_t>.metaTypes,
    nullptr
} };

void KCMSoundTheme::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KCMSoundTheme *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->themesLoaded(); break;
        case 1: _t->themeChanged(); break;
        case 2: _t->playingChanged(); break;
        case 3: _t->showSuccessMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->showErrorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->cancelSound(); break;
        case 6: _t->onPlayingFinished(); break;
        case 7: { int _r = _t->indexOf((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 8: { QString _r = _t->nameFor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 9: { int _r = _t->playSound((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->installThemeFromFile((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 11: { QString _r = _t->errorString((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KCMSoundTheme::*)()>(_a, &KCMSoundTheme::themesLoaded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMSoundTheme::*)()>(_a, &KCMSoundTheme::themeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMSoundTheme::*)()>(_a, &KCMSoundTheme::playingChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMSoundTheme::*)(const QString & )>(_a, &KCMSoundTheme::showSuccessMessage, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMSoundTheme::*)(const QString & )>(_a, &KCMSoundTheme::showErrorMessage, 4))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<ThemeInfo*> >(); break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< SoundThemeSettings* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<SoundThemeSettings**>(_v) = _t->settings(); break;
        case 1: *reinterpret_cast<QList<ThemeInfo*>*>(_v) = _t->m_themes; break;
        case 2: *reinterpret_cast<int*>(_v) = _t->currentIndex(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->m_playingTheme; break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->m_playingSound; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1:
            if (QtMocHelpers::setProperty(_t->m_themes, *reinterpret_cast<QList<ThemeInfo*>*>(_v)))
                Q_EMIT _t->themesLoaded();
            break;
        case 3:
            if (QtMocHelpers::setProperty(_t->m_playingTheme, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->playingChanged();
            break;
        case 4:
            if (QtMocHelpers::setProperty(_t->m_playingSound, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->playingChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *KCMSoundTheme::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KCMSoundTheme::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KCMSoundThemeE_t>.strings))
        return static_cast<void*>(this);
    return KQuickManagedConfigModule::qt_metacast(_clname);
}

int KCMSoundTheme::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KQuickManagedConfigModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void KCMSoundTheme::themesLoaded()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KCMSoundTheme::themeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KCMSoundTheme::playingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KCMSoundTheme::showSuccessMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KCMSoundTheme::showErrorMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
