// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#include "desktopthemedata.h"

#include "desktopthemesettings.h"




DesktopThemeData::DesktopThemeData(QObject *parent)
: KCModuleData(parent)
, m_settings(new DesktopThemeSettings(this))

{
autoRegisterSkeletons();
}

DesktopThemeSettings *DesktopThemeData::settings() const
{
    return m_settings;
}





#include "moc_desktopthemedata.cpp"
