// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "plasma_changeicons_debug.h"


Q_LOGGING_CATEGORY(PLASMA_CHANGEICONS_DEBUG, "org.kde.plasma.changeicons", QtInfoMsg)

