/****************************************************************************
** Meta object code from reading C++ file 'abstractmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/applets/kicker/abstractmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'abstractmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13AbstractModelE_t {};
} // unnamed namespace

template <> constexpr inline auto AbstractModel::qt_create_metaobjectdata<qt_meta_tag_ZN13AbstractModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AbstractModel",
        "QML.Element",
        "anonymous",
        "descriptionChanged",
        "",
        "countChanged",
        "separatorCountChanged",
        "iconSizeChanged",
        "favoritesModelChanged",
        "sectionsChanged",
        "trigger",
        "row",
        "actionId",
        "QVariant",
        "argument",
        "refresh",
        "labelForRow",
        "modelForRow",
        "AbstractModel*",
        "rowForModel",
        "model",
        "description",
        "count",
        "separatorCount",
        "iconSize",
        "favoritesModel",
        "sections",
        "QAbstractListModel*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'descriptionChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'countChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'separatorCountChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iconSizeChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'favoritesModelChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sectionsChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'trigger'
        QtMocHelpers::MethodData<bool(int, const QString &, const QVariant &)>(10, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 11 }, { QMetaType::QString, 12 }, { 0x80000000 | 13, 14 },
        }}),
        // Method 'refresh'
        QtMocHelpers::MethodData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'labelForRow'
        QtMocHelpers::MethodData<QString(int)>(16, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 11 },
        }}),
        // Method 'modelForRow'
        QtMocHelpers::MethodData<AbstractModel *(int)>(17, 4, QMC::AccessPublic, 0x80000000 | 18, {{
            { QMetaType::Int, 11 },
        }}),
        // Method 'rowForModel'
        QtMocHelpers::MethodData<int(AbstractModel *)>(19, 4, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 18, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'description'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'count'
        QtMocHelpers::PropertyData<int>(22, QMetaType::Int, QMC::DefaultPropertyFlags, 1),
        // property 'separatorCount'
        QtMocHelpers::PropertyData<int>(23, QMetaType::Int, QMC::DefaultPropertyFlags, 2),
        // property 'iconSize'
        QtMocHelpers::PropertyData<int>(24, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'favoritesModel'
        QtMocHelpers::PropertyData<AbstractModel*>(25, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'sections'
        QtMocHelpers::PropertyData<QAbstractListModel*>(26, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<AbstractModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AbstractModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13AbstractModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13AbstractModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13AbstractModelE_t>.metaTypes,
    nullptr
} };

void AbstractModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->descriptionChanged(); break;
        case 1: _t->countChanged(); break;
        case 2: _t->separatorCountChanged(); break;
        case 3: _t->iconSizeChanged(); break;
        case 4: _t->favoritesModelChanged(); break;
        case 5: _t->sectionsChanged(); break;
        case 6: { bool _r = _t->trigger((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->refresh(); break;
        case 8: { QString _r = _t->labelForRow((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 9: { AbstractModel* _r = _t->modelForRow((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<AbstractModel**>(_a[0]) = std::move(_r); }  break;
        case 10: { int _r = _t->rowForModel((*reinterpret_cast<std::add_pointer_t<AbstractModel*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AbstractModel* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractModel::*)()>(_a, &AbstractModel::descriptionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractModel::*)()>(_a, &AbstractModel::countChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractModel::*)()>(_a, &AbstractModel::separatorCountChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractModel::*)()>(_a, &AbstractModel::iconSizeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractModel::*)()>(_a, &AbstractModel::favoritesModelChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractModel::*)()>(_a, &AbstractModel::sectionsChanged, 5))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< AbstractModel* >(); break;
        case 5:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractListModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->description(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->count(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->separatorCount(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->iconSize(); break;
        case 4: *reinterpret_cast<AbstractModel**>(_v) = _t->favoritesModel(); break;
        case 5: *reinterpret_cast<QAbstractListModel**>(_v) = _t->sections(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 3: _t->setIconSize(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setFavoritesModel(*reinterpret_cast<AbstractModel**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *AbstractModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13AbstractModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int AbstractModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void AbstractModel::descriptionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AbstractModel::countChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AbstractModel::separatorCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AbstractModel::iconSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AbstractModel::favoritesModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void AbstractModel::sectionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
