/****************************************************************************
** Meta object code from reading C++ file 'sessionsmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/components/sessionsprivate/sessionsmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sessionsmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13SessionsModelE_t {};
} // unnamed namespace

template <> constexpr inline auto SessionsModel::qt_create_metaobjectdata<qt_meta_tag_ZN13SessionsModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SessionsModel",
        "QML.Element",
        "auto",
        "shouldLockChanged",
        "",
        "showNewSessionEntryChanged",
        "countChanged",
        "includeUnusedSessionsChanged",
        "includeOwnSessionChanged",
        "switchedUser",
        "vt",
        "startedNewSession",
        "aboutToLockScreen",
        "reload",
        "switchUser",
        "shouldLock",
        "startNewSession",
        "canSwitchUser",
        "canStartNewSession",
        "showNewSessionEntry",
        "includeUnusedSessions",
        "includeOwnSession",
        "count",
        "UserRoles",
        "NameRole",
        "RealNameRole",
        "IconRole",
        "IconNameRole",
        "DisplayNumberRole",
        "VtNumberRole",
        "SessionRole",
        "IsTtyRole"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'shouldLockChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showNewSessionEntryChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'countChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'includeUnusedSessionsChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'includeOwnSessionChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'switchedUser'
        QtMocHelpers::SignalData<void(int)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Signal 'startedNewSession'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'aboutToLockScreen'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'reload'
        QtMocHelpers::MethodData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'switchUser'
        QtMocHelpers::MethodData<void(int, bool)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 }, { QMetaType::Bool, 15 },
        }}),
        // Method 'switchUser'
        QtMocHelpers::MethodData<void(int)>(14, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Method 'startNewSession'
        QtMocHelpers::MethodData<void(bool)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Method 'startNewSession'
        QtMocHelpers::MethodData<void()>(16, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'canSwitchUser'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'canStartNewSession'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'shouldLock'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'showNewSessionEntry'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'includeUnusedSessions'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'includeOwnSession'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'count'
        QtMocHelpers::PropertyData<int>(22, QMetaType::Int, QMC::DefaultPropertyFlags, 2),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'UserRoles'
        QtMocHelpers::EnumData<enum UserRoles>(23, 23, QMC::EnumFlags{}).add({
            {   24, UserRoles::NameRole },
            {   25, UserRoles::RealNameRole },
            {   26, UserRoles::IconRole },
            {   27, UserRoles::IconNameRole },
            {   28, UserRoles::DisplayNumberRole },
            {   29, UserRoles::VtNumberRole },
            {   30, UserRoles::SessionRole },
            {   31, UserRoles::IsTtyRole },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<SessionsModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject SessionsModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13SessionsModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13SessionsModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13SessionsModelE_t>.metaTypes,
    nullptr
} };

void SessionsModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SessionsModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->shouldLockChanged(); break;
        case 1: _t->showNewSessionEntryChanged(); break;
        case 2: _t->countChanged(); break;
        case 3: _t->includeUnusedSessionsChanged(); break;
        case 4: _t->includeOwnSessionChanged(); break;
        case 5: _t->switchedUser((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->startedNewSession(); break;
        case 7: _t->aboutToLockScreen(); break;
        case 8: _t->reload(); break;
        case 9: _t->switchUser((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 10: _t->switchUser((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->startNewSession((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->startNewSession(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SessionsModel::*)()>(_a, &SessionsModel::shouldLockChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionsModel::*)()>(_a, &SessionsModel::showNewSessionEntryChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionsModel::*)()>(_a, &SessionsModel::countChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionsModel::*)()>(_a, &SessionsModel::includeUnusedSessionsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionsModel::*)()>(_a, &SessionsModel::includeOwnSessionChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionsModel::*)(int )>(_a, &SessionsModel::switchedUser, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionsModel::*)()>(_a, &SessionsModel::startedNewSession, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionsModel::*)()>(_a, &SessionsModel::aboutToLockScreen, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->canSwitchUser(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->canStartNewSession(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->shouldLock(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->m_showNewSessionEntry; break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->includeUnusedSessions(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->includeOwnSession(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->rowCount(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 3: _t->setShowNewSessionEntry(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setIncludeUnusedSessions(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setIncludeOwnSession(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *SessionsModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SessionsModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13SessionsModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int SessionsModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void SessionsModel::shouldLockChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SessionsModel::showNewSessionEntryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SessionsModel::countChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void SessionsModel::includeUnusedSessionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void SessionsModel::includeOwnSessionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void SessionsModel::switchedUser(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void SessionsModel::startedNewSession()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void SessionsModel::aboutToLockScreen()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
