/****************************************************************************
** Meta object code from reading C++ file 'appinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-workspace-6.7.1/shell/scripting/appinterface.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'appinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18WorkspaceScripting12AppInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto WorkspaceScripting::AppInterface::qt_create_metaobjectdata<qt_meta_tag_ZN18WorkspaceScripting12AppInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WorkspaceScripting::AppInterface",
        "print",
        "",
        "string",
        "screenGeometry",
        "QJSValue",
        "screen",
        "lockCorona",
        "locked",
        "sleep",
        "ms",
        "hasBattery",
        "screenCount",
        "activityIds",
        "QList<int>",
        "panelIds",
        "knownPanelTypes",
        "knownActivityTypes",
        "knownWidgetTypes",
        "theme",
        "applicationVersion",
        "platformVersion",
        "scriptingVersion",
        "multihead",
        "multiheadScreen",
        "locale",
        "language",
        "languageId"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'print'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'screenGeometry'
        QtMocHelpers::SlotData<QJSValue(int) const>(4, 2, QMC::AccessPublic, 0x80000000 | 5, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'lockCorona'
        QtMocHelpers::SlotData<void(bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'sleep'
        QtMocHelpers::SlotData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'locked'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'hasBattery'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'screenCount'
        QtMocHelpers::PropertyData<int>(12, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'activityIds'
        QtMocHelpers::PropertyData<QList<int>>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'panelIds'
        QtMocHelpers::PropertyData<QList<int>>(15, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'knownPanelTypes'
        QtMocHelpers::PropertyData<QStringList>(16, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'knownActivityTypes'
        QtMocHelpers::PropertyData<QStringList>(17, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'knownWidgetTypes'
        QtMocHelpers::PropertyData<QStringList>(18, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'theme'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'applicationVersion'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'platformVersion'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'scriptingVersion'
        QtMocHelpers::PropertyData<int>(22, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'multihead'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'multiheadScreen'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'locale'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'language'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'languageId'
        QtMocHelpers::PropertyData<QString>(27, QMetaType::QString, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AppInterface, qt_meta_tag_ZN18WorkspaceScripting12AppInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WorkspaceScripting::AppInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18WorkspaceScripting12AppInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18WorkspaceScripting12AppInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18WorkspaceScripting12AppInterfaceE_t>.metaTypes,
    nullptr
} };

void WorkspaceScripting::AppInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AppInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->print((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: { QJSValue _r = _t->screenGeometry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->lockCorona((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->sleep((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AppInterface::*)(const QString & )>(_a, &AppInterface::print, 0))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 4:
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<int> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->coronaLocked(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->hasBattery(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->screenCount(); break;
        case 3: *reinterpret_cast<QList<int>*>(_v) = _t->activityIds(); break;
        case 4: *reinterpret_cast<QList<int>*>(_v) = _t->panelIds(); break;
        case 5: *reinterpret_cast<QStringList*>(_v) = _t->knownPanelTypes(); break;
        case 6: *reinterpret_cast<QStringList*>(_v) = _t->knownActivityTypes(); break;
        case 7: *reinterpret_cast<QStringList*>(_v) = _t->knownWidgetTypes(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->theme(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->applicationVersion(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->platformVersion(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->scriptingVersion(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->multihead(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->multihead(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->locale(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->language(); break;
        case 16: *reinterpret_cast<QString*>(_v) = _t->languageId(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->lockCorona(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setTheme(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *WorkspaceScripting::AppInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WorkspaceScripting::AppInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18WorkspaceScripting12AppInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int WorkspaceScripting::AppInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void WorkspaceScripting::AppInterface::print(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
