/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<abstracttasksmodel.h>)
#  include <abstracttasksmodel.h>
#endif
#if __has_include(<activityinfo.h>)
#  include <activityinfo.h>
#endif
#if __has_include(<regionfiltermode.h>)
#  include <regionfiltermode.h>
#endif
#if __has_include(<screencasting.h>)
#  include <screencasting.h>
#endif
#if __has_include(<screencastingrequest.h>)
#  include <screencastingrequest.h>
#endif
#if __has_include(<tasksmodel.h>)
#  include <tasksmodel.h>
#endif
#if __has_include(<virtualdesktopinfo.h>)
#  include <virtualdesktopinfo.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_taskmanager()
{
    qmlRegisterModule("org.kde.taskmanager", 0, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    QMetaType::fromType<QAbstractProxyModel *>().id();
    QMetaType::fromType<QSortFilterProxyModel *>().id();
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &RegionFilterMode::staticMetaObject;},
            "RegionFilterMode");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&RegionFilterMode::staticMetaObject, "org.kde.taskmanager", 0, nullptr, &RegionFilterMode::staticMetaObject, nullptr);
    qmlRegisterEnum<RegionFilterMode::Mode>("RegionFilterMode::Mode");
    qmlRegisterTypesAndRevisions<Screencasting>("org.kde.taskmanager", 0);
    qmlRegisterTypesAndRevisions<ScreencastingRequest>("org.kde.taskmanager", 0);
    qmlRegisterTypesAndRevisions<TaskManager::AbstractTasksModel>("org.kde.taskmanager", 0);
    qmlRegisterEnum<TaskManager::AbstractTasksModel::AdditionalRoles>("TaskManager::AbstractTasksModel::AdditionalRoles");
    qmlRegisterTypesAndRevisions<TaskManager::ActivityInfo>("org.kde.taskmanager", 0);
    qmlRegisterTypesAndRevisions<TaskManager::TasksModel>("org.kde.taskmanager", 0);
    qmlRegisterEnum<TaskManager::TasksModel::SortMode>("TaskManager::TasksModel::SortMode");
    qmlRegisterEnum<TaskManager::TasksModel::GroupMode>("TaskManager::TasksModel::GroupMode");
    qmlRegisterTypesAndRevisions<TaskManager::VirtualDesktopInfo>("org.kde.taskmanager", 0);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.taskmanager", 0, 1);
}

static const QQmlModuleRegistration orgkdetaskmanagerRegistration("org.kde.taskmanager", qml_register_types_org_kde_taskmanager);
