/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<job.h>)
#  include <job.h>
#endif
#if __has_include(<notifications.h>)
#  include <notifications.h>
#endif
#if __has_include(<server.h>)
#  include <server.h>
#endif
#if __has_include(<serverinfo.h>)
#  include <serverinfo.h>
#endif
#if __has_include(<settings.h>)
#  include <settings.h>
#endif
#if __has_include(<watchednotificationsmodel.h>)
#  include <watchednotificationsmodel.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_notificationmanager()
{
    qmlRegisterModule("org.kde.notificationmanager", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    QMetaType::fromType<NotificationManager::AbstractNotificationsModel *>().id();
    qmlRegisterTypesAndRevisions<NotificationManager::Job>("org.kde.notificationmanager", 254);
    qmlRegisterTypesAndRevisions<NotificationManager::Notifications>("org.kde.notificationmanager", 254);
    qmlRegisterEnum<NotificationManager::Notifications::Roles>("NotificationManager::Notifications::Roles");
    qmlRegisterEnum<NotificationManager::Notifications::Type>("NotificationManager::Notifications::Type");
    qmlRegisterEnum<NotificationManager::Notifications::Urgency>("NotificationManager::Notifications::Urgency");
    qmlRegisterEnum<NotificationManager::Notifications::Urgencies>("NotificationManager::Notifications::Urgencies");
    qmlRegisterEnum<NotificationManager::Notifications::Urgency>("NotificationManager::Notifications::Urgency");
    qmlRegisterEnum<NotificationManager::Notifications::ClearFlag>("NotificationManager::Notifications::ClearFlag");
    qmlRegisterEnum<NotificationManager::Notifications::ClearFlags>("NotificationManager::Notifications::ClearFlags");
    qmlRegisterEnum<NotificationManager::Notifications::ClearFlag>("NotificationManager::Notifications::ClearFlag");
    qmlRegisterEnum<NotificationManager::Notifications::JobState>("NotificationManager::Notifications::JobState");
    qmlRegisterEnum<NotificationManager::Notifications::SortMode>("NotificationManager::Notifications::SortMode");
    qmlRegisterEnum<NotificationManager::Notifications::GroupMode>("NotificationManager::Notifications::GroupMode");
    qmlRegisterEnum<NotificationManager::Notifications::InvokeBehavior>("NotificationManager::Notifications::InvokeBehavior");
    qmlRegisterEnum<NotificationManager::Notifications::InvokeBehaviors>("NotificationManager::Notifications::InvokeBehaviors");
    qmlRegisterEnum<NotificationManager::Notifications::InvokeBehavior>("NotificationManager::Notifications::InvokeBehavior");
    qmlRegisterTypesAndRevisions<NotificationManager::Server>("org.kde.notificationmanager", 254);
    qmlRegisterEnum<NotificationManager::Server::CloseReason>("NotificationManager::Server::CloseReason");
    qmlRegisterTypesAndRevisions<NotificationManager::ServerInfo>("org.kde.notificationmanager", 254);
    qmlRegisterEnum<NotificationManager::ServerInfo::Status>("NotificationManager::ServerInfo::Status");
    qmlRegisterTypesAndRevisions<NotificationManager::Settings>("org.kde.notificationmanager", 254);
    qmlRegisterEnum<NotificationManager::Settings::PopupPosition>("NotificationManager::Settings::PopupPosition");
    qmlRegisterEnum<NotificationManager::Settings::NotificationBehavior>("NotificationManager::Settings::NotificationBehavior");
    qmlRegisterEnum<NotificationManager::Settings::NotificationBehaviors>("NotificationManager::Settings::NotificationBehaviors");
    qmlRegisterEnum<NotificationManager::Settings::NotificationBehavior>("NotificationManager::Settings::NotificationBehavior");
    qmlRegisterTypesAndRevisions<NotificationManager::WatchedNotificationsModel>("org.kde.notificationmanager", 254);
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    QMetaType::fromType<QAbstractProxyModel *>().id();
    QMetaType::fromType<QSortFilterProxyModel *>().id();
    QT_WARNING_POP
    qmlRegisterModule("org.kde.notificationmanager", 254, 254);
}

static const QQmlModuleRegistration orgkdenotificationmanagerRegistration("org.kde.notificationmanager", qml_register_types_org_kde_notificationmanager);
