/****************************************************************************
** Meta object code from reading C++ file 'desktopview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-workspace-6.7.1/shell/desktopview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'desktopview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11DesktopViewE_t {};
} // unnamed namespace

template <> constexpr inline auto DesktopView::qt_create_metaobjectdata<qt_meta_tag_ZN11DesktopViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DesktopView",
        "stayBehindChanged",
        "",
        "candidateContainmentsChanged",
        "geometryChanged",
        "usedInAccentColorChanged",
        "accentColorChanged",
        "QColor",
        "accentColor",
        "screenToFollowChanged",
        "QScreen*",
        "screen",
        "strictAvailableScreenRectChanged",
        "showConfigurationInterface",
        "Plasma::Applet*",
        "applet",
        "slotContainmentChanged",
        "slotScreenChanged",
        "newId",
        "screenGeometryChanged",
        "fileFromPackage",
        "key",
        "fileName",
        "candidateContainments",
        "QVariantMap",
        "usedInAccentColor",
        "strictAvailableScreenRect",
        "QRect",
        "screenToFollow"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'stayBehindChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'candidateContainmentsChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'geometryChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'usedInAccentColorChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'accentColorChanged'
        QtMocHelpers::SignalData<void(const QColor &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'screenToFollowChanged'
        QtMocHelpers::SignalData<void(QScreen *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'strictAvailableScreenRectChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showConfigurationInterface'
        QtMocHelpers::SlotData<void(Plasma::Applet *)>(13, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'slotContainmentChanged'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotScreenChanged'
        QtMocHelpers::SlotData<void(int)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Slot 'screenGeometryChanged'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'fileFromPackage'
        QtMocHelpers::MethodData<QString(const QString &, const QString &)>(20, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 21 }, { QMetaType::QString, 22 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'candidateContainments'
        QtMocHelpers::PropertyData<QVariantMap>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'usedInAccentColor'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'accentColor'
        QtMocHelpers::PropertyData<QColor>(8, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'strictAvailableScreenRect'
        QtMocHelpers::PropertyData<QRect>(26, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 6),
        // property 'screenToFollow'
        QtMocHelpers::PropertyData<QScreen*>(28, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DesktopView, qt_meta_tag_ZN11DesktopViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DesktopView::staticMetaObject = { {
    QMetaObject::SuperData::link<PlasmaQuick::ContainmentView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DesktopViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DesktopViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11DesktopViewE_t>.metaTypes,
    nullptr
} };

void DesktopView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DesktopView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->stayBehindChanged(); break;
        case 1: _t->candidateContainmentsChanged(); break;
        case 2: _t->geometryChanged(); break;
        case 3: _t->usedInAccentColorChanged(); break;
        case 4: _t->accentColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 5: _t->screenToFollowChanged((*reinterpret_cast<std::add_pointer_t<QScreen*>>(_a[1]))); break;
        case 6: _t->strictAvailableScreenRectChanged(); break;
        case 7: _t->showConfigurationInterface((*reinterpret_cast<std::add_pointer_t<Plasma::Applet*>>(_a[1]))); break;
        case 8: _t->slotContainmentChanged(); break;
        case 9: _t->slotScreenChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->screenGeometryChanged(); break;
        case 11: { QString _r = _t->fileFromPackage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QScreen* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Plasma::Applet* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DesktopView::*)()>(_a, &DesktopView::stayBehindChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DesktopView::*)()>(_a, &DesktopView::candidateContainmentsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DesktopView::*)()>(_a, &DesktopView::geometryChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DesktopView::*)()>(_a, &DesktopView::usedInAccentColorChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DesktopView::*)(const QColor & )>(_a, &DesktopView::accentColorChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DesktopView::*)(QScreen * )>(_a, &DesktopView::screenToFollowChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DesktopView::*)()>(_a, &DesktopView::strictAvailableScreenRectChanged, 6))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QScreen* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QVariantMap*>(_v) = _t->candidateContainmentsGraphicItems(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->usedInAccentColor(); break;
        case 2: *reinterpret_cast<QColor*>(_v) = _t->accentColor(); break;
        case 3: *reinterpret_cast<QRect*>(_v) = _t->strictAvailableScreenRect(); break;
        case 4: *reinterpret_cast<QScreen**>(_v) = _t->screenToFollow(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setAccentColor(*reinterpret_cast<QColor*>(_v)); break;
        case 4: _t->setScreenToFollow(*reinterpret_cast<QScreen**>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 2: _t->resetAccentColor(); break;
        default: break;
        }
    }
}

const QMetaObject *DesktopView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DesktopView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DesktopViewE_t>.strings))
        return static_cast<void*>(this);
    return PlasmaQuick::ContainmentView::qt_metacast(_clname);
}

int DesktopView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PlasmaQuick::ContainmentView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void DesktopView::stayBehindChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DesktopView::candidateContainmentsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DesktopView::geometryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DesktopView::usedInAccentColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DesktopView::accentColorChanged(const QColor & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void DesktopView::screenToFollowChanged(QScreen * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void DesktopView::strictAvailableScreenRectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
