/********************************************************************************
** Form generated from reading UI file 'scmeditoroptions.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SCMEDITOROPTIONS_H
#define UI_SCMEDITOROPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kmessagewidget.h"

QT_BEGIN_NAMESPACE

class Ui_ScmEditorOptions
{
public:
    QVBoxLayout *verticalLayout;
    QCheckBox *useInactiveEffects;
    QCheckBox *inactiveSelectionEffect;
    QCheckBox *shadeSortedColumn;
    QCheckBox *accentTitlebar;
    QCheckBox *tintColors;
    QLabel *label;
    QSlider *tintStrengthSlider;
    QGroupBox *groupBox_5;
    QGridLayout *gridLayout_3;
    KMessageWidget *contrastValueWarning;
    QDoubleSpinBox *contrastPercentageSpinBox;
    QWidget *contrastExample;
    QLabel *label_8;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ScmEditorOptions)
    {
        if (ScmEditorOptions->objectName().isEmpty())
            ScmEditorOptions->setObjectName("ScmEditorOptions");
        ScmEditorOptions->resize(464, 436);
        verticalLayout = new QVBoxLayout(ScmEditorOptions);
        verticalLayout->setObjectName("verticalLayout");
        useInactiveEffects = new QCheckBox(ScmEditorOptions);
        useInactiveEffects->setObjectName("useInactiveEffects");

        verticalLayout->addWidget(useInactiveEffects);

        inactiveSelectionEffect = new QCheckBox(ScmEditorOptions);
        inactiveSelectionEffect->setObjectName("inactiveSelectionEffect");

        verticalLayout->addWidget(inactiveSelectionEffect);

        shadeSortedColumn = new QCheckBox(ScmEditorOptions);
        shadeSortedColumn->setObjectName("shadeSortedColumn");

        verticalLayout->addWidget(shadeSortedColumn);

        accentTitlebar = new QCheckBox(ScmEditorOptions);
        accentTitlebar->setObjectName("accentTitlebar");

        verticalLayout->addWidget(accentTitlebar);

        tintColors = new QCheckBox(ScmEditorOptions);
        tintColors->setObjectName("tintColors");

        verticalLayout->addWidget(tintColors);

        label = new QLabel(ScmEditorOptions);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        tintStrengthSlider = new QSlider(ScmEditorOptions);
        tintStrengthSlider->setObjectName("tintStrengthSlider");
        tintStrengthSlider->setMaximum(100);
        tintStrengthSlider->setOrientation(Qt::Orientation::Horizontal);

        verticalLayout->addWidget(tintStrengthSlider);

        groupBox_5 = new QGroupBox(ScmEditorOptions);
        groupBox_5->setObjectName("groupBox_5");
        groupBox_5->setFlat(false);
        groupBox_5->setCheckable(false);
        gridLayout_3 = new QGridLayout(groupBox_5);
        gridLayout_3->setSpacing(12);
        gridLayout_3->setObjectName("gridLayout_3");
        contrastValueWarning = new KMessageWidget(groupBox_5);
        contrastValueWarning->setObjectName("contrastValueWarning");
        contrastValueWarning->setEnabled(true);
        contrastValueWarning->setFrameShape(QFrame::Shape::NoFrame);
        contrastValueWarning->setWordWrap(true);
        contrastValueWarning->setCloseButtonVisible(false);
        contrastValueWarning->setMessageType(KMessageWidget::MessageType::Warning);

        gridLayout_3->addWidget(contrastValueWarning, 2, 0, 1, 3);

        contrastPercentageSpinBox = new QDoubleSpinBox(groupBox_5);
        contrastPercentageSpinBox->setObjectName("contrastPercentageSpinBox");
        contrastPercentageSpinBox->setMaximum(100.000000000000000);

        gridLayout_3->addWidget(contrastPercentageSpinBox, 1, 2, 1, 1);

        contrastExample = new QWidget(groupBox_5);
        contrastExample->setObjectName("contrastExample");
        contrastExample->setMinimumSize(QSize(25, 25));
        contrastExample->setMaximumSize(QSize(25, 25));
        contrastExample->setAutoFillBackground(false);

        gridLayout_3->addWidget(contrastExample, 1, 1, 1, 1);

        label_8 = new QLabel(groupBox_5);
        label_8->setObjectName("label_8");

        gridLayout_3->addWidget(label_8, 1, 0, 1, 1);


        verticalLayout->addWidget(groupBox_5);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(ScmEditorOptions);

        QMetaObject::connectSlotsByName(ScmEditorOptions);
    } // setupUi

    void retranslateUi(QWidget *ScmEditorOptions)
    {
        useInactiveEffects->setText(tr2i18n("Apply &effects to inactive windows", nullptr));
        inactiveSelectionEffect->setText(tr2i18n("Use different colors for in&active selections", nullptr));
        shadeSortedColumn->setText(tr2i18n("Shade sorted column &in lists", nullptr));
        accentTitlebar->setText(tr2i18n("Make window titlebars a&ccent-colored", nullptr));
        tintColors->setText(tr2i18n("Tint all colors with accent color", nullptr));
        label->setText(tr2i18n("Tint strength:", nullptr));
#if QT_CONFIG(tooltip)
        groupBox_5->setToolTip(tr2i18n("Contrast of the frames, separators and outlines", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBox_5->setTitle(tr2i18n("Frames and Outlines", nullptr));
        contrastValueWarning->setText(tr2i18n("Contrast values below 15% may produce visually awkward effects with some applications and color schemes. Consider yourself warned!", nullptr));
        contrastPercentageSpinBox->setSuffix(tr2i18n("%", nullptr));
        label_8->setText(tr2i18n("Contrast", nullptr));
        (void)ScmEditorOptions;
    } // retranslateUi

};

namespace Ui {
    class ScmEditorOptions: public Ui_ScmEditorOptions {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SCMEDITOROPTIONS_H

