/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kappmenu.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "appmenuadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class AppmenuAdaptor
 */

AppmenuAdaptor::AppmenuAdaptor(AppmenuDBus *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

AppmenuAdaptor::~AppmenuAdaptor()
{
    // destructor
}

void AppmenuAdaptor::reconfigure()
{
    // handle method call org.kde.kappmenu.reconfigure
    parent()->reconfigure();
}

void AppmenuAdaptor::showMenu(int x, int y, const QString &service, const QDBusObjectPath &objectPath, int actionId)
{
    // handle method call org.kde.kappmenu.showMenu
    parent()->showMenu(x, y, service, objectPath, actionId);
}


#include "moc_appmenuadaptor.cpp"
