/****************************************************************************
** Meta object code from reading C++ file 'screencastingrequest.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-workspace-6.7.1/libtaskmanager/screencastingrequest.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'screencastingrequest.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20ScreencastingRequestE_t {};
} // unnamed namespace

template <> constexpr inline auto ScreencastingRequest::qt_create_metaobjectdata<qt_meta_tag_ZN20ScreencastingRequestE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScreencastingRequest",
        "QML.Element",
        "auto",
        "nodeIdChanged",
        "",
        "nodeId",
        "uuidChanged",
        "uuid",
        "outputNameChanged",
        "outputNames",
        "objectSerialChanged",
        "objectSerial",
        "outputName"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nodeIdChanged'
        QtMocHelpers::SignalData<void(quint32)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 5 },
        }}),
        // Signal 'uuidChanged'
        QtMocHelpers::SignalData<void(const QString &)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'outputNameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'objectSerialChanged'
        QtMocHelpers::SignalData<void(quint64)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'uuid'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet, 1),
        // property 'outputName'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet, 2),
        // property 'nodeId'
        QtMocHelpers::PropertyData<quint32>(5, QMetaType::UInt, QMC::DefaultPropertyFlags, 0),
        // property 'objectSerial'
        QtMocHelpers::PropertyData<quint64>(11, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ScreencastingRequest, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ScreencastingRequest::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20ScreencastingRequestE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20ScreencastingRequestE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20ScreencastingRequestE_t>.metaTypes,
    nullptr
} };

void ScreencastingRequest::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScreencastingRequest *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nodeIdChanged((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 1: _t->uuidChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->outputNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->objectSerialChanged((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ScreencastingRequest::*)(quint32 )>(_a, &ScreencastingRequest::nodeIdChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreencastingRequest::*)(const QString & )>(_a, &ScreencastingRequest::uuidChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreencastingRequest::*)(const QString & )>(_a, &ScreencastingRequest::outputNameChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreencastingRequest::*)(quint64 )>(_a, &ScreencastingRequest::objectSerialChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->uuid(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->outputName(); break;
        case 2: *reinterpret_cast<quint32*>(_v) = _t->nodeId(); break;
        case 3: *reinterpret_cast<quint64*>(_v) = _t->objectSerial(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setUuid(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setOutputName(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 0: _t->resetUuid(); break;
        case 1: _t->resetOutputName(); break;
        default: break;
        }
    }
}

const QMetaObject *ScreencastingRequest::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScreencastingRequest::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20ScreencastingRequestE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ScreencastingRequest::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void ScreencastingRequest::nodeIdChanged(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ScreencastingRequest::uuidChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ScreencastingRequest::outputNameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ScreencastingRequest::objectSerialChanged(quint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
