// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#ifndef DESKTOPTHEMEDATA_H
#define DESKTOPTHEMEDATA_H

#include <QObject>

#include "kcmoduledata.h"



class DesktopThemeSettings;


class DesktopThemeData : public KCModuleData
{
    Q_OBJECT

public:
    explicit DesktopThemeData(QObject *parent = nullptr);
    DesktopThemeSettings *settings() const;


private:
    DesktopThemeSettings *m_settings;

};



#endif
