// This file is generated by kconfig_compiler_kf6 from jobsettings.kcfg.
// All changes you do to this file will be lost.

#include "jobsettings.h"

using namespace NotificationManager;

JobSettings::JobSettings( QObject *parent )
  : KConfigSkeleton( QStringLiteral( "plasmanotifyrc" ) )
{
  setParent(parent);
  KConfigCompilerSignallingItem::NotifyFunction notifyFunction = static_cast<KConfigCompilerSignallingItem::NotifyFunction>(&JobSettings::itemChanged);

  setCurrentGroup( QStringLiteral( "Jobs" ) );

  KConfigCompilerSignallingItem  *itemInNotifications;
  KConfigSkeleton::ItemBool  *innerItemInNotifications;
  innerItemInNotifications = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "InNotifications" ), mInNotifications, true );
  itemInNotifications = new KConfigCompilerSignallingItem(innerItemInNotifications, this, notifyFunction, signalInNotificationsChanged);
  itemInNotifications->setWriteFlags(KConfigBase::Notify);
  addItem( itemInNotifications, QStringLiteral( "InNotifications" ) );
  KConfigCompilerSignallingItem  *itemPermanentPopups;
  KConfigSkeleton::ItemBool  *innerItemPermanentPopups;
  innerItemPermanentPopups = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "PermanentPopups" ), mPermanentPopups, true );
  itemPermanentPopups = new KConfigCompilerSignallingItem(innerItemPermanentPopups, this, notifyFunction, signalPermanentPopupsChanged);
  itemPermanentPopups->setWriteFlags(KConfigBase::Notify);
  addItem( itemPermanentPopups, QStringLiteral( "PermanentPopups" ) );
}

bool JobSettings::defaultInNotificationsValue_helper() const
{

  return true;
}

bool JobSettings::defaultPermanentPopupsValue_helper() const
{

  return true;
}

JobSettings::~JobSettings()
{
}


void JobSettings::itemChanged(quint64 signalFlag) {

  switch (signalFlag) {
  case signalInNotificationsChanged:
    Q_EMIT InNotificationsChanged();
    break;
  case signalPermanentPopupsChanged:
    Q_EMIT PermanentPopupsChanged();
    break;
  }
}
