/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.PlasmaShell.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef PLASMASHELLADAPTOR_H
#define PLASMASHELLADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "shellcorona.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.PlasmaShell
 */
class PlasmaShellAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.PlasmaShell")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.PlasmaShell\">\n"
"    <property access=\"readwrite\" type=\"b\" name=\"editMode\"/>\n"
"    <property access=\"read\" type=\"s\" name=\"shell\"/>\n"
"    <method name=\"changeShell\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"shell\"/>\n"
"    </method>\n"
"    <method name=\"toggleDashboard\"/>\n"
"    <method name=\"toggleActivityManager\"/>\n"
"    <method name=\"toggleWidgetExplorer\"/>\n"
"    <method name=\"setDashboardShown\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"show\"/>\n"
"    </method>\n"
"    <method name=\"evaluateScript\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"script\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"output\"/>\n"
"    </method>\n"
"    <method name=\"color\">\n"
"      <arg direction=\"out\" type=\"u\" name=\"output\"/>\n"
"    </method>\n"
"    <method name=\"immutable\">\n"
"      <arg direction=\"out\" type=\"b\" name=\"output\"/>\n"
"    </method>\n"
"    <method name=\"dumpCurrentLayoutJS\">\n"
"      <arg direction=\"out\" type=\"ay\" name=\"script\"/>\n"
"    </method>\n"
"    <method name=\"loadLookAndFeelDefaultLayout\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"layout\"/>\n"
"    </method>\n"
"    <method name=\"activateLauncherMenu\"/>\n"
"    <method name=\"refreshCurrentShell\"/>\n"
"    <method name=\"wallpaper\">\n"
"      <arg direction=\"in\" type=\"u\" name=\"screenNum\"/>\n"
"      <arg direction=\"out\" type=\"a{sv}\" name=\"parameters\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </method>\n"
"    <method name=\"setWallpaper\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"wallpaperPlugin\"/>\n"
"      <arg direction=\"in\" type=\"a{sv}\" name=\"parameters\"/>\n"
"      <arg direction=\"in\" type=\"u\" name=\"screenNum\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.In1\"/>\n"
"    </method>\n"
"    <signal name=\"shellChanged\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"shell\"/>\n"
"    </signal>\n"
"    <signal name=\"wallpaperChanged\">\n"
"      <arg direction=\"out\" type=\"u\" name=\"screenNum\"/>\n"
"    </signal>\n"
"    <method name=\"grabContainmentImage\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"width\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"height\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"targetPath\"/>\n"
"      <arg direction=\"out\" type=\"b\" name=\"result\"/>\n"
"    </method>\n"
"    <signal name=\"colorChanged\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"changedColor\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    PlasmaShellAdaptor(ShellCorona *parent);
    ~PlasmaShellAdaptor() override;

    inline ShellCorona *parent() const
    { return static_cast<ShellCorona *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(bool editMode READ editMode WRITE setEditMode)
    bool editMode() const;
    void setEditMode(bool value);

    Q_PROPERTY(QString shell READ shell)
    QString shell() const;

public Q_SLOTS: // METHODS
    void activateLauncherMenu();
    void changeShell(const QString &shell);
    uint color();
    QByteArray dumpCurrentLayoutJS();
    QString evaluateScript(const QString &script);
    bool grabContainmentImage(const QString &name, int width, int height, const QString &targetPath);
    bool immutable();
    void loadLookAndFeelDefaultLayout(const QString &layout);
    void refreshCurrentShell();
    void setDashboardShown(bool show);
    void setWallpaper(const QString &wallpaperPlugin, const QVariantMap &parameters, uint screenNum);
    void toggleActivityManager();
    void toggleDashboard();
    void toggleWidgetExplorer();
    QVariantMap wallpaper(uint screenNum);
Q_SIGNALS: // SIGNALS
    void colorChanged(const QString &changedColor);
    void shellChanged(const QString &shell);
    void wallpaperChanged(uint screenNum);
};

#endif
