/****************************************************************************
** Meta object code from reading C++ file 'taskgroupingproxymodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-workspace-6.7.1/libtaskmanager/taskgroupingproxymodel.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'taskgroupingproxymodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11TaskManager22TaskGroupingProxyModelE_t {};
} // unnamed namespace

template <> constexpr inline auto TaskManager::TaskGroupingProxyModel::qt_create_metaobjectdata<qt_meta_tag_ZN11TaskManager22TaskGroupingProxyModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TaskManager::TaskGroupingProxyModel",
        "groupModeChanged",
        "",
        "groupDemandingAttentionChanged",
        "windowTasksThresholdChanged",
        "blacklistedAppIdsChanged",
        "blacklistedLauncherUrlsChanged",
        "sourceRowsAboutToBeInserted",
        "QModelIndex",
        "parent",
        "first",
        "last",
        "sourceRowsInserted",
        "start",
        "end",
        "sourceRowsAboutToBeRemoved",
        "sourceRowsRemoved",
        "sourceModelAboutToBeReset",
        "sourceModelReset",
        "sourceDataChanged",
        "QList<int>",
        "groupMode",
        "TasksModel::GroupMode",
        "groupDemandingAttention",
        "windowTasksThreshold",
        "blacklistedAppIds",
        "blacklistedLauncherUrls"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'groupModeChanged'
        QtMocHelpers::SignalData<void() const>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'groupDemandingAttentionChanged'
        QtMocHelpers::SignalData<void() const>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'windowTasksThresholdChanged'
        QtMocHelpers::SignalData<void() const>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'blacklistedAppIdsChanged'
        QtMocHelpers::SignalData<void() const>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'blacklistedLauncherUrlsChanged'
        QtMocHelpers::SignalData<void() const>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sourceRowsAboutToBeInserted'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { QMetaType::Int, 10 }, { QMetaType::Int, 11 },
        }}),
        // Slot 'sourceRowsInserted'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { QMetaType::Int, 13 }, { QMetaType::Int, 14 },
        }}),
        // Slot 'sourceRowsAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { QMetaType::Int, 10 }, { QMetaType::Int, 11 },
        }}),
        // Slot 'sourceRowsRemoved'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { QMetaType::Int, 13 }, { QMetaType::Int, 14 },
        }}),
        // Slot 'sourceModelAboutToBeReset'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sourceModelReset'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sourceDataChanged'
        QtMocHelpers::SlotData<void(QModelIndex, QModelIndex, QList<int>)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 2 }, { 0x80000000 | 8, 2 }, { 0x80000000 | 20, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'groupMode'
        QtMocHelpers::PropertyData<TasksModel::GroupMode>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'groupDemandingAttention'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'windowTasksThreshold'
        QtMocHelpers::PropertyData<int>(24, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'blacklistedAppIds'
        QtMocHelpers::PropertyData<QStringList>(25, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'blacklistedLauncherUrls'
        QtMocHelpers::PropertyData<QStringList>(26, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TaskGroupingProxyModel, qt_meta_tag_ZN11TaskManager22TaskGroupingProxyModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN11TaskManager22TaskGroupingProxyModelE[] = {
    QMetaObject::SuperData::link<TaskManager::TasksModel::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject TaskManager::TaskGroupingProxyModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11TaskManager22TaskGroupingProxyModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11TaskManager22TaskGroupingProxyModelE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN11TaskManager22TaskGroupingProxyModelE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11TaskManager22TaskGroupingProxyModelE_t>.metaTypes,
    nullptr
} };

void TaskManager::TaskGroupingProxyModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TaskGroupingProxyModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->groupModeChanged(); break;
        case 1: _t->groupDemandingAttentionChanged(); break;
        case 2: _t->windowTasksThresholdChanged(); break;
        case 3: _t->blacklistedAppIdsChanged(); break;
        case 4: _t->blacklistedLauncherUrlsChanged(); break;
        case 5: _t->d->sourceRowsAboutToBeInserted((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 6: _t->d->sourceRowsInserted((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 7: _t->d->sourceRowsAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 8: _t->d->sourceRowsRemoved((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 9: _t->d->sourceModelAboutToBeReset(); break;
        case 10: _t->d->sourceModelReset(); break;
        case 11: _t->d->sourceDataChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TaskGroupingProxyModel::*)() const>(_a, &TaskGroupingProxyModel::groupModeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TaskGroupingProxyModel::*)() const>(_a, &TaskGroupingProxyModel::groupDemandingAttentionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TaskGroupingProxyModel::*)() const>(_a, &TaskGroupingProxyModel::windowTasksThresholdChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TaskGroupingProxyModel::*)() const>(_a, &TaskGroupingProxyModel::blacklistedAppIdsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TaskGroupingProxyModel::*)() const>(_a, &TaskGroupingProxyModel::blacklistedLauncherUrlsChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<TasksModel::GroupMode*>(_v) = _t->groupMode(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->groupDemandingAttention(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->windowTasksThreshold(); break;
        case 3: *reinterpret_cast<QStringList*>(_v) = _t->blacklistedAppIds(); break;
        case 4: *reinterpret_cast<QStringList*>(_v) = _t->blacklistedLauncherUrls(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setGroupMode(*reinterpret_cast<TasksModel::GroupMode*>(_v)); break;
        case 1: _t->setGroupDemandingAttention(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setWindowTasksThreshold(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setBlacklistedAppIds(*reinterpret_cast<QStringList*>(_v)); break;
        case 4: _t->setBlacklistedLauncherUrls(*reinterpret_cast<QStringList*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *TaskManager::TaskGroupingProxyModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TaskManager::TaskGroupingProxyModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11TaskManager22TaskGroupingProxyModelE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "AbstractTasksModelIface"))
        return static_cast< AbstractTasksModelIface*>(this);
    return QAbstractProxyModel::qt_metacast(_clname);
}

int TaskManager::TaskGroupingProxyModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void TaskManager::TaskGroupingProxyModel::groupModeChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TaskGroupingProxyModel *>(this), &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TaskManager::TaskGroupingProxyModel::groupDemandingAttentionChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TaskGroupingProxyModel *>(this), &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void TaskManager::TaskGroupingProxyModel::windowTasksThresholdChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TaskGroupingProxyModel *>(this), &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void TaskManager::TaskGroupingProxyModel::blacklistedAppIdsChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TaskGroupingProxyModel *>(this), &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void TaskManager::TaskGroupingProxyModel::blacklistedLauncherUrlsChanged()const
{
    QMetaObject::activate(const_cast< TaskManager::TaskGroupingProxyModel *>(this), &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
