/****************************************************************************
** Meta object code from reading C++ file 'regionandlangsettingsbase.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../regionandlangsettingsbase.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'regionandlangsettingsbase.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN25RegionAndLangSettingsBaseE_t {};
} // unnamed namespace

template <> constexpr inline auto RegionAndLangSettingsBase::qt_create_metaobjectdata<qt_meta_tag_ZN25RegionAndLangSettingsBaseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "RegionAndLangSettingsBase",
        "langChanged",
        "",
        "numericChanged",
        "timeChanged",
        "monetaryChanged",
        "measurementChanged",
        "paperSizeChanged",
        "addressChanged",
        "nameStyleChanged",
        "phoneNumbersChanged",
        "ctypeChanged",
        "languageChanged",
        "lang",
        "isLangImmutable",
        "numeric",
        "isNumericImmutable",
        "defaultNumericValue",
        "time",
        "isTimeImmutable",
        "defaultTimeValue",
        "monetary",
        "isMonetaryImmutable",
        "defaultMonetaryValue",
        "measurement",
        "isMeasurementImmutable",
        "defaultMeasurementValue",
        "paperSize",
        "isPaperSizeImmutable",
        "defaultPaperSizeValue",
        "address",
        "isAddressImmutable",
        "defaultAddressValue",
        "nameStyle",
        "isNameStyleImmutable",
        "defaultNameStyleValue",
        "phoneNumbers",
        "isPhoneNumbersImmutable",
        "defaultPhoneNumbersValue",
        "ctype",
        "isCtypeImmutable",
        "defaultCtypeValue",
        "language",
        "isLanguageImmutable",
        "defaultLanguageValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'langChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'numericChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'timeChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'monetaryChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'measurementChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'paperSizeChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'addressChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nameStyleChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'phoneNumbersChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ctypeChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'languageChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'lang'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isLangImmutable'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'numeric'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isNumericImmutable'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNumericValue'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'time'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isTimeImmutable'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTimeValue'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'monetary'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isMonetaryImmutable'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMonetaryValue'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'measurement'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isMeasurementImmutable'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMeasurementValue'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'paperSize'
        QtMocHelpers::PropertyData<QString>(27, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isPaperSizeImmutable'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultPaperSizeValue'
        QtMocHelpers::PropertyData<QString>(29, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'address'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isAddressImmutable'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAddressValue'
        QtMocHelpers::PropertyData<QString>(32, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'nameStyle'
        QtMocHelpers::PropertyData<QString>(33, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isNameStyleImmutable'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNameStyleValue'
        QtMocHelpers::PropertyData<QString>(35, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'phoneNumbers'
        QtMocHelpers::PropertyData<QString>(36, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isPhoneNumbersImmutable'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultPhoneNumbersValue'
        QtMocHelpers::PropertyData<QString>(38, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ctype'
        QtMocHelpers::PropertyData<QString>(39, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isCtypeImmutable'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCtypeValue'
        QtMocHelpers::PropertyData<QString>(41, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'language'
        QtMocHelpers::PropertyData<QString>(42, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isLanguageImmutable'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLanguageValue'
        QtMocHelpers::PropertyData<QString>(44, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RegionAndLangSettingsBase, qt_meta_tag_ZN25RegionAndLangSettingsBaseE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject RegionAndLangSettingsBase::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25RegionAndLangSettingsBaseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25RegionAndLangSettingsBaseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25RegionAndLangSettingsBaseE_t>.metaTypes,
    nullptr
} };

void RegionAndLangSettingsBase::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RegionAndLangSettingsBase *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->langChanged(); break;
        case 1: _t->numericChanged(); break;
        case 2: _t->timeChanged(); break;
        case 3: _t->monetaryChanged(); break;
        case 4: _t->measurementChanged(); break;
        case 5: _t->paperSizeChanged(); break;
        case 6: _t->addressChanged(); break;
        case 7: _t->nameStyleChanged(); break;
        case 8: _t->phoneNumbersChanged(); break;
        case 9: _t->ctypeChanged(); break;
        case 10: _t->languageChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (RegionAndLangSettingsBase::*)()>(_a, &RegionAndLangSettingsBase::langChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (RegionAndLangSettingsBase::*)()>(_a, &RegionAndLangSettingsBase::numericChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (RegionAndLangSettingsBase::*)()>(_a, &RegionAndLangSettingsBase::timeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (RegionAndLangSettingsBase::*)()>(_a, &RegionAndLangSettingsBase::monetaryChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (RegionAndLangSettingsBase::*)()>(_a, &RegionAndLangSettingsBase::measurementChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (RegionAndLangSettingsBase::*)()>(_a, &RegionAndLangSettingsBase::paperSizeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (RegionAndLangSettingsBase::*)()>(_a, &RegionAndLangSettingsBase::addressChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (RegionAndLangSettingsBase::*)()>(_a, &RegionAndLangSettingsBase::nameStyleChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (RegionAndLangSettingsBase::*)()>(_a, &RegionAndLangSettingsBase::phoneNumbersChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (RegionAndLangSettingsBase::*)()>(_a, &RegionAndLangSettingsBase::ctypeChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (RegionAndLangSettingsBase::*)()>(_a, &RegionAndLangSettingsBase::languageChanged, 10))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->lang(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isLangImmutable(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->numeric(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isNumericImmutable(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->defaultNumericValue(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->time(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isTimeImmutable(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->defaultTimeValue(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->monetary(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isMonetaryImmutable(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->defaultMonetaryValue(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->measurement(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->isMeasurementImmutable(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->defaultMeasurementValue(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->paperSize(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->isPaperSizeImmutable(); break;
        case 16: *reinterpret_cast<QString*>(_v) = _t->defaultPaperSizeValue(); break;
        case 17: *reinterpret_cast<QString*>(_v) = _t->address(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->isAddressImmutable(); break;
        case 19: *reinterpret_cast<QString*>(_v) = _t->defaultAddressValue(); break;
        case 20: *reinterpret_cast<QString*>(_v) = _t->nameStyle(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->isNameStyleImmutable(); break;
        case 22: *reinterpret_cast<QString*>(_v) = _t->defaultNameStyleValue(); break;
        case 23: *reinterpret_cast<QString*>(_v) = _t->phoneNumbers(); break;
        case 24: *reinterpret_cast<bool*>(_v) = _t->isPhoneNumbersImmutable(); break;
        case 25: *reinterpret_cast<QString*>(_v) = _t->defaultPhoneNumbersValue(); break;
        case 26: *reinterpret_cast<QString*>(_v) = _t->ctype(); break;
        case 27: *reinterpret_cast<bool*>(_v) = _t->isCtypeImmutable(); break;
        case 28: *reinterpret_cast<QString*>(_v) = _t->defaultCtypeValue(); break;
        case 29: *reinterpret_cast<QString*>(_v) = _t->language(); break;
        case 30: *reinterpret_cast<bool*>(_v) = _t->isLanguageImmutable(); break;
        case 31: *reinterpret_cast<QString*>(_v) = _t->defaultLanguageValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLang(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setNumeric(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setTime(*reinterpret_cast<QString*>(_v)); break;
        case 8: _t->setMonetary(*reinterpret_cast<QString*>(_v)); break;
        case 11: _t->setMeasurement(*reinterpret_cast<QString*>(_v)); break;
        case 14: _t->setPaperSize(*reinterpret_cast<QString*>(_v)); break;
        case 17: _t->setAddress(*reinterpret_cast<QString*>(_v)); break;
        case 20: _t->setNameStyle(*reinterpret_cast<QString*>(_v)); break;
        case 23: _t->setPhoneNumbers(*reinterpret_cast<QString*>(_v)); break;
        case 26: _t->setCtype(*reinterpret_cast<QString*>(_v)); break;
        case 29: _t->setLanguage(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *RegionAndLangSettingsBase::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RegionAndLangSettingsBase::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25RegionAndLangSettingsBaseE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int RegionAndLangSettingsBase::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    return _id;
}

// SIGNAL 0
void RegionAndLangSettingsBase::langChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void RegionAndLangSettingsBase::numericChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void RegionAndLangSettingsBase::timeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void RegionAndLangSettingsBase::monetaryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void RegionAndLangSettingsBase::measurementChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void RegionAndLangSettingsBase::paperSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void RegionAndLangSettingsBase::addressChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void RegionAndLangSettingsBase::nameStyleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void RegionAndLangSettingsBase::phoneNumbersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void RegionAndLangSettingsBase::ctypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void RegionAndLangSettingsBase::languageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
