/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.secretprompter.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef SECRETPROMPTERADAPTOR_H
#define SECRETPROMPTERADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "ksecretprompter.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.secretprompter
 */
class SecretprompterAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.secretprompter")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.secretprompter\">\n"
"    <method name=\"UnlockCollectionPrompt\">\n"
"      <arg direction=\"in\" type=\"o\" name=\"request\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"window_id\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"activation_token\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"collection_name\"/>\n"
"    </method>\n"
"    <method name=\"CreateCollectionPrompt\">\n"
"      <arg direction=\"in\" type=\"o\" name=\"request\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"window_id\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"activation_token\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"collection_name\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    SecretprompterAdaptor(KSecretPrompter *parent);
    ~SecretprompterAdaptor() override;

    inline KSecretPrompter *parent() const
    { return static_cast<KSecretPrompter *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void CreateCollectionPrompt(const QDBusObjectPath &request, const QString &window_id, const QString &activation_token, const QString &collection_name);
    void UnlockCollectionPrompt(const QDBusObjectPath &request, const QString &window_id, const QString &activation_token, const QString &collection_name);
Q_SIGNALS: // SIGNALS
};

#endif
