// This file is generated by kconfig_compiler_kf6 from cursorthemesettings.kcfg.
// All changes you do to this file will be lost.

#include "cursorthemesettings.h"

CursorThemeSettings::CursorThemeSettings( QObject *parent )
  : KConfigSkeleton( QStringLiteral( "kcminputrc" ) )
{
  setParent(parent);
  KConfigCompilerSignallingItem::NotifyFunction notifyFunction = static_cast<KConfigCompilerSignallingItem::NotifyFunction>(&CursorThemeSettings::itemChanged);

  setCurrentGroup( QStringLiteral( "Mouse" ) );

  KConfigCompilerSignallingItem  *itemCursorTheme;
  KConfigSkeleton::ItemString  *innerItemCursorTheme;
  innerItemCursorTheme = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "cursorTheme" ), mCursorTheme, QStringLiteral( "default" ) );
  itemCursorTheme = new KConfigCompilerSignallingItem(innerItemCursorTheme, this, notifyFunction, signalCursorThemeChanged);
  itemCursorTheme->setWriteFlags(KConfigBase::Notify);
  addItem( itemCursorTheme, QStringLiteral( "cursorTheme" ) );
  KConfigCompilerSignallingItem  *itemCursorSize;
  KConfigSkeleton::ItemInt  *innerItemCursorSize;
  innerItemCursorSize = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "cursorSize" ), mCursorSize, 24 );
  itemCursorSize = new KConfigCompilerSignallingItem(innerItemCursorSize, this, notifyFunction, signalCursorSizeChanged);
  itemCursorSize->setWriteFlags(KConfigBase::Notify);
  addItem( itemCursorSize, QStringLiteral( "cursorSize" ) );
}

QString CursorThemeSettings::defaultCursorThemeValue_helper() const
{

  return QStringLiteral( "default" );
}

int CursorThemeSettings::defaultCursorSizeValue_helper() const
{

  return 24;
}

CursorThemeSettings::~CursorThemeSettings()
{
}


void CursorThemeSettings::itemChanged(quint64 signalFlag) {

  switch (signalFlag) {
  case signalCursorThemeChanged:
    Q_EMIT cursorThemeChanged();
    break;
  case signalCursorSizeChanged:
    Q_EMIT cursorSizeChanged();
    break;
  }
}
