/****************************************************************************
** Meta object code from reading C++ file 'playercontainer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-workspace-6.7.1/libkmpris/playercontainer.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'playercontainer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23AbstractPlayerContainerE_t {};
} // unnamed namespace

template <> constexpr inline auto AbstractPlayerContainer::qt_create_metaobjectdata<qt_meta_tag_ZN23AbstractPlayerContainerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AbstractPlayerContainer",
        "canGoNextChanged",
        "",
        "canGoPreviousChanged",
        "canPlayChanged",
        "canPauseChanged",
        "canStopChanged",
        "canSeekChanged",
        "canControlChanged",
        "loopStatusChanged",
        "maximumRateChanged",
        "metadataChanged",
        "minimumRateChanged",
        "playbackStatusChanged",
        "positionChanged",
        "rateChanged",
        "shuffleChanged",
        "volumeChanged",
        "trackChanged",
        "artistChanged",
        "artUrlChanged",
        "albumChanged",
        "lengthChanged",
        "kdePidChanged",
        "canQuitChanged",
        "canSetFullscreenChanged",
        "canRaiseChanged",
        "supportedMimeTypesChanged",
        "supportedUriSchemesChanged",
        "desktopEntryChanged",
        "fullscreenChanged",
        "hasTrackListChanged",
        "identityChanged",
        "canGoNext",
        "canGoPrevious",
        "canPlay",
        "canPause",
        "canStop",
        "canSeek",
        "canControl",
        "loopStatus",
        "LoopStatus::Status",
        "maximumRate",
        "minimumRate",
        "playbackStatus",
        "PlaybackStatus::Status",
        "position",
        "rate",
        "shuffle",
        "ShuffleStatus::Status",
        "volume",
        "track",
        "artist",
        "artUrl",
        "album",
        "length",
        "kdePid",
        "canQuit",
        "canRaise",
        "canSetFullscreen",
        "supportedMimeTypes",
        "supportedUriSchemes",
        "desktopEntry",
        "iconName",
        "fullscreen",
        "hasTrackList",
        "identity",
        "instancePid"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'canGoNextChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canGoPreviousChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canPlayChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canPauseChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canStopChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canSeekChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canControlChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loopStatusChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maximumRateChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'metadataChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minimumRateChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playbackStatusChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rateChanged'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shuffleChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'volumeChanged'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'trackChanged'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'artistChanged'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'artUrlChanged'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'albumChanged'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lengthChanged'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'kdePidChanged'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canQuitChanged'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canSetFullscreenChanged'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canRaiseChanged'
        QtMocHelpers::SignalData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'supportedMimeTypesChanged'
        QtMocHelpers::SignalData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'supportedUriSchemesChanged'
        QtMocHelpers::SignalData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'desktopEntryChanged'
        QtMocHelpers::SignalData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fullscreenChanged'
        QtMocHelpers::SignalData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hasTrackListChanged'
        QtMocHelpers::SignalData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'identityChanged'
        QtMocHelpers::SignalData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'canGoNext'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'canGoPrevious'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'canPlay'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'canPause'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'canStop'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
        // property 'canSeek'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
        // property 'canControl'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'loopStatus'
        QtMocHelpers::PropertyData<LoopStatus::Status>(40, 0x80000000 | 41, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 7),
        // property 'maximumRate'
        QtMocHelpers::PropertyData<double>(42, QMetaType::Double, QMC::DefaultPropertyFlags, 8),
        // property 'minimumRate'
        QtMocHelpers::PropertyData<double>(43, QMetaType::Double, QMC::DefaultPropertyFlags, 10),
        // property 'playbackStatus'
        QtMocHelpers::PropertyData<PlaybackStatus::Status>(44, 0x80000000 | 45, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 11),
        // property 'position'
        QtMocHelpers::PropertyData<qlonglong>(46, QMetaType::LongLong, QMC::DefaultPropertyFlags, 12),
        // property 'rate'
        QtMocHelpers::PropertyData<double>(47, QMetaType::Double, QMC::DefaultPropertyFlags, 13),
        // property 'shuffle'
        QtMocHelpers::PropertyData<ShuffleStatus::Status>(48, 0x80000000 | 49, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 14),
        // property 'volume'
        QtMocHelpers::PropertyData<double>(50, QMetaType::Double, QMC::DefaultPropertyFlags, 15),
        // property 'track'
        QtMocHelpers::PropertyData<QString>(51, QMetaType::QString, QMC::DefaultPropertyFlags, 16),
        // property 'artist'
        QtMocHelpers::PropertyData<QString>(52, QMetaType::QString, QMC::DefaultPropertyFlags, 17),
        // property 'artUrl'
        QtMocHelpers::PropertyData<QString>(53, QMetaType::QString, QMC::DefaultPropertyFlags, 18),
        // property 'album'
        QtMocHelpers::PropertyData<QString>(54, QMetaType::QString, QMC::DefaultPropertyFlags, 19),
        // property 'length'
        QtMocHelpers::PropertyData<double>(55, QMetaType::Double, QMC::DefaultPropertyFlags, 20),
        // property 'kdePid'
        QtMocHelpers::PropertyData<uint>(56, QMetaType::UInt, QMC::DefaultPropertyFlags, 21),
        // property 'canQuit'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags, 22),
        // property 'canRaise'
        QtMocHelpers::PropertyData<bool>(58, QMetaType::Bool, QMC::DefaultPropertyFlags, 24),
        // property 'canSetFullscreen'
        QtMocHelpers::PropertyData<bool>(59, QMetaType::Bool, QMC::DefaultPropertyFlags, 23),
        // property 'supportedMimeTypes'
        QtMocHelpers::PropertyData<QStringList>(60, QMetaType::QStringList, QMC::DefaultPropertyFlags, 25),
        // property 'supportedUriSchemes'
        QtMocHelpers::PropertyData<QStringList>(61, QMetaType::QStringList, QMC::DefaultPropertyFlags, 26),
        // property 'desktopEntry'
        QtMocHelpers::PropertyData<QString>(62, QMetaType::QString, QMC::DefaultPropertyFlags, 27),
        // property 'iconName'
        QtMocHelpers::PropertyData<QString>(63, QMetaType::QString, QMC::DefaultPropertyFlags, 27),
        // property 'fullscreen'
        QtMocHelpers::PropertyData<bool>(64, QMetaType::Bool, QMC::DefaultPropertyFlags, 28),
        // property 'hasTrackList'
        QtMocHelpers::PropertyData<bool>(65, QMetaType::Bool, QMC::DefaultPropertyFlags, 29),
        // property 'identity'
        QtMocHelpers::PropertyData<QString>(66, QMetaType::QString, QMC::DefaultPropertyFlags, 30),
        // property 'instancePid'
        QtMocHelpers::PropertyData<uint>(67, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbstractPlayerContainer, qt_meta_tag_ZN23AbstractPlayerContainerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN23AbstractPlayerContainerE[] = {
    QMetaObject::SuperData::link<LoopStatus::staticMetaObject>(),
    QMetaObject::SuperData::link<PlaybackStatus::staticMetaObject>(),
    QMetaObject::SuperData::link<ShuffleStatus::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject AbstractPlayerContainer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AbstractPlayerContainerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AbstractPlayerContainerE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN23AbstractPlayerContainerE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23AbstractPlayerContainerE_t>.metaTypes,
    nullptr
} };

void AbstractPlayerContainer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractPlayerContainer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->canGoNextChanged(); break;
        case 1: _t->canGoPreviousChanged(); break;
        case 2: _t->canPlayChanged(); break;
        case 3: _t->canPauseChanged(); break;
        case 4: _t->canStopChanged(); break;
        case 5: _t->canSeekChanged(); break;
        case 6: _t->canControlChanged(); break;
        case 7: _t->loopStatusChanged(); break;
        case 8: _t->maximumRateChanged(); break;
        case 9: _t->metadataChanged(); break;
        case 10: _t->minimumRateChanged(); break;
        case 11: _t->playbackStatusChanged(); break;
        case 12: _t->positionChanged(); break;
        case 13: _t->rateChanged(); break;
        case 14: _t->shuffleChanged(); break;
        case 15: _t->volumeChanged(); break;
        case 16: _t->trackChanged(); break;
        case 17: _t->artistChanged(); break;
        case 18: _t->artUrlChanged(); break;
        case 19: _t->albumChanged(); break;
        case 20: _t->lengthChanged(); break;
        case 21: _t->kdePidChanged(); break;
        case 22: _t->canQuitChanged(); break;
        case 23: _t->canSetFullscreenChanged(); break;
        case 24: _t->canRaiseChanged(); break;
        case 25: _t->supportedMimeTypesChanged(); break;
        case 26: _t->supportedUriSchemesChanged(); break;
        case 27: _t->desktopEntryChanged(); break;
        case 28: _t->fullscreenChanged(); break;
        case 29: _t->hasTrackListChanged(); break;
        case 30: _t->identityChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractPlayerContainer::*)()>(_a, &AbstractPlayerContainer::canGoNextChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPlayerContainer::*)()>(_a, &AbstractPlayerContainer::canGoPreviousChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPlayerContainer::*)()>(_a, &AbstractPlayerContainer::canPlayChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPlayerContainer::*)()>(_a, &AbstractPlayerContainer::canPauseChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPlayerContainer::*)()>(_a, &AbstractPlayerContainer::canStopChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPlayerContainer::*)()>(_a, &AbstractPlayerContainer::canSeekChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPlayerContainer::*)()>(_a, &AbstractPlayerContainer::canControlChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPlayerContainer::*)()>(_a, &AbstractPlayerContainer::loopStatusChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPlayerContainer::*)()>(_a, &AbstractPlayerContainer::maximumRateChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPlayerContainer::*)()>(_a, &AbstractPlayerContainer::metadataChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPlayerContainer::*)()>(_a, &AbstractPlayerContainer::minimumRateChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPlayerContainer::*)()>(_a, &AbstractPlayerContainer::playbackStatusChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPlayerContainer::*)()>(_a, &AbstractPlayerContainer::positionChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPlayerContainer::*)()>(_a, &AbstractPlayerContainer::rateChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPlayerContainer::*)()>(_a, &AbstractPlayerContainer::shuffleChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPlayerContainer::*)()>(_a, &AbstractPlayerContainer::volumeChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPlayerContainer::*)()>(_a, &AbstractPlayerContainer::trackChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPlayerContainer::*)()>(_a, &AbstractPlayerContainer::artistChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPlayerContainer::*)()>(_a, &AbstractPlayerContainer::artUrlChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPlayerContainer::*)()>(_a, &AbstractPlayerContainer::albumChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPlayerContainer::*)()>(_a, &AbstractPlayerContainer::lengthChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPlayerContainer::*)()>(_a, &AbstractPlayerContainer::kdePidChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPlayerContainer::*)()>(_a, &AbstractPlayerContainer::canQuitChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPlayerContainer::*)()>(_a, &AbstractPlayerContainer::canSetFullscreenChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPlayerContainer::*)()>(_a, &AbstractPlayerContainer::canRaiseChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPlayerContainer::*)()>(_a, &AbstractPlayerContainer::supportedMimeTypesChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPlayerContainer::*)()>(_a, &AbstractPlayerContainer::supportedUriSchemesChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPlayerContainer::*)()>(_a, &AbstractPlayerContainer::desktopEntryChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPlayerContainer::*)()>(_a, &AbstractPlayerContainer::fullscreenChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPlayerContainer::*)()>(_a, &AbstractPlayerContainer::hasTrackListChanged, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPlayerContainer::*)()>(_a, &AbstractPlayerContainer::identityChanged, 30))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->canGoNext(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->canGoPrevious(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->canPlay(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->canPause(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->canStop(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->canSeek(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->canControl(); break;
        case 7: *reinterpret_cast<LoopStatus::Status*>(_v) = _t->loopStatus(); break;
        case 8: *reinterpret_cast<double*>(_v) = _t->maximumRate(); break;
        case 9: *reinterpret_cast<double*>(_v) = _t->minimumRate(); break;
        case 10: *reinterpret_cast<PlaybackStatus::Status*>(_v) = _t->playbackStatus(); break;
        case 11: *reinterpret_cast<qlonglong*>(_v) = _t->position(); break;
        case 12: *reinterpret_cast<double*>(_v) = _t->rate(); break;
        case 13: *reinterpret_cast<ShuffleStatus::Status*>(_v) = _t->shuffle(); break;
        case 14: *reinterpret_cast<double*>(_v) = _t->volume(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->track(); break;
        case 16: *reinterpret_cast<QString*>(_v) = _t->artist(); break;
        case 17: *reinterpret_cast<QString*>(_v) = _t->artUrl(); break;
        case 18: *reinterpret_cast<QString*>(_v) = _t->album(); break;
        case 19: *reinterpret_cast<double*>(_v) = _t->length(); break;
        case 20: *reinterpret_cast<uint*>(_v) = _t->kdePid(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->canQuit(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->canRaise(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->canSetFullscreen(); break;
        case 24: *reinterpret_cast<QStringList*>(_v) = _t->supportedMimeTypes(); break;
        case 25: *reinterpret_cast<QStringList*>(_v) = _t->supportedUriSchemes(); break;
        case 26: *reinterpret_cast<QString*>(_v) = _t->desktopEntry(); break;
        case 27: *reinterpret_cast<QString*>(_v) = _t->iconName(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->fullscreen(); break;
        case 29: *reinterpret_cast<bool*>(_v) = _t->hasTrackList(); break;
        case 30: *reinterpret_cast<QString*>(_v) = _t->identity(); break;
        case 31: *reinterpret_cast<uint*>(_v) = _t->instancePid(); break;
        default: break;
        }
    }
}

const QMetaObject *AbstractPlayerContainer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractPlayerContainer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AbstractPlayerContainerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AbstractPlayerContainer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 31)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 31;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 31)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 31;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    return _id;
}

// SIGNAL 0
void AbstractPlayerContainer::canGoNextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AbstractPlayerContainer::canGoPreviousChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AbstractPlayerContainer::canPlayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AbstractPlayerContainer::canPauseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AbstractPlayerContainer::canStopChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void AbstractPlayerContainer::canSeekChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void AbstractPlayerContainer::canControlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void AbstractPlayerContainer::loopStatusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void AbstractPlayerContainer::maximumRateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void AbstractPlayerContainer::metadataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void AbstractPlayerContainer::minimumRateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void AbstractPlayerContainer::playbackStatusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void AbstractPlayerContainer::positionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void AbstractPlayerContainer::rateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void AbstractPlayerContainer::shuffleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void AbstractPlayerContainer::volumeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void AbstractPlayerContainer::trackChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void AbstractPlayerContainer::artistChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void AbstractPlayerContainer::artUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void AbstractPlayerContainer::albumChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void AbstractPlayerContainer::lengthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void AbstractPlayerContainer::kdePidChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void AbstractPlayerContainer::canQuitChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void AbstractPlayerContainer::canSetFullscreenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void AbstractPlayerContainer::canRaiseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void AbstractPlayerContainer::supportedMimeTypesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void AbstractPlayerContainer::supportedUriSchemesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void AbstractPlayerContainer::desktopEntryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void AbstractPlayerContainer::fullscreenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}

// SIGNAL 29
void AbstractPlayerContainer::hasTrackListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}

// SIGNAL 30
void AbstractPlayerContainer::identityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 30, nullptr);
}
namespace {
struct qt_meta_tag_ZN15PlayerContainerE_t {};
} // unnamed namespace

template <> constexpr inline auto PlayerContainer::qt_create_metaobjectdata<qt_meta_tag_ZN15PlayerContainerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PlayerContainer",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "PlayerContainer objects can be obtained from Mpris2Model",
        "initialFetchFinished",
        "",
        "PlayerContainer*",
        "container",
        "initialFetchFailed",
        "onGetPropsFinished",
        "QDBusPendingCallWatcher*",
        "watcher",
        "onPropertiesChanged",
        "interface",
        "QVariantMap",
        "changedProperties",
        "invalidatedProperties",
        "onSeeked",
        "position",
        "Next",
        "OpenUri",
        "Uri",
        "Pause",
        "Play",
        "PlayPause",
        "Previous",
        "Seek",
        "Offset",
        "Stop",
        "Quit",
        "Raise",
        "updatePosition",
        "changeVolume",
        "delta",
        "showOSD",
        "loopStatusChanged",
        "positionChanged",
        "rateChanged",
        "shuffleChanged",
        "volumeChanged",
        "fullscreenChanged",
        "playbackStatusChanged",
        "loopStatus",
        "LoopStatus::Status",
        "rate",
        "shuffle",
        "ShuffleStatus::Status",
        "volume",
        "fullscreen",
        "playbackStatus",
        "PlaybackStatus::Status"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'initialFetchFinished'
        QtMocHelpers::SignalData<void(PlayerContainer *)>(7, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'initialFetchFailed'
        QtMocHelpers::SignalData<void(PlayerContainer *)>(11, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'onGetPropsFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(12, 8, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'onPropertiesChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariantMap &, const QStringList &)>(15, 8, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 16 }, { 0x80000000 | 17, 18 }, { QMetaType::QStringList, 19 },
        }}),
        // Slot 'onSeeked'
        QtMocHelpers::SlotData<void(qlonglong)>(20, 8, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::LongLong, 21 },
        }}),
        // Method 'Next'
        QtMocHelpers::MethodData<void()>(22, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'OpenUri'
        QtMocHelpers::MethodData<void(const QString &)>(23, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 24 },
        }}),
        // Method 'Pause'
        QtMocHelpers::MethodData<void()>(25, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'Play'
        QtMocHelpers::MethodData<void()>(26, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'PlayPause'
        QtMocHelpers::MethodData<void()>(27, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'Previous'
        QtMocHelpers::MethodData<void()>(28, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'Seek'
        QtMocHelpers::MethodData<void(qlonglong)>(29, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 30 },
        }}),
        // Method 'Stop'
        QtMocHelpers::MethodData<void()>(31, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'Quit'
        QtMocHelpers::MethodData<void()>(32, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'Raise'
        QtMocHelpers::MethodData<void()>(33, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'updatePosition'
        QtMocHelpers::MethodData<void()>(34, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'changeVolume'
        QtMocHelpers::MethodData<void(double, bool)>(35, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 36 }, { QMetaType::Bool, 37 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'loopStatus'
        QtMocHelpers::PropertyData<LoopStatus::Status>(45, 0x80000000 | 46, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0x70000000 | 38),
        // property 'position'
        QtMocHelpers::PropertyData<qlonglong>(21, QMetaType::LongLong, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0x70000000 | 39),
        // property 'rate'
        QtMocHelpers::PropertyData<double>(47, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0x70000000 | 40),
        // property 'shuffle'
        QtMocHelpers::PropertyData<ShuffleStatus::Status>(48, 0x80000000 | 49, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0x70000000 | 41),
        // property 'volume'
        QtMocHelpers::PropertyData<double>(50, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0x70000000 | 42),
        // property 'fullscreen'
        QtMocHelpers::PropertyData<bool>(51, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0x70000000 | 43),
        // property 'playbackStatus'
        QtMocHelpers::PropertyData<PlaybackStatus::Status>(52, 0x80000000 | 53, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0x70000000 | 44),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<PlayerContainer, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN15PlayerContainerE[] = {
    QMetaObject::SuperData::link<LoopStatus::staticMetaObject>(),
    QMetaObject::SuperData::link<ShuffleStatus::staticMetaObject>(),
    QMetaObject::SuperData::link<PlaybackStatus::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject PlayerContainer::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractPlayerContainer::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15PlayerContainerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15PlayerContainerE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN15PlayerContainerE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15PlayerContainerE_t>.metaTypes,
    nullptr
} };

void PlayerContainer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PlayerContainer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->initialFetchFinished((*reinterpret_cast<std::add_pointer_t<PlayerContainer*>>(_a[1]))); break;
        case 1: _t->initialFetchFailed((*reinterpret_cast<std::add_pointer_t<PlayerContainer*>>(_a[1]))); break;
        case 2: _t->onGetPropsFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 3: _t->onPropertiesChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        case 4: _t->onSeeked((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 5: _t->Next(); break;
        case 6: _t->OpenUri((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->Pause(); break;
        case 8: _t->Play(); break;
        case 9: _t->PlayPause(); break;
        case 10: _t->Previous(); break;
        case 11: _t->Seek((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 12: _t->Stop(); break;
        case 13: _t->Quit(); break;
        case 14: _t->Raise(); break;
        case 15: _t->updatePosition(); break;
        case 16: _t->changeVolume((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PlayerContainer* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PlayerContainer* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PlayerContainer::*)(PlayerContainer * )>(_a, &PlayerContainer::initialFetchFinished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlayerContainer::*)(PlayerContainer * )>(_a, &PlayerContainer::initialFetchFailed, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<LoopStatus::Status*>(_v) = _t->loopStatus(); break;
        case 1: *reinterpret_cast<qlonglong*>(_v) = _t->position(); break;
        case 2: *reinterpret_cast<double*>(_v) = _t->rate(); break;
        case 3: *reinterpret_cast<ShuffleStatus::Status*>(_v) = _t->shuffle(); break;
        case 4: *reinterpret_cast<double*>(_v) = _t->volume(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->fullscreen(); break;
        case 6: *reinterpret_cast<PlaybackStatus::Status*>(_v) = _t->playbackStatus(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLoopStatus(*reinterpret_cast<LoopStatus::Status*>(_v)); break;
        case 1: _t->setPosition(*reinterpret_cast<qlonglong*>(_v)); break;
        case 2: _t->setRate(*reinterpret_cast<double*>(_v)); break;
        case 3: _t->setShuffle(*reinterpret_cast<ShuffleStatus::Status*>(_v)); break;
        case 4: _t->setVolume(*reinterpret_cast<double*>(_v)); break;
        case 5: _t->setFullscreen(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setPlaybackStatus(*reinterpret_cast<PlaybackStatus::Status*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PlayerContainer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PlayerContainer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15PlayerContainerE_t>.strings))
        return static_cast<void*>(this);
    return AbstractPlayerContainer::qt_metacast(_clname);
}

int PlayerContainer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractPlayerContainer::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void PlayerContainer::initialFetchFinished(PlayerContainer * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PlayerContainer::initialFetchFailed(PlayerContainer * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
namespace CheckNotifySignalValidity_ZN15PlayerContainerE {
template<typename T> using has_nullary_loopStatusChanged = decltype(std::declval<T>().loopStatusChanged());
template<typename T> using has_unary_loopStatusChanged = decltype(std::declval<T>().loopStatusChanged(std::declval<LoopStatus::Status>()));
static_assert(qxp::is_detected_v<has_nullary_loopStatusChanged, PlayerContainer> || qxp::is_detected_v<has_unary_loopStatusChanged, PlayerContainer>,
              "NOTIFY signal loopStatusChanged does not exist in class (or is private in its parent)");
template<typename T> using has_nullary_positionChanged = decltype(std::declval<T>().positionChanged());
template<typename T> using has_unary_positionChanged = decltype(std::declval<T>().positionChanged(std::declval<qlonglong>()));
static_assert(qxp::is_detected_v<has_nullary_positionChanged, PlayerContainer> || qxp::is_detected_v<has_unary_positionChanged, PlayerContainer>,
              "NOTIFY signal positionChanged does not exist in class (or is private in its parent)");
template<typename T> using has_nullary_rateChanged = decltype(std::declval<T>().rateChanged());
template<typename T> using has_unary_rateChanged = decltype(std::declval<T>().rateChanged(std::declval<double>()));
static_assert(qxp::is_detected_v<has_nullary_rateChanged, PlayerContainer> || qxp::is_detected_v<has_unary_rateChanged, PlayerContainer>,
              "NOTIFY signal rateChanged does not exist in class (or is private in its parent)");
template<typename T> using has_nullary_shuffleChanged = decltype(std::declval<T>().shuffleChanged());
template<typename T> using has_unary_shuffleChanged = decltype(std::declval<T>().shuffleChanged(std::declval<ShuffleStatus::Status>()));
static_assert(qxp::is_detected_v<has_nullary_shuffleChanged, PlayerContainer> || qxp::is_detected_v<has_unary_shuffleChanged, PlayerContainer>,
              "NOTIFY signal shuffleChanged does not exist in class (or is private in its parent)");
template<typename T> using has_nullary_volumeChanged = decltype(std::declval<T>().volumeChanged());
template<typename T> using has_unary_volumeChanged = decltype(std::declval<T>().volumeChanged(std::declval<double>()));
static_assert(qxp::is_detected_v<has_nullary_volumeChanged, PlayerContainer> || qxp::is_detected_v<has_unary_volumeChanged, PlayerContainer>,
              "NOTIFY signal volumeChanged does not exist in class (or is private in its parent)");
template<typename T> using has_nullary_fullscreenChanged = decltype(std::declval<T>().fullscreenChanged());
template<typename T> using has_unary_fullscreenChanged = decltype(std::declval<T>().fullscreenChanged(std::declval<bool>()));
static_assert(qxp::is_detected_v<has_nullary_fullscreenChanged, PlayerContainer> || qxp::is_detected_v<has_unary_fullscreenChanged, PlayerContainer>,
              "NOTIFY signal fullscreenChanged does not exist in class (or is private in its parent)");
template<typename T> using has_nullary_playbackStatusChanged = decltype(std::declval<T>().playbackStatusChanged());
template<typename T> using has_unary_playbackStatusChanged = decltype(std::declval<T>().playbackStatusChanged(std::declval<PlaybackStatus::Status>()));
static_assert(qxp::is_detected_v<has_nullary_playbackStatusChanged, PlayerContainer> || qxp::is_detected_v<has_unary_playbackStatusChanged, PlayerContainer>,
              "NOTIFY signal playbackStatusChanged does not exist in class (or is private in its parent)");
}
namespace {
struct qt_meta_tag_ZN10LoopStatusE_t {};
} // unnamed namespace

template <> constexpr inline auto LoopStatus::qt_create_metaobjectdata<qt_meta_tag_ZN10LoopStatusE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LoopStatus",
        "QML.Element",
        "auto",
        "Status",
        "Unknown",
        "None",
        "Playlist",
        "Track"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Status'
        QtMocHelpers::EnumData<Status>(3, 3, QMC::EnumFlags{}).add({
            {    4, Status::Unknown },
            {    5, Status::None },
            {    6, Status::Playlist },
            {    7, Status::Track },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN10LoopStatusE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN10LoopStatusE =
    LoopStatus::qt_create_metaobjectdata<qt_meta_tag_ZN10LoopStatusE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN10LoopStatusE =
    qt_staticMetaObjectContent_ZN10LoopStatusE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN10LoopStatusE =
    qt_staticMetaObjectContent_ZN10LoopStatusE.relocatingData;

Q_CONSTINIT const QMetaObject LoopStatus::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN10LoopStatusE.stringdata,
    qt_staticMetaObjectStaticContent_ZN10LoopStatusE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN10LoopStatusE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN13ShuffleStatusE_t {};
} // unnamed namespace

template <> constexpr inline auto ShuffleStatus::qt_create_metaobjectdata<qt_meta_tag_ZN13ShuffleStatusE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ShuffleStatus",
        "QML.Element",
        "auto",
        "Status",
        "Unknown",
        "Off",
        "On"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Status'
        QtMocHelpers::EnumData<Status>(3, 3, QMC::EnumFlags{}).add({
            {    4, Status::Unknown },
            {    5, Status::Off },
            {    6, Status::On },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN13ShuffleStatusE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN13ShuffleStatusE =
    ShuffleStatus::qt_create_metaobjectdata<qt_meta_tag_ZN13ShuffleStatusE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN13ShuffleStatusE =
    qt_staticMetaObjectContent_ZN13ShuffleStatusE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN13ShuffleStatusE =
    qt_staticMetaObjectContent_ZN13ShuffleStatusE.relocatingData;

Q_CONSTINIT const QMetaObject ShuffleStatus::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN13ShuffleStatusE.stringdata,
    qt_staticMetaObjectStaticContent_ZN13ShuffleStatusE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN13ShuffleStatusE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN14PlaybackStatusE_t {};
} // unnamed namespace

template <> constexpr inline auto PlaybackStatus::qt_create_metaobjectdata<qt_meta_tag_ZN14PlaybackStatusE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PlaybackStatus",
        "QML.Element",
        "auto",
        "Status",
        "Unknown",
        "Stopped",
        "Playing",
        "Paused"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Status'
        QtMocHelpers::EnumData<Status>(3, 3, QMC::EnumFlags{}).add({
            {    4, Status::Unknown },
            {    5, Status::Stopped },
            {    6, Status::Playing },
            {    7, Status::Paused },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN14PlaybackStatusE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN14PlaybackStatusE =
    PlaybackStatus::qt_create_metaobjectdata<qt_meta_tag_ZN14PlaybackStatusE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN14PlaybackStatusE =
    qt_staticMetaObjectContent_ZN14PlaybackStatusE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN14PlaybackStatusE =
    qt_staticMetaObjectContent_ZN14PlaybackStatusE.relocatingData;

Q_CONSTINIT const QMetaObject PlaybackStatus::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN14PlaybackStatusE.stringdata,
    qt_staticMetaObjectStaticContent_ZN14PlaybackStatusE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN14PlaybackStatusE.metaTypes,
    nullptr
} };

QT_WARNING_POP
