/****************************************************************************
** Meta object code from reading C++ file 'fonts.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/kcms/fonts/fonts.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fonts.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6KFontsE_t {};
} // unnamed namespace

template <> constexpr inline auto KFonts::qt_create_metaobjectdata<qt_meta_tag_ZN6KFontsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KFonts",
        "fontsHaveChanged",
        "",
        "hintingCurrentIndexChanged",
        "subPixelCurrentIndexChanged",
        "aliasingChangeApplied",
        "fontDpiSettingsChanged",
        "fontTooSmall",
        "imageProviderReadyChanged",
        "load",
        "save",
        "adjustAllFonts",
        "adjustFont",
        "QFont",
        "font",
        "category",
        "fontsSettings",
        "FontsSettings*",
        "fontsAASettings",
        "FontsAASettings*",
        "subPixelOptionsModel",
        "QAbstractItemModel*",
        "subPixelCurrentIndex",
        "hintingOptionsModel",
        "hintingCurrentIndex",
        "imageProviderReady"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'fontsHaveChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hintingCurrentIndexChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'subPixelCurrentIndexChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'aliasingChangeApplied'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontDpiSettingsChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontTooSmall'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'imageProviderReadyChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'load'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'adjustAllFonts'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'adjustFont'
        QtMocHelpers::SlotData<void(const QFont &, const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { QMetaType::QString, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'fontsSettings'
        QtMocHelpers::PropertyData<FontsSettings*>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'fontsAASettings'
        QtMocHelpers::PropertyData<FontsAASettings*>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'subPixelOptionsModel'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'subPixelCurrentIndex'
        QtMocHelpers::PropertyData<int>(22, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'hintingOptionsModel'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(23, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'hintingCurrentIndex'
        QtMocHelpers::PropertyData<int>(24, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'imageProviderReady'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KFonts, qt_meta_tag_ZN6KFontsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KFonts::staticMetaObject = { {
    QMetaObject::SuperData::link<KQuickManagedConfigModule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6KFontsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6KFontsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6KFontsE_t>.metaTypes,
    nullptr
} };

void KFonts::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KFonts *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->fontsHaveChanged(); break;
        case 1: _t->hintingCurrentIndexChanged(); break;
        case 2: _t->subPixelCurrentIndexChanged(); break;
        case 3: _t->aliasingChangeApplied(); break;
        case 4: _t->fontDpiSettingsChanged(); break;
        case 5: _t->fontTooSmall(); break;
        case 6: _t->imageProviderReadyChanged(); break;
        case 7: _t->load(); break;
        case 8: _t->save(); break;
        case 9: _t->adjustAllFonts(); break;
        case 10: _t->adjustFont((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KFonts::*)()>(_a, &KFonts::fontsHaveChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KFonts::*)()>(_a, &KFonts::hintingCurrentIndexChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KFonts::*)()>(_a, &KFonts::subPixelCurrentIndexChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KFonts::*)()>(_a, &KFonts::aliasingChangeApplied, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KFonts::*)()>(_a, &KFonts::fontDpiSettingsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KFonts::*)()>(_a, &KFonts::fontTooSmall, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KFonts::*)()>(_a, &KFonts::imageProviderReadyChanged, 6))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< FontsAASettings* >(); break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< FontsSettings* >(); break;
        case 4:
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractItemModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<FontsSettings**>(_v) = _t->fontsSettings(); break;
        case 1: *reinterpret_cast<FontsAASettings**>(_v) = _t->fontsAASettings(); break;
        case 2: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->subPixelOptionsModel(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->subPixelCurrentIndex(); break;
        case 4: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->hintingOptionsModel(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->hintingCurrentIndex(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->imageProviderReady(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 3: _t->setSubPixelCurrentIndex(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setHintingCurrentIndex(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KFonts::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KFonts::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6KFontsE_t>.strings))
        return static_cast<void*>(this);
    return KQuickManagedConfigModule::qt_metacast(_clname);
}

int KFonts::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KQuickManagedConfigModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void KFonts::fontsHaveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KFonts::hintingCurrentIndexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KFonts::subPixelCurrentIndexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KFonts::aliasingChangeApplied()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KFonts::fontDpiSettingsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KFonts::fontTooSmall()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KFonts::imageProviderReadyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
