/****************************************************************************
** Meta object code from reading C++ file 'kcmstyle.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/kcms/style/kcmstyle.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcmstyle.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KCMStyleE_t {};
} // unnamed namespace

template <> constexpr inline auto KCMStyle::qt_create_metaobjectdata<qt_meta_tag_ZN8KCMStyleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KCMStyle",
        "mainToolBarStyleChanged",
        "",
        "otherToolBarStyleChanged",
        "gtkConfigKdedModuleLoadedChanged",
        "showErrorMessage",
        "message",
        "styleReconfigured",
        "styleName",
        "configure",
        "title",
        "QQuickItem*",
        "ctx",
        "gtkPage",
        "GtkPage*",
        "model",
        "StylesModel*",
        "styleSettings",
        "StyleSettings*",
        "mainToolBarStyle",
        "ToolBarStyle",
        "otherToolBarStyle",
        "gtkConfigKdedModuleLoaded",
        "NoText",
        "TextOnly",
        "TextBesideIcon",
        "TextUnderIcon"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'mainToolBarStyleChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'otherToolBarStyleChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'gtkConfigKdedModuleLoadedChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showErrorMessage'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'styleReconfigured'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Method 'configure'
        QtMocHelpers::MethodData<void(const QString &, const QString &, QQuickItem *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 8 }, { 0x80000000 | 11, 12 },
        }}),
        // Method 'configure'
        QtMocHelpers::MethodData<void(const QString &, const QString &)>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'gtkPage'
        QtMocHelpers::PropertyData<GtkPage*>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'model'
        QtMocHelpers::PropertyData<StylesModel*>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'styleSettings'
        QtMocHelpers::PropertyData<StyleSettings*>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'mainToolBarStyle'
        QtMocHelpers::PropertyData<enum ToolBarStyle>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'otherToolBarStyle'
        QtMocHelpers::PropertyData<enum ToolBarStyle>(21, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'gtkConfigKdedModuleLoaded'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ToolBarStyle'
        QtMocHelpers::EnumData<enum ToolBarStyle>(20, 20, QMC::EnumFlags{}).add({
            {   23, ToolBarStyle::NoText },
            {   24, ToolBarStyle::TextOnly },
            {   25, ToolBarStyle::TextBesideIcon },
            {   26, ToolBarStyle::TextUnderIcon },
        }),
    };
    return QtMocHelpers::metaObjectData<KCMStyle, qt_meta_tag_ZN8KCMStyleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KCMStyle::staticMetaObject = { {
    QMetaObject::SuperData::link<KQuickManagedConfigModule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KCMStyleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KCMStyleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KCMStyleE_t>.metaTypes,
    nullptr
} };

void KCMStyle::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KCMStyle *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->mainToolBarStyleChanged(); break;
        case 1: _t->otherToolBarStyleChanged(); break;
        case 2: _t->gtkConfigKdedModuleLoadedChanged(); break;
        case 3: _t->showErrorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->styleReconfigured((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->configure((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[3]))); break;
        case 6: _t->configure((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KCMStyle::*)()>(_a, &KCMStyle::mainToolBarStyleChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMStyle::*)()>(_a, &KCMStyle::otherToolBarStyleChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMStyle::*)()>(_a, &KCMStyle::gtkConfigKdedModuleLoadedChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMStyle::*)(const QString & )>(_a, &KCMStyle::showErrorMessage, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMStyle::*)(const QString & )>(_a, &KCMStyle::styleReconfigured, 4))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< GtkPage* >(); break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< StyleSettings* >(); break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< StylesModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<GtkPage**>(_v) = _t->gtkPage(); break;
        case 1: *reinterpret_cast<StylesModel**>(_v) = _t->model(); break;
        case 2: *reinterpret_cast<StyleSettings**>(_v) = _t->styleSettings(); break;
        case 3: *reinterpret_cast<enum ToolBarStyle*>(_v) = _t->mainToolBarStyle(); break;
        case 4: *reinterpret_cast<enum ToolBarStyle*>(_v) = _t->otherToolBarStyle(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->gtkConfigKdedModuleLoaded(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 3: _t->setMainToolBarStyle(*reinterpret_cast<enum ToolBarStyle*>(_v)); break;
        case 4: _t->setOtherToolBarStyle(*reinterpret_cast<enum ToolBarStyle*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KCMStyle::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KCMStyle::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KCMStyleE_t>.strings))
        return static_cast<void*>(this);
    return KQuickManagedConfigModule::qt_metacast(_clname);
}

int KCMStyle::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KQuickManagedConfigModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void KCMStyle::mainToolBarStyleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KCMStyle::otherToolBarStyleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KCMStyle::gtkConfigKdedModuleLoadedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KCMStyle::showErrorMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KCMStyle::styleReconfigured(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
