// This file is generated by kconfig_compiler_kf6 from smserversettings.kcfg.
// All changes you do to this file will be lost.

#include "smserversettings.h"

SMServerSettings::SMServerSettings( )
  : KConfigSkeleton( QStringLiteral( "ksmserverrc" ) )
{
  setCurrentGroup( QStringLiteral( "General" ) );

  KConfigSkeleton::ItemBool  *itemConfirmLogout;
  itemConfirmLogout = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "confirmLogout" ), mConfirmLogout, true );
  addItem( itemConfirmLogout, QStringLiteral( "confirmLogout" ) );
  KConfigSkeleton::ItemInt  *itemShutdownType;
  itemShutdownType = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "shutdownType" ), mShutdownType, 0 );
  addItem( itemShutdownType, QStringLiteral( "shutdownType" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valuesloginMode;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("restorePreviousLogout");
    valuesloginMode.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("restoreSavedSession");
    valuesloginMode.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("emptySession");
    valuesloginMode.append( choice );
  }
  KConfigSkeleton::ItemEnum  *itemLoginMode;
  itemLoginMode = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "loginMode" ), mLoginMode, valuesloginMode, restorePreviousLogout );
  addItem( itemLoginMode, QStringLiteral( "loginMode" ) );
  KConfigSkeleton::ItemString  *itemExcludeApps;
  itemExcludeApps = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "excludeApps" ), mExcludeApps );
  addItem( itemExcludeApps, QStringLiteral( "excludeApps" ) );
}

SMServerSettings::~SMServerSettings()
{
}

