/****************************************************************************
** Meta object code from reading C++ file 'dbusservicewatcher.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/components/dbus/dbusservicewatcher.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QProperty>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbusservicewatcher.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18DBusServiceWatcherE_t {};
} // unnamed namespace

template <> constexpr inline auto DBusServiceWatcher::qt_create_metaobjectdata<qt_meta_tag_ZN18DBusServiceWatcherE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DBusServiceWatcher",
        "QML.Element",
        "auto",
        "busTypeChanged",
        "",
        "watchedServiceChanged",
        "registeredChanged",
        "busType",
        "BusType::Type",
        "watchedService",
        "registered"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'busTypeChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'watchedServiceChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'registeredChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'busType'
        QtMocHelpers::PropertyData<BusType::Type>(7, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'watchedService'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'registered'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DBusServiceWatcher, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN18DBusServiceWatcherE[] = {
    QMetaObject::SuperData::link<BusType::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject DBusServiceWatcher::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18DBusServiceWatcherE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18DBusServiceWatcherE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN18DBusServiceWatcherE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18DBusServiceWatcherE_t>.metaTypes,
    nullptr
} };

void DBusServiceWatcher::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DBusServiceWatcher *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->busTypeChanged(); break;
        case 1: _t->watchedServiceChanged(); break;
        case 2: _t->registeredChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DBusServiceWatcher::*)()>(_a, &DBusServiceWatcher::busTypeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusServiceWatcher::*)()>(_a, &DBusServiceWatcher::watchedServiceChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusServiceWatcher::*)()>(_a, &DBusServiceWatcher::registeredChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<BusType::Type*>(_v) = _t->busType(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->watchedService(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isRegistered().value(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBusType(*reinterpret_cast<BusType::Type*>(_v)); break;
        case 1: _t->setWatchedService(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::BindableProperty) {
        switch (_id) {
        case 2: *static_cast<QUntypedBindable *>(_a[0]) = _t->isRegistered(); break;
        default: break;
        }
    }
}

const QMetaObject *DBusServiceWatcher::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DBusServiceWatcher::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18DBusServiceWatcherE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QObject::qt_metacast(_clname);
}

int DBusServiceWatcher::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void DBusServiceWatcher::busTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DBusServiceWatcher::watchedServiceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DBusServiceWatcher::registeredChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
namespace {
struct qt_meta_tag_ZN7BusTypeE_t {};
} // unnamed namespace

template <> constexpr inline auto BusType::qt_create_metaobjectdata<qt_meta_tag_ZN7BusTypeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BusType",
        "QML.Element",
        "auto",
        "Type",
        "Session",
        "System"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Type'
        QtMocHelpers::EnumData<Type>(3, 3, QMC::EnumFlags{}).add({
            {    4, Type::Session },
            {    5, Type::System },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN7BusTypeE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN7BusTypeE =
    BusType::qt_create_metaobjectdata<qt_meta_tag_ZN7BusTypeE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN7BusTypeE =
    qt_staticMetaObjectContent_ZN7BusTypeE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN7BusTypeE =
    qt_staticMetaObjectContent_ZN7BusTypeE.relocatingData;

Q_CONSTINIT const QMetaObject BusType::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN7BusTypeE.stringdata,
    qt_staticMetaObjectStaticContent_ZN7BusTypeE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN7BusTypeE.metaTypes,
    nullptr
} };

QT_WARNING_POP
