/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<calendar.h>)
#  include <calendar.h>
#endif
#if __has_include(<daysmodel.h>)
#  include <daysmodel.h>
#endif
#if __has_include(<eventdatadecorator.h>)
#  include <eventdatadecorator.h>
#endif
#if __has_include(<eventpluginsmanager.h>)
#  include <eventpluginsmanager.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_plasma_workspace_calendar()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<Calendar>("org.kde.plasma.workspace.calendar", 2);
    qmlRegisterEnum<Calendar::Type>("Calendar::Type");
    qmlRegisterEnum<Calendar::DateMatchingPrecision>("Calendar::DateMatchingPrecision");
    qmlRegisterTypesAndRevisions<DaysModel>("org.kde.plasma.workspace.calendar", 2);
    qmlRegisterTypesAndRevisions<EventDataDecorator>("org.kde.plasma.workspace.calendar", 2);
    qmlRegisterTypesAndRevisions<EventPluginsManager>("org.kde.plasma.workspace.calendar", 2);
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QT_WARNING_POP
    qmlRegisterModule("org.kde.plasma.workspace.calendar", 2, 0);
}

static const QQmlModuleRegistration orgkdeplasmaworkspacecalendarRegistration("org.kde.plasma.workspace.calendar", qml_register_types_org_kde_plasma_workspace_calendar);
