/****************************************************************************
** Meta object code from reading C++ file 'notificationfilterproxymodel_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-workspace-6.7.1/libnotificationmanager/notificationfilterproxymodel_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'notificationfilterproxymodel_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19NotificationManager28NotificationFilterProxyModelE_t {};
} // unnamed namespace

template <> constexpr inline auto NotificationManager::NotificationFilterProxyModel::qt_create_metaobjectdata<qt_meta_tag_ZN19NotificationManager28NotificationFilterProxyModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NotificationManager::NotificationFilterProxyModel",
        "urgenciesChanged",
        "",
        "showExpiredChanged",
        "showDismissedChanged",
        "showAddedDuringInhibitionChanged",
        "ignoreBlacklistDuringInhibitionChanged",
        "blacklistedDesktopEntriesChanged",
        "blacklistedNotifyRcNamesChanged",
        "whitelistedDesktopEntriesChanged",
        "whitelistedNotifyRcNamesChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'urgenciesChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showExpiredChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showDismissedChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showAddedDuringInhibitionChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ignoreBlacklistDuringInhibitionChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'blacklistedDesktopEntriesChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'blacklistedNotifyRcNamesChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'whitelistedDesktopEntriesChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'whitelistedNotifyRcNamesChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NotificationFilterProxyModel, qt_meta_tag_ZN19NotificationManager28NotificationFilterProxyModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject NotificationManager::NotificationFilterProxyModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QSortFilterProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationManager28NotificationFilterProxyModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationManager28NotificationFilterProxyModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19NotificationManager28NotificationFilterProxyModelE_t>.metaTypes,
    nullptr
} };

void NotificationManager::NotificationFilterProxyModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NotificationFilterProxyModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->urgenciesChanged(); break;
        case 1: _t->showExpiredChanged(); break;
        case 2: _t->showDismissedChanged(); break;
        case 3: _t->showAddedDuringInhibitionChanged(); break;
        case 4: _t->ignoreBlacklistDuringInhibitionChanged(); break;
        case 5: _t->blacklistedDesktopEntriesChanged(); break;
        case 6: _t->blacklistedNotifyRcNamesChanged(); break;
        case 7: _t->whitelistedDesktopEntriesChanged(); break;
        case 8: _t->whitelistedNotifyRcNamesChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NotificationFilterProxyModel::*)()>(_a, &NotificationFilterProxyModel::urgenciesChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationFilterProxyModel::*)()>(_a, &NotificationFilterProxyModel::showExpiredChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationFilterProxyModel::*)()>(_a, &NotificationFilterProxyModel::showDismissedChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationFilterProxyModel::*)()>(_a, &NotificationFilterProxyModel::showAddedDuringInhibitionChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationFilterProxyModel::*)()>(_a, &NotificationFilterProxyModel::ignoreBlacklistDuringInhibitionChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationFilterProxyModel::*)()>(_a, &NotificationFilterProxyModel::blacklistedDesktopEntriesChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationFilterProxyModel::*)()>(_a, &NotificationFilterProxyModel::blacklistedNotifyRcNamesChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationFilterProxyModel::*)()>(_a, &NotificationFilterProxyModel::whitelistedDesktopEntriesChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationFilterProxyModel::*)()>(_a, &NotificationFilterProxyModel::whitelistedNotifyRcNamesChanged, 8))
            return;
    }
}

const QMetaObject *NotificationManager::NotificationFilterProxyModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NotificationManager::NotificationFilterProxyModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationManager28NotificationFilterProxyModelE_t>.strings))
        return static_cast<void*>(this);
    return QSortFilterProxyModel::qt_metacast(_clname);
}

int NotificationManager::NotificationFilterProxyModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSortFilterProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void NotificationManager::NotificationFilterProxyModel::urgenciesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void NotificationManager::NotificationFilterProxyModel::showExpiredChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void NotificationManager::NotificationFilterProxyModel::showDismissedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void NotificationManager::NotificationFilterProxyModel::showAddedDuringInhibitionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void NotificationManager::NotificationFilterProxyModel::ignoreBlacklistDuringInhibitionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void NotificationManager::NotificationFilterProxyModel::blacklistedDesktopEntriesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void NotificationManager::NotificationFilterProxyModel::blacklistedNotifyRcNamesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void NotificationManager::NotificationFilterProxyModel::whitelistedDesktopEntriesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void NotificationManager::NotificationFilterProxyModel::whitelistedNotifyRcNamesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
