// This file was generated by qtwaylandscanner
// source file is kde-screen-edge-v1.xml

#ifndef QT_WAYLAND_KDE_SCREEN_EDGE_V1
#define QT_WAYLAND_KDE_SCREEN_EDGE_V1

#include "wayland-kde-screen-edge-v1-client-protocol.h"
#include <QByteArray>
#include <QString>

struct wl_registry;

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")

namespace QtWayland {
    class  kde_screen_edge_manager_v1
    {
    public:
        kde_screen_edge_manager_v1(struct ::wl_registry *registry, uint32_t id, int version);
        kde_screen_edge_manager_v1(struct ::kde_screen_edge_manager_v1 *object);
        kde_screen_edge_manager_v1();

        virtual ~kde_screen_edge_manager_v1();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::kde_screen_edge_manager_v1 *object);

        struct ::kde_screen_edge_manager_v1 *object() { return m_kde_screen_edge_manager_v1; }
        const struct ::kde_screen_edge_manager_v1 *object() const { return m_kde_screen_edge_manager_v1; }
        static kde_screen_edge_manager_v1 *fromObject(struct ::kde_screen_edge_manager_v1 *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        enum error {
            error_invalid_border = 0, // the specified border value is invalid
            error_invalid_role = 1, // the surface has invalid role
            error_already_constructed = 2, // the surface already has a screen edge
        };

        enum border {
            border_top = 1, // top screen edge
            border_bottom = 2, // bottom screen edge
            border_left = 3, // left screen edge
            border_right = 4, // right screen edge
        };

        void destroy();
        struct ::kde_auto_hide_screen_edge_v1 *get_auto_hide_screen_edge(uint32_t border, struct ::wl_surface *surface);

    private:
        struct ::kde_screen_edge_manager_v1 *m_kde_screen_edge_manager_v1;
    };

    class  kde_auto_hide_screen_edge_v1
    {
    public:
        kde_auto_hide_screen_edge_v1(struct ::wl_registry *registry, uint32_t id, int version);
        kde_auto_hide_screen_edge_v1(struct ::kde_auto_hide_screen_edge_v1 *object);
        kde_auto_hide_screen_edge_v1();

        virtual ~kde_auto_hide_screen_edge_v1();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::kde_auto_hide_screen_edge_v1 *object);

        struct ::kde_auto_hide_screen_edge_v1 *object() { return m_kde_auto_hide_screen_edge_v1; }
        const struct ::kde_auto_hide_screen_edge_v1 *object() const { return m_kde_auto_hide_screen_edge_v1; }
        static kde_auto_hide_screen_edge_v1 *fromObject(struct ::kde_auto_hide_screen_edge_v1 *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        void destroy();
        void deactivate();
        void activate();

    private:
        struct ::kde_auto_hide_screen_edge_v1 *m_kde_auto_hide_screen_edge_v1;
    };
}

QT_WARNING_POP
QT_END_NAMESPACE

#endif
