// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "batterycontrol_debug.h"

 namespace COMPONENTS {
Q_LOGGING_CATEGORY(BATTERYCONTROL, "org.kde.batterycontrol", QtWarningMsg)
} 
