/****************************************************************************
** Meta object code from reading C++ file 'watchednotificationsmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-workspace-6.7.1/libnotificationmanager/watchednotificationsmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'watchednotificationsmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19NotificationManager25WatchedNotificationsModelE_t {};
} // unnamed namespace

template <> constexpr inline auto NotificationManager::WatchedNotificationsModel::qt_create_metaobjectdata<qt_meta_tag_ZN19NotificationManager25WatchedNotificationsModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NotificationManager::WatchedNotificationsModel",
        "QML.Element",
        "auto",
        "validChanged",
        "",
        "valid",
        "expire",
        "notificationId",
        "close",
        "invokeDefaultAction",
        "Notifications::InvokeBehavior",
        "behavior",
        "invokeAction",
        "actionName",
        "reply",
        "text"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'validChanged'
        QtMocHelpers::SignalData<void(bool)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Method 'expire'
        QtMocHelpers::MethodData<void(uint)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 7 },
        }}),
        // Method 'close'
        QtMocHelpers::MethodData<void(uint)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 7 },
        }}),
        // Method 'invokeDefaultAction'
        QtMocHelpers::MethodData<void(uint, Notifications::InvokeBehavior)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 7 }, { 0x80000000 | 10, 11 },
        }}),
        // Method 'invokeDefaultAction'
        QtMocHelpers::MethodData<void(uint)>(9, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::UInt, 7 },
        }}),
        // Method 'invokeAction'
        QtMocHelpers::MethodData<void(uint, const QString &, Notifications::InvokeBehavior)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 7 }, { QMetaType::QString, 13 }, { 0x80000000 | 10, 11 },
        }}),
        // Method 'invokeAction'
        QtMocHelpers::MethodData<void(uint, const QString &)>(12, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::UInt, 7 }, { QMetaType::QString, 13 },
        }}),
        // Method 'reply'
        QtMocHelpers::MethodData<void(uint, const QString &, Notifications::InvokeBehavior)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 7 }, { QMetaType::QString, 15 }, { 0x80000000 | 10, 11 },
        }}),
        // Method 'reply'
        QtMocHelpers::MethodData<void(uint, const QString &)>(14, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::UInt, 7 }, { QMetaType::QString, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'valid'
        QtMocHelpers::PropertyData<bool>(5, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<WatchedNotificationsModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject NotificationManager::WatchedNotificationsModel::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractNotificationsModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationManager25WatchedNotificationsModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationManager25WatchedNotificationsModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19NotificationManager25WatchedNotificationsModelE_t>.metaTypes,
    nullptr
} };

void NotificationManager::WatchedNotificationsModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WatchedNotificationsModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->validChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->expire((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 2: _t->close((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 3: _t->invokeDefaultAction((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Notifications::InvokeBehavior>>(_a[2]))); break;
        case 4: _t->invokeDefaultAction((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 5: _t->invokeAction((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Notifications::InvokeBehavior>>(_a[3]))); break;
        case 6: _t->invokeAction((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: _t->reply((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Notifications::InvokeBehavior>>(_a[3]))); break;
        case 8: _t->reply((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WatchedNotificationsModel::*)(bool )>(_a, &WatchedNotificationsModel::validChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->valid(); break;
        default: break;
        }
    }
}

const QMetaObject *NotificationManager::WatchedNotificationsModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NotificationManager::WatchedNotificationsModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationManager25WatchedNotificationsModelE_t>.strings))
        return static_cast<void*>(this);
    return AbstractNotificationsModel::qt_metacast(_clname);
}

int NotificationManager::WatchedNotificationsModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractNotificationsModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void NotificationManager::WatchedNotificationsModel::validChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
