/********************************************************************************
** Form generated from reading UI file 'stylepreview.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_STYLEPREVIEW_H
#define UI_STYLEPREVIEW_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QScrollBar>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_StylePreview
{
public:
    QHBoxLayout *horizontalLayout;
    QTabWidget *tabWidget;
    QWidget *tab_1;
    QGridLayout *gridLayout;
    QSpinBox *spinBox;
    QSlider *horizontalSlider;
    QPushButton *pushButton;
    QScrollBar *verticalScrollBar;
    QComboBox *comboBox;
    QVBoxLayout *verticalLayout_1;
    QCheckBox *checkBox;
    QRadioButton *radioButton_2;
    QRadioButton *radioButton_1;
    QProgressBar *progressBar;
    QWidget *tab_2;

    void setupUi(QWidget *StylePreview)
    {
        if (StylePreview->objectName().isEmpty())
            StylePreview->setObjectName("StylePreview");
        StylePreview->resize(360, 172);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(StylePreview->sizePolicy().hasHeightForWidth());
        StylePreview->setSizePolicy(sizePolicy);
        horizontalLayout = new QHBoxLayout(StylePreview);
        horizontalLayout->setObjectName("horizontalLayout");
        tabWidget = new QTabWidget(StylePreview);
        tabWidget->setObjectName("tabWidget");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Maximum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(tabWidget->sizePolicy().hasHeightForWidth());
        tabWidget->setSizePolicy(sizePolicy1);
        tab_1 = new QWidget();
        tab_1->setObjectName("tab_1");
        gridLayout = new QGridLayout(tab_1);
        gridLayout->setObjectName("gridLayout");
        spinBox = new QSpinBox(tab_1);
        spinBox->setObjectName("spinBox");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(spinBox->sizePolicy().hasHeightForWidth());
        spinBox->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(spinBox, 7, 2, 1, 1);

        horizontalSlider = new QSlider(tab_1);
        horizontalSlider->setObjectName("horizontalSlider");
        horizontalSlider->setValue(30);
        horizontalSlider->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSlider, 8, 0, 1, 1);

        pushButton = new QPushButton(tab_1);
        pushButton->setObjectName("pushButton");
        sizePolicy2.setHeightForWidth(pushButton->sizePolicy().hasHeightForWidth());
        pushButton->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(pushButton, 7, 1, 1, 1);

        verticalScrollBar = new QScrollBar(tab_1);
        verticalScrollBar->setObjectName("verticalScrollBar");
        verticalScrollBar->setMaximum(10);

        gridLayout->addWidget(verticalScrollBar, 6, 3, 4, 1);

        comboBox = new QComboBox(tab_1);
        comboBox->addItem(QString());
        comboBox->setObjectName("comboBox");
        sizePolicy2.setHeightForWidth(comboBox->sizePolicy().hasHeightForWidth());
        comboBox->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(comboBox, 6, 1, 1, 2);

        verticalLayout_1 = new QVBoxLayout();
        verticalLayout_1->setObjectName("verticalLayout_1");
        checkBox = new QCheckBox(tab_1);
        checkBox->setObjectName("checkBox");
        checkBox->setChecked(true);

        verticalLayout_1->addWidget(checkBox);

        radioButton_2 = new QRadioButton(tab_1);
        radioButton_2->setObjectName("radioButton_2");
        radioButton_2->setChecked(true);

        verticalLayout_1->addWidget(radioButton_2);

        radioButton_1 = new QRadioButton(tab_1);
        radioButton_1->setObjectName("radioButton_1");

        verticalLayout_1->addWidget(radioButton_1);


        gridLayout->addLayout(verticalLayout_1, 6, 0, 2, 1);

        progressBar = new QProgressBar(tab_1);
        progressBar->setObjectName("progressBar");
        progressBar->setValue(70);

        gridLayout->addWidget(progressBar, 8, 1, 1, 2);

        tabWidget->addTab(tab_1, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        tabWidget->addTab(tab_2, QString());

        horizontalLayout->addWidget(tabWidget);


        retranslateUi(StylePreview);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(StylePreview);
    } // setupUi

    void retranslateUi(QWidget *StylePreview)
    {
        pushButton->setText(tr2i18n("Push Button", nullptr));
        comboBox->setItemText(0, tr2i18n("Combo box", nullptr));

        checkBox->setText(tr2i18n("Checkbox", nullptr));
        radioButton_2->setText(tr2i18n("Radio button", nullptr));
        radioButton_1->setText(tr2i18n("Radio button", nullptr));
        progressBar->setFormat(tr2i18n("%p%", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_1), tr2i18n("Tab 1", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_2), tr2i18n("Tab 2", nullptr));
        (void)StylePreview;
    } // retranslateUi

};

namespace Ui {
    class StylePreview: public Ui_StylePreview {};
} // namespace Ui

QT_END_NAMESPACE

#endif // STYLEPREVIEW_H

