/****************************************************************************
** Meta object code from reading C++ file 'devicecontrol.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/applets/devicenotifier/devicecontrol.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'devicecontrol.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13DeviceControlE_t {};
} // unnamed namespace

template <> constexpr inline auto DeviceControl::qt_create_metaobjectdata<qt_meta_tag_ZN13DeviceControlE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DeviceControl",
        "deviceAboutToBeRemoved",
        "",
        "udi",
        "onDeviceAdded",
        "onDeviceRemoved",
        "onDeviceSizeChanged",
        "onDeviceStatusChanged",
        "onDeviceMessageChanged",
        "DeviceModels",
        "Udi",
        "Description",
        "Type",
        "Icon",
        "Emblems",
        "IsBusy",
        "IsRemovable",
        "IsRemote",
        "FreeSpace",
        "Size",
        "FreeSpaceText",
        "SizeText",
        "Mounted",
        "State",
        "OperationResult",
        "Timestamp",
        "Message",
        "Actions"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'deviceAboutToBeRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'onDeviceAdded'
        QtMocHelpers::SlotData<void(const QString &)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'onDeviceRemoved'
        QtMocHelpers::SlotData<void(const QString &)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'onDeviceSizeChanged'
        QtMocHelpers::SlotData<void(const QString &)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'onDeviceStatusChanged'
        QtMocHelpers::SlotData<void(const QString &)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'onDeviceMessageChanged'
        QtMocHelpers::SlotData<void(const QString &)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'DeviceModels'
        QtMocHelpers::EnumData<enum DeviceModels>(9, 9, QMC::EnumFlags{}).add({
            {   10, DeviceModels::Udi },
            {   11, DeviceModels::Description },
            {   12, DeviceModels::Type },
            {   13, DeviceModels::Icon },
            {   14, DeviceModels::Emblems },
            {   15, DeviceModels::IsBusy },
            {   16, DeviceModels::IsRemovable },
            {   17, DeviceModels::IsRemote },
            {   18, DeviceModels::FreeSpace },
            {   19, DeviceModels::Size },
            {   20, DeviceModels::FreeSpaceText },
            {   21, DeviceModels::SizeText },
            {   22, DeviceModels::Mounted },
            {   23, DeviceModels::State },
            {   24, DeviceModels::OperationResult },
            {   25, DeviceModels::Timestamp },
            {   26, DeviceModels::Message },
            {   27, DeviceModels::Actions },
        }),
    };
    return QtMocHelpers::metaObjectData<DeviceControl, qt_meta_tag_ZN13DeviceControlE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DeviceControl::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DeviceControlE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DeviceControlE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13DeviceControlE_t>.metaTypes,
    nullptr
} };

void DeviceControl::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeviceControl *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->deviceAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->onDeviceAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->onDeviceRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->onDeviceSizeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->onDeviceStatusChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->onDeviceMessageChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DeviceControl::*)(const QString & )>(_a, &DeviceControl::deviceAboutToBeRemoved, 0))
            return;
    }
}

const QMetaObject *DeviceControl::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeviceControl::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DeviceControlE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int DeviceControl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void DeviceControl::deviceAboutToBeRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
