/****************************************************************************
** Meta object code from reading C++ file 'daysmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/components/calendar/daysmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'daysmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9DaysModelE_t {};
} // unnamed namespace

template <> constexpr inline auto DaysModel::qt_create_metaobjectdata<qt_meta_tag_ZN9DaysModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DaysModel",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "agendaUpdated",
        "updatedDate",
        "update",
        "onDataReady",
        "QMultiHash<QDate,CalendarEvents::EventData>",
        "data",
        "onEventModified",
        "CalendarEvents::EventData",
        "onEventRemoved",
        "uid",
        "onAlternateCalendarDateReady",
        "QHash<QDate,QCalendar::YearMonthDay>",
        "onSubLabelReady",
        "QHash<QDate,CalendarEvents::CalendarEventsPlugin::SubLabel>",
        "setPluginsManager",
        "EventPluginsManager*",
        "manager",
        "eventsForDate",
        "QVariantList",
        "date"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'agendaUpdated'
        QtMocHelpers::SignalData<void(const QDate &)>(7, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 8 },
        }}),
        // Slot 'update'
        QtMocHelpers::SlotData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onDataReady'
        QtMocHelpers::SlotData<void(const QMultiHash<QDate,CalendarEvents::EventData> &)>(10, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'onEventModified'
        QtMocHelpers::SlotData<void(const CalendarEvents::EventData &)>(13, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 12 },
        }}),
        // Slot 'onEventRemoved'
        QtMocHelpers::SlotData<void(const QString &)>(15, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Slot 'onAlternateCalendarDateReady'
        QtMocHelpers::SlotData<void(const QHash<QDate,QCalendar::YearMonthDay> &)>(17, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 18, 12 },
        }}),
        // Slot 'onSubLabelReady'
        QtMocHelpers::SlotData<void(const QHash<QDate,CalendarEvents::CalendarEventsPlugin::SubLabel> &)>(19, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 12 },
        }}),
        // Method 'setPluginsManager'
        QtMocHelpers::MethodData<void(EventPluginsManager *)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Method 'eventsForDate'
        QtMocHelpers::MethodData<QVariantList(const QDate &)>(24, 6, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::QDate, 26 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DaysModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DaysModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DaysModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DaysModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9DaysModelE_t>.metaTypes,
    nullptr
} };

void DaysModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DaysModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->agendaUpdated((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 1: _t->update(); break;
        case 2: _t->onDataReady((*reinterpret_cast<std::add_pointer_t<QMultiHash<QDate,CalendarEvents::EventData>>>(_a[1]))); break;
        case 3: _t->onEventModified((*reinterpret_cast<std::add_pointer_t<CalendarEvents::EventData>>(_a[1]))); break;
        case 4: _t->onEventRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->onAlternateCalendarDateReady((*reinterpret_cast<std::add_pointer_t<QHash<QDate,QCalendar::YearMonthDay>>>(_a[1]))); break;
        case 6: _t->onSubLabelReady((*reinterpret_cast<std::add_pointer_t<QHash<QDate,CalendarEvents::CalendarEventsPlugin::SubLabel>>>(_a[1]))); break;
        case 7: _t->setPluginsManager((*reinterpret_cast<std::add_pointer_t<EventPluginsManager*>>(_a[1]))); break;
        case 8: { QVariantList _r = _t->eventsForDate((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< EventPluginsManager* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DaysModel::*)(const QDate & )>(_a, &DaysModel::agendaUpdated, 0))
            return;
    }
}

const QMetaObject *DaysModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DaysModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DaysModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int DaysModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void DaysModel::agendaUpdated(const QDate & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
