/****************************************************************************
** Meta object code from reading C++ file 'shellcorona.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-workspace-6.7.1/shell/shellcorona.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'shellcorona.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11ShellCoronaE_t {};
} // unnamed namespace

template <> constexpr inline auto ShellCorona::qt_create_metaobjectdata<qt_meta_tag_ZN11ShellCoronaE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ShellCorona",
        "D-Bus Interface",
        "org.kde.PlasmaShell",
        "glInitializationFailed",
        "",
        "containmentPreviewReady",
        "Plasma::Containment*",
        "containment",
        "path",
        "accentColorFromWallpaperEnabledChanged",
        "colorChanged",
        "QColor",
        "color",
        "screenOrderChanged",
        "QList<QScreen*>",
        "screens",
        "wallpaperChanged",
        "screenNum",
        "panelBeingConfiguredChanged",
        "shellAboutToChange",
        "shell",
        "shellChanged",
        "screenUiReadyChanged",
        "screen",
        "ready",
        "requestApplicationConfigSync",
        "slotCyclePanelFocus",
        "setShell",
        "changeShell",
        "toggleDashboard",
        "setDashboardShown",
        "show",
        "toggleActivityManager",
        "toggleWidgetExplorer",
        "evaluateScript",
        "string",
        "setWallpaper",
        "wallpaperPlugin",
        "QVariantMap",
        "parameters",
        "activateLauncherMenu",
        "QRgb",
        "dumpCurrentLayoutJS",
        "loadLookAndFeelDefaultLayout",
        "layout",
        "addPanel",
        "plugin",
        "nextActivity",
        "previousActivity",
        "setTestModeLayout",
        "panelCount",
        "refreshCurrentShell",
        "load",
        "unload",
        "loadDefaultLayout",
        "processUpdateScripts",
        "screenForContainment",
        "const Plasma::Containment*",
        "showAlternativesForApplet",
        "Plasma::Applet*",
        "applet",
        "createWaitingPanels",
        "handleContainmentAdded",
        "c",
        "syncAppConfig",
        "checkActivities",
        "cleanupOldPanelConfig",
        "currentActivityChanged",
        "newActivity",
        "activityAdded",
        "id",
        "activityRemoved",
        "checkAddPanelAction",
        "QAction*",
        "action",
        "populateAddPanelsMenu",
        "addOutput",
        "QScreen*",
        "panelContainmentDestroyed",
        "cont",
        "handleScreenRemoved",
        "handleScreenOrderChanged",
        "activateTaskManagerEntry",
        "index",
        "screenGeometry",
        "QRect",
        "availableScreenRegion",
        "QRegion",
        "availableScreenRect",
        "availableActivities",
        "wallpaper",
        "showAddPanelContextMenu",
        "QPoint",
        "pos",
        "enteredEditModeViaDesktop",
        "isScreenUiReady",
        "numScreens",
        "panelBeingConfigured",
        "PanelView*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'glInitializationFailed'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'containmentPreviewReady'
        QtMocHelpers::SignalData<void(Plasma::Containment *, const QString &)>(5, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'accentColorFromWallpaperEnabledChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorChanged'
        QtMocHelpers::SignalData<void(const QColor &)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'screenOrderChanged'
        QtMocHelpers::SignalData<void(QList<QScreen*>)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Signal 'wallpaperChanged'
        QtMocHelpers::SignalData<void(uint)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 17 },
        }}),
        // Signal 'panelBeingConfiguredChanged'
        QtMocHelpers::SignalData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shellAboutToChange'
        QtMocHelpers::SignalData<void(const QString &)>(19, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Signal 'shellChanged'
        QtMocHelpers::SignalData<void(const QString &)>(21, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Signal 'screenUiReadyChanged'
        QtMocHelpers::SignalData<void(int, bool)>(22, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 }, { QMetaType::Bool, 24 },
        }}),
        // Slot 'requestApplicationConfigSync'
        QtMocHelpers::SlotData<void()>(25, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCyclePanelFocus'
        QtMocHelpers::SlotData<void()>(26, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setShell'
        QtMocHelpers::SlotData<void(const QString &)>(27, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'shell'
        QtMocHelpers::SlotData<QString() const>(20, 4, QMC::AccessPublic, QMetaType::QString),
        // Slot 'changeShell'
        QtMocHelpers::SlotData<void(const QString &)>(28, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'toggleDashboard'
        QtMocHelpers::SlotData<void()>(29, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setDashboardShown'
        QtMocHelpers::SlotData<void(bool)>(30, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 31 },
        }}),
        // Slot 'toggleActivityManager'
        QtMocHelpers::SlotData<void()>(32, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleWidgetExplorer'
        QtMocHelpers::SlotData<void()>(33, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'evaluateScript'
        QtMocHelpers::SlotData<QString(const QString &)>(34, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 35 },
        }}),
        // Slot 'setWallpaper'
        QtMocHelpers::SlotData<void(const QString &, const QVariantMap &, uint)>(36, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 }, { 0x80000000 | 38, 39 }, { QMetaType::UInt, 17 },
        }}),
        // Slot 'setWallpaper'
        QtMocHelpers::SlotData<void(const QString &, const QVariantMap &)>(36, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 37 }, { 0x80000000 | 38, 39 },
        }}),
        // Slot 'activateLauncherMenu'
        QtMocHelpers::SlotData<void()>(40, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'color'
        QtMocHelpers::SlotData<QRgb() const>(12, 4, QMC::AccessPublic, 0x80000000 | 41),
        // Slot 'dumpCurrentLayoutJS'
        QtMocHelpers::SlotData<QByteArray() const>(42, 4, QMC::AccessPublic, QMetaType::QByteArray),
        // Slot 'loadLookAndFeelDefaultLayout'
        QtMocHelpers::SlotData<void(const QString &)>(43, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 44 },
        }}),
        // Slot 'addPanel'
        QtMocHelpers::SlotData<Plasma::Containment *(const QString &)>(45, 4, QMC::AccessPublic, 0x80000000 | 6, {{
            { QMetaType::QString, 46 },
        }}),
        // Slot 'nextActivity'
        QtMocHelpers::SlotData<void()>(47, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'previousActivity'
        QtMocHelpers::SlotData<void()>(48, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setTestModeLayout'
        QtMocHelpers::SlotData<void(const QString &)>(49, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 44 },
        }}),
        // Slot 'panelCount'
        QtMocHelpers::SlotData<int() const>(50, 4, QMC::AccessPublic, QMetaType::Int),
        // Slot 'refreshCurrentShell'
        QtMocHelpers::SlotData<void()>(51, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'load'
        QtMocHelpers::SlotData<void()>(52, 4, QMC::AccessProtected, QMetaType::Void),
        // Slot 'unload'
        QtMocHelpers::SlotData<void()>(53, 4, QMC::AccessProtected, QMetaType::Void),
        // Slot 'loadDefaultLayout'
        QtMocHelpers::SlotData<void()>(54, 4, QMC::AccessProtected, QMetaType::Void),
        // Slot 'processUpdateScripts'
        QtMocHelpers::SlotData<void()>(55, 4, QMC::AccessProtected, QMetaType::Void),
        // Slot 'screenForContainment'
        QtMocHelpers::SlotData<int(const Plasma::Containment *) const>(56, 4, QMC::AccessProtected, QMetaType::Int, {{
            { 0x80000000 | 57, 7 },
        }}),
        // Slot 'showAlternativesForApplet'
        QtMocHelpers::SlotData<void(Plasma::Applet *)>(58, 4, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 59, 60 },
        }}),
        // Slot 'createWaitingPanels'
        QtMocHelpers::SlotData<void()>(61, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleContainmentAdded'
        QtMocHelpers::SlotData<void(Plasma::Containment *)>(62, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 63 },
        }}),
        // Slot 'syncAppConfig'
        QtMocHelpers::SlotData<void()>(64, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'checkActivities'
        QtMocHelpers::SlotData<void()>(65, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'cleanupOldPanelConfig'
        QtMocHelpers::SlotData<void()>(66, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'currentActivityChanged'
        QtMocHelpers::SlotData<void(const QString &)>(67, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 68 },
        }}),
        // Slot 'activityAdded'
        QtMocHelpers::SlotData<void(const QString &)>(69, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 70 },
        }}),
        // Slot 'activityRemoved'
        QtMocHelpers::SlotData<void(const QString &)>(71, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 70 },
        }}),
        // Slot 'checkAddPanelAction'
        QtMocHelpers::SlotData<void()>(72, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addPanel'
        QtMocHelpers::SlotData<void()>(45, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addPanel'
        QtMocHelpers::SlotData<void(QAction *)>(45, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 73, 74 },
        }}),
        // Slot 'populateAddPanelsMenu'
        QtMocHelpers::SlotData<void()>(75, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addOutput'
        QtMocHelpers::SlotData<void(QScreen *)>(76, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 77, 23 },
        }}),
        // Slot 'panelContainmentDestroyed'
        QtMocHelpers::SlotData<void(QObject *)>(78, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 79 },
        }}),
        // Slot 'handleScreenRemoved'
        QtMocHelpers::SlotData<void(QScreen *)>(80, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 77, 23 },
        }}),
        // Slot 'handleScreenOrderChanged'
        QtMocHelpers::SlotData<void(QList<QScreen*>)>(81, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'activateTaskManagerEntry'
        QtMocHelpers::SlotData<void(int)>(82, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 83 },
        }}),
        // Method 'screenGeometry'
        QtMocHelpers::MethodData<QRect(int) const>(84, 4, QMC::AccessPublic, 0x80000000 | 85, {{
            { QMetaType::Int, 70 },
        }}),
        // Method 'availableScreenRegion'
        QtMocHelpers::MethodData<QRegion(int) const>(86, 4, QMC::AccessPublic, 0x80000000 | 87, {{
            { QMetaType::Int, 70 },
        }}),
        // Method 'availableScreenRect'
        QtMocHelpers::MethodData<QRect(int) const>(88, 4, QMC::AccessPublic, 0x80000000 | 85, {{
            { QMetaType::Int, 70 },
        }}),
        // Method 'availableActivities'
        QtMocHelpers::MethodData<QStringList() const>(89, 4, QMC::AccessPublic, QMetaType::QStringList),
        // Method 'wallpaper'
        QtMocHelpers::MethodData<QVariantMap(uint)>(90, 4, QMC::AccessPublic, 0x80000000 | 38, {{
            { QMetaType::UInt, 17 },
        }}),
        // Method 'wallpaper'
        QtMocHelpers::MethodData<QVariantMap()>(90, 4, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 38),
        // Method 'showAddPanelContextMenu'
        QtMocHelpers::MethodData<void(const QPoint)>(91, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 92, 93 },
        }}),
        // Method 'enteredEditModeViaDesktop'
        QtMocHelpers::MethodData<bool()>(94, 4, QMC::AccessPublic, QMetaType::Bool),
        // Method 'isScreenUiReady'
        QtMocHelpers::MethodData<bool(int)>(95, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'shell'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags, 8),
        // property 'numScreens'
        QtMocHelpers::PropertyData<int>(96, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'panelBeingConfigured'
        QtMocHelpers::PropertyData<PanelView*>(97, 0x80000000 | 98, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 6),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ShellCorona, qt_meta_tag_ZN11ShellCoronaE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ShellCorona::staticMetaObject = { {
    QMetaObject::SuperData::link<Plasma::Corona::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ShellCoronaE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ShellCoronaE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11ShellCoronaE_t>.metaTypes,
    nullptr
} };

void ShellCorona::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ShellCorona *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->glInitializationFailed(); break;
        case 1: _t->containmentPreviewReady((*reinterpret_cast<std::add_pointer_t<Plasma::Containment*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->accentColorFromWallpaperEnabledChanged(); break;
        case 3: _t->colorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 4: _t->screenOrderChanged((*reinterpret_cast<std::add_pointer_t<QList<QScreen*>>>(_a[1]))); break;
        case 5: _t->wallpaperChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 6: _t->panelBeingConfiguredChanged(); break;
        case 7: _t->shellAboutToChange((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->shellChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->screenUiReadyChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 10: _t->requestApplicationConfigSync(); break;
        case 11: _t->slotCyclePanelFocus(); break;
        case 12: _t->setShell((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: { QString _r = _t->shell();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->changeShell((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->toggleDashboard(); break;
        case 16: _t->setDashboardShown((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->toggleActivityManager(); break;
        case 18: _t->toggleWidgetExplorer(); break;
        case 19: { QString _r = _t->evaluateScript((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 20: _t->setWallpaper((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3]))); break;
        case 21: _t->setWallpaper((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2]))); break;
        case 22: _t->activateLauncherMenu(); break;
        case 23: { QRgb _r = _t->color();
            if (_a[0]) *reinterpret_cast<QRgb*>(_a[0]) = std::move(_r); }  break;
        case 24: { QByteArray _r = _t->dumpCurrentLayoutJS();
            if (_a[0]) *reinterpret_cast<QByteArray*>(_a[0]) = std::move(_r); }  break;
        case 25: _t->loadLookAndFeelDefaultLayout((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 26: { Plasma::Containment* _r = _t->addPanel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Plasma::Containment**>(_a[0]) = std::move(_r); }  break;
        case 27: _t->nextActivity(); break;
        case 28: _t->previousActivity(); break;
        case 29: _t->setTestModeLayout((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 30: { int _r = _t->panelCount();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 31: _t->refreshCurrentShell(); break;
        case 32: _t->load(); break;
        case 33: _t->unload(); break;
        case 34: _t->loadDefaultLayout(); break;
        case 35: _t->processUpdateScripts(); break;
        case 36: { int _r = _t->screenForContainment((*reinterpret_cast<std::add_pointer_t<const Plasma::Containment*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 37: _t->showAlternativesForApplet((*reinterpret_cast<std::add_pointer_t<Plasma::Applet*>>(_a[1]))); break;
        case 38: _t->createWaitingPanels(); break;
        case 39: _t->handleContainmentAdded((*reinterpret_cast<std::add_pointer_t<Plasma::Containment*>>(_a[1]))); break;
        case 40: _t->syncAppConfig(); break;
        case 41: _t->checkActivities(); break;
        case 42: _t->cleanupOldPanelConfig(); break;
        case 43: _t->currentActivityChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 44: _t->activityAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 45: _t->activityRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 46: _t->checkAddPanelAction(); break;
        case 47: _t->addPanel(); break;
        case 48: _t->addPanel((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 49: _t->populateAddPanelsMenu(); break;
        case 50: _t->addOutput((*reinterpret_cast<std::add_pointer_t<QScreen*>>(_a[1]))); break;
        case 51: _t->panelContainmentDestroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 52: _t->handleScreenRemoved((*reinterpret_cast<std::add_pointer_t<QScreen*>>(_a[1]))); break;
        case 53: _t->handleScreenOrderChanged((*reinterpret_cast<std::add_pointer_t<QList<QScreen*>>>(_a[1]))); break;
        case 54: _t->activateTaskManagerEntry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 55: { QRect _r = _t->screenGeometry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QRect*>(_a[0]) = std::move(_r); }  break;
        case 56: { QRegion _r = _t->availableScreenRegion((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QRegion*>(_a[0]) = std::move(_r); }  break;
        case 57: { QRect _r = _t->availableScreenRect((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QRect*>(_a[0]) = std::move(_r); }  break;
        case 58: { QStringList _r = _t->availableActivities();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 59: { QVariantMap _r = _t->wallpaper((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 60: { QVariantMap _r = _t->wallpaper();
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 61: _t->showAddPanelContextMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 62: { bool _r = _t->enteredEditModeViaDesktop();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 63: { bool _r = _t->isScreenUiReady((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Plasma::Containment* >(); break;
            }
            break;
        case 37:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Plasma::Applet* >(); break;
            }
            break;
        case 39:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Plasma::Containment* >(); break;
            }
            break;
        case 48:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ShellCorona::*)()>(_a, &ShellCorona::glInitializationFailed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShellCorona::*)(Plasma::Containment * , const QString & )>(_a, &ShellCorona::containmentPreviewReady, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShellCorona::*)()>(_a, &ShellCorona::accentColorFromWallpaperEnabledChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShellCorona::*)(const QColor & )>(_a, &ShellCorona::colorChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShellCorona::*)(QList<QScreen*> )>(_a, &ShellCorona::screenOrderChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShellCorona::*)(uint )>(_a, &ShellCorona::wallpaperChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShellCorona::*)()>(_a, &ShellCorona::panelBeingConfiguredChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShellCorona::*)(const QString & )>(_a, &ShellCorona::shellAboutToChange, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShellCorona::*)(const QString & )>(_a, &ShellCorona::shellChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShellCorona::*)(int , bool )>(_a, &ShellCorona::screenUiReadyChanged, 9))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->shell(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->numScreens(); break;
        case 2: *reinterpret_cast<PanelView**>(_v) = _t->panelBeingConfigured(); break;
        default: break;
        }
    }
}

const QMetaObject *ShellCorona::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ShellCorona::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ShellCoronaE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return Plasma::Corona::qt_metacast(_clname);
}

int ShellCorona::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Plasma::Corona::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 64)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 64;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 64)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 64;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void ShellCorona::glInitializationFailed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ShellCorona::containmentPreviewReady(Plasma::Containment * _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void ShellCorona::accentColorFromWallpaperEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ShellCorona::colorChanged(const QColor & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ShellCorona::screenOrderChanged(QList<QScreen*> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void ShellCorona::wallpaperChanged(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void ShellCorona::panelBeingConfiguredChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void ShellCorona::shellAboutToChange(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void ShellCorona::shellChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void ShellCorona::screenUiReadyChanged(int _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}
QT_WARNING_POP
