// This file is generated by kconfig_compiler_kf6 from desktopthemesettings.kcfg.
// All changes you do to this file will be lost.

#include "desktopthemesettings.h"

DesktopThemeSettings::DesktopThemeSettings( QObject *parent )
  : KConfigSkeleton( QStringLiteral( "plasmarc" ) )
{
  setParent(parent);
  KConfigCompilerSignallingItem::NotifyFunction notifyFunction = static_cast<KConfigCompilerSignallingItem::NotifyFunction>(&DesktopThemeSettings::itemChanged);

  setCurrentGroup( QStringLiteral( "Theme" ) );

  KConfigCompilerSignallingItem  *itemName;
  KConfigSkeleton::ItemString  *innerItemName;
  innerItemName = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "name" ), mName, QStringLiteral( "default" ) );
  itemName = new KConfigCompilerSignallingItem(innerItemName, this, notifyFunction, signalNameChanged);
  itemName->setWriteFlags(KConfigBase::Notify);
  addItem( itemName, QStringLiteral( "name" ) );
}

QString DesktopThemeSettings::defaultNameValue_helper() const
{

  return QStringLiteral( "default" );
}

DesktopThemeSettings::~DesktopThemeSettings()
{
}


void DesktopThemeSettings::itemChanged(quint64 signalFlag) {

  switch (signalFlag) {
  case signalNameChanged:
    Q_EMIT nameChanged();
    break;
  }
}
