/****************************************************************************
** Meta object code from reading C++ file 'dashboardwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/applets/kicker/dashboardwindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dashboardwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15DashboardWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto DashboardWindow::qt_create_metaobjectdata<qt_meta_tag_ZN15DashboardWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DashboardWindow",
        "QML.Element",
        "auto",
        "DefaultProperty",
        "mainItem",
        "mainItemChanged",
        "",
        "visualParentChanged",
        "keyEventProxyChanged",
        "backgroundColorChanged",
        "keyEscapePressed",
        "updateTheme",
        "visualParentWindowChanged",
        "QQuickWindow*",
        "window",
        "visualParentScreenChanged",
        "QScreen*",
        "screen",
        "toggle",
        "QQuickItem*",
        "visualParent",
        "keyEventProxy",
        "backgroundColor",
        "QColor"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'mainItemChanged'
        QtMocHelpers::SignalData<void() const>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'visualParentChanged'
        QtMocHelpers::SignalData<void() const>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'keyEventProxyChanged'
        QtMocHelpers::SignalData<void() const>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'backgroundColorChanged'
        QtMocHelpers::SignalData<void() const>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'keyEscapePressed'
        QtMocHelpers::SignalData<void() const>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateTheme'
        QtMocHelpers::SlotData<void()>(11, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'visualParentWindowChanged'
        QtMocHelpers::SlotData<void(QQuickWindow *)>(12, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'visualParentScreenChanged'
        QtMocHelpers::SlotData<void(QScreen *)>(15, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Method 'toggle'
        QtMocHelpers::MethodData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'mainItem'
        QtMocHelpers::PropertyData<QQuickItem*>(4, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'visualParent'
        QtMocHelpers::PropertyData<QQuickItem*>(20, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'keyEventProxy'
        QtMocHelpers::PropertyData<QQuickItem*>(21, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'backgroundColor'
        QtMocHelpers::PropertyData<QColor>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<DashboardWindow, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DashboardWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DashboardWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DashboardWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15DashboardWindowE_t>.metaTypes,
    nullptr
} };

void DashboardWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DashboardWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->mainItemChanged(); break;
        case 1: _t->visualParentChanged(); break;
        case 2: _t->keyEventProxyChanged(); break;
        case 3: _t->backgroundColorChanged(); break;
        case 4: _t->keyEscapePressed(); break;
        case 5: _t->updateTheme(); break;
        case 6: _t->visualParentWindowChanged((*reinterpret_cast<std::add_pointer_t<QQuickWindow*>>(_a[1]))); break;
        case 7: _t->visualParentScreenChanged((*reinterpret_cast<std::add_pointer_t<QScreen*>>(_a[1]))); break;
        case 8: _t->toggle(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuickWindow* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QScreen* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DashboardWindow::*)() const>(_a, &DashboardWindow::mainItemChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DashboardWindow::*)() const>(_a, &DashboardWindow::visualParentChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DashboardWindow::*)() const>(_a, &DashboardWindow::keyEventProxyChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DashboardWindow::*)() const>(_a, &DashboardWindow::backgroundColorChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DashboardWindow::*)() const>(_a, &DashboardWindow::keyEscapePressed, 4))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQuickItem**>(_v) = _t->mainItem(); break;
        case 1: *reinterpret_cast<QQuickItem**>(_v) = _t->visualParent(); break;
        case 2: *reinterpret_cast<QQuickItem**>(_v) = _t->keyEventProxy(); break;
        case 3: *reinterpret_cast<QColor*>(_v) = _t->backgroundColor(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMainItem(*reinterpret_cast<QQuickItem**>(_v)); break;
        case 1: _t->setVisualParent(*reinterpret_cast<QQuickItem**>(_v)); break;
        case 2: _t->setKeyEventProxy(*reinterpret_cast<QQuickItem**>(_v)); break;
        case 3: _t->setBackgroundColor(*reinterpret_cast<QColor*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DashboardWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DashboardWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DashboardWindowE_t>.strings))
        return static_cast<void*>(this);
    return QQuickWindow::qt_metacast(_clname);
}

int DashboardWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void DashboardWindow::mainItemChanged()const
{
    QMetaObject::activate(const_cast< DashboardWindow *>(this), &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DashboardWindow::visualParentChanged()const
{
    QMetaObject::activate(const_cast< DashboardWindow *>(this), &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DashboardWindow::keyEventProxyChanged()const
{
    QMetaObject::activate(const_cast< DashboardWindow *>(this), &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DashboardWindow::backgroundColorChanged()const
{
    QMetaObject::activate(const_cast< DashboardWindow *>(this), &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DashboardWindow::keyEscapePressed()const
{
    QMetaObject::activate(const_cast< DashboardWindow *>(this), &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
