/****************************************************************************
** Meta object code from reading C++ file 'autostartmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/kcms/autostart/autostartmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'autostartmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14AutostartModelE_t {};
} // unnamed namespace

template <> constexpr inline auto AutostartModel::qt_create_metaobjectdata<qt_meta_tag_ZN14AutostartModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AutostartModel",
        "error",
        "",
        "message",
        "nonExecutableScript",
        "fileName",
        "AutostartModel::AutostartEntrySource",
        "kind",
        "removeEntry",
        "row",
        "editApplication",
        "QQuickItem*",
        "context",
        "addScript",
        "QUrl",
        "url",
        "AutostartEntrySource",
        "showApplicationDialog",
        "makeFileExecutable",
        "usingSystemdBoot",
        "XdgAutoStart",
        "XdgScripts",
        "PlasmaShutdown",
        "PlasmaEnvScripts"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'error'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'nonExecutableScript'
        QtMocHelpers::SignalData<void(const QString &, AutostartModel::AutostartEntrySource)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Method 'removeEntry'
        QtMocHelpers::MethodData<void(int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Method 'editApplication'
        QtMocHelpers::MethodData<void(int, QQuickItem *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 }, { 0x80000000 | 11, 12 },
        }}),
        // Method 'addScript'
        QtMocHelpers::MethodData<void(const QUrl &, enum AutostartEntrySource)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { 0x80000000 | 16, 7 },
        }}),
        // Method 'showApplicationDialog'
        QtMocHelpers::MethodData<void(QQuickItem *)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Method 'makeFileExecutable'
        QtMocHelpers::MethodData<void(const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'usingSystemdBoot'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'AutostartEntrySource'
        QtMocHelpers::EnumData<enum AutostartEntrySource>(16, 16, QMC::EnumFlags{}).add({
            {   20, AutostartEntrySource::XdgAutoStart },
            {   21, AutostartEntrySource::XdgScripts },
            {   22, AutostartEntrySource::PlasmaShutdown },
            {   23, AutostartEntrySource::PlasmaEnvScripts },
        }),
    };
    return QtMocHelpers::metaObjectData<AutostartModel, qt_meta_tag_ZN14AutostartModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AutostartModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AutostartModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AutostartModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14AutostartModelE_t>.metaTypes,
    nullptr
} };

void AutostartModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AutostartModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->nonExecutableScript((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<AutostartModel::AutostartEntrySource>>(_a[2]))); break;
        case 2: _t->removeEntry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->editApplication((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[2]))); break;
        case 4: _t->addScript((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<enum AutostartEntrySource>>(_a[2]))); break;
        case 5: _t->showApplicationDialog((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1]))); break;
        case 6: _t->makeFileExecutable((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AutostartModel::*)(const QString & )>(_a, &AutostartModel::error, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AutostartModel::*)(const QString & , AutostartModel::AutostartEntrySource )>(_a, &AutostartModel::nonExecutableScript, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->usingSystemdBoot(); break;
        default: break;
        }
    }
}

const QMetaObject *AutostartModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AutostartModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AutostartModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int AutostartModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void AutostartModel::error(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AutostartModel::nonExecutableScript(const QString & _t1, AutostartModel::AutostartEntrySource _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
QT_WARNING_POP
