/****************************************************************************
** Meta object code from reading C++ file 'colors.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/kcms/colors/colors.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'colors.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9KCMColorsE_t {};
} // unnamed namespace

template <> constexpr inline auto KCMColors::qt_create_metaobjectdata<qt_meta_tag_ZN9KCMColorsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KCMColors",
        "accentColorChanged",
        "",
        "lastUsedCustomAccentColorChanged",
        "accentColorFromWallpaperChanged",
        "downloadingFileChanged",
        "showSuccessMessage",
        "message",
        "showErrorMessage",
        "showSchemeNotInstalledWarning",
        "schemeName",
        "load",
        "save",
        "wallpaperAccentColorArrivedSlot",
        "QDBusPendingCallWatcher*",
        "call",
        "loadSelectedColorScheme",
        "knsEntryChanged",
        "KNSCore::Entry",
        "entry",
        "installSchemeFromFile",
        "QUrl",
        "url",
        "editScheme",
        "QQuickItem*",
        "ctx",
        "tinted",
        "QColor",
        "color",
        "accent",
        "tints",
        "tintFactor",
        "accentBackground",
        "background",
        "accentForeground",
        "isActive",
        "model",
        "ColorsModel*",
        "filteredModel",
        "FilterProxyModel*",
        "colorsSettings",
        "ColorsSettings*",
        "downloadingFile",
        "accentColor",
        "lastUsedCustomAccentColor",
        "accentColorFromWallpaper",
        "SchemeFilter",
        "AllSchemes",
        "LightSchemes",
        "DarkSchemes"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'accentColorChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastUsedCustomAccentColorChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'accentColorFromWallpaperChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'downloadingFileChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showSuccessMessage'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'showErrorMessage'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'showSchemeNotInstalledWarning'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'load'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'wallpaperAccentColorArrivedSlot'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Method 'loadSelectedColorScheme'
        QtMocHelpers::MethodData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'knsEntryChanged'
        QtMocHelpers::MethodData<void(const KNSCore::Entry &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Method 'installSchemeFromFile'
        QtMocHelpers::MethodData<void(const QUrl &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Method 'editScheme'
        QtMocHelpers::MethodData<void(const QString &, QQuickItem *)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { 0x80000000 | 24, 25 },
        }}),
        // Method 'tinted'
        QtMocHelpers::MethodData<QColor(const QColor &, const QColor &, bool, qreal)>(26, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { 0x80000000 | 27, 28 }, { 0x80000000 | 27, 29 }, { QMetaType::Bool, 30 }, { QMetaType::QReal, 31 },
        }}),
        // Method 'accentBackground'
        QtMocHelpers::MethodData<QColor(const QColor &, const QColor &)>(32, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { 0x80000000 | 27, 29 }, { 0x80000000 | 27, 33 },
        }}),
        // Method 'accentForeground'
        QtMocHelpers::MethodData<QColor(const QColor &, const bool &)>(34, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { 0x80000000 | 27, 29 }, { QMetaType::Bool, 35 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'model'
        QtMocHelpers::PropertyData<ColorsModel*>(36, 0x80000000 | 37, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'filteredModel'
        QtMocHelpers::PropertyData<FilterProxyModel*>(38, 0x80000000 | 39, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'colorsSettings'
        QtMocHelpers::PropertyData<ColorsSettings*>(40, 0x80000000 | 41, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'downloadingFile'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'accentColor'
        QtMocHelpers::PropertyData<QColor>(43, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'lastUsedCustomAccentColor'
        QtMocHelpers::PropertyData<QColor>(44, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'accentColorFromWallpaper'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'SchemeFilter'
        QtMocHelpers::EnumData<enum SchemeFilter>(46, 46, QMC::EnumFlags{}).add({
            {   47, SchemeFilter::AllSchemes },
            {   48, SchemeFilter::LightSchemes },
            {   49, SchemeFilter::DarkSchemes },
        }),
    };
    return QtMocHelpers::metaObjectData<KCMColors, qt_meta_tag_ZN9KCMColorsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KCMColors::staticMetaObject = { {
    QMetaObject::SuperData::link<KQuickManagedConfigModule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KCMColorsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KCMColorsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9KCMColorsE_t>.metaTypes,
    nullptr
} };

void KCMColors::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KCMColors *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->accentColorChanged(); break;
        case 1: _t->lastUsedCustomAccentColorChanged(); break;
        case 2: _t->accentColorFromWallpaperChanged(); break;
        case 3: _t->downloadingFileChanged(); break;
        case 4: _t->showSuccessMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->showErrorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->showSchemeNotInstalledWarning((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->load(); break;
        case 8: _t->save(); break;
        case 9: _t->wallpaperAccentColorArrivedSlot((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 10: _t->loadSelectedColorScheme(); break;
        case 11: _t->knsEntryChanged((*reinterpret_cast<std::add_pointer_t<KNSCore::Entry>>(_a[1]))); break;
        case 12: _t->installSchemeFromFile((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 13: _t->editScheme((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[2]))); break;
        case 14: { QColor _r = _t->tinted((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 15: { QColor _r = _t->accentBackground((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 16: { QColor _r = _t->accentForeground((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KCMColors::*)()>(_a, &KCMColors::accentColorChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMColors::*)()>(_a, &KCMColors::lastUsedCustomAccentColorChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMColors::*)()>(_a, &KCMColors::accentColorFromWallpaperChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMColors::*)()>(_a, &KCMColors::downloadingFileChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMColors::*)(const QString & )>(_a, &KCMColors::showSuccessMessage, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMColors::*)(const QString & )>(_a, &KCMColors::showErrorMessage, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMColors::*)(const QString & )>(_a, &KCMColors::showSchemeNotInstalledWarning, 6))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ColorsModel* >(); break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ColorsSettings* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<ColorsModel**>(_v) = _t->model(); break;
        case 1: *reinterpret_cast<FilterProxyModel**>(_v) = _t->filteredModel(); break;
        case 2: *reinterpret_cast<ColorsSettings**>(_v) = _t->colorsSettings(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->downloadingFile(); break;
        case 4: *reinterpret_cast<QColor*>(_v) = _t->accentColor(); break;
        case 5: *reinterpret_cast<QColor*>(_v) = _t->lastUsedCustomAccentColor(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->accentColorFromWallpaper(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 4: _t->setAccentColor(*reinterpret_cast<QColor*>(_v)); break;
        case 5: _t->setLastUsedCustomAccentColor(*reinterpret_cast<QColor*>(_v)); break;
        case 6: _t->setAccentColorFromWallpaper(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KCMColors::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KCMColors::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KCMColorsE_t>.strings))
        return static_cast<void*>(this);
    return KQuickManagedConfigModule::qt_metacast(_clname);
}

int KCMColors::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KQuickManagedConfigModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void KCMColors::accentColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KCMColors::lastUsedCustomAccentColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KCMColors::accentColorFromWallpaperChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KCMColors::downloadingFileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KCMColors::showSuccessMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KCMColors::showErrorMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void KCMColors::showSchemeNotInstalledWarning(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
