/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<draghelper.h>)
#  include <draghelper.h>
#endif
#if __has_include(<fileinfo.h>)
#  include <fileinfo.h>
#endif
#if __has_include(<filemenu.h>)
#  include <filemenu.h>
#endif
#if __has_include(<globalshortcuts.h>)
#  include <globalshortcuts.h>
#endif
#if __has_include(<jobaggregator.h>)
#  include <jobaggregator.h>
#endif
#if __has_include(<notificationapplet.h>)
#  include <notificationapplet.h>
#endif
#if __has_include(<notificationwindow.h>)
#  include <notificationwindow.h>
#endif
#if __has_include(<thumbnailer.h>)
#  include <thumbnailer.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_plasma_applet_org_kde_plasma_notifications()
{
    qmlRegisterModule("plasma.applet.org.kde.plasma.notifications", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<DragHelper>("plasma.applet.org.kde.plasma.notifications", 254);
    qmlRegisterTypesAndRevisions<FileInfo>("plasma.applet.org.kde.plasma.notifications", 254);
    qmlRegisterTypesAndRevisions<FileMenu>("plasma.applet.org.kde.plasma.notifications", 254);
    qmlRegisterTypesAndRevisions<GlobalShortcuts>("plasma.applet.org.kde.plasma.notifications", 254);
    qmlRegisterTypesAndRevisions<InputDisabler>("plasma.applet.org.kde.plasma.notifications", 254);
    qmlRegisterTypesAndRevisions<JobAggregator>("plasma.applet.org.kde.plasma.notifications", 254);
    qmlRegisterTypesAndRevisions<NotificationWindow>("plasma.applet.org.kde.plasma.notifications", 254);
    qmlRegisterTypesAndRevisions<Thumbnailer>("plasma.applet.org.kde.plasma.notifications", 254);
    QT_WARNING_POP
    qmlRegisterModule("plasma.applet.org.kde.plasma.notifications", 254, 254);
}

static const QQmlModuleRegistration plasmaappletorgkdeplasmanotificationsRegistration("plasma.applet.org.kde.plasma.notifications", qml_register_types_plasma_applet_org_kde_plasma_notifications);
