/****************************************************************************
** Meta object code from reading C++ file 'kastatsfavoritesmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/applets/kicker/kastatsfavoritesmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kastatsfavoritesmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21KAStatsFavoritesModelE_t {};
} // unnamed namespace

template <> constexpr inline auto KAStatsFavoritesModel::qt_create_metaobjectdata<qt_meta_tag_ZN21KAStatsFavoritesModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KAStatsFavoritesModel",
        "QML.Element",
        "auto",
        "enabledChanged",
        "",
        "favoritesChanged",
        "maxFavoritesChanged",
        "favoriteAdded",
        "id",
        "refresh",
        "trigger",
        "row",
        "actionId",
        "QVariant",
        "argument",
        "isFavorite",
        "addFavorite",
        "index",
        "removeFavorite",
        "addFavoriteTo",
        "activityId",
        "removeFavoriteFrom",
        "setFavoriteOn",
        "portOldFavorites",
        "ids",
        "linkedActivitiesFor",
        "moveRow",
        "from",
        "to",
        "initForClient",
        "client",
        "activityNameForId",
        "enabled",
        "favorites",
        "maxFavorites",
        "activities"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'favoritesChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maxFavoritesChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'favoriteAdded'
        QtMocHelpers::SignalData<void(const QString &)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'refresh'
        QtMocHelpers::SlotData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'trigger'
        QtMocHelpers::MethodData<bool(int, const QString &, const QVariant &)>(10, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 11 }, { QMetaType::QString, 12 }, { 0x80000000 | 13, 14 },
        }}),
        // Method 'isFavorite'
        QtMocHelpers::MethodData<bool(const QString &) const>(15, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 8 },
        }}),
        // Method 'addFavorite'
        QtMocHelpers::MethodData<void(const QString &, int)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::Int, 17 },
        }}),
        // Method 'addFavorite'
        QtMocHelpers::MethodData<void(const QString &)>(16, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Method 'removeFavorite'
        QtMocHelpers::MethodData<void(const QString &)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Method 'addFavoriteTo'
        QtMocHelpers::MethodData<void(const QString &, const QString &, int)>(19, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::QString, 20 }, { QMetaType::Int, 17 },
        }}),
        // Method 'addFavoriteTo'
        QtMocHelpers::MethodData<void(const QString &, const QString &)>(19, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::QString, 20 },
        }}),
        // Method 'removeFavoriteFrom'
        QtMocHelpers::MethodData<void(const QString &, const QString &)>(21, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::QString, 20 },
        }}),
        // Method 'setFavoriteOn'
        QtMocHelpers::MethodData<void(const QString &, const QString &)>(22, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::QString, 20 },
        }}),
        // Method 'portOldFavorites'
        QtMocHelpers::MethodData<void(const QStringList &)>(23, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 24 },
        }}),
        // Method 'linkedActivitiesFor'
        QtMocHelpers::MethodData<QStringList(const QString &) const>(25, 4, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 8 },
        }}),
        // Method 'moveRow'
        QtMocHelpers::MethodData<void(int, int)>(26, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 27 }, { QMetaType::Int, 28 },
        }}),
        // Method 'initForClient'
        QtMocHelpers::MethodData<void(const QString &)>(29, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 30 },
        }}),
        // Method 'activityNameForId'
        QtMocHelpers::MethodData<QString(const QString &) const>(31, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'favorites'
        QtMocHelpers::PropertyData<QStringList>(33, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'maxFavorites'
        QtMocHelpers::PropertyData<int>(34, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'activities'
        QtMocHelpers::PropertyData<QObject*>(35, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<KAStatsFavoritesModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KAStatsFavoritesModel::staticMetaObject = { {
    QMetaObject::SuperData::link<PlaceholderModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21KAStatsFavoritesModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21KAStatsFavoritesModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21KAStatsFavoritesModelE_t>.metaTypes,
    nullptr
} };

void KAStatsFavoritesModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KAStatsFavoritesModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->enabledChanged(); break;
        case 1: _t->favoritesChanged(); break;
        case 2: _t->maxFavoritesChanged(); break;
        case 3: _t->favoriteAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->refresh(); break;
        case 5: { bool _r = _t->trigger((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->isFavorite((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->addFavorite((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 8: _t->addFavorite((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->removeFavorite((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->addFavoriteTo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 11: _t->addFavoriteTo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 12: _t->removeFavoriteFrom((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 13: _t->setFavoriteOn((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 14: _t->portOldFavorites((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 15: { QStringList _r = _t->linkedActivitiesFor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->moveRow((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 17: _t->initForClient((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: { QString _r = _t->activityNameForId((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KAStatsFavoritesModel::*)()>(_a, &KAStatsFavoritesModel::enabledChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KAStatsFavoritesModel::*)()>(_a, &KAStatsFavoritesModel::favoritesChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KAStatsFavoritesModel::*)()>(_a, &KAStatsFavoritesModel::maxFavoritesChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KAStatsFavoritesModel::*)(const QString & )>(_a, &KAStatsFavoritesModel::favoriteAdded, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        case 1: *reinterpret_cast<QStringList*>(_v) = _t->favorites(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->maxFavorites(); break;
        case 3: *reinterpret_cast<QObject**>(_v) = _t->activities(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setFavorites(*reinterpret_cast<QStringList*>(_v)); break;
        case 2: _t->setMaxFavorites(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KAStatsFavoritesModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KAStatsFavoritesModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21KAStatsFavoritesModelE_t>.strings))
        return static_cast<void*>(this);
    return PlaceholderModel::qt_metacast(_clname);
}

int KAStatsFavoritesModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PlaceholderModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void KAStatsFavoritesModel::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KAStatsFavoritesModel::favoritesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KAStatsFavoritesModel::maxFavoritesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KAStatsFavoritesModel::favoriteAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
