/****************************************************************************
** Meta object code from reading C++ file 'actionsinfo.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/applets/devicenotifier/actionsinfo.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'actionsinfo.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11ActionsInfoE_t {};
} // unnamed namespace

template <> constexpr inline auto ActionsInfo::qt_create_metaobjectdata<qt_meta_tag_ZN11ActionsInfoE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ActionsInfo",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Non-createable type that is associated with a specific device",
        "defaultActionIconChanged",
        "",
        "icon",
        "defaultActionTextChanged",
        "text",
        "unmountActionIsValidChanged",
        "udi",
        "status",
        "onPredicatesChanged",
        "QHash<QString,Solid::Predicate>",
        "predicates",
        "onIsActionValidChanged",
        "action",
        "onActionIconChanged",
        "onActionTextChanged",
        "actionTriggered",
        "operation",
        "defaultActionName",
        "defaultActionIcon",
        "defaultActionText",
        "ActionInfo",
        "Name",
        "Icon",
        "Text"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'defaultActionIconChanged'
        QtMocHelpers::SignalData<void(const QString &)>(7, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'defaultActionTextChanged'
        QtMocHelpers::SignalData<void(const QString &)>(10, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Signal 'unmountActionIsValidChanged'
        QtMocHelpers::SignalData<void(const QString &, bool)>(12, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 }, { QMetaType::Bool, 14 },
        }}),
        // Slot 'onPredicatesChanged'
        QtMocHelpers::SlotData<void(const QHash<QString,Solid::Predicate> &)>(15, 8, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'onIsActionValidChanged'
        QtMocHelpers::SlotData<void(const QString &, bool)>(18, 8, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 19 }, { QMetaType::Bool, 14 },
        }}),
        // Slot 'onActionIconChanged'
        QtMocHelpers::SlotData<void(const QString &)>(20, 8, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Slot 'onActionTextChanged'
        QtMocHelpers::SlotData<void(const QString &)>(21, 8, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Method 'actionTriggered'
        QtMocHelpers::MethodData<void(const QString &)>(22, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'defaultActionName'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultActionIcon'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'defaultActionText'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ActionInfo'
        QtMocHelpers::EnumData<enum ActionInfo>(27, 27, QMC::EnumFlags{}).add({
            {   28, ActionInfo::Name },
            {   29, ActionInfo::Icon },
            {   30, ActionInfo::Text },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<ActionsInfo, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ActionsInfo::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ActionsInfoE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ActionsInfoE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11ActionsInfoE_t>.metaTypes,
    nullptr
} };

void ActionsInfo::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ActionsInfo *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->defaultActionIconChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->defaultActionTextChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->unmountActionIsValidChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 3: _t->onPredicatesChanged((*reinterpret_cast<std::add_pointer_t<QHash<QString,Solid::Predicate>>>(_a[1]))); break;
        case 4: _t->onIsActionValidChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 5: _t->onActionIconChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->onActionTextChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->actionTriggered((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ActionsInfo::*)(const QString & )>(_a, &ActionsInfo::defaultActionIconChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActionsInfo::*)(const QString & )>(_a, &ActionsInfo::defaultActionTextChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActionsInfo::*)(const QString & , bool )>(_a, &ActionsInfo::unmountActionIsValidChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->defaultActionName(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->defaultActionIcon(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->defaultActionText(); break;
        default: break;
        }
    }
}

const QMetaObject *ActionsInfo::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ActionsInfo::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ActionsInfoE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int ActionsInfo::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void ActionsInfo::defaultActionIconChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ActionsInfo::defaultActionTextChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ActionsInfo::unmountActionIsValidChanged(const QString & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}
QT_WARNING_POP
