/****************************************************************************
** Meta object code from reading C++ file 'nighttimesettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../nighttimesettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'nighttimesettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17NightTimeSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto NightTimeSettings::qt_create_metaobjectdata<qt_meta_tag_ZN17NightTimeSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NightTimeSettings",
        "sourceChanged",
        "",
        "automaticLocationChanged",
        "manualLatitudeChanged",
        "manualLongitudeChanged",
        "sunsetStartChanged",
        "sunriseStartChanged",
        "transitionDurationChanged",
        "source",
        "isSourceImmutable",
        "automaticLocation",
        "isAutomaticLocationImmutable",
        "manualLatitude",
        "isManualLatitudeImmutable",
        "manualLongitude",
        "isManualLongitudeImmutable",
        "sunsetStart",
        "isSunsetStartImmutable",
        "sunriseStart",
        "isSunriseStartImmutable",
        "transitionDuration",
        "isTransitionDurationImmutable",
        "Source",
        "Location",
        "Times"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sourceChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'automaticLocationChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'manualLatitudeChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'manualLongitudeChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sunsetStartChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sunriseStartChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'transitionDurationChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'source'
        QtMocHelpers::PropertyData<int>(9, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isSourceImmutable'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'automaticLocation'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isAutomaticLocationImmutable'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'manualLatitude'
        QtMocHelpers::PropertyData<double>(13, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isManualLatitudeImmutable'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'manualLongitude'
        QtMocHelpers::PropertyData<double>(15, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isManualLongitudeImmutable'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sunsetStart'
        QtMocHelpers::PropertyData<QTime>(17, QMetaType::QTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isSunsetStartImmutable'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sunriseStart'
        QtMocHelpers::PropertyData<QTime>(19, QMetaType::QTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isSunriseStartImmutable'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'transitionDuration'
        QtMocHelpers::PropertyData<uint>(21, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isTransitionDurationImmutable'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Source'
        QtMocHelpers::EnumData<enum Source>(23, 23, QMC::EnumFlags{}).add({
            {   24, Source::Location },
            {   25, Source::Times },
        }),
    };
    return QtMocHelpers::metaObjectData<NightTimeSettings, qt_meta_tag_ZN17NightTimeSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject NightTimeSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17NightTimeSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17NightTimeSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17NightTimeSettingsE_t>.metaTypes,
    nullptr
} };

void NightTimeSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NightTimeSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sourceChanged(); break;
        case 1: _t->automaticLocationChanged(); break;
        case 2: _t->manualLatitudeChanged(); break;
        case 3: _t->manualLongitudeChanged(); break;
        case 4: _t->sunsetStartChanged(); break;
        case 5: _t->sunriseStartChanged(); break;
        case 6: _t->transitionDurationChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NightTimeSettings::*)()>(_a, &NightTimeSettings::sourceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NightTimeSettings::*)()>(_a, &NightTimeSettings::automaticLocationChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NightTimeSettings::*)()>(_a, &NightTimeSettings::manualLatitudeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NightTimeSettings::*)()>(_a, &NightTimeSettings::manualLongitudeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (NightTimeSettings::*)()>(_a, &NightTimeSettings::sunsetStartChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (NightTimeSettings::*)()>(_a, &NightTimeSettings::sunriseStartChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (NightTimeSettings::*)()>(_a, &NightTimeSettings::transitionDurationChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->source(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isSourceImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->automaticLocation(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isAutomaticLocationImmutable(); break;
        case 4: *reinterpret_cast<double*>(_v) = _t->manualLatitude(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isManualLatitudeImmutable(); break;
        case 6: *reinterpret_cast<double*>(_v) = _t->manualLongitude(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isManualLongitudeImmutable(); break;
        case 8: *reinterpret_cast<QTime*>(_v) = _t->sunsetStart(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isSunsetStartImmutable(); break;
        case 10: *reinterpret_cast<QTime*>(_v) = _t->sunriseStart(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->isSunriseStartImmutable(); break;
        case 12: *reinterpret_cast<uint*>(_v) = _t->transitionDuration(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isTransitionDurationImmutable(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSource(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setAutomaticLocation(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setManualLatitude(*reinterpret_cast<double*>(_v)); break;
        case 6: _t->setManualLongitude(*reinterpret_cast<double*>(_v)); break;
        case 8: _t->setSunsetStart(*reinterpret_cast<QTime*>(_v)); break;
        case 10: _t->setSunriseStart(*reinterpret_cast<QTime*>(_v)); break;
        case 12: _t->setTransitionDuration(*reinterpret_cast<uint*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *NightTimeSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NightTimeSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17NightTimeSettingsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int NightTimeSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void NightTimeSettings::sourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void NightTimeSettings::automaticLocationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void NightTimeSettings::manualLatitudeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void NightTimeSettings::manualLongitudeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void NightTimeSettings::sunsetStartChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void NightTimeSettings::sunriseStartChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void NightTimeSettings::transitionDurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
