/****************************************************************************
** Meta object code from reading C++ file 'behaviorsettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../behaviorsettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'behaviorsettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19NotificationManager16BehaviorSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto NotificationManager::BehaviorSettings::qt_create_metaobjectdata<qt_meta_tag_ZN19NotificationManager16BehaviorSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NotificationManager::BehaviorSettings",
        "ShowPopupsChanged",
        "",
        "ShowPopupsInDndModeChanged",
        "ShowInHistoryChanged",
        "ShowBadgesChanged",
        "showPopups",
        "isShowPopupsImmutable",
        "defaultShowPopupsValue",
        "showPopupsInDndMode",
        "isShowPopupsInDndModeImmutable",
        "defaultShowPopupsInDndModeValue",
        "showInHistory",
        "isShowInHistoryImmutable",
        "defaultShowInHistoryValue",
        "showBadges",
        "isShowBadgesImmutable",
        "defaultShowBadgesValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ShowPopupsChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowPopupsInDndModeChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowInHistoryChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowBadgesChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'showPopups'
        QtMocHelpers::PropertyData<bool>(6, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isShowPopupsImmutable'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowPopupsValue'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showPopupsInDndMode'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isShowPopupsInDndModeImmutable'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowPopupsInDndModeValue'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showInHistory'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isShowInHistoryImmutable'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowInHistoryValue'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showBadges'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isShowBadgesImmutable'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowBadgesValue'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BehaviorSettings, qt_meta_tag_ZN19NotificationManager16BehaviorSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject NotificationManager::BehaviorSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationManager16BehaviorSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationManager16BehaviorSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19NotificationManager16BehaviorSettingsE_t>.metaTypes,
    nullptr
} };

void NotificationManager::BehaviorSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BehaviorSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ShowPopupsChanged(); break;
        case 1: _t->ShowPopupsInDndModeChanged(); break;
        case 2: _t->ShowInHistoryChanged(); break;
        case 3: _t->ShowBadgesChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BehaviorSettings::*)()>(_a, &BehaviorSettings::ShowPopupsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BehaviorSettings::*)()>(_a, &BehaviorSettings::ShowPopupsInDndModeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BehaviorSettings::*)()>(_a, &BehaviorSettings::ShowInHistoryChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (BehaviorSettings::*)()>(_a, &BehaviorSettings::ShowBadgesChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->showPopups(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isShowPopupsImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultShowPopupsValue(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->showPopupsInDndMode(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isShowPopupsInDndModeImmutable(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->defaultShowPopupsInDndModeValue(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->showInHistory(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isShowInHistoryImmutable(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->defaultShowInHistoryValue(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->showBadges(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isShowBadgesImmutable(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->defaultShowBadgesValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setShowPopups(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setShowPopupsInDndMode(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setShowInHistory(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setShowBadges(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *NotificationManager::BehaviorSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NotificationManager::BehaviorSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationManager16BehaviorSettingsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int NotificationManager::BehaviorSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void NotificationManager::BehaviorSettings::ShowPopupsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void NotificationManager::BehaviorSettings::ShowPopupsInDndModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void NotificationManager::BehaviorSettings::ShowInHistoryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void NotificationManager::BehaviorSettings::ShowBadgesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
