/****************************************************************************
** Meta object code from reading C++ file 'appletslayout.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/components/containmentlayoutmanager/appletslayout.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'appletslayout.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13AppletsLayoutE_t {};
} // unnamed namespace

template <> constexpr inline auto AppletsLayout::qt_create_metaobjectdata<qt_meta_tag_ZN13AppletsLayoutE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AppletsLayout",
        "QML.Element",
        "auto",
        "appletRefused",
        "",
        "applet",
        "x",
        "y",
        "configKeyChanged",
        "fallbackConfigKeyChanged",
        "relayoutLockChanged",
        "containmentChanged",
        "minimumItemWidthChanged",
        "minimumItemHeightChanged",
        "defaultItemWidthChanged",
        "defaultItemHeightChanged",
        "cellWidthChanged",
        "cellHeightChanged",
        "acceptsAppletCallbackChanged",
        "appletContainerComponentChanged",
        "placeHolderChanged",
        "eventManagerToFilterChanged",
        "editModeConditionChanged",
        "editModeChanged",
        "containmentItemChanged",
        "appletAdded",
        "Plasma::Applet*",
        "appletRemoved",
        "save",
        "showPlaceHolderAt",
        "QRectF",
        "geom",
        "showPlaceHolderForItem",
        "ItemContainer*",
        "item",
        "hidePlaceHolder",
        "isRectAvailable",
        "width",
        "height",
        "itemIsManaged",
        "positionItem",
        "restoreItem",
        "releaseSpace",
        "configKey",
        "fallbackConfigKey",
        "relayoutLock",
        "containment",
        "Plasma::Containment*",
        "containmentItem",
        "PlasmaQuick::AppletQuickItem*",
        "acceptsAppletCallback",
        "QJSValue",
        "minimumItemWidth",
        "minimumItemHeight",
        "defaultItemWidth",
        "defaultItemHeight",
        "cellWidth",
        "cellHeight",
        "appletContainerComponent",
        "QQmlComponent*",
        "placeHolder",
        "eventManagerToFilter",
        "QQuickItem*",
        "editModeCondition",
        "AppletsLayout::EditModeCondition",
        "editMode",
        "PreferredLayoutDirection",
        "Closest",
        "LeftToRight",
        "RightToLeft",
        "TopToBottom",
        "BottomToTop",
        "EditModeCondition",
        "Locked",
        "Manual",
        "AfterPressAndHold"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'appletRefused'
        QtMocHelpers::SignalData<void(QObject *, int, int)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 5 }, { QMetaType::Int, 6 }, { QMetaType::Int, 7 },
        }}),
        // Signal 'configKeyChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fallbackConfigKeyChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'relayoutLockChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'containmentChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minimumItemWidthChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minimumItemHeightChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultItemWidthChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultItemHeightChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cellWidthChanged'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cellHeightChanged'
        QtMocHelpers::SignalData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'acceptsAppletCallbackChanged'
        QtMocHelpers::SignalData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'appletContainerComponentChanged'
        QtMocHelpers::SignalData<void()>(19, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'placeHolderChanged'
        QtMocHelpers::SignalData<void()>(20, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'eventManagerToFilterChanged'
        QtMocHelpers::SignalData<void()>(21, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'editModeConditionChanged'
        QtMocHelpers::SignalData<void()>(22, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'editModeChanged'
        QtMocHelpers::SignalData<void()>(23, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'containmentItemChanged'
        QtMocHelpers::SignalData<void()>(24, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'appletAdded'
        QtMocHelpers::SlotData<void(Plasma::Applet *)>(25, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 5 },
        }}),
        // Slot 'appletRemoved'
        QtMocHelpers::SlotData<void(Plasma::Applet *)>(27, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 5 },
        }}),
        // Method 'save'
        QtMocHelpers::MethodData<void()>(28, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'showPlaceHolderAt'
        QtMocHelpers::MethodData<void(const QRectF &)>(29, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Method 'showPlaceHolderForItem'
        QtMocHelpers::MethodData<void(ItemContainer *)>(32, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Method 'hidePlaceHolder'
        QtMocHelpers::MethodData<void()>(35, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'isRectAvailable'
        QtMocHelpers::MethodData<bool(qreal, qreal, qreal, qreal)>(36, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QReal, 6 }, { QMetaType::QReal, 7 }, { QMetaType::QReal, 37 }, { QMetaType::QReal, 38 },
        }}),
        // Method 'itemIsManaged'
        QtMocHelpers::MethodData<bool(ItemContainer *)>(39, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Method 'positionItem'
        QtMocHelpers::MethodData<void(ItemContainer *)>(40, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Method 'restoreItem'
        QtMocHelpers::MethodData<void(ItemContainer *)>(41, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Method 'releaseSpace'
        QtMocHelpers::MethodData<void(ItemContainer *)>(42, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'configKey'
        QtMocHelpers::PropertyData<QString>(43, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'fallbackConfigKey'
        QtMocHelpers::PropertyData<QString>(44, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'relayoutLock'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'containment'
        QtMocHelpers::PropertyData<Plasma::Containment*>(46, 0x80000000 | 47, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'containmentItem'
        QtMocHelpers::PropertyData<PlasmaQuick::AppletQuickItem*>(48, 0x80000000 | 49, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 17),
        // property 'acceptsAppletCallback'
        QtMocHelpers::PropertyData<QJSValue>(50, 0x80000000 | 51, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 11),
        // property 'minimumItemWidth'
        QtMocHelpers::PropertyData<qreal>(52, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'minimumItemHeight'
        QtMocHelpers::PropertyData<qreal>(53, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'defaultItemWidth'
        QtMocHelpers::PropertyData<qreal>(54, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'defaultItemHeight'
        QtMocHelpers::PropertyData<qreal>(55, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'cellWidth'
        QtMocHelpers::PropertyData<qreal>(56, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'cellHeight'
        QtMocHelpers::PropertyData<qreal>(57, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'appletContainerComponent'
        QtMocHelpers::PropertyData<QQmlComponent*>(58, 0x80000000 | 59, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 12),
        // property 'placeHolder'
        QtMocHelpers::PropertyData<ItemContainer*>(60, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 13),
        // property 'eventManagerToFilter'
        QtMocHelpers::PropertyData<QQuickItem*>(61, 0x80000000 | 62, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 14),
        // property 'editModeCondition'
        QtMocHelpers::PropertyData<AppletsLayout::EditModeCondition>(63, 0x80000000 | 64, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 15),
        // property 'editMode'
        QtMocHelpers::PropertyData<bool>(65, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'PreferredLayoutDirection'
        QtMocHelpers::EnumData<enum PreferredLayoutDirection>(66, 66, QMC::EnumFlags{}).add({
            {   67, PreferredLayoutDirection::Closest },
            {   68, PreferredLayoutDirection::LeftToRight },
            {   69, PreferredLayoutDirection::RightToLeft },
            {   70, PreferredLayoutDirection::TopToBottom },
            {   71, PreferredLayoutDirection::BottomToTop },
        }),
        // enum 'EditModeCondition'
        QtMocHelpers::EnumData<enum EditModeCondition>(72, 72, QMC::EnumFlags{}).add({
            {   73, EditModeCondition::Locked },
            {   74, EditModeCondition::Manual },
            {   75, EditModeCondition::AfterPressAndHold },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<AppletsLayout, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AppletsLayout::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13AppletsLayoutE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13AppletsLayoutE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13AppletsLayoutE_t>.metaTypes,
    nullptr
} };

void AppletsLayout::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AppletsLayout *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->appletRefused((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 1: _t->configKeyChanged(); break;
        case 2: _t->fallbackConfigKeyChanged(); break;
        case 3: _t->relayoutLockChanged(); break;
        case 4: _t->containmentChanged(); break;
        case 5: _t->minimumItemWidthChanged(); break;
        case 6: _t->minimumItemHeightChanged(); break;
        case 7: _t->defaultItemWidthChanged(); break;
        case 8: _t->defaultItemHeightChanged(); break;
        case 9: _t->cellWidthChanged(); break;
        case 10: _t->cellHeightChanged(); break;
        case 11: _t->acceptsAppletCallbackChanged(); break;
        case 12: _t->appletContainerComponentChanged(); break;
        case 13: _t->placeHolderChanged(); break;
        case 14: _t->eventManagerToFilterChanged(); break;
        case 15: _t->editModeConditionChanged(); break;
        case 16: _t->editModeChanged(); break;
        case 17: _t->containmentItemChanged(); break;
        case 18: _t->appletAdded((*reinterpret_cast<std::add_pointer_t<Plasma::Applet*>>(_a[1]))); break;
        case 19: _t->appletRemoved((*reinterpret_cast<std::add_pointer_t<Plasma::Applet*>>(_a[1]))); break;
        case 20: _t->save(); break;
        case 21: _t->showPlaceHolderAt((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1]))); break;
        case 22: _t->showPlaceHolderForItem((*reinterpret_cast<std::add_pointer_t<ItemContainer*>>(_a[1]))); break;
        case 23: _t->hidePlaceHolder(); break;
        case 24: { bool _r = _t->isRectAvailable((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 25: { bool _r = _t->itemIsManaged((*reinterpret_cast<std::add_pointer_t<ItemContainer*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 26: _t->positionItem((*reinterpret_cast<std::add_pointer_t<ItemContainer*>>(_a[1]))); break;
        case 27: _t->restoreItem((*reinterpret_cast<std::add_pointer_t<ItemContainer*>>(_a[1]))); break;
        case 28: _t->releaseSpace((*reinterpret_cast<std::add_pointer_t<ItemContainer*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AppletsLayout::*)(QObject * , int , int )>(_a, &AppletsLayout::appletRefused, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppletsLayout::*)()>(_a, &AppletsLayout::configKeyChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppletsLayout::*)()>(_a, &AppletsLayout::fallbackConfigKeyChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppletsLayout::*)()>(_a, &AppletsLayout::relayoutLockChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppletsLayout::*)()>(_a, &AppletsLayout::containmentChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppletsLayout::*)()>(_a, &AppletsLayout::minimumItemWidthChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppletsLayout::*)()>(_a, &AppletsLayout::minimumItemHeightChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppletsLayout::*)()>(_a, &AppletsLayout::defaultItemWidthChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppletsLayout::*)()>(_a, &AppletsLayout::defaultItemHeightChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppletsLayout::*)()>(_a, &AppletsLayout::cellWidthChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppletsLayout::*)()>(_a, &AppletsLayout::cellHeightChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppletsLayout::*)()>(_a, &AppletsLayout::acceptsAppletCallbackChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppletsLayout::*)()>(_a, &AppletsLayout::appletContainerComponentChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppletsLayout::*)()>(_a, &AppletsLayout::placeHolderChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppletsLayout::*)()>(_a, &AppletsLayout::eventManagerToFilterChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppletsLayout::*)()>(_a, &AppletsLayout::editModeConditionChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppletsLayout::*)()>(_a, &AppletsLayout::editModeChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (AppletsLayout::*)()>(_a, &AppletsLayout::containmentItemChanged, 17))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
        case 12:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlComponent* >(); break;
        case 14:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->configKey(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->fallbackConfigKey(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->relayoutLock(); break;
        case 3: *reinterpret_cast<Plasma::Containment**>(_v) = _t->containment(); break;
        case 4: *reinterpret_cast<PlasmaQuick::AppletQuickItem**>(_v) = _t->containmentItem(); break;
        case 5: *reinterpret_cast<QJSValue*>(_v) = _t->acceptsAppletCallback(); break;
        case 6: *reinterpret_cast<qreal*>(_v) = _t->minimumItemWidth(); break;
        case 7: *reinterpret_cast<qreal*>(_v) = _t->minimumItemHeight(); break;
        case 8: *reinterpret_cast<qreal*>(_v) = _t->defaultItemWidth(); break;
        case 9: *reinterpret_cast<qreal*>(_v) = _t->defaultItemHeight(); break;
        case 10: *reinterpret_cast<qreal*>(_v) = _t->cellWidth(); break;
        case 11: *reinterpret_cast<qreal*>(_v) = _t->cellHeight(); break;
        case 12: *reinterpret_cast<QQmlComponent**>(_v) = _t->appletContainerComponent(); break;
        case 13: *reinterpret_cast<ItemContainer**>(_v) = _t->placeHolder(); break;
        case 14: *reinterpret_cast<QQuickItem**>(_v) = _t->eventManagerToFilter(); break;
        case 15: *reinterpret_cast<AppletsLayout::EditModeCondition*>(_v) = _t->editModeCondition(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->editMode(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setConfigKey(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setFallbackConfigKey(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setRelayoutLock(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setContainment(*reinterpret_cast<Plasma::Containment**>(_v)); break;
        case 4: _t->setContainmentItem(*reinterpret_cast<PlasmaQuick::AppletQuickItem**>(_v)); break;
        case 5: _t->setAcceptsAppletCallback(*reinterpret_cast<QJSValue*>(_v)); break;
        case 6: _t->setMinimumItemWidth(*reinterpret_cast<qreal*>(_v)); break;
        case 7: _t->setMinimumItemHeight(*reinterpret_cast<qreal*>(_v)); break;
        case 8: _t->setDefaultItemWidth(*reinterpret_cast<qreal*>(_v)); break;
        case 9: _t->setDefaultItemHeight(*reinterpret_cast<qreal*>(_v)); break;
        case 10: _t->setCellWidth(*reinterpret_cast<qreal*>(_v)); break;
        case 11: _t->setCellHeight(*reinterpret_cast<qreal*>(_v)); break;
        case 12: _t->setAppletContainerComponent(*reinterpret_cast<QQmlComponent**>(_v)); break;
        case 13: _t->setPlaceHolder(*reinterpret_cast<ItemContainer**>(_v)); break;
        case 14: _t->setEventManagerToFilter(*reinterpret_cast<QQuickItem**>(_v)); break;
        case 15: _t->setEditModeCondition(*reinterpret_cast<AppletsLayout::EditModeCondition*>(_v)); break;
        case 16: _t->setEditMode(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *AppletsLayout::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AppletsLayout::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13AppletsLayoutE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int AppletsLayout::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 29;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void AppletsLayout::appletRefused(QObject * _t1, int _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void AppletsLayout::configKeyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AppletsLayout::fallbackConfigKeyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AppletsLayout::relayoutLockChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AppletsLayout::containmentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void AppletsLayout::minimumItemWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void AppletsLayout::minimumItemHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void AppletsLayout::defaultItemWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void AppletsLayout::defaultItemHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void AppletsLayout::cellWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void AppletsLayout::cellHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void AppletsLayout::acceptsAppletCallbackChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void AppletsLayout::appletContainerComponentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void AppletsLayout::placeHolderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void AppletsLayout::eventManagerToFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void AppletsLayout::editModeConditionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void AppletsLayout::editModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void AppletsLayout::containmentItemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}
QT_WARNING_POP
