/****************************************************************************
** Meta object code from reading C++ file 'dbusmenuadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "dbusmenuadaptor.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbusmenuadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15DbusmenuAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto DbusmenuAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN15DbusmenuAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DbusmenuAdaptor",
        "D-Bus Interface",
        "com.canonical.dbusmenu",
        "D-Bus Introspection",
        "  <interface name=\"com.canonical.dbusmenu\">\n    <property acces"
        "s=\"read\" type=\"u\" name=\"Version\"/>\n    <property access=\"r"
        "ead\" type=\"s\" name=\"Status\"/>\n    <signal name=\"ItemsProper"
        "tiesUpdated\">\n      <annotation value=\"DBusMenuItemList\" name="
        "\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n      <annotation valu"
        "e=\"DBusMenuItemKeysList\" name=\"org.qtproject.QtDBus.QtTypeName."
        "Out1\"/>\n      <arg direction=\"out\" type=\"a(ia{sv})\"/>\n     "
        " <arg direction=\"out\" type=\"a(ias)\"/>\n    </signal>\n    <sig"
        "nal name=\"LayoutUpdated\">\n      <arg direction=\"out\" type=\"u"
        "\" name=\"revision\"/>\n      <arg direction=\"out\" type=\"i\" na"
        "me=\"parentId\"/>\n    </signal>\n    <signal name=\"ItemActivatio"
        "nRequested\">\n      <arg direction=\"out\" type=\"i\" name=\"id\""
        "/>\n      <arg direction=\"out\" type=\"u\" name=\"timeStamp\"/>\n"
        "    </signal>\n    <method name=\"Event\">\n      <arg direction=\""
        "in\" type=\"i\" name=\"id\"/>\n      <arg direction=\"in\" type=\""
        "s\" name=\"eventId\"/>\n      <arg direction=\"in\" type=\"v\" nam"
        "e=\"data\"/>\n      <arg direction=\"in\" type=\"u\" name=\"timest"
        "amp\"/>\n      <annotation value=\"true\" name=\"org.freedesktop.D"
        "Bus.Method.NoReply\"/>\n    </method>\n    <method name=\"GetPrope"
        "rty\">\n      <arg direction=\"out\" type=\"v\"/>\n      <arg dire"
        "ction=\"in\" type=\"i\" name=\"id\"/>\n      <arg direction=\"in\""
        " type=\"s\" name=\"property\"/>\n    </method>\n    <method name=\""
        "GetLayout\">\n      <arg direction=\"out\" type=\"u\"/>\n      <ar"
        "g direction=\"in\" type=\"i\" name=\"parentId\"/>\n      <arg dire"
        "ction=\"in\" type=\"i\" name=\"recursionDepth\"/>\n      <arg dire"
        "ction=\"in\" type=\"as\" name=\"propertyNames\"/>\n      <arg dire"
        "ction=\"out\" type=\"(ia{sv}av)\" name=\"item\"/>\n      <annotati"
        "on value=\"DBusMenuLayoutItem\" name=\"org.qtproject.QtDBus.QtType"
        "Name.Out1\"/>\n    </method>\n    <method name=\"GetGroupPropertie"
        "s\">\n      <arg direction=\"out\" type=\"a(ia{sv})\"/>\n      <an"
        "notation value=\"DBusMenuItemList\" name=\"org.qtproject.QtDBus.Qt"
        "TypeName.Out0\"/>\n      <arg direction=\"in\" type=\"ai\" name=\""
        "ids\"/>\n      <annotation value=\"QList&lt;int&gt;\" name=\"org.q"
        "tproject.QtDBus.QtTypeName.In0\"/>\n      <arg direction=\"in\" ty"
        "pe=\"as\" name=\"propertyNames\"/>\n    </method>\n    <method nam"
        "e=\"AboutToShow\">\n      <arg direction=\"out\" type=\"b\"/>\n   "
        "   <arg direction=\"in\" type=\"i\" name=\"id\"/>\n    </method>\n"
        "  </interface>\n",
        "ItemActivationRequested",
        "",
        "id",
        "timeStamp",
        "ItemsPropertiesUpdated",
        "DBusMenuItemList",
        "in0",
        "DBusMenuItemKeysList",
        "in1",
        "LayoutUpdated",
        "revision",
        "parentId",
        "AboutToShow",
        "Event",
        "Q_NOREPLY",
        "eventId",
        "QDBusVariant",
        "data",
        "timestamp",
        "GetGroupProperties",
        "QList<int>",
        "ids",
        "propertyNames",
        "GetLayout",
        "recursionDepth",
        "DBusMenuLayoutItem&",
        "item",
        "GetProperty",
        "property",
        "Status",
        "Version"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ItemActivationRequested'
        QtMocHelpers::SignalData<void(int, uint)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 }, { QMetaType::UInt, 8 },
        }}),
        // Signal 'ItemsPropertiesUpdated'
        QtMocHelpers::SignalData<void(DBusMenuItemList, DBusMenuItemKeysList)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Signal 'LayoutUpdated'
        QtMocHelpers::SignalData<void(uint, int)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 15 }, { QMetaType::Int, 16 },
        }}),
        // Slot 'AboutToShow'
        QtMocHelpers::SlotData<bool(int)>(17, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'Event'
        QtMocHelpers::SlotData<void(int, const QString &, const QDBusVariant &, uint)>(18, 19, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 }, { QMetaType::QString, 20 }, { 0x80000000 | 21, 22 }, { QMetaType::UInt, 23 },
        }}),
        // Slot 'GetGroupProperties'
        QtMocHelpers::SlotData<DBusMenuItemList(const QList<int> &, const QStringList &)>(24, 6, QMC::AccessPublic, 0x80000000 | 10, {{
            { 0x80000000 | 25, 26 }, { QMetaType::QStringList, 27 },
        }}),
        // Slot 'GetLayout'
        QtMocHelpers::SlotData<uint(int, int, const QStringList &, DBusMenuLayoutItem &)>(28, 6, QMC::AccessPublic, QMetaType::UInt, {{
            { QMetaType::Int, 16 }, { QMetaType::Int, 29 }, { QMetaType::QStringList, 27 }, { 0x80000000 | 30, 31 },
        }}),
        // Slot 'GetProperty'
        QtMocHelpers::SlotData<QDBusVariant(int, const QString &)>(32, 6, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::Int, 7 }, { QMetaType::QString, 33 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Status'
        QtMocHelpers::PropertyData<QString>(34, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Version'
        QtMocHelpers::PropertyData<uint>(35, QMetaType::UInt, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<DbusmenuAdaptor, qt_meta_tag_ZN15DbusmenuAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DbusmenuAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DbusmenuAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DbusmenuAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15DbusmenuAdaptorE_t>.metaTypes,
    nullptr
} };

void DbusmenuAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DbusmenuAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ItemActivationRequested((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 1: _t->ItemsPropertiesUpdated((*reinterpret_cast<std::add_pointer_t<DBusMenuItemList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<DBusMenuItemKeysList>>(_a[2]))); break;
        case 2: _t->LayoutUpdated((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 3: { bool _r = _t->AboutToShow((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->Event((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4]))); break;
        case 5: { DBusMenuItemList _r = _t->GetGroupProperties((*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<DBusMenuItemList*>(_a[0]) = std::move(_r); }  break;
        case 6: { uint _r = _t->GetLayout((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<DBusMenuLayoutItem&>>(_a[4])));
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusVariant _r = _t->GetProperty((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusVariant*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DbusmenuAdaptor::*)(int , uint )>(_a, &DbusmenuAdaptor::ItemActivationRequested, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbusmenuAdaptor::*)(DBusMenuItemList , DBusMenuItemKeysList )>(_a, &DbusmenuAdaptor::ItemsPropertiesUpdated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbusmenuAdaptor::*)(uint , int )>(_a, &DbusmenuAdaptor::LayoutUpdated, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->status(); break;
        case 1: *reinterpret_cast<uint*>(_v) = _t->version(); break;
        default: break;
        }
    }
}

const QMetaObject *DbusmenuAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DbusmenuAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DbusmenuAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int DbusmenuAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void DbusmenuAdaptor::ItemActivationRequested(int _t1, uint _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void DbusmenuAdaptor::ItemsPropertiesUpdated(DBusMenuItemList _t1, DBusMenuItemKeysList _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void DbusmenuAdaptor::LayoutUpdated(uint _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}
QT_WARNING_POP
