/****************************************************************************
** Meta object code from reading C++ file 'fontssettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../fontssettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fontssettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13FontsSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto FontsSettings::qt_create_metaobjectdata<qt_meta_tag_ZN13FontsSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FontsSettings",
        "fontChanged",
        "",
        "fixedChanged",
        "smallestReadableFontChanged",
        "toolBarFontChanged",
        "menuFontChanged",
        "activeFontChanged",
        "font",
        "QFont",
        "isFontImmutable",
        "defaultFontValue",
        "fixed",
        "isFixedImmutable",
        "defaultFixedValue",
        "smallestReadableFont",
        "isSmallestReadableFontImmutable",
        "defaultSmallestReadableFontValue",
        "toolBarFont",
        "isToolBarFontImmutable",
        "defaultToolBarFontValue",
        "menuFont",
        "isMenuFontImmutable",
        "defaultMenuFontValue",
        "activeFont",
        "isActiveFontImmutable",
        "defaultActiveFontValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'fontChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fixedChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'smallestReadableFontChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'toolBarFontChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'menuFontChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeFontChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'font'
        QtMocHelpers::PropertyData<QFont>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'isFontImmutable'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultFontValue'
        QtMocHelpers::PropertyData<QFont>(11, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'fixed'
        QtMocHelpers::PropertyData<QFont>(12, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'isFixedImmutable'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultFixedValue'
        QtMocHelpers::PropertyData<QFont>(14, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'smallestReadableFont'
        QtMocHelpers::PropertyData<QFont>(15, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'isSmallestReadableFontImmutable'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSmallestReadableFontValue'
        QtMocHelpers::PropertyData<QFont>(17, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'toolBarFont'
        QtMocHelpers::PropertyData<QFont>(18, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'isToolBarFontImmutable'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultToolBarFontValue'
        QtMocHelpers::PropertyData<QFont>(20, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'menuFont'
        QtMocHelpers::PropertyData<QFont>(21, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'isMenuFontImmutable'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMenuFontValue'
        QtMocHelpers::PropertyData<QFont>(23, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'activeFont'
        QtMocHelpers::PropertyData<QFont>(24, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'isActiveFontImmutable'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultActiveFontValue'
        QtMocHelpers::PropertyData<QFont>(26, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FontsSettings, qt_meta_tag_ZN13FontsSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject FontsSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13FontsSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13FontsSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13FontsSettingsE_t>.metaTypes,
    nullptr
} };

void FontsSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FontsSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->fontChanged(); break;
        case 1: _t->fixedChanged(); break;
        case 2: _t->smallestReadableFontChanged(); break;
        case 3: _t->toolBarFontChanged(); break;
        case 4: _t->menuFontChanged(); break;
        case 5: _t->activeFontChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FontsSettings::*)()>(_a, &FontsSettings::fontChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FontsSettings::*)()>(_a, &FontsSettings::fixedChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FontsSettings::*)()>(_a, &FontsSettings::smallestReadableFontChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FontsSettings::*)()>(_a, &FontsSettings::toolBarFontChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FontsSettings::*)()>(_a, &FontsSettings::menuFontChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FontsSettings::*)()>(_a, &FontsSettings::activeFontChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QFont*>(_v) = _t->font(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isFontImmutable(); break;
        case 2: *reinterpret_cast<QFont*>(_v) = _t->defaultFontValue(); break;
        case 3: *reinterpret_cast<QFont*>(_v) = _t->fixed(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isFixedImmutable(); break;
        case 5: *reinterpret_cast<QFont*>(_v) = _t->defaultFixedValue(); break;
        case 6: *reinterpret_cast<QFont*>(_v) = _t->smallestReadableFont(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isSmallestReadableFontImmutable(); break;
        case 8: *reinterpret_cast<QFont*>(_v) = _t->defaultSmallestReadableFontValue(); break;
        case 9: *reinterpret_cast<QFont*>(_v) = _t->toolBarFont(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isToolBarFontImmutable(); break;
        case 11: *reinterpret_cast<QFont*>(_v) = _t->defaultToolBarFontValue(); break;
        case 12: *reinterpret_cast<QFont*>(_v) = _t->menuFont(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isMenuFontImmutable(); break;
        case 14: *reinterpret_cast<QFont*>(_v) = _t->defaultMenuFontValue(); break;
        case 15: *reinterpret_cast<QFont*>(_v) = _t->activeFont(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isActiveFontImmutable(); break;
        case 17: *reinterpret_cast<QFont*>(_v) = _t->defaultActiveFontValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setFont(*reinterpret_cast<QFont*>(_v)); break;
        case 3: _t->setFixed(*reinterpret_cast<QFont*>(_v)); break;
        case 6: _t->setSmallestReadableFont(*reinterpret_cast<QFont*>(_v)); break;
        case 9: _t->setToolBarFont(*reinterpret_cast<QFont*>(_v)); break;
        case 12: _t->setMenuFont(*reinterpret_cast<QFont*>(_v)); break;
        case 15: _t->setActiveFont(*reinterpret_cast<QFont*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *FontsSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FontsSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13FontsSettingsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int FontsSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void FontsSettings::fontChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void FontsSettings::fixedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void FontsSettings::smallestReadableFontChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void FontsSettings::toolBarFontChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void FontsSettings::menuFontChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void FontsSettings::activeFontChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
