/****************************************************************************
** Meta object code from reading C++ file 'draghelper.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/applets/kicker/draghelper.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'draghelper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10DragHelperE_t {};
} // unnamed namespace

template <> constexpr inline auto DragHelper::qt_create_metaobjectdata<qt_meta_tag_ZN10DragHelperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DragHelper",
        "QML.Element",
        "auto",
        "dragIconSizeChanged",
        "",
        "dropped",
        "draggingChanged",
        "isDrag",
        "oldX",
        "oldY",
        "newX",
        "newY",
        "startDrag",
        "QQuickItem*",
        "item",
        "QUrl",
        "url",
        "icon",
        "extraMimeType",
        "extraMimeData",
        "doDrag",
        "dragIconSize",
        "dragging"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'dragIconSizeChanged'
        QtMocHelpers::SignalData<void() const>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dropped'
        QtMocHelpers::SignalData<void() const>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'draggingChanged'
        QtMocHelpers::SignalData<void() const>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'isDrag'
        QtMocHelpers::MethodData<bool(int, int, int, int) const>(7, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 8 }, { QMetaType::Int, 9 }, { QMetaType::Int, 10 }, { QMetaType::Int, 11 },
        }}),
        // Method 'startDrag'
        QtMocHelpers::MethodData<void(QQuickItem *, const QUrl &, const QString &, const QString &, const QString &)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { 0x80000000 | 15, 16 }, { QMetaType::QString, 17 }, { QMetaType::QString, 18 },
            { QMetaType::QString, 19 },
        }}),
        // Method 'startDrag'
        QtMocHelpers::MethodData<void(QQuickItem *, const QUrl &, const QString &, const QString &)>(12, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { 0x80000000 | 15, 16 }, { QMetaType::QString, 17 }, { QMetaType::QString, 18 },
        }}),
        // Method 'startDrag'
        QtMocHelpers::MethodData<void(QQuickItem *, const QUrl &, const QString &)>(12, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { 0x80000000 | 15, 16 }, { QMetaType::QString, 17 },
        }}),
        // Method 'startDrag'
        QtMocHelpers::MethodData<void(QQuickItem *, const QUrl &)>(12, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { 0x80000000 | 15, 16 },
        }}),
        // Method 'startDrag'
        QtMocHelpers::MethodData<void(QQuickItem *)>(12, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Method 'doDrag'
        QtMocHelpers::MethodData<void(QQuickItem *, const QUrl &, const QString &, const QString &, const QString &)>(20, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { 0x80000000 | 15, 16 }, { QMetaType::QString, 17 }, { QMetaType::QString, 18 },
            { QMetaType::QString, 19 },
        }}),
        // Method 'doDrag'
        QtMocHelpers::MethodData<void(QQuickItem *, const QUrl &, const QString &, const QString &)>(20, 4, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { 0x80000000 | 15, 16 }, { QMetaType::QString, 17 }, { QMetaType::QString, 18 },
        }}),
        // Method 'doDrag'
        QtMocHelpers::MethodData<void(QQuickItem *, const QUrl &, const QString &)>(20, 4, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { 0x80000000 | 15, 16 }, { QMetaType::QString, 17 },
        }}),
        // Method 'doDrag'
        QtMocHelpers::MethodData<void(QQuickItem *, const QUrl &)>(20, 4, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { 0x80000000 | 15, 16 },
        }}),
        // Method 'doDrag'
        QtMocHelpers::MethodData<void(QQuickItem *)>(20, 4, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'dragIconSize'
        QtMocHelpers::PropertyData<int>(21, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'dragging'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DragHelper, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DragHelper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10DragHelperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10DragHelperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10DragHelperE_t>.metaTypes,
    nullptr
} };

void DragHelper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DragHelper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dragIconSizeChanged(); break;
        case 1: _t->dropped(); break;
        case 2: _t->draggingChanged(); break;
        case 3: { bool _r = _t->isDrag((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->startDrag((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 5: _t->startDrag((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 6: _t->startDrag((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 7: _t->startDrag((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 8: _t->startDrag((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1]))); break;
        case 9: _t->doDrag((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 10: _t->doDrag((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 11: _t->doDrag((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 12: _t->doDrag((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 13: _t->doDrag((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DragHelper::*)() const>(_a, &DragHelper::dragIconSizeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DragHelper::*)() const>(_a, &DragHelper::dropped, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DragHelper::*)() const>(_a, &DragHelper::draggingChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->dragIconSize(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isDragging(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDragIconSize(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DragHelper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DragHelper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10DragHelperE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DragHelper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void DragHelper::dragIconSizeChanged()const
{
    QMetaObject::activate(const_cast< DragHelper *>(this), &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DragHelper::dropped()const
{
    QMetaObject::activate(const_cast< DragHelper *>(this), &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DragHelper::draggingChanged()const
{
    QMetaObject::activate(const_cast< DragHelper *>(this), &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
