/****************************************************************************
** Meta object code from reading C++ file 'sessionmanagement.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-workspace-6.7.1/libkworkspace/sessionmanagement.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sessionmanagement.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17SessionManagementE_t {};
} // unnamed namespace

template <> constexpr inline auto SessionManagement::qt_create_metaobjectdata<qt_meta_tag_ZN17SessionManagementE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SessionManagement",
        "stateChanged",
        "",
        "canShutdownChanged",
        "canRebootChanged",
        "canLogoutChanged",
        "canSuspendChanged",
        "canHybridSuspendChanged",
        "canHibernateChanged",
        "canSuspendThenHibernateChanged",
        "canSwitchUserChanged",
        "canLockChanged",
        "canSaveSessionChanged",
        "aboutToSuspend",
        "resumingFromSuspend",
        "requestShutdown",
        "ConfirmationMode",
        "requestReboot",
        "requestLogout",
        "requestLogoutPrompt",
        "suspend",
        "hybridSuspend",
        "hibernate",
        "suspendThenHibernate",
        "switchUser",
        "lock",
        "saveSession",
        "state",
        "State",
        "canShutdown",
        "canReboot",
        "canLogout",
        "canSuspend",
        "canHibernate",
        "canSuspendThenHibernate",
        "canSwitchUser",
        "canLock",
        "canSaveSession",
        "Loading",
        "Ready",
        "Error",
        "Default",
        "Skip",
        "ForcePrompt"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canShutdownChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canRebootChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canLogoutChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canSuspendChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canHybridSuspendChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canHibernateChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canSuspendThenHibernateChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canSwitchUserChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canLockChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canSaveSessionChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'aboutToSuspend'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resumingFromSuspend'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'requestShutdown'
        QtMocHelpers::SlotData<void(enum ConfirmationMode)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 2 },
        }}),
        // Slot 'requestShutdown'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'requestReboot'
        QtMocHelpers::SlotData<void(enum ConfirmationMode)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 2 },
        }}),
        // Slot 'requestReboot'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'requestLogout'
        QtMocHelpers::SlotData<void(enum ConfirmationMode)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 2 },
        }}),
        // Slot 'requestLogout'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'requestLogoutPrompt'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'suspend'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'hybridSuspend'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'hibernate'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'suspendThenHibernate'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'switchUser'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'lock'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveSession'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'state'
        QtMocHelpers::PropertyData<enum State>(27, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'canShutdown'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'canReboot'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'canLogout'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'canSuspend'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
        // property 'canHibernate'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'canSuspendThenHibernate'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags, 7),
        // property 'canSwitchUser'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags, 8),
        // property 'canLock'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags, 9),
        // property 'canSaveSession'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags, 10),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'State'
        QtMocHelpers::EnumData<enum State>(28, 28, QMC::EnumIsScoped).add({
            {   38, State::Loading },
            {   39, State::Ready },
            {   40, State::Error },
        }),
        // enum 'ConfirmationMode'
        QtMocHelpers::EnumData<enum ConfirmationMode>(16, 16, QMC::EnumIsScoped).add({
            {   41, ConfirmationMode::Default },
            {   42, ConfirmationMode::Skip },
            {   43, ConfirmationMode::ForcePrompt },
        }),
    };
    return QtMocHelpers::metaObjectData<SessionManagement, qt_meta_tag_ZN17SessionManagementE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SessionManagement::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17SessionManagementE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17SessionManagementE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17SessionManagementE_t>.metaTypes,
    nullptr
} };

void SessionManagement::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SessionManagement *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->stateChanged(); break;
        case 1: _t->canShutdownChanged(); break;
        case 2: _t->canRebootChanged(); break;
        case 3: _t->canLogoutChanged(); break;
        case 4: _t->canSuspendChanged(); break;
        case 5: _t->canHybridSuspendChanged(); break;
        case 6: _t->canHibernateChanged(); break;
        case 7: _t->canSuspendThenHibernateChanged(); break;
        case 8: _t->canSwitchUserChanged(); break;
        case 9: _t->canLockChanged(); break;
        case 10: _t->canSaveSessionChanged(); break;
        case 11: _t->aboutToSuspend(); break;
        case 12: _t->resumingFromSuspend(); break;
        case 13: _t->requestShutdown((*reinterpret_cast<std::add_pointer_t<enum ConfirmationMode>>(_a[1]))); break;
        case 14: _t->requestShutdown(); break;
        case 15: _t->requestReboot((*reinterpret_cast<std::add_pointer_t<enum ConfirmationMode>>(_a[1]))); break;
        case 16: _t->requestReboot(); break;
        case 17: _t->requestLogout((*reinterpret_cast<std::add_pointer_t<enum ConfirmationMode>>(_a[1]))); break;
        case 18: _t->requestLogout(); break;
        case 19: _t->requestLogoutPrompt(); break;
        case 20: _t->suspend(); break;
        case 21: _t->hybridSuspend(); break;
        case 22: _t->hibernate(); break;
        case 23: _t->suspendThenHibernate(); break;
        case 24: _t->switchUser(); break;
        case 25: _t->lock(); break;
        case 26: _t->saveSession(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SessionManagement::*)()>(_a, &SessionManagement::stateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionManagement::*)()>(_a, &SessionManagement::canShutdownChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionManagement::*)()>(_a, &SessionManagement::canRebootChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionManagement::*)()>(_a, &SessionManagement::canLogoutChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionManagement::*)()>(_a, &SessionManagement::canSuspendChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionManagement::*)()>(_a, &SessionManagement::canHybridSuspendChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionManagement::*)()>(_a, &SessionManagement::canHibernateChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionManagement::*)()>(_a, &SessionManagement::canSuspendThenHibernateChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionManagement::*)()>(_a, &SessionManagement::canSwitchUserChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionManagement::*)()>(_a, &SessionManagement::canLockChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionManagement::*)()>(_a, &SessionManagement::canSaveSessionChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionManagement::*)()>(_a, &SessionManagement::aboutToSuspend, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionManagement::*)()>(_a, &SessionManagement::resumingFromSuspend, 12))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum State*>(_v) = _t->state(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->canShutdown(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->canReboot(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->canLogout(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->canSuspend(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->canHibernate(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->canSuspendThenHibernate(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->canSwitchUser(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->canLock(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->canSaveSession(); break;
        default: break;
        }
    }
}

const QMetaObject *SessionManagement::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SessionManagement::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17SessionManagementE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SessionManagement::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 27)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 27;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void SessionManagement::stateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SessionManagement::canShutdownChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SessionManagement::canRebootChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void SessionManagement::canLogoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void SessionManagement::canSuspendChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void SessionManagement::canHybridSuspendChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void SessionManagement::canHibernateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void SessionManagement::canSuspendThenHibernateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void SessionManagement::canSwitchUserChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void SessionManagement::canLockChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void SessionManagement::canSaveSessionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void SessionManagement::aboutToSuspend()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void SessionManagement::resumingFromSuspend()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}
QT_WARNING_POP
