/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Startup.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef STARTUPADAPTOR_H
#define STARTUPADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "startup.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.Startup
 */
class StartupAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.Startup")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.Startup\">\n"
"    <method name=\"updateLaunchEnv\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"key\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"value\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    StartupAdaptor(Startup *parent);
    ~StartupAdaptor() override;

    inline Startup *parent() const
    { return static_cast<Startup *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void updateLaunchEnv(const QString &key, const QString &value);
Q_SIGNALS: // SIGNALS
};

#endif
