/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was net.reactivated.Fprint.Device.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef FPRINT_DEVICE_INTERFACE_H
#define FPRINT_DEVICE_INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface net.reactivated.Fprint.Device
 */
class NetReactivatedFprintDeviceInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "net.reactivated.Fprint.Device"; }

public:
    NetReactivatedFprintDeviceInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~NetReactivatedFprintDeviceInterface();

    Q_PROPERTY(QString name READ name)
    inline QString name() const
    { return qvariant_cast< QString >(property("name")); }

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> Claim(const QString &username)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(username);
        return asyncCallWithArgumentList(QStringLiteral("Claim"), argumentList);
    }

    inline QDBusPendingReply<> DeleteEnrolledFinger(const QString &finger_name)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(finger_name);
        return asyncCallWithArgumentList(QStringLiteral("DeleteEnrolledFinger"), argumentList);
    }

    inline QDBusPendingReply<> DeleteEnrolledFingers(const QString &username)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(username);
        return asyncCallWithArgumentList(QStringLiteral("DeleteEnrolledFingers"), argumentList);
    }

    inline QDBusPendingReply<> DeleteEnrolledFingers2()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("DeleteEnrolledFingers2"), argumentList);
    }

    inline QDBusPendingReply<> EnrollStart(const QString &finger_name)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(finger_name);
        return asyncCallWithArgumentList(QStringLiteral("EnrollStart"), argumentList);
    }

    inline QDBusPendingReply<> EnrollStop()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("EnrollStop"), argumentList);
    }

    inline QDBusPendingReply<QStringList> ListEnrolledFingers(const QString &username)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(username);
        return asyncCallWithArgumentList(QStringLiteral("ListEnrolledFingers"), argumentList);
    }

    inline QDBusPendingReply<> Release()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("Release"), argumentList);
    }

    inline QDBusPendingReply<> VerifyStart(const QString &finger_name)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(finger_name);
        return asyncCallWithArgumentList(QStringLiteral("VerifyStart"), argumentList);
    }

    inline QDBusPendingReply<> VerifyStop()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("VerifyStop"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void EnrollStatus(const QString &result, bool done);
    void VerifyFingerSelected(const QString &finger_name);
    void VerifyStatus(const QString &result, bool done);
};

#endif
