/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.gtk.Actions.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef GTKACTIONS_INTERFACE_H
#define GTKACTIONS_INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>
#include "gdbusmenutypes_p.h"

/*
 * Proxy class for interface org.gtk.Actions
 */
class OrgGtkActionsInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.gtk.Actions"; }

public:
    OrgGtkActionsInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgGtkActionsInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> Activate(const QString &action_name, const QVariantList &parameter, const QVariantMap &platform_data)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(action_name) << QVariant::fromValue(parameter) << QVariant::fromValue(platform_data);
        return asyncCallWithArgumentList(QStringLiteral("Activate"), argumentList);
    }

    inline QDBusPendingReply<GMenuAction> Describe(const QString &action_name)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(action_name);
        return asyncCallWithArgumentList(QStringLiteral("Describe"), argumentList);
    }

    inline QDBusPendingReply<GMenuActionMap> DescribeAll()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("DescribeAll"), argumentList);
    }

    inline QDBusPendingReply<QStringList> List()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("List"), argumentList);
    }

    inline QDBusPendingReply<> SetState(const QString &action_name, const QDBusVariant &value, const QVariantMap &platform_data)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(action_name) << QVariant::fromValue(value) << QVariant::fromValue(platform_data);
        return asyncCallWithArgumentList(QStringLiteral("SetState"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void Changed(const QStringList &removals, StringBoolMap enable_changes, const QVariantMap &state_changes, GMenuActionMap additions);
};

#endif
