/****************************************************************************
** Meta object code from reading C++ file 'jobsmodel_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-workspace-6.7.1/libnotificationmanager/jobsmodel_p.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'jobsmodel_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19NotificationManager16JobsModelPrivateE_t {};
} // unnamed namespace

template <> constexpr inline auto NotificationManager::JobsModelPrivate::qt_create_metaobjectdata<qt_meta_tag_ZN19NotificationManager16JobsModelPrivateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NotificationManager::JobsModelPrivate",
        "jobViewAboutToBeAdded",
        "",
        "row",
        "Job*",
        "job",
        "jobViewAdded",
        "jobViewAboutToBeRemoved",
        "jobViewRemoved",
        "jobViewChanged",
        "QList<int>",
        "roles",
        "serviceOwnershipLost",
        "jobUrlsChanged",
        "urls",
        "requiresJobTrackerChanged",
        "req"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'jobViewAboutToBeAdded'
        QtMocHelpers::SignalData<void(int, Job *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'jobViewAdded'
        QtMocHelpers::SignalData<void(int, Job *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'jobViewAboutToBeRemoved'
        QtMocHelpers::SignalData<void(int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'jobViewRemoved'
        QtMocHelpers::SignalData<void(int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'jobViewChanged'
        QtMocHelpers::SignalData<void(int, Job *, const QList<int> &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 10, 11 },
        }}),
        // Signal 'serviceOwnershipLost'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'jobUrlsChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 14 },
        }}),
        // Signal 'requiresJobTrackerChanged'
        QtMocHelpers::SignalData<void(const bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<JobsModelPrivate, qt_meta_tag_ZN19NotificationManager16JobsModelPrivateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject NotificationManager::JobsModelPrivate::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationManager16JobsModelPrivateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationManager16JobsModelPrivateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19NotificationManager16JobsModelPrivateE_t>.metaTypes,
    nullptr
} };

void NotificationManager::JobsModelPrivate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<JobsModelPrivate *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->jobViewAboutToBeAdded((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Job*>>(_a[2]))); break;
        case 1: _t->jobViewAdded((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Job*>>(_a[2]))); break;
        case 2: _t->jobViewAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->jobViewRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->jobViewChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Job*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[3]))); break;
        case 5: _t->serviceOwnershipLost(); break;
        case 6: _t->jobUrlsChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 7: _t->requiresJobTrackerChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (JobsModelPrivate::*)(int , Job * )>(_a, &JobsModelPrivate::jobViewAboutToBeAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (JobsModelPrivate::*)(int , Job * )>(_a, &JobsModelPrivate::jobViewAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (JobsModelPrivate::*)(int )>(_a, &JobsModelPrivate::jobViewAboutToBeRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (JobsModelPrivate::*)(int )>(_a, &JobsModelPrivate::jobViewRemoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (JobsModelPrivate::*)(int , Job * , const QList<int> & )>(_a, &JobsModelPrivate::jobViewChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (JobsModelPrivate::*)()>(_a, &JobsModelPrivate::serviceOwnershipLost, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (JobsModelPrivate::*)(const QStringList & )>(_a, &JobsModelPrivate::jobUrlsChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (JobsModelPrivate::*)(const bool )>(_a, &JobsModelPrivate::requiresJobTrackerChanged, 7))
            return;
    }
}

const QMetaObject *NotificationManager::JobsModelPrivate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NotificationManager::JobsModelPrivate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationManager16JobsModelPrivateE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QObject::qt_metacast(_clname);
}

int NotificationManager::JobsModelPrivate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void NotificationManager::JobsModelPrivate::jobViewAboutToBeAdded(int _t1, Job * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void NotificationManager::JobsModelPrivate::jobViewAdded(int _t1, Job * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void NotificationManager::JobsModelPrivate::jobViewAboutToBeRemoved(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void NotificationManager::JobsModelPrivate::jobViewRemoved(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void NotificationManager::JobsModelPrivate::jobViewChanged(int _t1, Job * _t2, const QList<int> & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3);
}

// SIGNAL 5
void NotificationManager::JobsModelPrivate::serviceOwnershipLost()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void NotificationManager::JobsModelPrivate::jobUrlsChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void NotificationManager::JobsModelPrivate::requiresJobTrackerChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
