// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "notifications_debug.h"


Q_LOGGING_CATEGORY(PLASMA_APPLET_NOTIFICATIONS_DEBUG, "org.kde.plasma.notifications", QtInfoMsg)

