/****************************************************************************
** Meta object code from reading C++ file 'klipper.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-workspace-6.7.1/klipper/klipper.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'klipper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7KlipperE_t {};
} // unnamed namespace

template <> constexpr inline auto Klipper::qt_create_metaobjectdata<qt_meta_tag_ZN7KlipperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Klipper",
        "D-Bus Interface",
        "org.kde.klipper.klipper",
        "passivePopup",
        "",
        "caption",
        "text",
        "editFinished",
        "std::shared_ptr<const HistoryItem>",
        "item",
        "result",
        "clipboardHistoryUpdated",
        "getClipboardContents",
        "setClipboardContents",
        "s",
        "clearClipboardContents",
        "clearClipboardHistory",
        "saveClipboardHistory",
        "getClipboardHistoryMenu",
        "getClipboardHistoryItem",
        "i",
        "showKlipperPopupMenu",
        "showKlipperManuallyInvokeActionMenu",
        "reloadConfig",
        "saveSession",
        "slotConfigure",
        "slotCycleNext",
        "slotCyclePrev",
        "slotPopupMenu",
        "setURLGrabberEnabled",
        "showPopupMenu",
        "QMenu*",
        "slotRepeatAction",
        "slotHistoryChanged",
        "isTop",
        "slotStartShowTimer",
        "loadSettings"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'passivePopup'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 6 },
        }}),
        // Signal 'editFinished'
        QtMocHelpers::SignalData<void(std::shared_ptr<const HistoryItem>, int)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { QMetaType::Int, 10 },
        }}),
        // Signal 'clipboardHistoryUpdated'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'getClipboardContents'
        QtMocHelpers::SlotData<QString()>(12, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'setClipboardContents'
        QtMocHelpers::SlotData<void(const QString &)>(13, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'clearClipboardContents'
        QtMocHelpers::SlotData<void()>(15, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'clearClipboardHistory'
        QtMocHelpers::SlotData<void()>(16, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'saveClipboardHistory'
        QtMocHelpers::SlotData<void()>(17, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'getClipboardHistoryMenu'
        QtMocHelpers::SlotData<QStringList()>(18, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList),
        // Slot 'getClipboardHistoryItem'
        QtMocHelpers::SlotData<QString(int)>(19, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::Int, 20 },
        }}),
        // Slot 'showKlipperPopupMenu'
        QtMocHelpers::SlotData<void()>(21, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'showKlipperManuallyInvokeActionMenu'
        QtMocHelpers::SlotData<void()>(22, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'reloadConfig'
        QtMocHelpers::SlotData<void()>(23, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'saveSession'
        QtMocHelpers::SlotData<void()>(24, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotConfigure'
        QtMocHelpers::SlotData<void()>(25, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCycleNext'
        QtMocHelpers::SlotData<void()>(26, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCyclePrev'
        QtMocHelpers::SlotData<void()>(27, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPopupMenu'
        QtMocHelpers::SlotData<void()>(28, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setURLGrabberEnabled'
        QtMocHelpers::SlotData<void(bool)>(29, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Slot 'showPopupMenu'
        QtMocHelpers::SlotData<void(QMenu *)>(30, 4, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 31, 4 },
        }}),
        // Slot 'slotRepeatAction'
        QtMocHelpers::SlotData<void()>(32, 4, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotHistoryChanged'
        QtMocHelpers::SlotData<void(bool)>(33, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 34 },
        }}),
        // Slot 'slotHistoryChanged'
        QtMocHelpers::SlotData<void()>(33, 4, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotStartShowTimer'
        QtMocHelpers::SlotData<void()>(35, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'loadSettings'
        QtMocHelpers::SlotData<void()>(36, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Klipper, qt_meta_tag_ZN7KlipperE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Klipper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KlipperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KlipperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7KlipperE_t>.metaTypes,
    nullptr
} };

void Klipper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Klipper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->passivePopup((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->editFinished((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<const HistoryItem>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 2: _t->clipboardHistoryUpdated(); break;
        case 3: { QString _r = _t->getClipboardContents();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->setClipboardContents((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->clearClipboardContents(); break;
        case 6: _t->clearClipboardHistory(); break;
        case 7: _t->saveClipboardHistory(); break;
        case 8: { QStringList _r = _t->getClipboardHistoryMenu();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 9: { QString _r = _t->getClipboardHistoryItem((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->showKlipperPopupMenu(); break;
        case 11: _t->showKlipperManuallyInvokeActionMenu(); break;
        case 12: _t->reloadConfig(); break;
        case 13: _t->saveSession(); break;
        case 14: _t->slotConfigure(); break;
        case 15: _t->slotCycleNext(); break;
        case 16: _t->slotCyclePrev(); break;
        case 17: _t->slotPopupMenu(); break;
        case 18: _t->setURLGrabberEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->showPopupMenu((*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[1]))); break;
        case 20: _t->slotRepeatAction(); break;
        case 21: _t->slotHistoryChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 22: _t->slotHistoryChanged(); break;
        case 23: _t->slotStartShowTimer(); break;
        case 24: _t->loadSettings(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Klipper::*)(const QString & , const QString & )>(_a, &Klipper::passivePopup, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Klipper::*)(std::shared_ptr<const HistoryItem> , int )>(_a, &Klipper::editFinished, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Klipper::*)()>(_a, &Klipper::clipboardHistoryUpdated, 2))
            return;
    }
}

const QMetaObject *Klipper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Klipper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KlipperE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QObject::qt_metacast(_clname);
}

int Klipper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 25;
    }
    return _id;
}

// SIGNAL 0
void Klipper::passivePopup(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void Klipper::editFinished(std::shared_ptr<const HistoryItem> _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void Klipper::clipboardHistoryUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
