/****************************************************************************
** Meta object code from reading C++ file 'FontInst.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../plasma-workspace-6.7.1/kcms/kfontinst/dbus/FontInst.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'FontInst.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3KFI8FontInstE_t {};
} // unnamed namespace

template <> constexpr inline auto KFI::FontInst::qt_create_metaobjectdata<qt_meta_tag_ZN3KFI8FontInstE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KFI::FontInst",
        "D-Bus Interface",
        "org.kde.fontinst",
        "fontList",
        "",
        "pid",
        "QList<KFI::Families>",
        "families",
        "status",
        "fontStat",
        "KFI::Family",
        "font",
        "fontsAdded",
        "KFI::Families",
        "fontsRemoved",
        "list",
        "Q_NOREPLY",
        "folders",
        "statFont",
        "install",
        "file",
        "createAfm",
        "toSystem",
        "checkConfig",
        "uninstall",
        "family",
        "style",
        "fromSystem",
        "name",
        "move",
        "enable",
        "inSystem",
        "disable",
        "removeFile",
        "reconfigure",
        "force",
        "folderName",
        "sys",
        "saveDisabled",
        "connectionsTimeout",
        "fontListTimeout"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'fontList'
        QtMocHelpers::SignalData<void(int, const QList<KFI::Families> &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Signal 'status'
        QtMocHelpers::SignalData<void(int, int)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::Int, 8 },
        }}),
        // Signal 'fontStat'
        QtMocHelpers::SignalData<void(int, const KFI::Family &)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { 0x80000000 | 10, 11 },
        }}),
        // Signal 'fontsAdded'
        QtMocHelpers::SignalData<void(const KFI::Families &)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 7 },
        }}),
        // Signal 'fontsRemoved'
        QtMocHelpers::SignalData<void(const KFI::Families &)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 7 },
        }}),
        // Slot 'list'
        QtMocHelpers::SlotData<void(int, int)>(15, 16, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 5 },
        }}),
        // Slot 'statFont'
        QtMocHelpers::SlotData<void(const QString &, int, int)>(18, 16, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { QMetaType::Int, 17 }, { QMetaType::Int, 5 },
        }}),
        // Slot 'install'
        QtMocHelpers::SlotData<void(const QString &, bool, bool, int, bool)>(19, 16, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 }, { QMetaType::Bool, 21 }, { QMetaType::Bool, 22 }, { QMetaType::Int, 5 },
            { QMetaType::Bool, 23 },
        }}),
        // Slot 'uninstall'
        QtMocHelpers::SlotData<void(const QString &, quint32, bool, int, bool)>(24, 16, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 }, { QMetaType::UInt, 26 }, { QMetaType::Bool, 27 }, { QMetaType::Int, 5 },
            { QMetaType::Bool, 23 },
        }}),
        // Slot 'uninstall'
        QtMocHelpers::SlotData<void(const QString &, bool, int, bool)>(24, 16, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 }, { QMetaType::Bool, 27 }, { QMetaType::Int, 5 }, { QMetaType::Bool, 23 },
        }}),
        // Slot 'move'
        QtMocHelpers::SlotData<void(const QString &, quint32, bool, int, bool)>(29, 16, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 }, { QMetaType::UInt, 26 }, { QMetaType::Bool, 22 }, { QMetaType::Int, 5 },
            { QMetaType::Bool, 23 },
        }}),
        // Slot 'enable'
        QtMocHelpers::SlotData<void(const QString &, quint32, bool, int, bool)>(30, 16, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 }, { QMetaType::UInt, 26 }, { QMetaType::Bool, 31 }, { QMetaType::Int, 5 },
            { QMetaType::Bool, 23 },
        }}),
        // Slot 'disable'
        QtMocHelpers::SlotData<void(const QString &, quint32, bool, int, bool)>(32, 16, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 }, { QMetaType::UInt, 26 }, { QMetaType::Bool, 31 }, { QMetaType::Int, 5 },
            { QMetaType::Bool, 23 },
        }}),
        // Slot 'removeFile'
        QtMocHelpers::SlotData<void(const QString &, quint32, const QString &, bool, int, bool)>(33, 16, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 }, { QMetaType::UInt, 26 }, { QMetaType::QString, 20 }, { QMetaType::Bool, 27 },
            { QMetaType::Int, 5 }, { QMetaType::Bool, 23 },
        }}),
        // Slot 'reconfigure'
        QtMocHelpers::SlotData<void(int, bool)>(34, 16, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::Bool, 35 },
        }}),
        // Slot 'folderName'
        QtMocHelpers::SlotData<QString(bool)>(36, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::Bool, 37 },
        }}),
        // Slot 'saveDisabled'
        QtMocHelpers::SlotData<void()>(38, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'connectionsTimeout'
        QtMocHelpers::SlotData<void()>(39, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'fontListTimeout'
        QtMocHelpers::SlotData<void()>(40, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<FontInst, qt_meta_tag_ZN3KFI8FontInstE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KFI::FontInst::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3KFI8FontInstE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3KFI8FontInstE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3KFI8FontInstE_t>.metaTypes,
    nullptr
} };

void KFI::FontInst::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FontInst *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->fontList((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<KFI::Families>>>(_a[2]))); break;
        case 1: _t->status((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 2: _t->fontStat((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KFI::Family>>(_a[2]))); break;
        case 3: _t->fontsAdded((*reinterpret_cast<std::add_pointer_t<KFI::Families>>(_a[1]))); break;
        case 4: _t->fontsRemoved((*reinterpret_cast<std::add_pointer_t<KFI::Families>>(_a[1]))); break;
        case 5: _t->list((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 6: _t->statFont((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 7: _t->install((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 8: _t->uninstall((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 9: _t->uninstall((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 10: _t->move((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 11: _t->enable((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 12: _t->disable((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 13: _t->removeFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6]))); break;
        case 14: _t->reconfigure((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 15: { QString _r = _t->folderName((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->saveDisabled(); break;
        case 17: _t->connectionsTimeout(); break;
        case 18: _t->fontListTimeout(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FontInst::*)(int , const QList<KFI::Families> & )>(_a, &FontInst::fontList, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FontInst::*)(int , int )>(_a, &FontInst::status, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FontInst::*)(int , const KFI::Family & )>(_a, &FontInst::fontStat, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FontInst::*)(const KFI::Families & )>(_a, &FontInst::fontsAdded, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FontInst::*)(const KFI::Families & )>(_a, &FontInst::fontsRemoved, 4))
            return;
    }
}

const QMetaObject *KFI::FontInst::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KFI::FontInst::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3KFI8FontInstE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KFI::FontInst::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void KFI::FontInst::fontList(int _t1, const QList<KFI::Families> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void KFI::FontInst::status(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void KFI::FontInst::fontStat(int _t1, const KFI::Family & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void KFI::FontInst::fontsAdded(const KFI::Families & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KFI::FontInst::fontsRemoved(const KFI::Families & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
