// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#ifndef STYLEDATA_H
#define STYLEDATA_H

#include <QObject>

#include "kcmoduledata.h"



class StyleSettings;


class StyleData : public KCModuleData
{
    Q_OBJECT

public:
    explicit StyleData(QObject *parent = nullptr);
    StyleSettings *settings() const;


private:
    StyleSettings *m_settings;

};



#endif
