// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#include "soundthemedata.h"

#include "soundthemesettings.h"




SoundThemeData::SoundThemeData(QObject *parent)
: KCModuleData(parent)
, m_settings(new SoundThemeSettings(this))

{
autoRegisterSkeletons();
}

SoundThemeSettings *SoundThemeData::settings() const
{
    return m_settings;
}





#include "moc_soundthemedata.cpp"
