// This file is generated by kconfig_compiler_kf6 from terminal_settings.kcfg.
// All changes you do to this file will be lost.

#include "terminal_settings.h"

TerminalSettings::TerminalSettings( QObject *parent )
  : KConfigSkeleton( QStringLiteral( "kdeglobals" ) )
{
  setParent(parent);
  setCurrentGroup( QStringLiteral( "General" ) );

  KConfigSkeleton::ItemString  *itemTerminalApplication;
  itemTerminalApplication = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "TerminalApplication" ), mTerminalApplication, QStringLiteral( "konsole" ) );
  addItem( itemTerminalApplication, QStringLiteral( "terminalApplication" ) );
  KConfigSkeleton::ItemString  *itemTerminalService;
  itemTerminalService = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "TerminalService" ), mTerminalService, QStringLiteral( "org.kde.konsole.desktop" ) );
  addItem( itemTerminalService, QStringLiteral( "terminalService" ) );
}

QString TerminalSettings::defaultTerminalApplicationValue_helper() const
{

  return QStringLiteral( "konsole" );
}

QString TerminalSettings::defaultTerminalServiceValue_helper() const
{

  return QStringLiteral( "org.kde.konsole.desktop" );
}

TerminalSettings::~TerminalSettings()
{
}

