/****************************************************************************
** Meta object code from reading C++ file 'FontList.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../plasma-workspace-6.7.1/kcms/kfontinst/kcmfontinst/FontList.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#include <QtCore/QSet>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'FontList.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3KFI9CFontListE_t {};
} // unnamed namespace

template <> constexpr inline auto KFI::CFontList::qt_create_metaobjectdata<qt_meta_tag_ZN3KFI9CFontListE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KFI::CFontList",
        "listingPercent",
        "",
        "p",
        "unsetSlowUpdates",
        "load",
        "dbusServiceOwnerChanged",
        "name",
        "from",
        "to",
        "fontList",
        "pid",
        "QList<KFI::Families>",
        "families",
        "fontsAdded",
        "KFI::Families",
        "fontsRemoved"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'listingPercent'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'unsetSlowUpdates'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'load'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'dbusServiceOwnerChanged'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 }, { QMetaType::QString, 9 },
        }}),
        // Slot 'fontList'
        QtMocHelpers::SlotData<void(int, const QList<KFI::Families> &)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Slot 'fontsAdded'
        QtMocHelpers::SlotData<void(const KFI::Families &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 13 },
        }}),
        // Slot 'fontsRemoved'
        QtMocHelpers::SlotData<void(const KFI::Families &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CFontList, qt_meta_tag_ZN3KFI9CFontListE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KFI::CFontList::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3KFI9CFontListE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3KFI9CFontListE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3KFI9CFontListE_t>.metaTypes,
    nullptr
} };

void KFI::CFontList::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CFontList *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->listingPercent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->unsetSlowUpdates(); break;
        case 2: _t->load(); break;
        case 3: _t->dbusServiceOwnerChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 4: _t->fontList((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<KFI::Families>>>(_a[2]))); break;
        case 5: _t->fontsAdded((*reinterpret_cast<std::add_pointer_t<KFI::Families>>(_a[1]))); break;
        case 6: _t->fontsRemoved((*reinterpret_cast<std::add_pointer_t<KFI::Families>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CFontList::*)(int )>(_a, &CFontList::listingPercent, 0))
            return;
    }
}

const QMetaObject *KFI::CFontList::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KFI::CFontList::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3KFI9CFontListE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int KFI::CFontList::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void KFI::CFontList::listingPercent(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN3KFI24CFontListSortFilterProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto KFI::CFontListSortFilterProxy::qt_create_metaobjectdata<qt_meta_tag_ZN3KFI24CFontListSortFilterProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KFI::CFontListSortFilterProxy",
        "refresh",
        "",
        "timeout",
        "fcResults"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'refresh'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'timeout'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'fcResults'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CFontListSortFilterProxy, qt_meta_tag_ZN3KFI24CFontListSortFilterProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KFI::CFontListSortFilterProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QSortFilterProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3KFI24CFontListSortFilterProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3KFI24CFontListSortFilterProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3KFI24CFontListSortFilterProxyE_t>.metaTypes,
    nullptr
} };

void KFI::CFontListSortFilterProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CFontListSortFilterProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->refresh(); break;
        case 1: _t->timeout(); break;
        case 2: _t->fcResults(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CFontListSortFilterProxy::*)()>(_a, &CFontListSortFilterProxy::refresh, 0))
            return;
    }
}

const QMetaObject *KFI::CFontListSortFilterProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KFI::CFontListSortFilterProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3KFI24CFontListSortFilterProxyE_t>.strings))
        return static_cast<void*>(this);
    return QSortFilterProxyModel::qt_metacast(_clname);
}

int KFI::CFontListSortFilterProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSortFilterProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void KFI::CFontListSortFilterProxy::refresh()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN3KFI13CFontListViewE_t {};
} // unnamed namespace

template <> constexpr inline auto KFI::CFontListView::qt_create_metaobjectdata<qt_meta_tag_ZN3KFI13CFontListViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KFI::CFontListView",
        "del",
        "",
        "print",
        "enable",
        "disable",
        "fontsDropped",
        "QSet<QUrl>",
        "itemsSelected",
        "QModelIndexList",
        "refresh",
        "reload",
        "listingPercent",
        "percent",
        "refreshFilter",
        "filterText",
        "text",
        "filterCriteria",
        "crit",
        "ws",
        "ft",
        "setSortColumn",
        "col",
        "selectionChanged",
        "QItemSelection",
        "selected",
        "deselected",
        "itemCollapsed",
        "QModelIndex",
        "index",
        "view"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'del'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'print'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enable'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'disable'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontsDropped'
        QtMocHelpers::SignalData<void(const QSet<QUrl> &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Signal 'itemsSelected'
        QtMocHelpers::SignalData<void(const QModelIndexList &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 },
        }}),
        // Signal 'refresh'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'reload'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'listingPercent'
        QtMocHelpers::SlotData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Slot 'refreshFilter'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'filterText'
        QtMocHelpers::SlotData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Slot 'filterCriteria'
        QtMocHelpers::SlotData<void(int, qulonglong, const QStringList &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 }, { QMetaType::ULongLong, 19 }, { QMetaType::QStringList, 20 },
        }}),
        // Slot 'setSortColumn'
        QtMocHelpers::SlotData<void(int)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'selectionChanged'
        QtMocHelpers::SlotData<void(const QItemSelection &, const QItemSelection &)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 25 }, { 0x80000000 | 24, 26 },
        }}),
        // Slot 'itemCollapsed'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'view'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CFontListView, qt_meta_tag_ZN3KFI13CFontListViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KFI::CFontListView::staticMetaObject = { {
    QMetaObject::SuperData::link<QTreeView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3KFI13CFontListViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3KFI13CFontListViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3KFI13CFontListViewE_t>.metaTypes,
    nullptr
} };

void KFI::CFontListView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CFontListView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->del(); break;
        case 1: _t->print(); break;
        case 2: _t->enable(); break;
        case 3: _t->disable(); break;
        case 4: _t->fontsDropped((*reinterpret_cast<std::add_pointer_t<QSet<QUrl>>>(_a[1]))); break;
        case 5: _t->itemsSelected((*reinterpret_cast<std::add_pointer_t<QModelIndexList>>(_a[1]))); break;
        case 6: _t->refresh(); break;
        case 7: _t->reload(); break;
        case 8: _t->listingPercent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->refreshFilter(); break;
        case 10: _t->filterText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->filterCriteria((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        case 12: _t->setSortColumn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->selectionChanged((*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[2]))); break;
        case 14: _t->itemCollapsed((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 15: _t->view(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QModelIndexList >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QItemSelection >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CFontListView::*)()>(_a, &CFontListView::del, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CFontListView::*)()>(_a, &CFontListView::print, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CFontListView::*)()>(_a, &CFontListView::enable, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CFontListView::*)()>(_a, &CFontListView::disable, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CFontListView::*)(const QSet<QUrl> & )>(_a, &CFontListView::fontsDropped, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CFontListView::*)(const QModelIndexList & )>(_a, &CFontListView::itemsSelected, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (CFontListView::*)()>(_a, &CFontListView::refresh, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (CFontListView::*)()>(_a, &CFontListView::reload, 7))
            return;
    }
}

const QMetaObject *KFI::CFontListView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KFI::CFontListView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3KFI13CFontListViewE_t>.strings))
        return static_cast<void*>(this);
    return QTreeView::qt_metacast(_clname);
}

int KFI::CFontListView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void KFI::CFontListView::del()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KFI::CFontListView::print()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KFI::CFontListView::enable()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KFI::CFontListView::disable()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KFI::CFontListView::fontsDropped(const QSet<QUrl> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KFI::CFontListView::itemsSelected(const QModelIndexList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void KFI::CFontListView::refresh()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KFI::CFontListView::reload()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
