/****************************************************************************
** Meta object code from reading C++ file 'kuiserveradaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "kuiserveradaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kuiserveradaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KuiserverAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto KuiserverAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN16KuiserverAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KuiserverAdaptor",
        "D-Bus Interface",
        "org.kde.kuiserver",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.kuiserver\">\n    <method name=\"regis"
        "terService\">\n      <arg direction=\"in\" type=\"s\" name=\"servi"
        "ce\"/>\n      <arg direction=\"in\" type=\"s\" name=\"objectPath\""
        "/>\n    </method>\n    <method name=\"emitJobUrlsChanged\"/>\n    "
        "<method name=\"requiresJobTracker\">\n      <arg direction=\"out\""
        " type=\"b\"/>\n    </method>\n    <method name=\"registeredJobCont"
        "acts\">\n      <arg direction=\"out\" type=\"as\"/>\n    </method>"
        "\n    <signal name=\"jobUrlsChanged\">\n      <arg direction=\"out"
        "\" type=\"as\"/>\n      <annotation value=\"QList&lt;QString&gt;\""
        " name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n    </signal>\n "
        "   <signal name=\"requiresJobTrackerChanged\">\n      <arg directi"
        "on=\"out\" type=\"b\"/>\n    </signal>\n  </interface>\n",
        "jobUrlsChanged",
        "",
        "in0",
        "requiresJobTrackerChanged",
        "emitJobUrlsChanged",
        "registerService",
        "service",
        "objectPath",
        "registeredJobContacts",
        "requiresJobTracker"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'jobUrlsChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 7 },
        }}),
        // Signal 'requiresJobTrackerChanged'
        QtMocHelpers::SignalData<void(bool)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Slot 'emitJobUrlsChanged'
        QtMocHelpers::SlotData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'registerService'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 12 },
        }}),
        // Slot 'registeredJobContacts'
        QtMocHelpers::SlotData<QStringList()>(13, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'requiresJobTracker'
        QtMocHelpers::SlotData<bool()>(14, 6, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<KuiserverAdaptor, qt_meta_tag_ZN16KuiserverAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KuiserverAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KuiserverAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KuiserverAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KuiserverAdaptorE_t>.metaTypes,
    nullptr
} };

void KuiserverAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KuiserverAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->jobUrlsChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 1: _t->requiresJobTrackerChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->emitJobUrlsChanged(); break;
        case 3: _t->registerService((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: { QStringList _r = _t->registeredJobContacts();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->requiresJobTracker();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KuiserverAdaptor::*)(const QStringList & )>(_a, &KuiserverAdaptor::jobUrlsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KuiserverAdaptor::*)(bool )>(_a, &KuiserverAdaptor::requiresJobTrackerChanged, 1))
            return;
    }
}

const QMetaObject *KuiserverAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KuiserverAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KuiserverAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int KuiserverAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void KuiserverAdaptor::jobUrlsChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KuiserverAdaptor::requiresJobTrackerChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
