// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#ifndef FONTSDATA_H
#define FONTSDATA_H

#include <QObject>

#include "kcmoduledata.h"



class FontsSettings;
class FontsAASettings;


class FontsData : public KCModuleData
{
    Q_OBJECT

public:
    explicit FontsData(QObject *parent = nullptr);
    FontsSettings *fontsSettings() const;
FontsAASettings *fontsAASettings() const;


private:
    FontsSettings *m_fontsSettings;
FontsAASettings *m_fontsAASettings;

};



#endif
