// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "debug.h"


Q_LOGGING_CATEGORY(FALLBACK_SESSION_RESTORE, "org.kde.plasma-fallback-session-restore", QtInfoMsg)

