// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#ifndef COLORSDATA_H
#define COLORSDATA_H

#include <QObject>

#include "kcmoduledata.h"



class ColorsSettings;


class ColorsData : public KCModuleData
{
    Q_OBJECT

public:
    explicit ColorsData(QObject *parent = nullptr);
    ColorsSettings *settings() const;


private:
    ColorsSettings *m_settings;

};



#endif
