/****************************************************************************
** Meta object code from reading C++ file 'eventdatadecorator.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/components/calendar/eventdatadecorator.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'eventdatadecorator.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18EventDataDecoratorE_t {};
} // unnamed namespace

template <> constexpr inline auto EventDataDecorator::qt_create_metaobjectdata<qt_meta_tag_ZN18EventDataDecoratorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EventDataDecorator",
        "QML.Element",
        "eventData",
        "startDateTime",
        "endDateTime",
        "isAllDay",
        "isMinor",
        "title",
        "description",
        "eventColor",
        "eventType"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'startDateTime'
        QtMocHelpers::PropertyData<QDateTime>(3, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'endDateTime'
        QtMocHelpers::PropertyData<QDateTime>(4, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'isAllDay'
        QtMocHelpers::PropertyData<bool>(5, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'isMinor'
        QtMocHelpers::PropertyData<bool>(6, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'title'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'description'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'eventColor'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'eventType'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<EventDataDecorator, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject EventDataDecorator::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18EventDataDecoratorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18EventDataDecoratorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18EventDataDecoratorE_t>.metaTypes,
    nullptr
} };

void EventDataDecorator::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<EventDataDecorator *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QDateTime*>(_v) = _t->startDateTime(); break;
        case 1: *reinterpret_cast<QDateTime*>(_v) = _t->endDateTime(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isAllDay(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isMinor(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->description(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->eventColor(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->eventType(); break;
        default: break;
        }
    }
}
QT_WARNING_POP
