/****************************************************************************
** Meta object code from reading C++ file 'fontsaasettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/kcms/fonts/fontsaasettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fontsaasettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15FontsAASettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto FontsAASettings::qt_create_metaobjectdata<qt_meta_tag_ZN15FontsAASettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FontsAASettings",
        "excludeChanged",
        "",
        "excludeFromChanged",
        "excludeToChanged",
        "antiAliasingChanged",
        "dpiChanged",
        "subPixelChanged",
        "hintingChanged",
        "aliasingChangeApplied",
        "excludeStateProxyChanged",
        "exclude",
        "excludeFrom",
        "excludeTo",
        "antiAliasing",
        "dpi",
        "subPixel",
        "KXftConfig::SubPixel::Type",
        "hinting",
        "KXftConfig::Hint::Style",
        "isAaImmutable",
        "excludeStateProxy"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'excludeChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'excludeFromChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'excludeToChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'antiAliasingChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dpiChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'subPixelChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hintingChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'aliasingChangeApplied'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'excludeStateProxyChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'exclude'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'excludeFrom'
        QtMocHelpers::PropertyData<int>(12, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'excludeTo'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'antiAliasing'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'dpi'
        QtMocHelpers::PropertyData<int>(15, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'subPixel'
        QtMocHelpers::PropertyData<KXftConfig::SubPixel::Type>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'hinting'
        QtMocHelpers::PropertyData<KXftConfig::Hint::Style>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'isAaImmutable'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'excludeStateProxy'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags, 8),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FontsAASettings, qt_meta_tag_ZN15FontsAASettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject FontsAASettings::staticMetaObject = { {
    QMetaObject::SuperData::link<FontsAASettingsBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15FontsAASettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15FontsAASettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15FontsAASettingsE_t>.metaTypes,
    nullptr
} };

void FontsAASettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FontsAASettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->excludeChanged(); break;
        case 1: _t->excludeFromChanged(); break;
        case 2: _t->excludeToChanged(); break;
        case 3: _t->antiAliasingChanged(); break;
        case 4: _t->dpiChanged(); break;
        case 5: _t->subPixelChanged(); break;
        case 6: _t->hintingChanged(); break;
        case 7: _t->aliasingChangeApplied(); break;
        case 8: _t->excludeStateProxyChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FontsAASettings::*)()>(_a, &FontsAASettings::excludeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FontsAASettings::*)()>(_a, &FontsAASettings::excludeFromChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FontsAASettings::*)()>(_a, &FontsAASettings::excludeToChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FontsAASettings::*)()>(_a, &FontsAASettings::antiAliasingChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FontsAASettings::*)()>(_a, &FontsAASettings::dpiChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FontsAASettings::*)()>(_a, &FontsAASettings::subPixelChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (FontsAASettings::*)()>(_a, &FontsAASettings::hintingChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (FontsAASettings::*)()>(_a, &FontsAASettings::aliasingChangeApplied, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (FontsAASettings::*)()>(_a, &FontsAASettings::excludeStateProxyChanged, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->exclude(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->excludeFrom(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->excludeTo(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->antiAliasing(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->dpi(); break;
        case 5: *reinterpret_cast<KXftConfig::SubPixel::Type*>(_v) = _t->subPixel(); break;
        case 6: *reinterpret_cast<KXftConfig::Hint::Style*>(_v) = _t->hinting(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isAaImmutable(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->excludeStateProxy(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setExclude(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setExcludeFrom(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setExcludeTo(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setAntiAliasing(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setDpi(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setSubPixel(*reinterpret_cast<KXftConfig::SubPixel::Type*>(_v)); break;
        case 6: _t->setHinting(*reinterpret_cast<KXftConfig::Hint::Style*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *FontsAASettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FontsAASettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15FontsAASettingsE_t>.strings))
        return static_cast<void*>(this);
    return FontsAASettingsBase::qt_metacast(_clname);
}

int FontsAASettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = FontsAASettingsBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void FontsAASettings::excludeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void FontsAASettings::excludeFromChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void FontsAASettings::excludeToChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void FontsAASettings::antiAliasingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void FontsAASettings::dpiChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void FontsAASettings::subPixelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void FontsAASettings::hintingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void FontsAASettings::aliasingChangeApplied()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void FontsAASettings::excludeStateProxyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
