// /qt/qml/plasma/applet/org/kde/plasma/cameraindicator/main.qml
#include <QtQml/qqmlprivate.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qobject.h>
#include <QtCore/qstring.h>
#include <QtCore/qstringlist.h>
#include <QtCore/qtimezone.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <QtQml/qqmlcomponent.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmllist.h>
#include <type_traits>
namespace QmlCacheGeneratedCode {
namespace _qt_qml_plasma_applet_org_kde_plasma_cameraindicator_main_qml {
extern const unsigned char qmlData alignas(16) [];
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x49,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x11,0x0,0x0,0x52,0x22,0x4b,0xa3,
0xee,0x88,0xbe,0xa9,0xcd,0x30,0x31,0x96,
0xec,0xcd,0xa5,0x46,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x2,0x0,0x0,
0x38,0x0,0x0,0x0,0x40,0x5,0x0,0x0,
0x7,0x0,0x0,0x0,0xc8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xe4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xe4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xe4,0x0,0x0,0x0,
0x2e,0x0,0x0,0x0,0xe4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x9c,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xa0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xa0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xa0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xa0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xa0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xa0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xa0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xa0,0x1,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x68,0xe,0x0,0x0,
0xa0,0x1,0x0,0x0,0xf8,0x1,0x0,0x0,
0x50,0x2,0x0,0x0,0xb0,0x2,0x0,0x0,
0x88,0x3,0x0,0x0,0x68,0x4,0x0,0x0,
0xe8,0x4,0x0,0x0,0x53,0x0,0x0,0x0,
0xe0,0x1,0x0,0x0,0xf0,0x1,0x0,0x0,
0x53,0x0,0x0,0x0,0xe0,0x1,0x0,0x0,
0xf0,0x1,0x0,0x0,0x33,0x1,0x0,0x0,
0x0,0x2,0x0,0x0,0x10,0x2,0x0,0x0,
0x33,0x0,0x0,0x0,0x20,0x2,0x0,0x0,
0x30,0x2,0x0,0x0,0x93,0x1,0x0,0x0,
0x40,0x2,0x0,0x0,0x77,0x2,0x0,0x0,
0x93,0x1,0x0,0x0,0x80,0x2,0x0,0x0,
0x93,0x1,0x0,0x0,0x80,0x2,0x0,0x0,
0xb7,0x2,0x0,0x0,0x77,0x2,0x0,0x0,
0x93,0x1,0x0,0x0,0x40,0x2,0x0,0x0,
0x93,0x1,0x0,0x0,0xe0,0x2,0x0,0x0,
0x93,0x1,0x0,0x0,0x80,0x2,0x0,0x0,
0x93,0x1,0x0,0x0,0x80,0x2,0x0,0x0,
0x93,0x1,0x0,0x0,0xe0,0x2,0x0,0x0,
0x93,0x1,0x0,0x0,0x80,0x2,0x0,0x0,
0x33,0x0,0x0,0x0,0x20,0x3,0x0,0x0,
0x30,0x3,0x0,0x0,0xf3,0x0,0x0,0x0,
0x33,0x0,0x0,0x0,0x20,0x3,0x0,0x0,
0x40,0x3,0x0,0x0,0x33,0x0,0x0,0x0,
0x20,0x3,0x0,0x0,0x50,0x3,0x0,0x0,
0x73,0x0,0x0,0x0,0x60,0x3,0x0,0x0,
0x70,0x3,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0xf,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x8,0x0,0x0,0x0,
0x13,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x13,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x0,0x3c,0x1,
0x3c,0x2,0x18,0x7,0x10,0xc,0x9c,0x7,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0xf,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x8,0x0,0x0,0x0,
0x14,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x14,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x3,0x3c,0x4,
0x3c,0x5,0x18,0x7,0x10,0xc,0x9c,0x7,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x13,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x8,0x0,0x0,0x0,
0x16,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x16,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x6,0x3c,0x7,
0x3c,0x8,0x18,0x7,0x2e,0x9,0x3c,0xa,
0x3c,0xb,0x6c,0x7,0x18,0x6,0x2,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x80,0x0,0x0,0x0,0x41,0x0,0x0,0x0,
0x12,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x6,0x0,
0xff,0xff,0xff,0xff,0xd,0x0,0x0,0x0,
0x18,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x19,0x0,0x0,0x0,0x3,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x1a,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x1a,0x0,0x0,0x0,
0x1b,0x0,0x0,0x0,0x6,0x0,0x0,0x0,
0x31,0x0,0x0,0x0,0x1d,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x3e,0x0,0x0,0x0,
0x1e,0x0,0x0,0x0,0x8,0x0,0x0,0x0,
0x2e,0xc,0x3c,0xd,0x74,0x50,0xd,0x12,
0x25,0x18,0x9,0x12,0x26,0x18,0xa,0xb4,
0xe,0x2,0x9,0x2,0x2e,0xf,0x3c,0x10,
0x50,0x17,0x12,0x25,0x18,0x9,0x12,0x29,
0x18,0xa,0x12,0x2a,0x18,0xb,0x2e,0x11,
0x3c,0x12,0x18,0xc,0xb4,0x13,0x4,0x9,
0x2,0x12,0x25,0x18,0x9,0x12,0x2c,0x18,
0xa,0xb4,0x14,0x2,0x9,0x2,0x16,0x6,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x98,0x0,0x0,0x0,0x37,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x8,0x0,
0xff,0xff,0xff,0xff,0xa,0x0,0x0,0x0,
0x20,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x21,0x0,0x0,0x0,0x3,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x22,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x20,0x0,0x0,0x0,
0x23,0x0,0x0,0x0,0x6,0x0,0x0,0x0,
0x23,0x0,0x0,0x0,0x24,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x2e,0x0,0x0,0x0,
0x25,0x0,0x0,0x0,0x9,0x0,0x0,0x0,
0x31,0x0,0x0,0x0,0x27,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x34,0x0,0x0,0x0,
0x28,0x0,0x0,0x0,0xb,0x0,0x0,0x0,
0x2e,0x15,0x3c,0x16,0x74,0x50,0x3,0x12,
0x2d,0x2,0x2e,0x17,0x3c,0x18,0x18,0x7,
0x6,0x64,0x7,0x50,0xe,0x2e,0x19,0x3c,
0x1a,0x18,0x8,0x6,0x6c,0x8,0x50,0x3,
0x12,0x2f,0x2,0x2e,0x1b,0x3c,0x1c,0x18,
0x9,0x6,0x64,0x9,0x50,0x3,0x12,0x30,
0x2,0x12,0x31,0x2,0x16,0x6,0x2,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x33,0x0,0x0,0x0,
0x17,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x9,0x0,0x0,0x0,
0x29,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x29,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x1d,0x3c,0x1e,
0x18,0x7,0x6,0x64,0x7,0x4e,0xb,0x2e,
0x1f,0x3c,0x20,0x18,0x8,0x6,0x64,0x8,
0x50,0x8,0x2e,0x21,0x3c,0x22,0x3c,0x23,
0x4c,0x12,0x2e,0x24,0x50,0x8,0x2e,0x25,
0x3c,0x26,0x3c,0x27,0x4c,0x6,0x2e,0x28,
0x3c,0x29,0x3c,0x2a,0x18,0x6,0x2,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x9,0x0,0x0,0x0,
0x1b,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x2d,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x2d,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x2b,0x3c,0x2c,
0x3c,0x2d,0x18,0x6,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x20,0x6,0x0,0x0,0x28,0x6,0x0,0x0,
0x40,0x6,0x0,0x0,0x78,0x6,0x0,0x0,
0x98,0x6,0x0,0x0,0xc8,0x6,0x0,0x0,
0xe0,0x6,0x0,0x0,0x8,0x7,0x0,0x0,
0x20,0x7,0x0,0x0,0x58,0x7,0x0,0x0,
0x78,0x7,0x0,0x0,0x88,0x7,0x0,0x0,
0xa8,0x7,0x0,0x0,0xe8,0x7,0x0,0x0,
0x8,0x8,0x0,0x0,0x48,0x8,0x0,0x0,
0x78,0x8,0x0,0x0,0xc8,0x8,0x0,0x0,
0xf0,0x8,0x0,0x0,0x30,0x9,0x0,0x0,
0x48,0x9,0x0,0x0,0x58,0x9,0x0,0x0,
0x88,0x9,0x0,0x0,0xa0,0x9,0x0,0x0,
0xd0,0x9,0x0,0x0,0x0,0xa,0x0,0x0,
0x18,0xa,0x0,0x0,0x28,0xa,0x0,0x0,
0x58,0xa,0x0,0x0,0x88,0xa,0x0,0x0,
0xb8,0xa,0x0,0x0,0xc8,0xa,0x0,0x0,
0xe0,0xa,0x0,0x0,0x0,0xb,0x0,0x0,
0x28,0xb,0x0,0x0,0x48,0xb,0x0,0x0,
0x70,0xb,0x0,0x0,0xa0,0xb,0x0,0x0,
0xc0,0xb,0x0,0x0,0x8,0xc,0x0,0x0,
0x18,0xc,0x0,0x0,0x38,0xc,0x0,0x0,
0x68,0xc,0x0,0x0,0x98,0xc,0x0,0x0,
0xb0,0xc,0x0,0x0,0xe0,0xc,0x0,0x0,
0x20,0xd,0x0,0x0,0x38,0xd,0x0,0x0,
0x68,0xd,0x0,0x0,0x98,0xd,0x0,0x0,
0xc8,0xd,0x0,0x0,0xd8,0xd,0x0,0x0,
0xf8,0xd,0x0,0x0,0x18,0xe,0x0,0x0,
0x38,0xe,0x0,0x0,0x50,0xe,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x17,0x0,0x0,0x0,0x6f,0x0,0x72,0x0,
0x67,0x0,0x2e,0x0,0x6b,0x0,0x64,0x0,
0x65,0x0,0x2e,0x0,0x70,0x0,0x6c,0x0,
0x61,0x0,0x73,0x0,0x6d,0x0,0x61,0x0,
0x2e,0x0,0x70,0x0,0x6c,0x0,0x61,0x0,
0x73,0x0,0x6d,0x0,0x6f,0x0,0x69,0x0,
0x64,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x50,0x0,0x6c,0x0,
0x61,0x0,0x73,0x0,0x6d,0x0,0x61,0x0,
0x43,0x0,0x6f,0x0,0x72,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x6f,0x0,0x72,0x0,
0x67,0x0,0x2e,0x0,0x6b,0x0,0x64,0x0,
0x65,0x0,0x2e,0x0,0x70,0x0,0x6c,0x0,
0x61,0x0,0x73,0x0,0x6d,0x0,0x61,0x0,
0x2e,0x0,0x63,0x0,0x6f,0x0,0x72,0x0,
0x65,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x4b,0x0,0x69,0x0,
0x72,0x0,0x69,0x0,0x67,0x0,0x61,0x0,
0x6d,0x0,0x69,0x0,0x0,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x6f,0x0,0x72,0x0,
0x67,0x0,0x2e,0x0,0x6b,0x0,0x64,0x0,
0x65,0x0,0x2e,0x0,0x6b,0x0,0x69,0x0,
0x72,0x0,0x69,0x0,0x67,0x0,0x61,0x0,
0x6d,0x0,0x69,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x4d,0x0,0x6f,0x0,
0x6e,0x0,0x69,0x0,0x74,0x0,0x6f,0x0,
0x72,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x6f,0x0,0x72,0x0,
0x67,0x0,0x2e,0x0,0x6b,0x0,0x64,0x0,
0x65,0x0,0x2e,0x0,0x70,0x0,0x69,0x0,
0x70,0x0,0x65,0x0,0x77,0x0,0x69,0x0,
0x72,0x0,0x65,0x0,0x2e,0x0,0x6d,0x0,
0x6f,0x0,0x6e,0x0,0x69,0x0,0x74,0x0,
0x6f,0x0,0x72,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x50,0x0,0x6c,0x0,
0x61,0x0,0x73,0x0,0x6d,0x0,0x6f,0x0,
0x69,0x0,0x64,0x0,0x49,0x0,0x74,0x0,
0x65,0x0,0x6d,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x72,0x0,0x6f,0x0,
0x6f,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x73,0x0,0x77,0x0,
0x69,0x0,0x74,0x0,0x63,0x0,0x68,0x0,
0x57,0x0,0x69,0x0,0x64,0x0,0x74,0x0,
0x68,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1a,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x73,0x0,0x77,0x0,0x69,0x0,
0x74,0x0,0x63,0x0,0x68,0x0,0x57,0x0,
0x69,0x0,0x64,0x0,0x74,0x0,0x68,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x73,0x0,0x77,0x0,
0x69,0x0,0x74,0x0,0x63,0x0,0x68,0x0,
0x48,0x0,0x65,0x0,0x69,0x0,0x67,0x0,
0x68,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0x1b,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x73,0x0,0x77,0x0,0x69,0x0,
0x74,0x0,0x63,0x0,0x68,0x0,0x48,0x0,
0x65,0x0,0x69,0x0,0x67,0x0,0x68,0x0,
0x74,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x69,0x0,0x6e,0x0,
0x45,0x0,0x6d,0x0,0x62,0x0,0x65,0x0,
0x64,0x0,0x64,0x0,0x65,0x0,0x64,0x0,
0x43,0x0,0x6f,0x0,0x6e,0x0,0x74,0x0,
0x61,0x0,0x69,0x0,0x6e,0x0,0x6d,0x0,
0x65,0x0,0x6e,0x0,0x74,0x0,0x0,0x0,
0x24,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x69,0x0,0x6e,0x0,0x45,0x0,
0x6d,0x0,0x62,0x0,0x65,0x0,0x64,0x0,
0x64,0x0,0x65,0x0,0x64,0x0,0x43,0x0,
0x6f,0x0,0x6e,0x0,0x74,0x0,0x61,0x0,
0x69,0x0,0x6e,0x0,0x6d,0x0,0x65,0x0,
0x6e,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x74,0x0,0x6f,0x0,
0x6f,0x0,0x6c,0x0,0x54,0x0,0x69,0x0,
0x70,0x0,0x53,0x0,0x75,0x0,0x62,0x0,
0x54,0x0,0x65,0x0,0x78,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1d,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x74,0x0,0x6f,0x0,0x6f,0x0,
0x6c,0x0,0x54,0x0,0x69,0x0,0x70,0x0,
0x53,0x0,0x75,0x0,0x62,0x0,0x54,0x0,
0x65,0x0,0x78,0x0,0x74,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x50,0x0,0x6c,0x0,
0x61,0x0,0x73,0x0,0x6d,0x0,0x6f,0x0,
0x69,0x0,0x64,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x69,0x0,0x63,0x0,
0x6f,0x0,0x6e,0x0,0x0,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x69,0x0,0x63,0x0,0x6f,0x0,
0x6e,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x73,0x0,0x74,0x0,
0x61,0x0,0x74,0x0,0x75,0x0,0x73,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x73,0x0,0x74,0x0,0x61,0x0,
0x74,0x0,0x75,0x0,0x73,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x4d,0x0,0x6f,0x0,
0x6e,0x0,0x69,0x0,0x74,0x0,0x6f,0x0,
0x72,0x0,0x2e,0x0,0x4d,0x0,0x65,0x0,
0x64,0x0,0x69,0x0,0x61,0x0,0x4d,0x0,
0x6f,0x0,0x6e,0x0,0x69,0x0,0x74,0x0,
0x6f,0x0,0x72,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x6d,0x0,0x6f,0x0,
0x6e,0x0,0x69,0x0,0x74,0x0,0x6f,0x0,
0x72,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x72,0x0,0x6f,0x0,
0x6c,0x0,0x65,0x0,0x0,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x72,0x0,0x6f,0x0,0x6c,0x0,
0x65,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x12,0x0,0x0,0x0,0x46,0x0,0x75,0x0,
0x6c,0x0,0x6c,0x0,0x52,0x0,0x65,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x65,0x0,0x6e,0x0,0x74,0x0,0x61,0x0,
0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x12,0x0,0x0,0x0,0x66,0x0,0x75,0x0,
0x6c,0x0,0x6c,0x0,0x52,0x0,0x65,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x65,0x0,0x6e,0x0,0x74,0x0,0x61,0x0,
0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x55,0x0,0x6e,0x0,
0x69,0x0,0x74,0x0,0x73,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x67,0x0,0x72,0x0,
0x69,0x0,0x64,0x0,0x55,0x0,0x6e,0x0,
0x69,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x63,0x0,0x6f,0x0,
0x6e,0x0,0x74,0x0,0x61,0x0,0x69,0x0,
0x6e,0x0,0x6d,0x0,0x65,0x0,0x6e,0x0,
0x74,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xf,0x0,0x0,0x0,0x63,0x0,0x6f,0x0,
0x6e,0x0,0x74,0x0,0x61,0x0,0x69,0x0,
0x6e,0x0,0x6d,0x0,0x65,0x0,0x6e,0x0,
0x74,0x0,0x54,0x0,0x79,0x0,0x70,0x0,
0x65,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x43,0x0,0x6f,0x0,
0x6e,0x0,0x74,0x0,0x61,0x0,0x69,0x0,
0x6e,0x0,0x6d,0x0,0x65,0x0,0x6e,0x0,
0x74,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x43,0x0,0x75,0x0,
0x73,0x0,0x74,0x0,0x6f,0x0,0x6d,0x0,
0x45,0x0,0x6d,0x0,0x62,0x0,0x65,0x0,
0x64,0x0,0x64,0x0,0x65,0x0,0x64,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x12,0x0,0x0,0x0,0x64,0x0,0x65,0x0,
0x74,0x0,0x65,0x0,0x63,0x0,0x74,0x0,
0x69,0x0,0x6f,0x0,0x6e,0x0,0x41,0x0,
0x76,0x0,0x61,0x0,0x69,0x0,0x6c,0x0,
0x61,0x0,0x62,0x0,0x6c,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x40,0x0,0x69,0x0,
0x6e,0x0,0x66,0x0,0x6f,0x0,0x3a,0x0,
0x74,0x0,0x6f,0x0,0x6f,0x0,0x6c,0x0,
0x74,0x0,0x69,0x0,0x70,0x0,0x0,0x0,
0x1f,0x0,0x0,0x0,0x43,0x0,0x61,0x0,
0x6d,0x0,0x65,0x0,0x72,0x0,0x61,0x0,
0x20,0x0,0x69,0x0,0x6e,0x0,0x64,0x0,
0x69,0x0,0x63,0x0,0x61,0x0,0x74,0x0,
0x6f,0x0,0x72,0x0,0x20,0x0,0x69,0x0,
0x73,0x0,0x20,0x0,0x75,0x0,0x6e,0x0,
0x61,0x0,0x76,0x0,0x61,0x0,0x69,0x0,
0x6c,0x0,0x61,0x0,0x62,0x0,0x6c,0x0,
0x65,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x69,0x0,0x31,0x0,
0x38,0x0,0x6e,0x0,0x63,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x72,0x0,0x75,0x0,
0x6e,0x0,0x6e,0x0,0x69,0x0,0x6e,0x0,
0x67,0x0,0x43,0x0,0x6f,0x0,0x75,0x0,
0x6e,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0x12,0x0,0x0,0x0,0x41,0x0,0x20,0x0,
0x63,0x0,0x61,0x0,0x6d,0x0,0x65,0x0,
0x72,0x0,0x61,0x0,0x20,0x0,0x69,0x0,
0x73,0x0,0x20,0x0,0x69,0x0,0x6e,0x0,
0x20,0x0,0x75,0x0,0x73,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x25,0x0,0x31,0x0,
0x20,0x0,0x63,0x0,0x61,0x0,0x6d,0x0,
0x65,0x0,0x72,0x0,0x61,0x0,0x73,0x0,
0x20,0x0,0x61,0x0,0x72,0x0,0x65,0x0,
0x20,0x0,0x69,0x0,0x6e,0x0,0x20,0x0,
0x75,0x0,0x73,0x0,0x65,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x69,0x0,0x31,0x0,
0x38,0x0,0x6e,0x0,0x63,0x0,0x70,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x4e,0x0,0x6f,0x0,
0x20,0x0,0x63,0x0,0x61,0x0,0x6d,0x0,
0x65,0x0,0x72,0x0,0x61,0x0,0x20,0x0,
0x69,0x0,0x73,0x0,0x20,0x0,0x69,0x0,
0x6e,0x0,0x20,0x0,0x75,0x0,0x73,0x0,
0x65,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1b,0x0,0x0,0x0,0x6e,0x0,0x65,0x0,
0x74,0x0,0x77,0x0,0x6f,0x0,0x72,0x0,
0x6b,0x0,0x2d,0x0,0x64,0x0,0x69,0x0,
0x73,0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,
0x6e,0x0,0x65,0x0,0x63,0x0,0x74,0x0,
0x2d,0x0,0x73,0x0,0x79,0x0,0x6d,0x0,
0x62,0x0,0x6f,0x0,0x6c,0x0,0x69,0x0,
0x63,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x69,0x0,0x64,0x0,
0x6c,0x0,0x65,0x0,0x43,0x0,0x6f,0x0,
0x75,0x0,0x6e,0x0,0x74,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x63,0x0,0x61,0x0,
0x6d,0x0,0x65,0x0,0x72,0x0,0x61,0x0,
0x2d,0x0,0x72,0x0,0x65,0x0,0x61,0x0,
0x64,0x0,0x79,0x0,0x2d,0x0,0x73,0x0,
0x79,0x0,0x6d,0x0,0x62,0x0,0x6f,0x0,
0x6c,0x0,0x69,0x0,0x63,0x0,0x0,0x0,
0x12,0x0,0x0,0x0,0x63,0x0,0x61,0x0,
0x6d,0x0,0x65,0x0,0x72,0x0,0x61,0x0,
0x2d,0x0,0x6f,0x0,0x6e,0x0,0x2d,0x0,
0x73,0x0,0x79,0x0,0x6d,0x0,0x62,0x0,
0x6f,0x0,0x6c,0x0,0x69,0x0,0x63,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x63,0x0,0x61,0x0,
0x6d,0x0,0x65,0x0,0x72,0x0,0x61,0x0,
0x2d,0x0,0x6f,0x0,0x66,0x0,0x66,0x0,
0x2d,0x0,0x73,0x0,0x79,0x0,0x6d,0x0,
0x62,0x0,0x6f,0x0,0x6c,0x0,0x69,0x0,
0x63,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x54,0x0,0x79,0x0,
0x70,0x0,0x65,0x0,0x73,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x41,0x0,0x63,0x0,
0x74,0x0,0x69,0x0,0x76,0x0,0x65,0x0,
0x53,0x0,0x74,0x0,0x61,0x0,0x74,0x0,
0x75,0x0,0x73,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x48,0x0,0x69,0x0,
0x64,0x0,0x64,0x0,0x65,0x0,0x6e,0x0,
0x53,0x0,0x74,0x0,0x61,0x0,0x74,0x0,
0x75,0x0,0x73,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x50,0x0,0x61,0x0,
0x73,0x0,0x73,0x0,0x69,0x0,0x76,0x0,
0x65,0x0,0x53,0x0,0x74,0x0,0x61,0x0,
0x74,0x0,0x75,0x0,0x73,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x4d,0x0,0x65,0x0,
0x64,0x0,0x69,0x0,0x61,0x0,0x52,0x0,
0x6f,0x0,0x6c,0x0,0x65,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x43,0x0,0x61,0x0,
0x6d,0x0,0x65,0x0,0x72,0x0,0x61,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x74,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x9,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x1,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x10,0x0,0xff,0xff,0x0,0x0,
0x1,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0xc,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x1,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x5,0x0,0x0,0x0,
0xd,0x0,0x10,0x0,0xff,0xff,0x0,0x0,
0x1,0x0,0x0,0x0,0x8,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0xe,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x84,0x0,0x0,0x0,
0x8c,0x1,0x0,0x0,0x14,0x2,0x0,0x0,
0x84,0x2,0x0,0x0,0x9,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x1,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x60,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x60,0x0,0x0,0x0,0x60,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x60,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x8,0x1,0x0,0x0,
0x10,0x0,0x10,0x0,0x11,0x0,0x50,0x0,
0x8,0x1,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x1,0x0,0x0,0x0,0x0,0x0,0x0,
0xf,0x0,0x0,0x0,0x3,0x0,0x0,0x20,
0x16,0x0,0x50,0x0,0x1d,0x0,0x0,0x0,
0x0,0x0,0x8,0x0,0x3,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x30,0x0,0x50,0x0,
0x30,0x0,0x90,0x1,0x11,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x3,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x50,0x0,
0x18,0x0,0x50,0x1,0xf,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x16,0x0,0x30,0x1,
0x16,0x0,0xa0,0x2,0xd,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x14,0x0,0x50,0x0,
0x14,0x0,0x30,0x1,0xb,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x13,0x0,0x50,0x0,
0x13,0x0,0x20,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x8,0x0,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x2b,0x0,0x50,0x0,
0x2b,0x0,0x50,0x0,0x13,0x0,0x0,0x0,
0x0,0x0,0x9,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x0,0x50,0x0,
0x20,0x0,0xe0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x2,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x84,0x0,0x0,0x0,
0x20,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x84,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x84,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x16,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x5,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x29,0x0,0xe0,0x0,0x29,0x0,0x60,0x1,
0x14,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x4,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x20,0x0,0xe0,0x0,0x20,0x0,0x40,0x1,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x19,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x1,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6c,0x0,0x0,0x0,
0x2b,0x0,0x50,0x0,0x2c,0x0,0x90,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1a,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x6,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x2d,0x0,0x90,0x0,0x2d,0x0,0xf0,0x0,
0x0,0x0,0x0,0x0,0x1c,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x30,0x0,0x90,0x1,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0
};
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[] = {
{ 0, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<int>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for switchWidth at line 19, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_2, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_2 = nullptr;
double v2_4;
double v2_8;
int v2_10;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->loadSingletonLookup(1, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initLoadSingletonLookup(1, 5);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<int *>(argv[0]) = int();
}
return;
}
}
{
}
// generate_GetLookup
{
int retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
while (!aotContext->getObjectLookup(2, s.v2_2, &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initGetObjectLookup(2, s.v2_2);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<int *>(argv[0]) = int();
}
return;
}
}
s.v2_4 = double(std::move(retrieved));
}
{
}
// generate_StoreReg
{
}
// generate_LoadInt
s.v2_8 = double(12);
{
}
// generate_Mul
s.v2_10 = QJSNumberCoercion::toInteger((s.v2_4 * s.v2_8));
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<int *>(argv[0]) = s.v2_10;
}
return;
}
 },{ 1, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<int>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for switchHeight at line 20, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_2, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_2 = nullptr;
double v2_4;
double v2_8;
int v2_10;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->loadSingletonLookup(4, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initLoadSingletonLookup(4, 5);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<int *>(argv[0]) = int();
}
return;
}
}
{
}
// generate_GetLookup
{
int retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
while (!aotContext->getObjectLookup(5, s.v2_2, &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initGetObjectLookup(5, s.v2_2);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<int *>(argv[0]) = int();
}
return;
}
}
s.v2_4 = double(std::move(retrieved));
}
{
}
// generate_StoreReg
{
}
// generate_LoadInt
s.v2_8 = double(12);
{
}
// generate_Mul
s.v2_10 = QJSNumberCoercion::toInteger((s.v2_4 * s.v2_8));
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<int *>(argv[0]) = s.v2_10;
}
return;
}
 },{ 2, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<bool>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for inEmbeddedContainment at line 22, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
    aotContext->mark(v2_2, markStack);
    aotContext->mark(v2_4, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QObject *v2_2 = nullptr;
QVariant v2_4;
bool v2_14;
int v2_12;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadAttachedLookup(6, aotContext->qmlScopeObject, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadAttachedLookup(6, QQmlPrivate::AOTCompiledContext::InvalidStringId, aotContext->qmlScopeObject);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = bool();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(7, s.v2_0, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(7, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = bool();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
while (!aotContext->getObjectLookup(8, s.v2_2, &s.v2_4)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initGetObjectLookupAsVariant(8, s.v2_2);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = bool();
}
return;
}
}
{
}
// generate_StoreReg
{
}
{
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
while (!aotContext->getEnumLookup(11, &s.v2_12)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
aotContext->initGetEnumLookup(11, []() { static const auto t = QMetaType::fromName("Plasma::Containment*"); return t; }().metaObject(), "Type", "CustomEmbedded");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = bool();
}
return;
}
}
{
}
// generate_CmpStrictEqual
s.v2_14 = QJSPrimitiveValue(s.v2_12).strictlyEquals(aotContext->engine->fromVariant<QJSPrimitiveValue>(s.v2_4));
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = s.v2_14;
}
return;
}
 },{ 4, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<QString>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for icon at line 32, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
    aotContext->mark(v2_10, markStack);
    aotContext->mark(v2_21, markStack);
    aotContext->mark(v2_35, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QObject *v2_10 = nullptr;
QObject *v2_21 = nullptr;
QObject *v2_35 = nullptr;
QString v2_32;
QString v2_46;
QString v2_49;
QString v2_7;
bool v2_17;
bool v2_28;
bool v2_2;
bool v2_42;
bool v2_4;
int v2_12;
int v2_16;
int v2_23;
int v2_27;
int v2_37;
int v2_41;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(21, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(21);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(22, s.v2_0, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(22, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_UNot
s.v2_4 = !s.v2_2;
{
}
// generate_JumpFalse
if (!s.v2_4) {
    goto label_0;
}
{
}
// generate_LoadRuntimeString
s.v2_7 = QStringLiteral("network-disconnect-symbolic");
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = std::move(s.v2_7);
}
return;
label_0:;
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(12);
#endif
while (!aotContext->loadContextIdLookup(23, &s.v2_10)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(12);
#endif
aotContext->initLoadContextIdLookup(23);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
while (!aotContext->getObjectLookup(24, s.v2_10, &s.v2_12)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
aotContext->initGetObjectLookup(24, s.v2_10);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadZero
s.v2_16 = 0;
{
}
// generate_CmpGt
s.v2_17 = s.v2_12 > s.v2_16;
{
}
// generate_JumpFalse
if (!s.v2_17) {
    goto label_1;
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(23);
#endif
while (!aotContext->loadContextIdLookup(25, &s.v2_21)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(23);
#endif
aotContext->initLoadContextIdLookup(25);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(25);
#endif
while (!aotContext->getObjectLookup(26, s.v2_21, &s.v2_23)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(25);
#endif
aotContext->initGetObjectLookup(26, s.v2_21);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadZero
s.v2_27 = 0;
{
}
// generate_CmpStrictEqual
s.v2_28 = s.v2_23 == s.v2_27;
{
}
// generate_JumpFalse
if (!s.v2_28) {
    goto label_1;
}
{
}
// generate_LoadRuntimeString
s.v2_32 = QStringLiteral("camera-ready-symbolic");
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = std::move(s.v2_32);
}
return;
label_1:;
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(37);
#endif
while (!aotContext->loadContextIdLookup(27, &s.v2_35)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(37);
#endif
aotContext->initLoadContextIdLookup(27);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(39);
#endif
while (!aotContext->getObjectLookup(28, s.v2_35, &s.v2_37)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(39);
#endif
aotContext->initGetObjectLookup(28, s.v2_35);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadZero
s.v2_41 = 0;
{
}
// generate_CmpGt
s.v2_42 = s.v2_37 > s.v2_41;
{
}
// generate_JumpFalse
if (!s.v2_42) {
    goto label_2;
}
{
}
// generate_LoadRuntimeString
s.v2_46 = QStringLiteral("camera-on-symbolic");
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = std::move(s.v2_46);
}
return;
label_2:;
// generate_LoadRuntimeString
s.v2_49 = QStringLiteral("camera-off-symbolic");
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = std::move(s.v2_49);
}
return;
}
 },{ 5, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("Plasma::Types::ItemStatus"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for status at line 41, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
    aotContext->mark(v2_11, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QObject *v2_11 = nullptr;
bool v2_18;
bool v2_30;
bool v2_7;
int c2_48;
int v2_13;
int v2_17;
int v2_26;
int v2_2;
int v2_38;
int v2_46;
int v2_6;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(29, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(29);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("Plasma::Types::ItemStatus"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(30, s.v2_0, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(30, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("Plasma::Types::ItemStatus"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadZero
s.v2_6 = 0;
{
}
// generate_CmpGt
s.v2_7 = s.v2_2 > s.v2_6;
{
}
// generate_JumpTrue
if (s.v2_7) {
    goto label_0;
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(13);
#endif
while (!aotContext->loadContextIdLookup(31, &s.v2_11)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(13);
#endif
aotContext->initLoadContextIdLookup(31);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("Plasma::Types::ItemStatus"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(15);
#endif
while (!aotContext->getObjectLookup(32, s.v2_11, &s.v2_13)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(15);
#endif
aotContext->initGetObjectLookup(32, s.v2_11);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("Plasma::Types::ItemStatus"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadZero
s.v2_17 = 0;
{
}
// generate_CmpGt
s.v2_18 = s.v2_13 > s.v2_17;
{
}
// generate_JumpFalse
if (!s.v2_18) {
    goto label_1;
}
{
}
label_0:;
{
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(28);
#endif
while (!aotContext->getEnumLookup(35, &s.v2_26)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(28);
#endif
aotContext->initGetEnumLookup(35, []() { static const auto t = QMetaType::fromName("Plasma::Types*"); return t; }().metaObject(), "ItemStatus", "ActiveStatus");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("Plasma::Types::ItemStatus"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_Jump
{
s.c2_48 = s.v2_26;
    goto label_2;
}
label_1:;
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(32);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(36, &s.v2_30)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(32);
#endif
aotContext->initLoadScopeObjectPropertyLookup(36);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("Plasma::Types::ItemStatus"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_JumpFalse
if (!s.v2_30) {
    goto label_3;
}
{
}
{
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(40);
#endif
while (!aotContext->getEnumLookup(39, &s.v2_38)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(40);
#endif
aotContext->initGetEnumLookup(39, []() { static const auto t = QMetaType::fromName("Plasma::Types*"); return t; }().metaObject(), "ItemStatus", "HiddenStatus");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("Plasma::Types::ItemStatus"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_Jump
{
s.c2_48 = s.v2_38;
    goto label_2;
}
label_3:;
{
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(48);
#endif
while (!aotContext->getEnumLookup(42, &s.v2_46)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(48);
#endif
aotContext->initGetEnumLookup(42, []() { static const auto t = QMetaType::fromName("Plasma::Types*"); return t; }().metaObject(), "ItemStatus", "PassiveStatus");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("Plasma::Types::ItemStatus"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
s.c2_48 = s.v2_46;
}
label_2:;
{
}
// generate_Ret
if (argv[0]) {
    const QMetaType returnType = QMetaType::fromType<int>();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], &s.c2_48);
}
return;
}
 },{ 6, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("MediaRole::Role"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for role at line 45, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
int v2_4;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
while (!aotContext->getEnumLookup(45, &s.v2_4)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initGetEnumLookup(45, []() { static const auto t = QMetaType::fromName("MediaRole"); return t; }().metaObject(), "Role", "Camera");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("MediaRole::Role"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    const QMetaType returnType = QMetaType::fromType<int>();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], &s.v2_4);
}
return;
}
 },{ 0, 0, nullptr, nullptr }};
}
}
