/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<applicationintegration.h>)
#  include <applicationintegration.h>
#endif
#if __has_include(<clipboardmenu.h>)
#  include <clipboardmenu.h>
#endif
#if __has_include(<timezonemodel.h>)
#  include <timezonemodel.h>
#endif
#if __has_include(<timezonesi18n.h>)
#  include <timezonesi18n.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_plasma_private_digitalclock()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<ApplicationIntegration>("org.kde.plasma.private.digitalclock", 1);
    qmlRegisterTypesAndRevisions<ClipboardMenu>("org.kde.plasma.private.digitalclock", 1);
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    QMetaType::fromType<QAbstractProxyModel *>().id();
    QMetaType::fromType<QSortFilterProxyModel *>().id();
    qmlRegisterTypesAndRevisions<TimeZoneFilterProxy>("org.kde.plasma.private.digitalclock", 1);
    qmlRegisterTypesAndRevisions<TimeZoneModel>("org.kde.plasma.private.digitalclock", 1);
    qmlRegisterTypesAndRevisions<TimeZoneUtils>("org.kde.plasma.private.digitalclock", 1);
    qmlRegisterTypesAndRevisions<TimeZonesI18n>("org.kde.plasma.private.digitalclock", 1);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.plasma.private.digitalclock", 1, 0);
}

static const QQmlModuleRegistration orgkdeplasmaprivatedigitalclockRegistration("org.kde.plasma.private.digitalclock", qml_register_types_org_kde_plasma_private_digitalclock);
