/****************************************************************************
** Meta object code from reading C++ file 'panelview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-workspace-6.7.1/shell/panelview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'panelview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9PanelViewE_t {};
} // unnamed namespace

template <> constexpr inline auto PanelView::qt_create_metaobjectdata<qt_meta_tag_ZN9PanelViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PanelView",
        "alignmentChanged",
        "",
        "offsetChanged",
        "screenGeometryChanged",
        "thicknessChanged",
        "lengthChanged",
        "maximumLengthChanged",
        "minimumLengthChanged",
        "backgroundHintsChanged",
        "enabledBordersChanged",
        "floatingChanged",
        "floatingAppletsChanged",
        "minThicknessChanged",
        "unsupportedConfigurationChanged",
        "geometryChanged",
        "relativeConfigRectChanged",
        "screenToFollowChanged",
        "QScreen*",
        "screen",
        "visibilityModeChanged",
        "opacityModeChanged",
        "lengthModeChanged",
        "adaptiveOpacityEnabledChanged",
        "userConfiguringChanged",
        "showConfigurationInterface",
        "Plasma::Applet*",
        "applet",
        "setAutoHideEnabled",
        "autoHideEnabled",
        "showTemporarily",
        "refreshContainment",
        "refreshStatus",
        "Plasma::Types::ItemStatus",
        "restoreAutoHide",
        "screenDestroyed",
        "adaptToScreen",
        "handleQmlStatusChange",
        "QQmlComponent::Status",
        "status",
        "updateMask",
        "updateEnabledBorders",
        "updatePadding",
        "updateFloating",
        "updateFloatingAnimationDuration",
        "updateShadows",
        "updateTouchingWindow",
        "fileFromPackage",
        "key",
        "fileName",
        "maximize",
        "geometryByDistance",
        "QRect",
        "distance",
        "dogdeGeometryByDistance",
        "fixUnsupportedConfiguration",
        "clonePanelTo",
        "Plasma::Types::Location",
        "location",
        "alignment",
        "Qt::Alignment",
        "offset",
        "thickness",
        "length",
        "maximumLength",
        "minimumLength",
        "backgroundHints",
        "Plasma::Types::BackgroundHints",
        "enabledBorders",
        "KSvg::FrameSvg::EnabledBorders",
        "screenToFollow",
        "visibilityMode",
        "VisibilityMode",
        "opacityMode",
        "OpacityMode",
        "lengthMode",
        "LengthMode",
        "adaptiveOpacityEnabled",
        "floating",
        "minThickness",
        "relativeConfigRect",
        "userConfiguring",
        "unsupportedConfiguration",
        "unsupportedConfigurationDescription",
        "floatingApplets",
        "NormalPanel",
        "AutoHide",
        "DodgeWindows",
        "WindowsGoBelow",
        "Adaptive",
        "Opaque",
        "Translucent",
        "FillAvailable",
        "FitContent",
        "Custom"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'alignmentChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'offsetChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'screenGeometryChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'thicknessChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lengthChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maximumLengthChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minimumLengthChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'backgroundHintsChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledBordersChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'floatingChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'floatingAppletsChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minThicknessChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'unsupportedConfigurationChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'geometryChanged'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'relativeConfigRectChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'screenToFollowChanged'
        QtMocHelpers::SignalData<void(QScreen *)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Signal 'visibilityModeChanged'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'opacityModeChanged'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lengthModeChanged'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'adaptiveOpacityEnabledChanged'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'userConfiguringChanged'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showConfigurationInterface'
        QtMocHelpers::SlotData<void(Plasma::Applet *)>(25, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'setAutoHideEnabled'
        QtMocHelpers::SlotData<void(bool)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 29 },
        }}),
        // Slot 'showTemporarily'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'refreshContainment'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'refreshStatus'
        QtMocHelpers::SlotData<void(Plasma::Types::ItemStatus)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 33, 2 },
        }}),
        // Slot 'restoreAutoHide'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'screenDestroyed'
        QtMocHelpers::SlotData<void(QObject *)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 19 },
        }}),
        // Slot 'adaptToScreen'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleQmlStatusChange'
        QtMocHelpers::SlotData<void(QQmlComponent::Status)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 38, 39 },
        }}),
        // Slot 'updateMask'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateEnabledBorders'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updatePadding'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateFloating'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateFloatingAnimationDuration'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateShadows'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateTouchingWindow'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'fileFromPackage'
        QtMocHelpers::MethodData<QString(const QString &, const QString &)>(47, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 48 }, { QMetaType::QString, 49 },
        }}),
        // Method 'maximize'
        QtMocHelpers::MethodData<void()>(50, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'geometryByDistance'
        QtMocHelpers::MethodData<QRect(int) const>(51, 2, QMC::AccessPublic, 0x80000000 | 52, {{
            { QMetaType::Int, 53 },
        }}),
        // Method 'dogdeGeometryByDistance'
        QtMocHelpers::MethodData<QRect(int) const>(54, 2, QMC::AccessPublic, 0x80000000 | 52, {{
            { QMetaType::Int, 53 },
        }}),
        // Method 'fixUnsupportedConfiguration'
        QtMocHelpers::MethodData<void()>(55, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'clonePanelTo'
        QtMocHelpers::MethodData<void(Plasma::Types::Location, QScreen *)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 57, 58 }, { 0x80000000 | 18, 19 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'alignment'
        QtMocHelpers::PropertyData<Qt::Alignment>(59, 0x80000000 | 60, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'offset'
        QtMocHelpers::PropertyData<int>(61, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'thickness'
        QtMocHelpers::PropertyData<int>(62, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'length'
        QtMocHelpers::PropertyData<int>(63, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'maximumLength'
        QtMocHelpers::PropertyData<int>(64, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'minimumLength'
        QtMocHelpers::PropertyData<int>(65, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'backgroundHints'
        QtMocHelpers::PropertyData<Plasma::Types::BackgroundHints>(66, 0x80000000 | 67, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'enabledBorders'
        QtMocHelpers::PropertyData<KSvg::FrameSvg::EnabledBorders>(68, 0x80000000 | 69, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 8),
        // property 'screenToFollow'
        QtMocHelpers::PropertyData<QScreen*>(70, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 15),
        // property 'visibilityMode'
        QtMocHelpers::PropertyData<enum VisibilityMode>(71, 0x80000000 | 72, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 16),
        // property 'opacityMode'
        QtMocHelpers::PropertyData<enum OpacityMode>(73, 0x80000000 | 74, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 17),
        // property 'lengthMode'
        QtMocHelpers::PropertyData<enum LengthMode>(75, 0x80000000 | 76, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 18),
        // property 'adaptiveOpacityEnabled'
        QtMocHelpers::PropertyData<bool>(77, QMetaType::Bool, QMC::DefaultPropertyFlags, 19),
        // property 'floating'
        QtMocHelpers::PropertyData<bool>(78, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'minThickness'
        QtMocHelpers::PropertyData<int>(79, QMetaType::Int, QMC::DefaultPropertyFlags, 11),
        // property 'relativeConfigRect'
        QtMocHelpers::PropertyData<QRect>(80, 0x80000000 | 52, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 14),
        // property 'userConfiguring'
        QtMocHelpers::PropertyData<bool>(81, QMetaType::Bool, QMC::DefaultPropertyFlags, 20),
        // property 'unsupportedConfiguration'
        QtMocHelpers::PropertyData<bool>(82, QMetaType::Bool, QMC::DefaultPropertyFlags, 12),
        // property 'unsupportedConfigurationDescription'
        QtMocHelpers::PropertyData<QString>(83, QMetaType::QString, QMC::DefaultPropertyFlags, 12),
        // property 'floatingApplets'
        QtMocHelpers::PropertyData<bool>(84, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'VisibilityMode'
        QtMocHelpers::EnumData<enum VisibilityMode>(72, 72, QMC::EnumFlags{}).add({
            {   85, VisibilityMode::NormalPanel },
            {   86, VisibilityMode::AutoHide },
            {   87, VisibilityMode::DodgeWindows },
            {   88, VisibilityMode::WindowsGoBelow },
        }),
        // enum 'OpacityMode'
        QtMocHelpers::EnumData<enum OpacityMode>(74, 74, QMC::EnumFlags{}).add({
            {   89, OpacityMode::Adaptive },
            {   90, OpacityMode::Opaque },
            {   91, OpacityMode::Translucent },
        }),
        // enum 'LengthMode'
        QtMocHelpers::EnumData<enum LengthMode>(76, 76, QMC::EnumFlags{}).add({
            {   92, LengthMode::FillAvailable },
            {   93, LengthMode::FitContent },
            {   94, LengthMode::Custom },
        }),
    };
    return QtMocHelpers::metaObjectData<PanelView, qt_meta_tag_ZN9PanelViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN9PanelViewE[] = {
    QMetaObject::SuperData::link<Plasma::Types::staticMetaObject>(),
    QMetaObject::SuperData::link<KSvg::FrameSvg::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject PanelView::staticMetaObject = { {
    QMetaObject::SuperData::link<PlasmaQuick::ContainmentView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9PanelViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9PanelViewE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN9PanelViewE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9PanelViewE_t>.metaTypes,
    nullptr
} };

void PanelView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PanelView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->alignmentChanged(); break;
        case 1: _t->offsetChanged(); break;
        case 2: _t->screenGeometryChanged(); break;
        case 3: _t->thicknessChanged(); break;
        case 4: _t->lengthChanged(); break;
        case 5: _t->maximumLengthChanged(); break;
        case 6: _t->minimumLengthChanged(); break;
        case 7: _t->backgroundHintsChanged(); break;
        case 8: _t->enabledBordersChanged(); break;
        case 9: _t->floatingChanged(); break;
        case 10: _t->floatingAppletsChanged(); break;
        case 11: _t->minThicknessChanged(); break;
        case 12: _t->unsupportedConfigurationChanged(); break;
        case 13: _t->geometryChanged(); break;
        case 14: _t->relativeConfigRectChanged(); break;
        case 15: _t->screenToFollowChanged((*reinterpret_cast<std::add_pointer_t<QScreen*>>(_a[1]))); break;
        case 16: _t->visibilityModeChanged(); break;
        case 17: _t->opacityModeChanged(); break;
        case 18: _t->lengthModeChanged(); break;
        case 19: _t->adaptiveOpacityEnabledChanged(); break;
        case 20: _t->userConfiguringChanged(); break;
        case 21: _t->showConfigurationInterface((*reinterpret_cast<std::add_pointer_t<Plasma::Applet*>>(_a[1]))); break;
        case 22: _t->setAutoHideEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 23: _t->showTemporarily(); break;
        case 24: _t->refreshContainment(); break;
        case 25: _t->refreshStatus((*reinterpret_cast<std::add_pointer_t<Plasma::Types::ItemStatus>>(_a[1]))); break;
        case 26: _t->restoreAutoHide(); break;
        case 27: _t->screenDestroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 28: _t->adaptToScreen(); break;
        case 29: _t->handleQmlStatusChange((*reinterpret_cast<std::add_pointer_t<QQmlComponent::Status>>(_a[1]))); break;
        case 30: _t->updateMask(); break;
        case 31: _t->updateEnabledBorders(); break;
        case 32: _t->updatePadding(); break;
        case 33: _t->updateFloating(); break;
        case 34: _t->updateFloatingAnimationDuration(); break;
        case 35: _t->updateShadows(); break;
        case 36: _t->updateTouchingWindow(); break;
        case 37: { QString _r = _t->fileFromPackage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 38: _t->maximize(); break;
        case 39: { QRect _r = _t->geometryByDistance((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QRect*>(_a[0]) = std::move(_r); }  break;
        case 40: { QRect _r = _t->dogdeGeometryByDistance((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QRect*>(_a[0]) = std::move(_r); }  break;
        case 41: _t->fixUnsupportedConfiguration(); break;
        case 42: _t->clonePanelTo((*reinterpret_cast<std::add_pointer_t<Plasma::Types::Location>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QScreen*>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QScreen* >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Plasma::Applet* >(); break;
            }
            break;
        case 42:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QScreen* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PanelView::*)()>(_a, &PanelView::alignmentChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelView::*)()>(_a, &PanelView::offsetChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelView::*)()>(_a, &PanelView::screenGeometryChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelView::*)()>(_a, &PanelView::thicknessChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelView::*)()>(_a, &PanelView::lengthChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelView::*)()>(_a, &PanelView::maximumLengthChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelView::*)()>(_a, &PanelView::minimumLengthChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelView::*)()>(_a, &PanelView::backgroundHintsChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelView::*)()>(_a, &PanelView::enabledBordersChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelView::*)()>(_a, &PanelView::floatingChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelView::*)()>(_a, &PanelView::floatingAppletsChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelView::*)()>(_a, &PanelView::minThicknessChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelView::*)()>(_a, &PanelView::unsupportedConfigurationChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelView::*)()>(_a, &PanelView::geometryChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelView::*)()>(_a, &PanelView::relativeConfigRectChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelView::*)(QScreen * )>(_a, &PanelView::screenToFollowChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelView::*)()>(_a, &PanelView::visibilityModeChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelView::*)()>(_a, &PanelView::opacityModeChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelView::*)()>(_a, &PanelView::lengthModeChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelView::*)()>(_a, &PanelView::adaptiveOpacityEnabledChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelView::*)()>(_a, &PanelView::userConfiguringChanged, 20))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 8:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QScreen* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<Qt::Alignment*>(_v) = _t->alignment(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->offset(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->thickness(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->length(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->maximumLength(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->minimumLength(); break;
        case 6: *reinterpret_cast<Plasma::Types::BackgroundHints*>(_v) = _t->backgroundHints(); break;
        case 7: *reinterpret_cast<KSvg::FrameSvg::EnabledBorders*>(_v) = _t->enabledBorders(); break;
        case 8: *reinterpret_cast<QScreen**>(_v) = _t->screenToFollow(); break;
        case 9: *reinterpret_cast<enum VisibilityMode*>(_v) = _t->visibilityMode(); break;
        case 10: *reinterpret_cast<enum OpacityMode*>(_v) = _t->opacityMode(); break;
        case 11: *reinterpret_cast<enum LengthMode*>(_v) = _t->lengthMode(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->adaptiveOpacityEnabled(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->floating(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->minThickness(); break;
        case 15: *reinterpret_cast<QRect*>(_v) = _t->relativeConfigRect(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isUserConfiguring(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->isUnsupportedConfiguration(); break;
        case 18: *reinterpret_cast<QString*>(_v) = _t->unsupportedConfigurationDescription(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->floatingApplets(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAlignment(*reinterpret_cast<Qt::Alignment*>(_v)); break;
        case 1: _t->setOffset(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setThickness(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setLength(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setMaximumLength(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setMinimumLength(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setBackgroundHints(*reinterpret_cast<Plasma::Types::BackgroundHints*>(_v)); break;
        case 8: _t->setScreenToFollow(*reinterpret_cast<QScreen**>(_v)); break;
        case 9: _t->setVisibilityMode(*reinterpret_cast<enum VisibilityMode*>(_v)); break;
        case 10: _t->setOpacityMode(*reinterpret_cast<enum OpacityMode*>(_v)); break;
        case 11: _t->setLengthMode(*reinterpret_cast<enum LengthMode*>(_v)); break;
        case 13: _t->setFloating(*reinterpret_cast<bool*>(_v)); break;
        case 19: _t->setFloatingApplets(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PanelView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PanelView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9PanelViewE_t>.strings))
        return static_cast<void*>(this);
    return PlasmaQuick::ContainmentView::qt_metacast(_clname);
}

int PanelView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PlasmaQuick::ContainmentView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 43)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 43;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 43)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 43;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void PanelView::alignmentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PanelView::offsetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PanelView::screenGeometryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PanelView::thicknessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void PanelView::lengthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void PanelView::maximumLengthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void PanelView::minimumLengthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void PanelView::backgroundHintsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void PanelView::enabledBordersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void PanelView::floatingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void PanelView::floatingAppletsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void PanelView::minThicknessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void PanelView::unsupportedConfigurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void PanelView::geometryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void PanelView::relativeConfigRectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void PanelView::screenToFollowChanged(QScreen * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void PanelView::visibilityModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void PanelView::opacityModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void PanelView::lengthModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void PanelView::adaptiveOpacityEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void PanelView::userConfiguringChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}
QT_WARNING_POP
