// This file is generated by kconfig_compiler_kf6 from lookandfeelautoswitcherstate.kcfg.
// All changes you do to this file will be lost.
#ifndef LOOKANDFEELAUTOSWITCHERSTATE_H
#define LOOKANDFEELAUTOSWITCHERSTATE_H

#include <qglobal.h>
#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class LookAndFeelAutoSwitcherState : public KConfigSkeleton
{
  public:

    LookAndFeelAutoSwitcherState( );
    ~LookAndFeelAutoSwitcherState() override;

    /**
      Set SerializedSchedule
    */
    void setSerializedSchedule( const QString & v )
    {
      if (!isSerializedScheduleImmutable())
        mSerializedSchedule = v;
    }

    /**
      Get SerializedSchedule
    */
    QString serializedSchedule() const
    {
      return mSerializedSchedule;
    }

    /**
      Is SerializedSchedule Immutable
    */
    bool isSerializedScheduleImmutable() const
    {
      return isImmutable( QStringLiteral( "SerializedSchedule" ) );
    }

  protected:

    // DarkLightCycle
    QString mSerializedSchedule;
};

#endif

