/****************************************************************************
** Meta object code from reading C++ file 'view.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-workspace-6.7.1/krunner/view.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'view.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4ViewE_t {};
} // unnamed namespace

template <> constexpr inline auto View::qt_create_metaobjectdata<qt_meta_tag_ZN4ViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "View",
        "QML.Element",
        "RunnerWindow",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "D-Bus Interface",
        "org.kde.krunner.App",
        "historyBehaviorChanged",
        "retainPriorSearchChanged",
        "pinnedChanged",
        "helpEnabledChanged",
        "activityChanged",
        "activity",
        "display",
        "toggleDisplay",
        "displaySingleRunner",
        "runnerName",
        "displayWithClipboardContents",
        "query",
        "term",
        "querySingleRunner",
        "loadConfig",
        "objectIncubated",
        "slotFocusWindowChanged",
        "pinned",
        "helpEnabled",
        "retainPriorSearch",
        "historyBehavior",
        "HistoryBehavior",
        "Disabled",
        "ImmediateCompletion",
        "CompletionSuggestion"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'historyBehaviorChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'retainPriorSearchChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pinnedChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'helpEnabledChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activityChanged'
        QtMocHelpers::SignalData<void(const QString &)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'display'
        QtMocHelpers::SlotData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleDisplay'
        QtMocHelpers::SlotData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'displaySingleRunner'
        QtMocHelpers::SlotData<void(const QString &)>(17, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 },
        }}),
        // Slot 'displayWithClipboardContents'
        QtMocHelpers::SlotData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'query'
        QtMocHelpers::SlotData<void(const QString &)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'querySingleRunner'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(22, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 21 },
        }}),
        // Slot 'loadConfig'
        QtMocHelpers::SlotData<void()>(23, 6, QMC::AccessProtected, QMetaType::Void),
        // Slot 'objectIncubated'
        QtMocHelpers::SlotData<void()>(24, 6, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotFocusWindowChanged'
        QtMocHelpers::SlotData<void()>(25, 6, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'pinned'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'helpEnabled'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'retainPriorSearch'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'historyBehavior'
        QtMocHelpers::PropertyData<enum HistoryBehavior>(29, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'HistoryBehavior'
        QtMocHelpers::EnumData<enum HistoryBehavior>(30, 30, QMC::EnumFlags{}).add({
            {   31, HistoryBehavior::Disabled },
            {   32, HistoryBehavior::ImmediateCompletion },
            {   33, HistoryBehavior::CompletionSuggestion },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<View, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject View::staticMetaObject = { {
    QMetaObject::SuperData::link<PlasmaQuick::PlasmaWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4ViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4ViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4ViewE_t>.metaTypes,
    nullptr
} };

void View::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<View *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->historyBehaviorChanged(); break;
        case 1: _t->retainPriorSearchChanged(); break;
        case 2: _t->pinnedChanged(); break;
        case 3: _t->helpEnabledChanged(); break;
        case 4: _t->activityChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->display(); break;
        case 6: _t->toggleDisplay(); break;
        case 7: _t->displaySingleRunner((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->displayWithClipboardContents(); break;
        case 9: _t->query((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->querySingleRunner((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 11: _t->loadConfig(); break;
        case 12: _t->objectIncubated(); break;
        case 13: _t->slotFocusWindowChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (View::*)()>(_a, &View::historyBehaviorChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (View::*)()>(_a, &View::retainPriorSearchChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (View::*)()>(_a, &View::pinnedChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (View::*)()>(_a, &View::helpEnabledChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (View::*)(const QString & )>(_a, &View::activityChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->pinned(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->helpEnabled(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->retainPriorSearch(); break;
        case 3: *reinterpret_cast<enum HistoryBehavior*>(_v) = _t->historyBehavior(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPinned(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *View::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *View::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4ViewE_t>.strings))
        return static_cast<void*>(this);
    return PlasmaQuick::PlasmaWindow::qt_metacast(_clname);
}

int View::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PlasmaQuick::PlasmaWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void View::historyBehaviorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void View::retainPriorSearchChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void View::pinnedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void View::helpEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void View::activityChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
