/****************************************************************************
** Meta object code from reading C++ file 'main.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/kcms/icons/main.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'main.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10IconModuleE_t {};
} // unnamed namespace

template <> constexpr inline auto IconModule::qt_create_metaobjectdata<qt_meta_tag_ZN10IconModuleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "IconModule",
        "downloadingFileChanged",
        "",
        "showSuccessMessage",
        "message",
        "showErrorMessage",
        "showProgress",
        "hideProgress",
        "reloadConfig",
        "ghnsEntriesChanged",
        "installThemeFromFile",
        "QUrl",
        "url",
        "pluginIndex",
        "pluginName",
        "previewIcons",
        "QVariantList",
        "themeName",
        "size",
        "dpr",
        "limit",
        "iconsSettings",
        "IconsSettings*",
        "iconsModel",
        "IconsModel*",
        "downloadingFile"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'downloadingFileChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showSuccessMessage'
        QtMocHelpers::SignalData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'showErrorMessage'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'showProgress'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'hideProgress'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'reloadConfig'
        QtMocHelpers::MethodData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'ghnsEntriesChanged'
        QtMocHelpers::MethodData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'installThemeFromFile'
        QtMocHelpers::MethodData<void(const QUrl &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Method 'pluginIndex'
        QtMocHelpers::MethodData<int(const QString &) const>(13, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 14 },
        }}),
        // Method 'previewIcons'
        QtMocHelpers::MethodData<QVariantList(const QString &, int, qreal, int)>(15, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QString, 17 }, { QMetaType::Int, 18 }, { QMetaType::QReal, 19 }, { QMetaType::Int, 20 },
        }}),
        // Method 'previewIcons'
        QtMocHelpers::MethodData<QVariantList(const QString &, int, qreal)>(15, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 16, {{
            { QMetaType::QString, 17 }, { QMetaType::Int, 18 }, { QMetaType::QReal, 19 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'iconsSettings'
        QtMocHelpers::PropertyData<IconsSettings*>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'iconsModel'
        QtMocHelpers::PropertyData<IconsModel*>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'downloadingFile'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<IconModule, qt_meta_tag_ZN10IconModuleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject IconModule::staticMetaObject = { {
    QMetaObject::SuperData::link<KQuickManagedConfigModule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10IconModuleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10IconModuleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10IconModuleE_t>.metaTypes,
    nullptr
} };

void IconModule::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IconModule *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->downloadingFileChanged(); break;
        case 1: _t->showSuccessMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->showErrorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->showProgress((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->hideProgress(); break;
        case 5: _t->reloadConfig(); break;
        case 6: _t->ghnsEntriesChanged(); break;
        case 7: _t->installThemeFromFile((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 8: { int _r = _t->pluginIndex((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 9: { QVariantList _r = _t->previewIcons((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 10: { QVariantList _r = _t->previewIcons((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (IconModule::*)()>(_a, &IconModule::downloadingFileChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconModule::*)(const QString & )>(_a, &IconModule::showSuccessMessage, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconModule::*)(const QString & )>(_a, &IconModule::showErrorMessage, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconModule::*)(const QString & )>(_a, &IconModule::showProgress, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconModule::*)()>(_a, &IconModule::hideProgress, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<IconsSettings**>(_v) = _t->iconsSettings(); break;
        case 1: *reinterpret_cast<IconsModel**>(_v) = _t->iconsModel(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->downloadingFile(); break;
        default: break;
        }
    }
}

const QMetaObject *IconModule::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IconModule::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10IconModuleE_t>.strings))
        return static_cast<void*>(this);
    return KQuickManagedConfigModule::qt_metacast(_clname);
}

int IconModule::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KQuickManagedConfigModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void IconModule::downloadingFileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void IconModule::showSuccessMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void IconModule::showErrorMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void IconModule::showProgress(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void IconModule::hideProgress()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
