/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.JobViewServerV2.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "jobviewserverv2adaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class JobViewServerV2Adaptor
 */

JobViewServerV2Adaptor::JobViewServerV2Adaptor(NotificationManager::JobsModelPrivate *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

JobViewServerV2Adaptor::~JobViewServerV2Adaptor()
{
    // destructor
}

QDBusObjectPath JobViewServerV2Adaptor::requestView(const QString &desktopEntry, int capabilities, const QVariantMap &hints)
{
    // handle method call org.kde.JobViewServerV2.requestView
    return parent()->requestView(desktopEntry, capabilities, hints);
}


#include "moc_jobviewserverv2adaptor.cpp"
