/****************************************************************************
** Meta object code from reading C++ file 'rootmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/applets/kicker/rootmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'rootmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9RootModelE_t {};
} // unnamed namespace

template <> constexpr inline auto RootModel::qt_create_metaobjectdata<qt_meta_tag_ZN9RootModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "RootModel",
        "QML.Element",
        "auto",
        "refreshed",
        "",
        "systemFavoritesModelChanged",
        "showAllAppsChanged",
        "showAllAppsCategorizedChanged",
        "showRecentAppsChanged",
        "showRecentDocsChanged",
        "showRecentFoldersChanged",
        "showPowerSessionChanged",
        "recentOrderingChanged",
        "recentAppsModelChanged",
        "showFavoritesPlaceholderChanged",
        "highlightNewlyInstalledAppsChanged",
        "showRootSeparatorChanged",
        "refresh",
        "onResourceScoresChanged",
        "activity",
        "client",
        "resource",
        "score",
        "lastUpdate",
        "firstUpdate",
        "trigger",
        "row",
        "actionId",
        "QVariant",
        "argument",
        "systemFavoritesModel",
        "showAllApps",
        "showAllAppsCategorized",
        "showRecentApps",
        "showRecentDocs",
        "showRecentFolders",
        "recentOrdering",
        "showPowerSession",
        "showFavoritesPlaceholder",
        "highlightNewlyInstalledApps",
        "showRootSeparator"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'refreshed'
        QtMocHelpers::SignalData<void() const>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'systemFavoritesModelChanged'
        QtMocHelpers::SignalData<void() const>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showAllAppsChanged'
        QtMocHelpers::SignalData<void() const>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showAllAppsCategorizedChanged'
        QtMocHelpers::SignalData<void() const>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showRecentAppsChanged'
        QtMocHelpers::SignalData<void() const>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showRecentDocsChanged'
        QtMocHelpers::SignalData<void() const>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showRecentFoldersChanged'
        QtMocHelpers::SignalData<void() const>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showPowerSessionChanged'
        QtMocHelpers::SignalData<void() const>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'recentOrderingChanged'
        QtMocHelpers::SignalData<void() const>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'recentAppsModelChanged'
        QtMocHelpers::SignalData<void() const>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showFavoritesPlaceholderChanged'
        QtMocHelpers::SignalData<void() const>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'highlightNewlyInstalledAppsChanged'
        QtMocHelpers::SignalData<void() const>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showRootSeparatorChanged'
        QtMocHelpers::SignalData<void() const>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'refresh'
        QtMocHelpers::SlotData<void()>(17, 4, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onResourceScoresChanged'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, double, unsigned int, unsigned int)>(18, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 19 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { QMetaType::Double, 22 },
            { QMetaType::UInt, 23 }, { QMetaType::UInt, 24 },
        }}),
        // Method 'trigger'
        QtMocHelpers::MethodData<bool(int, const QString &, const QVariant &)>(25, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 26 }, { QMetaType::QString, 27 }, { 0x80000000 | 28, 29 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'systemFavoritesModel'
        QtMocHelpers::PropertyData<QObject*>(30, QMetaType::QObjectStar, QMC::DefaultPropertyFlags, 1),
        // property 'showAllApps'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'showAllAppsCategorized'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'showRecentApps'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'showRecentDocs'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'showRecentFolders'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'recentOrdering'
        QtMocHelpers::PropertyData<int>(36, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'showPowerSession'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'showFavoritesPlaceholder'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'highlightNewlyInstalledApps'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'showRootSeparator'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<RootModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject RootModel::staticMetaObject = { {
    QMetaObject::SuperData::link<AppsModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9RootModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9RootModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9RootModelE_t>.metaTypes,
    nullptr
} };

void RootModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RootModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->refreshed(); break;
        case 1: _t->systemFavoritesModelChanged(); break;
        case 2: _t->showAllAppsChanged(); break;
        case 3: _t->showAllAppsCategorizedChanged(); break;
        case 4: _t->showRecentAppsChanged(); break;
        case 5: _t->showRecentDocsChanged(); break;
        case 6: _t->showRecentFoldersChanged(); break;
        case 7: _t->showPowerSessionChanged(); break;
        case 8: _t->recentOrderingChanged(); break;
        case 9: _t->recentAppsModelChanged(); break;
        case 10: _t->showFavoritesPlaceholderChanged(); break;
        case 11: _t->highlightNewlyInstalledAppsChanged(); break;
        case 12: _t->showRootSeparatorChanged(); break;
        case 13: _t->refresh(); break;
        case 14: _t->onResourceScoresChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[6]))); break;
        case 15: { bool _r = _t->trigger((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (RootModel::*)() const>(_a, &RootModel::refreshed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (RootModel::*)() const>(_a, &RootModel::systemFavoritesModelChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (RootModel::*)() const>(_a, &RootModel::showAllAppsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (RootModel::*)() const>(_a, &RootModel::showAllAppsCategorizedChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (RootModel::*)() const>(_a, &RootModel::showRecentAppsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (RootModel::*)() const>(_a, &RootModel::showRecentDocsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (RootModel::*)() const>(_a, &RootModel::showRecentFoldersChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (RootModel::*)() const>(_a, &RootModel::showPowerSessionChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (RootModel::*)() const>(_a, &RootModel::recentOrderingChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (RootModel::*)() const>(_a, &RootModel::recentAppsModelChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (RootModel::*)() const>(_a, &RootModel::showFavoritesPlaceholderChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (RootModel::*)() const>(_a, &RootModel::highlightNewlyInstalledAppsChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (RootModel::*)() const>(_a, &RootModel::showRootSeparatorChanged, 12))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QObject**>(_v) = _t->systemFavoritesModel(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->showAllApps(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->showAllAppsCategorized(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->showRecentApps(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->showRecentDocs(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->showRecentFolders(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->recentOrdering(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->showPowerSession(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->showFavoritesPlaceholder(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->highlightNewlyInstalledApps(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->showRootSeparator(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setShowAllApps(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setShowAllAppsCategorized(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setShowRecentApps(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setShowRecentDocs(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setShowRecentFolders(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setRecentOrdering(*reinterpret_cast<int*>(_v)); break;
        case 7: _t->setShowPowerSession(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setShowFavoritesPlaceholder(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setHighlightNewlyInstalledApps(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setShowRootSeparator(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *RootModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RootModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9RootModelE_t>.strings))
        return static_cast<void*>(this);
    return AppsModel::qt_metacast(_clname);
}

int RootModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AppsModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void RootModel::refreshed()const
{
    QMetaObject::activate(const_cast< RootModel *>(this), &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void RootModel::systemFavoritesModelChanged()const
{
    QMetaObject::activate(const_cast< RootModel *>(this), &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void RootModel::showAllAppsChanged()const
{
    QMetaObject::activate(const_cast< RootModel *>(this), &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void RootModel::showAllAppsCategorizedChanged()const
{
    QMetaObject::activate(const_cast< RootModel *>(this), &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void RootModel::showRecentAppsChanged()const
{
    QMetaObject::activate(const_cast< RootModel *>(this), &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void RootModel::showRecentDocsChanged()const
{
    QMetaObject::activate(const_cast< RootModel *>(this), &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void RootModel::showRecentFoldersChanged()const
{
    QMetaObject::activate(const_cast< RootModel *>(this), &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void RootModel::showPowerSessionChanged()const
{
    QMetaObject::activate(const_cast< RootModel *>(this), &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void RootModel::recentOrderingChanged()const
{
    QMetaObject::activate(const_cast< RootModel *>(this), &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void RootModel::recentAppsModelChanged()const
{
    QMetaObject::activate(const_cast< RootModel *>(this), &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void RootModel::showFavoritesPlaceholderChanged()const
{
    QMetaObject::activate(const_cast< RootModel *>(this), &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void RootModel::highlightNewlyInstalledAppsChanged()const
{
    QMetaObject::activate(const_cast< RootModel *>(this), &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void RootModel::showRootSeparatorChanged()const
{
    QMetaObject::activate(const_cast< RootModel *>(this), &staticMetaObject, 12, nullptr);
}
QT_WARNING_POP
