/****************************************************************************
** Meta object code from reading C++ file 'stylesettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../stylesettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'stylesettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13StyleSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto StyleSettings::qt_create_metaobjectdata<qt_meta_tag_ZN13StyleSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "StyleSettings",
        "widgetStyleChanged",
        "",
        "iconsOnButtonsChanged",
        "iconsInMenusChanged",
        "toolButtonStyleChanged",
        "toolButtonStyleOtherToolbarsChanged",
        "widgetStyle",
        "isWidgetStyleImmutable",
        "defaultWidgetStyleValue",
        "iconsOnButtons",
        "isIconsOnButtonsImmutable",
        "defaultIconsOnButtonsValue",
        "iconsInMenus",
        "isIconsInMenusImmutable",
        "defaultIconsInMenusValue",
        "toolButtonStyle",
        "isToolButtonStyleImmutable",
        "defaultToolButtonStyleValue",
        "toolButtonStyleOtherToolbars",
        "isToolButtonStyleOtherToolbarsImmutable",
        "defaultToolButtonStyleOtherToolbarsValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'widgetStyleChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iconsOnButtonsChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iconsInMenusChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'toolButtonStyleChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'toolButtonStyleOtherToolbarsChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'widgetStyle'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isWidgetStyleImmutable'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultWidgetStyleValue'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'iconsOnButtons'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isIconsOnButtonsImmutable'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultIconsOnButtonsValue'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'iconsInMenus'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isIconsInMenusImmutable'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultIconsInMenusValue'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'toolButtonStyle'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isToolButtonStyleImmutable'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultToolButtonStyleValue'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'toolButtonStyleOtherToolbars'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isToolButtonStyleOtherToolbarsImmutable'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultToolButtonStyleOtherToolbarsValue'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<StyleSettings, qt_meta_tag_ZN13StyleSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject StyleSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13StyleSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13StyleSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13StyleSettingsE_t>.metaTypes,
    nullptr
} };

void StyleSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<StyleSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->widgetStyleChanged(); break;
        case 1: _t->iconsOnButtonsChanged(); break;
        case 2: _t->iconsInMenusChanged(); break;
        case 3: _t->toolButtonStyleChanged(); break;
        case 4: _t->toolButtonStyleOtherToolbarsChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (StyleSettings::*)()>(_a, &StyleSettings::widgetStyleChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (StyleSettings::*)()>(_a, &StyleSettings::iconsOnButtonsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (StyleSettings::*)()>(_a, &StyleSettings::iconsInMenusChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (StyleSettings::*)()>(_a, &StyleSettings::toolButtonStyleChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (StyleSettings::*)()>(_a, &StyleSettings::toolButtonStyleOtherToolbarsChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->widgetStyle(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isWidgetStyleImmutable(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->defaultWidgetStyleValue(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->iconsOnButtons(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isIconsOnButtonsImmutable(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->defaultIconsOnButtonsValue(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->iconsInMenus(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isIconsInMenusImmutable(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->defaultIconsInMenusValue(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->toolButtonStyle(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isToolButtonStyleImmutable(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->defaultToolButtonStyleValue(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->toolButtonStyleOtherToolbars(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isToolButtonStyleOtherToolbarsImmutable(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->defaultToolButtonStyleOtherToolbarsValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setWidgetStyle(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setIconsOnButtons(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setIconsInMenus(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setToolButtonStyle(*reinterpret_cast<QString*>(_v)); break;
        case 12: _t->setToolButtonStyleOtherToolbars(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *StyleSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *StyleSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13StyleSettingsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int StyleSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void StyleSettings::widgetStyleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void StyleSettings::iconsOnButtonsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void StyleSettings::iconsInMenusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void StyleSettings::toolButtonStyleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void StyleSettings::toolButtonStyleOtherToolbarsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
