/****************************************************************************
** Meta object code from reading C++ file 'darklightschedulepreview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/kcms/nighttime/darklightschedulepreview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'darklightschedulepreview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24DarkLightSchedulePreviewE_t {};
} // unnamed namespace

template <> constexpr inline auto DarkLightSchedulePreview::qt_create_metaobjectdata<qt_meta_tag_ZN24DarkLightSchedulePreviewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DarkLightSchedulePreview",
        "coordinateChanged",
        "",
        "sunsetStartChanged",
        "sunriseStartChanged",
        "transitionDurationChanged",
        "startSunriseDateTimeChanged",
        "endSunriseDateTimeChanged",
        "startSunsetDateTimeChanged",
        "endSunsetDateTimeChanged",
        "fallbackReasonChanged",
        "coordinate",
        "QGeoCoordinate",
        "sunsetStart",
        "sunriseStart",
        "transitionDuration",
        "startSunriseDateTime",
        "endSunriseDateTime",
        "startSunsetDateTime",
        "endSunsetDateTime",
        "fallbackReason",
        "FallbackReason",
        "None",
        "PolarDay",
        "PolarNight",
        "Other"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'coordinateChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sunsetStartChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sunriseStartChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'transitionDurationChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'startSunriseDateTimeChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'endSunriseDateTimeChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'startSunsetDateTimeChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'endSunsetDateTimeChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fallbackReasonChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'coordinate'
        QtMocHelpers::PropertyData<QGeoCoordinate>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'sunsetStart'
        QtMocHelpers::PropertyData<QTime>(13, QMetaType::QTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'sunriseStart'
        QtMocHelpers::PropertyData<QTime>(14, QMetaType::QTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'transitionDuration'
        QtMocHelpers::PropertyData<int>(15, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'startSunriseDateTime'
        QtMocHelpers::PropertyData<QDateTime>(16, QMetaType::QDateTime, QMC::DefaultPropertyFlags, 4),
        // property 'endSunriseDateTime'
        QtMocHelpers::PropertyData<QDateTime>(17, QMetaType::QDateTime, QMC::DefaultPropertyFlags, 5),
        // property 'startSunsetDateTime'
        QtMocHelpers::PropertyData<QDateTime>(18, QMetaType::QDateTime, QMC::DefaultPropertyFlags, 6),
        // property 'endSunsetDateTime'
        QtMocHelpers::PropertyData<QDateTime>(19, QMetaType::QDateTime, QMC::DefaultPropertyFlags, 7),
        // property 'fallbackReason'
        QtMocHelpers::PropertyData<enum FallbackReason>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 8),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'FallbackReason'
        QtMocHelpers::EnumData<enum FallbackReason>(21, 21, QMC::EnumIsScoped).add({
            {   22, FallbackReason::None },
            {   23, FallbackReason::PolarDay },
            {   24, FallbackReason::PolarNight },
            {   25, FallbackReason::Other },
        }),
    };
    return QtMocHelpers::metaObjectData<DarkLightSchedulePreview, qt_meta_tag_ZN24DarkLightSchedulePreviewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DarkLightSchedulePreview::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24DarkLightSchedulePreviewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24DarkLightSchedulePreviewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24DarkLightSchedulePreviewE_t>.metaTypes,
    nullptr
} };

void DarkLightSchedulePreview::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DarkLightSchedulePreview *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->coordinateChanged(); break;
        case 1: _t->sunsetStartChanged(); break;
        case 2: _t->sunriseStartChanged(); break;
        case 3: _t->transitionDurationChanged(); break;
        case 4: _t->startSunriseDateTimeChanged(); break;
        case 5: _t->endSunriseDateTimeChanged(); break;
        case 6: _t->startSunsetDateTimeChanged(); break;
        case 7: _t->endSunsetDateTimeChanged(); break;
        case 8: _t->fallbackReasonChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DarkLightSchedulePreview::*)()>(_a, &DarkLightSchedulePreview::coordinateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DarkLightSchedulePreview::*)()>(_a, &DarkLightSchedulePreview::sunsetStartChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DarkLightSchedulePreview::*)()>(_a, &DarkLightSchedulePreview::sunriseStartChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DarkLightSchedulePreview::*)()>(_a, &DarkLightSchedulePreview::transitionDurationChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DarkLightSchedulePreview::*)()>(_a, &DarkLightSchedulePreview::startSunriseDateTimeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DarkLightSchedulePreview::*)()>(_a, &DarkLightSchedulePreview::endSunriseDateTimeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DarkLightSchedulePreview::*)()>(_a, &DarkLightSchedulePreview::startSunsetDateTimeChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DarkLightSchedulePreview::*)()>(_a, &DarkLightSchedulePreview::endSunsetDateTimeChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DarkLightSchedulePreview::*)()>(_a, &DarkLightSchedulePreview::fallbackReasonChanged, 8))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QGeoCoordinate >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QGeoCoordinate*>(_v) = _t->coordinate(); break;
        case 1: *reinterpret_cast<QTime*>(_v) = _t->sunsetStart(); break;
        case 2: *reinterpret_cast<QTime*>(_v) = _t->sunriseStart(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->transitionDuration(); break;
        case 4: *reinterpret_cast<QDateTime*>(_v) = _t->startSunriseDateTime(); break;
        case 5: *reinterpret_cast<QDateTime*>(_v) = _t->endSunriseDateTime(); break;
        case 6: *reinterpret_cast<QDateTime*>(_v) = _t->startSunsetDateTime(); break;
        case 7: *reinterpret_cast<QDateTime*>(_v) = _t->endSunsetDateTime(); break;
        case 8: *reinterpret_cast<enum FallbackReason*>(_v) = _t->fallbackReason(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCoordinate(*reinterpret_cast<QGeoCoordinate*>(_v)); break;
        case 1: _t->setSunsetStart(*reinterpret_cast<QTime*>(_v)); break;
        case 2: _t->setSunriseStart(*reinterpret_cast<QTime*>(_v)); break;
        case 3: _t->setTransitionDuration(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 0: _t->resetCoordinate(); break;
        default: break;
        }
    }
}

const QMetaObject *DarkLightSchedulePreview::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DarkLightSchedulePreview::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24DarkLightSchedulePreviewE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QObject::qt_metacast(_clname);
}

int DarkLightSchedulePreview::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void DarkLightSchedulePreview::coordinateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DarkLightSchedulePreview::sunsetStartChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DarkLightSchedulePreview::sunriseStartChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DarkLightSchedulePreview::transitionDurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DarkLightSchedulePreview::startSunriseDateTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DarkLightSchedulePreview::endSunriseDateTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DarkLightSchedulePreview::startSunsetDateTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void DarkLightSchedulePreview::endSunsetDateTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void DarkLightSchedulePreview::fallbackReasonChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
