/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.JobViewV2.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "jobviewv2adaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class JobViewV2Adaptor
 */

JobViewV2Adaptor::JobViewV2Adaptor(NotificationManager::JobPrivate *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

JobViewV2Adaptor::~JobViewV2Adaptor()
{
    // destructor
}

void JobViewV2Adaptor::clearDescriptionField(uint number)
{
    // handle method call org.kde.JobViewV2.clearDescriptionField
    parent()->clearDescriptionField(number);
}

bool JobViewV2Adaptor::setDescriptionField(uint number, const QString &name, const QString &value)
{
    // handle method call org.kde.JobViewV2.setDescriptionField
    return parent()->setDescriptionField(number, name, value);
}

void JobViewV2Adaptor::setDestUrl(const QDBusVariant &destUrl)
{
    // handle method call org.kde.JobViewV2.setDestUrl
    parent()->setDestUrl(destUrl);
}

void JobViewV2Adaptor::setError(uint errorCode)
{
    // handle method call org.kde.JobViewV2.setError
    parent()->setError(errorCode);
}

void JobViewV2Adaptor::setInfoMessage(const QString &message)
{
    // handle method call org.kde.JobViewV2.setInfoMessage
    parent()->setInfoMessage(message);
}

void JobViewV2Adaptor::setPercent(uint percent)
{
    // handle method call org.kde.JobViewV2.setPercent
    parent()->setPercent(percent);
}

void JobViewV2Adaptor::setProcessedAmount(qulonglong amount, const QString &unit)
{
    // handle method call org.kde.JobViewV2.setProcessedAmount
    parent()->setProcessedAmount(amount, unit);
}

void JobViewV2Adaptor::setSpeed(qulonglong bytesPerSecond)
{
    // handle method call org.kde.JobViewV2.setSpeed
    parent()->setSpeed(bytesPerSecond);
}

void JobViewV2Adaptor::setSuspended(bool suspended)
{
    // handle method call org.kde.JobViewV2.setSuspended
    parent()->setSuspended(suspended);
}

void JobViewV2Adaptor::setTotalAmount(qulonglong amount, const QString &unit)
{
    // handle method call org.kde.JobViewV2.setTotalAmount
    parent()->setTotalAmount(amount, unit);
}

void JobViewV2Adaptor::terminate(const QString &errorMessage)
{
    // handle method call org.kde.JobViewV2.terminate
    parent()->terminate(errorMessage);
}


#include "moc_jobviewv2adaptor.cpp"
