/********************************************************************************
** Form generated from reading UI file 'scmeditoreffects.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SCMEDITOREFFECTS_H
#define UI_SCMEDITOREFFECTS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"
#include "previewwidget.h"

QT_BEGIN_NAMESPACE

class Ui_ScmEditorEffects
{
public:
    QGridLayout *gridLayout;
    QLabel *label_4;
    QLabel *label_5;
    QComboBox *colorBox;
    QComboBox *intensityBox;
    QSpacerItem *spacer_3;
    QLabel *label_6;
    QSlider *colorSlider;
    QSlider *intensitySlider;
    KColorButton *colorButton;
    PreviewWidget *preview;
    QComboBox *contrastBox;
    QSpacerItem *spacer_4;
    QSlider *contrastSlider;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QWidget *ScmEditorEffects)
    {
        if (ScmEditorEffects->objectName().isEmpty())
            ScmEditorEffects->setObjectName("ScmEditorEffects");
        ScmEditorEffects->resize(400, 300);
        gridLayout = new QGridLayout(ScmEditorEffects);
        gridLayout->setObjectName("gridLayout");
        label_4 = new QLabel(ScmEditorEffects);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_4, 2, 0, 1, 1);

        label_5 = new QLabel(ScmEditorEffects);
        label_5->setObjectName("label_5");
        label_5->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_5, 1, 0, 1, 1);

        colorBox = new QComboBox(ScmEditorEffects);
        colorBox->addItem(QString());
        colorBox->addItem(QString());
        colorBox->addItem(QString());
        colorBox->addItem(QString());
        colorBox->setObjectName("colorBox");

        gridLayout->addWidget(colorBox, 2, 1, 1, 1);

        intensityBox = new QComboBox(ScmEditorEffects);
        intensityBox->addItem(QString());
        intensityBox->addItem(QString());
        intensityBox->addItem(QString());
        intensityBox->addItem(QString());
        intensityBox->setObjectName("intensityBox");

        gridLayout->addWidget(intensityBox, 1, 1, 1, 1);

        spacer_3 = new QSpacerItem(69, 22, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacer_3, 1, 3, 1, 1);

        label_6 = new QLabel(ScmEditorEffects);
        label_6->setObjectName("label_6");
        label_6->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_6, 4, 0, 1, 1);

        colorSlider = new QSlider(ScmEditorEffects);
        colorSlider->setObjectName("colorSlider");
        colorSlider->setEnabled(false);
        colorSlider->setMaximum(40);
        colorSlider->setPageStep(10);
        colorSlider->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(colorSlider, 2, 2, 1, 1);

        intensitySlider = new QSlider(ScmEditorEffects);
        intensitySlider->setObjectName("intensitySlider");
        intensitySlider->setEnabled(false);
        intensitySlider->setMaximum(40);
        intensitySlider->setPageStep(10);
        intensitySlider->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(intensitySlider, 1, 2, 1, 1);

        colorButton = new KColorButton(ScmEditorEffects);
        colorButton->setObjectName("colorButton");
        colorButton->setEnabled(false);

        gridLayout->addWidget(colorButton, 2, 3, 1, 1);

        preview = new PreviewWidget(ScmEditorEffects);
        preview->setObjectName("preview");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(preview->sizePolicy().hasHeightForWidth());
        preview->setSizePolicy(sizePolicy);
        preview->setMinimumSize(QSize(0, 10));

        gridLayout->addWidget(preview, 0, 0, 1, 4);

        contrastBox = new QComboBox(ScmEditorEffects);
        contrastBox->addItem(QString());
        contrastBox->addItem(QString());
        contrastBox->addItem(QString());
        contrastBox->setObjectName("contrastBox");

        gridLayout->addWidget(contrastBox, 4, 1, 1, 1);

        spacer_4 = new QSpacerItem(69, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacer_4, 4, 3, 1, 1);

        contrastSlider = new QSlider(ScmEditorEffects);
        contrastSlider->setObjectName("contrastSlider");
        contrastSlider->setEnabled(false);
        contrastSlider->setMaximum(20);
        contrastSlider->setPageStep(10);
        contrastSlider->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(contrastSlider, 4, 2, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_2, 5, 0, 1, 4);


        retranslateUi(ScmEditorEffects);

        QMetaObject::connectSlotsByName(ScmEditorEffects);
    } // setupUi

    void retranslateUi(QWidget *ScmEditorEffects)
    {
        label_4->setText(tr2i18n("Color:", nullptr));
        label_5->setText(tr2i18n("Intensity:", nullptr));
        colorBox->setItemText(0, tr2i18n("None", "no disabled color effect"));
        colorBox->setItemText(1, tr2i18n("Desaturate", "disabled color effect"));
        colorBox->setItemText(2, tr2i18n("Fade", "disabled color effect"));
        colorBox->setItemText(3, tr2i18n("Tint", "disabled color effect"));

#if QT_CONFIG(tooltip)
        colorBox->setToolTip(tr2i18n("Disabled color effect type", nullptr));
#endif // QT_CONFIG(tooltip)
        intensityBox->setItemText(0, tr2i18n("None", "no disabled intensity effect"));
        intensityBox->setItemText(1, tr2i18n("Shade", "disabled intensity effect"));
        intensityBox->setItemText(2, tr2i18n("Darken", "disabled intensity effect"));
        intensityBox->setItemText(3, tr2i18n("Lighten", "disabled intensity effect"));

#if QT_CONFIG(tooltip)
        intensityBox->setToolTip(tr2i18n("Disabled intensity effect type", nullptr));
#endif // QT_CONFIG(tooltip)
        label_6->setText(tr2i18n("Contrast:", nullptr));
#if QT_CONFIG(tooltip)
        colorSlider->setToolTip(tr2i18n("Disabled color effect amount", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        intensitySlider->setToolTip(tr2i18n("Disabled intensity effect amount", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        colorButton->setToolTip(tr2i18n("Disabled color", nullptr));
#endif // QT_CONFIG(tooltip)
        contrastBox->setItemText(0, tr2i18n("None", "no disabled contrast"));
        contrastBox->setItemText(1, tr2i18n("Fade", "disabled contrast"));
        contrastBox->setItemText(2, tr2i18n("Tint", "disabled contrast"));

#if QT_CONFIG(tooltip)
        contrastBox->setToolTip(tr2i18n("Disabled contrast type", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        contrastSlider->setToolTip(tr2i18n("Disabled contrast amount", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)ScmEditorEffects;
    } // retranslateUi

};

namespace Ui {
    class ScmEditorEffects: public Ui_ScmEditorEffects {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SCMEDITOREFFECTS_H

