/****************************************************************************
** Meta object code from reading C++ file 'simplefavoritesmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/applets/kicker/simplefavoritesmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'simplefavoritesmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20SimpleFavoritesModelE_t {};
} // unnamed namespace

template <> constexpr inline auto SimpleFavoritesModel::qt_create_metaobjectdata<qt_meta_tag_ZN20SimpleFavoritesModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SimpleFavoritesModel",
        "QML.Element",
        "auto",
        "enabledChanged",
        "",
        "favoritesChanged",
        "maxFavoritesChanged",
        "dropPlaceholderIndexChanged",
        "favoriteAdded",
        "id",
        "refresh",
        "trigger",
        "row",
        "actionId",
        "QVariant",
        "argument",
        "isFavorite",
        "addFavorite",
        "index",
        "removeFavorite",
        "moveRow",
        "from",
        "to",
        "enabled",
        "favorites",
        "maxFavorites",
        "dropPlaceholderIndex"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void() const>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'favoritesChanged'
        QtMocHelpers::SignalData<void() const>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maxFavoritesChanged'
        QtMocHelpers::SignalData<void() const>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dropPlaceholderIndexChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'favoriteAdded'
        QtMocHelpers::SignalData<void(const QString &)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'refresh'
        QtMocHelpers::SlotData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'trigger'
        QtMocHelpers::MethodData<bool(int, const QString &, const QVariant &)>(11, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 12 }, { QMetaType::QString, 13 }, { 0x80000000 | 14, 15 },
        }}),
        // Method 'isFavorite'
        QtMocHelpers::MethodData<bool(const QString &) const>(16, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 9 },
        }}),
        // Method 'addFavorite'
        QtMocHelpers::MethodData<void(const QString &, int)>(17, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { QMetaType::Int, 18 },
        }}),
        // Method 'addFavorite'
        QtMocHelpers::MethodData<void(const QString &)>(17, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Method 'removeFavorite'
        QtMocHelpers::MethodData<void(const QString &)>(19, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Method 'moveRow'
        QtMocHelpers::MethodData<void(int, int)>(20, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 }, { QMetaType::Int, 22 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'favorites'
        QtMocHelpers::PropertyData<QStringList>(24, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'maxFavorites'
        QtMocHelpers::PropertyData<int>(25, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'dropPlaceholderIndex'
        QtMocHelpers::PropertyData<int>(26, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<SimpleFavoritesModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject SimpleFavoritesModel::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20SimpleFavoritesModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20SimpleFavoritesModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20SimpleFavoritesModelE_t>.metaTypes,
    nullptr
} };

void SimpleFavoritesModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SimpleFavoritesModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->enabledChanged(); break;
        case 1: _t->favoritesChanged(); break;
        case 2: _t->maxFavoritesChanged(); break;
        case 3: _t->dropPlaceholderIndexChanged(); break;
        case 4: _t->favoriteAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->refresh(); break;
        case 6: { bool _r = _t->trigger((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->isFavorite((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->addFavorite((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 9: _t->addFavorite((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->removeFavorite((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->moveRow((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SimpleFavoritesModel::*)() const>(_a, &SimpleFavoritesModel::enabledChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SimpleFavoritesModel::*)() const>(_a, &SimpleFavoritesModel::favoritesChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SimpleFavoritesModel::*)() const>(_a, &SimpleFavoritesModel::maxFavoritesChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SimpleFavoritesModel::*)()>(_a, &SimpleFavoritesModel::dropPlaceholderIndexChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SimpleFavoritesModel::*)(const QString & )>(_a, &SimpleFavoritesModel::favoriteAdded, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        case 1: *reinterpret_cast<QStringList*>(_v) = _t->favorites(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->maxFavorites(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->dropPlaceholderIndex(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setFavorites(*reinterpret_cast<QStringList*>(_v)); break;
        case 2: _t->setMaxFavorites(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setDropPlaceholderIndex(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *SimpleFavoritesModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SimpleFavoritesModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20SimpleFavoritesModelE_t>.strings))
        return static_cast<void*>(this);
    return AbstractModel::qt_metacast(_clname);
}

int SimpleFavoritesModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void SimpleFavoritesModel::enabledChanged()const
{
    QMetaObject::activate(const_cast< SimpleFavoritesModel *>(this), &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SimpleFavoritesModel::favoritesChanged()const
{
    QMetaObject::activate(const_cast< SimpleFavoritesModel *>(this), &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SimpleFavoritesModel::maxFavoritesChanged()const
{
    QMetaObject::activate(const_cast< SimpleFavoritesModel *>(this), &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void SimpleFavoritesModel::dropPlaceholderIndexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void SimpleFavoritesModel::favoriteAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
