/****************************************************************************
** Meta object code from reading C++ file 'batterycontrol.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/components/batterycontrol/batterycontrol.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QProperty>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'batterycontrol.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19BatteryControlModelE_t {};
} // unnamed namespace

template <> constexpr inline auto BatteryControlModel::qt_create_metaobjectdata<qt_meta_tag_ZN19BatteryControlModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BatteryControlModel",
        "QML.Element",
        "auto",
        "hasCumulativeChanged",
        "",
        "status",
        "hasBatteriesChanged",
        "pluggedInChanged",
        "hasInternalBatteriesChanged",
        "stateChanged",
        "ChargeStateEnum",
        "state",
        "chargeStopThresholdChanged",
        "threshold",
        "remainingMsecChanged",
        "time",
        "smoothedRemainingMsecChanged",
        "percentChanged",
        "percent",
        "onServiceRegistered",
        "serviceName",
        "onServiceUnregistered",
        "batteryRemainingTimeChanged",
        "smoothedBatteryRemainingTimeChanged",
        "updateBatteryChargeStopThreshold",
        "updateAcPlugState",
        "onBattery",
        "updateOverallBattery",
        "updateBatteryCapacity",
        "newState",
        "udi",
        "updateBatteryChargeState",
        "updateBatteryChargePercent",
        "newValue",
        "updateBatteryEnergy",
        "updateBatteryPowerSupplyState",
        "updatePluggedInState",
        "deviceAdded",
        "deviceRemoved",
        "hasCumulative",
        "hasBatteries",
        "pluggedIn",
        "hasInternalBatteries",
        "chargeStopThreshold",
        "remainingMsec",
        "smoothedRemainingMsec",
        "BatteryRoles",
        "PrettyName",
        "Percent",
        "Capacity",
        "Energy",
        "PluggedIn",
        "IsPowerSupply",
        "ChargeState",
        "Type",
        "NoCharge",
        "Charging",
        "Discharging",
        "FullyCharged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'hasCumulativeChanged'
        QtMocHelpers::SignalData<void(bool)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'hasBatteriesChanged'
        QtMocHelpers::SignalData<void(bool)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'pluggedInChanged'
        QtMocHelpers::SignalData<void(bool)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'hasInternalBatteriesChanged'
        QtMocHelpers::SignalData<void(bool)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void(enum ChargeStateEnum)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'chargeStopThresholdChanged'
        QtMocHelpers::SignalData<void(int)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Signal 'remainingMsecChanged'
        QtMocHelpers::SignalData<void(qulonglong)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 15 },
        }}),
        // Signal 'smoothedRemainingMsecChanged'
        QtMocHelpers::SignalData<void(qulonglong)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 15 },
        }}),
        // Signal 'percentChanged'
        QtMocHelpers::SignalData<void(int)>(17, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Slot 'onServiceRegistered'
        QtMocHelpers::SlotData<void(const QString &)>(19, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'onServiceUnregistered'
        QtMocHelpers::SlotData<void(const QString &)>(21, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'batteryRemainingTimeChanged'
        QtMocHelpers::SlotData<void(qulonglong)>(22, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::ULongLong, 15 },
        }}),
        // Slot 'smoothedBatteryRemainingTimeChanged'
        QtMocHelpers::SlotData<void(qulonglong)>(23, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::ULongLong, 15 },
        }}),
        // Slot 'updateBatteryChargeStopThreshold'
        QtMocHelpers::SlotData<void(int)>(24, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Slot 'updateAcPlugState'
        QtMocHelpers::SlotData<void(bool)>(25, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'updateOverallBattery'
        QtMocHelpers::SlotData<void()>(27, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateBatteryCapacity'
        QtMocHelpers::SlotData<void(int, const QString &)>(28, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 29 }, { QMetaType::QString, 30 },
        }}),
        // Slot 'updateBatteryChargeState'
        QtMocHelpers::SlotData<void(int, const QString &)>(31, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 29 }, { QMetaType::QString, 30 },
        }}),
        // Slot 'updateBatteryChargePercent'
        QtMocHelpers::SlotData<void(int, const QString &)>(32, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 33 }, { QMetaType::QString, 30 },
        }}),
        // Slot 'updateBatteryEnergy'
        QtMocHelpers::SlotData<void(double, const QString &)>(34, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 33 }, { QMetaType::QString, 30 },
        }}),
        // Slot 'updateBatteryPowerSupplyState'
        QtMocHelpers::SlotData<void(bool, const QString &)>(35, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 29 }, { QMetaType::QString, 30 },
        }}),
        // Slot 'updatePluggedInState'
        QtMocHelpers::SlotData<void(bool, const QString &)>(36, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 26 }, { QMetaType::QString, 30 },
        }}),
        // Slot 'deviceAdded'
        QtMocHelpers::SlotData<void(const QString &)>(37, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 30 },
        }}),
        // Slot 'deviceRemoved'
        QtMocHelpers::SlotData<void(const QString &)>(38, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 30 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'hasCumulative'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 0),
        // property 'hasBatteries'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 1),
        // property 'pluggedIn'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 2),
        // property 'hasInternalBatteries'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 3),
        // property 'state'
        QtMocHelpers::PropertyData<enum ChargeStateEnum>(11, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Bindable, 4),
        // property 'chargeStopThreshold'
        QtMocHelpers::PropertyData<int>(43, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Bindable, 5),
        // property 'remainingMsec'
        QtMocHelpers::PropertyData<qulonglong>(44, QMetaType::ULongLong, QMC::DefaultPropertyFlags | QMC::Bindable, 6),
        // property 'smoothedRemainingMsec'
        QtMocHelpers::PropertyData<qulonglong>(45, QMetaType::ULongLong, QMC::DefaultPropertyFlags | QMC::Bindable, 7),
        // property 'percent'
        QtMocHelpers::PropertyData<int>(18, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Bindable, 8),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'BatteryRoles'
        QtMocHelpers::EnumData<enum BatteryRoles>(46, 46, QMC::EnumFlags{}).add({
            {   47, BatteryRoles::PrettyName },
            {   48, BatteryRoles::Percent },
            {   49, BatteryRoles::Capacity },
            {   50, BatteryRoles::Energy },
            {   51, BatteryRoles::PluggedIn },
            {   52, BatteryRoles::IsPowerSupply },
            {   53, BatteryRoles::ChargeState },
            {   54, BatteryRoles::Type },
        }),
        // enum 'ChargeStateEnum'
        QtMocHelpers::EnumData<enum ChargeStateEnum>(10, 10, QMC::EnumFlags{}).add({
            {   55, ChargeStateEnum::NoCharge },
            {   56, ChargeStateEnum::Charging },
            {   57, ChargeStateEnum::Discharging },
            {   58, ChargeStateEnum::FullyCharged },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<BatteryControlModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject BatteryControlModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19BatteryControlModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19BatteryControlModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19BatteryControlModelE_t>.metaTypes,
    nullptr
} };

void BatteryControlModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BatteryControlModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->hasCumulativeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->hasBatteriesChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->pluggedInChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->hasInternalBatteriesChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->stateChanged((*reinterpret_cast<std::add_pointer_t<enum ChargeStateEnum>>(_a[1]))); break;
        case 5: _t->chargeStopThresholdChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->remainingMsecChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 7: _t->smoothedRemainingMsecChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 8: _t->percentChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->onServiceRegistered((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->onServiceUnregistered((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->batteryRemainingTimeChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 12: _t->smoothedBatteryRemainingTimeChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 13: _t->updateBatteryChargeStopThreshold((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->updateAcPlugState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->updateOverallBattery(); break;
        case 16: _t->updateBatteryCapacity((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 17: _t->updateBatteryChargeState((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 18: _t->updateBatteryChargePercent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 19: _t->updateBatteryEnergy((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 20: _t->updateBatteryPowerSupplyState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 21: _t->updatePluggedInState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 22: _t->deviceAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 23: _t->deviceRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BatteryControlModel::*)(bool )>(_a, &BatteryControlModel::hasCumulativeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BatteryControlModel::*)(bool )>(_a, &BatteryControlModel::hasBatteriesChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BatteryControlModel::*)(bool )>(_a, &BatteryControlModel::pluggedInChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (BatteryControlModel::*)(bool )>(_a, &BatteryControlModel::hasInternalBatteriesChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (BatteryControlModel::*)(ChargeStateEnum )>(_a, &BatteryControlModel::stateChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (BatteryControlModel::*)(int )>(_a, &BatteryControlModel::chargeStopThresholdChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (BatteryControlModel::*)(qulonglong )>(_a, &BatteryControlModel::remainingMsecChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (BatteryControlModel::*)(qulonglong )>(_a, &BatteryControlModel::smoothedRemainingMsecChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (BatteryControlModel::*)(int )>(_a, &BatteryControlModel::percentChanged, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->bindableHasCumulative().value(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->bindableHasBatteries().value(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->bindablePluggedIn().value(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->bindableHasInternalBatteries().value(); break;
        case 4: *reinterpret_cast<enum ChargeStateEnum*>(_v) = _t->bindableState().value(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->bindableChargeStopThresholdChanged().value(); break;
        case 6: *reinterpret_cast<qulonglong*>(_v) = _t->bindableRemainingMsec().value(); break;
        case 7: *reinterpret_cast<qulonglong*>(_v) = _t->bindableSmoothedRemainingMsec().value(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->bindablePercent().value(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::BindableProperty) {
        switch (_id) {
        case 0: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableHasCumulative(); break;
        case 1: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableHasBatteries(); break;
        case 2: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindablePluggedIn(); break;
        case 3: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableHasInternalBatteries(); break;
        case 4: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableState(); break;
        case 5: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableChargeStopThresholdChanged(); break;
        case 6: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableRemainingMsec(); break;
        case 7: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableSmoothedRemainingMsec(); break;
        case 8: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindablePercent(); break;
        default: break;
        }
    }
}

const QMetaObject *BatteryControlModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BatteryControlModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19BatteryControlModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int BatteryControlModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 24;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void BatteryControlModel::hasCumulativeChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void BatteryControlModel::hasBatteriesChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void BatteryControlModel::pluggedInChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void BatteryControlModel::hasInternalBatteriesChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void BatteryControlModel::stateChanged(ChargeStateEnum _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void BatteryControlModel::chargeStopThresholdChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void BatteryControlModel::remainingMsecChanged(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void BatteryControlModel::smoothedRemainingMsecChanged(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void BatteryControlModel::percentChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}
QT_WARNING_POP
