/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<sessionsmodel.h>)
#  include <sessionsmodel.h>
#endif
#if __has_include(<types.h>)
#  include <types.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_plasma_private_sessions()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    qmlRegisterTypesAndRevisions<SessionManagementForeign>("org.kde.plasma.private.sessions", 2);
    qmlRegisterEnum<SessionManagement::State>("SessionManagement::State");
    qmlRegisterEnum<SessionManagement::ConfirmationMode>("SessionManagement::ConfirmationMode");
    qmlRegisterTypesAndRevisions<SessionsModel>("org.kde.plasma.private.sessions", 2);
    qmlRegisterEnum<SessionsModel::UserRoles>("SessionsModel::UserRoles");
    QT_WARNING_POP
    qmlRegisterModule("org.kde.plasma.private.sessions", 2, 0);
}

static const QQmlModuleRegistration orgkdeplasmaprivatesessionsRegistration("org.kde.plasma.private.sessions", qml_register_types_org_kde_plasma_private_sessions);
