/****************************************************************************
** Meta object code from reading C++ file 'interactiveconsole.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-workspace-6.7.1/interactiveconsole/interactiveconsole.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'interactiveconsole.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18InteractiveConsoleE_t {};
} // unnamed namespace

template <> constexpr inline auto InteractiveConsole::qt_create_metaobjectdata<qt_meta_tag_ZN18InteractiveConsoleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "InteractiveConsole",
        "scriptEngineChanged",
        "",
        "modeChanged",
        "visibleChanged",
        "print",
        "string",
        "reject",
        "openScriptFile",
        "saveScript",
        "scriptTextChanged",
        "evaluateScript",
        "clearEditor",
        "clearOutput",
        "scriptFileDataRecvd",
        "KIO::Job*",
        "job",
        "data",
        "scriptFileDataReq",
        "QByteArray&",
        "reenableEditor",
        "KJob*",
        "saveScriptUrlSelected",
        "result",
        "openScriptUrlSelected",
        "loadScriptFromUrl",
        "QUrl",
        "url",
        "populateTemplatesMenu",
        "loadTemplate",
        "QAction*",
        "useTemplate",
        "modeSelectionChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'scriptEngineChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modeChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'visibleChanged'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'print'
        QtMocHelpers::SlotData<void(const QString &)>(5, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'reject'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'openScriptFile'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveScript'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'scriptTextChanged'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'evaluateScript'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'clearEditor'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'clearOutput'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'scriptFileDataRecvd'
        QtMocHelpers::SlotData<void(KIO::Job *, const QByteArray &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { QMetaType::QByteArray, 17 },
        }}),
        // Slot 'scriptFileDataReq'
        QtMocHelpers::SlotData<void(KIO::Job *, QByteArray &)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 19, 17 },
        }}),
        // Slot 'reenableEditor'
        QtMocHelpers::SlotData<void(KJob *)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 16 },
        }}),
        // Slot 'saveScriptUrlSelected'
        QtMocHelpers::SlotData<void(int)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Slot 'openScriptUrlSelected'
        QtMocHelpers::SlotData<void(int)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Slot 'loadScriptFromUrl'
        QtMocHelpers::SlotData<void(const QUrl &)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'populateTemplatesMenu'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'loadTemplate'
        QtMocHelpers::SlotData<void(QAction *)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 30, 2 },
        }}),
        // Slot 'useTemplate'
        QtMocHelpers::SlotData<void(QAction *)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 30, 2 },
        }}),
        // Slot 'modeSelectionChanged'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<InteractiveConsole, qt_meta_tag_ZN18InteractiveConsoleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject InteractiveConsole::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18InteractiveConsoleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18InteractiveConsoleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18InteractiveConsoleE_t>.metaTypes,
    nullptr
} };

void InteractiveConsole::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<InteractiveConsole *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->scriptEngineChanged(); break;
        case 1: _t->modeChanged(); break;
        case 2: _t->visibleChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->print((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->reject(); break;
        case 5: _t->openScriptFile(); break;
        case 6: _t->saveScript(); break;
        case 7: _t->scriptTextChanged(); break;
        case 8: _t->evaluateScript(); break;
        case 9: _t->clearEditor(); break;
        case 10: _t->clearOutput(); break;
        case 11: _t->scriptFileDataRecvd((*reinterpret_cast<std::add_pointer_t<KIO::Job*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2]))); break;
        case 12: _t->scriptFileDataReq((*reinterpret_cast<std::add_pointer_t<KIO::Job*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray&>>(_a[2]))); break;
        case 13: _t->reenableEditor((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 14: _t->saveScriptUrlSelected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: _t->openScriptUrlSelected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->loadScriptFromUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 17: _t->populateTemplatesMenu(); break;
        case 18: _t->loadTemplate((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 19: _t->useTemplate((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 20: _t->modeSelectionChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KIO::Job* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KIO::Job* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (InteractiveConsole::*)()>(_a, &InteractiveConsole::scriptEngineChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (InteractiveConsole::*)()>(_a, &InteractiveConsole::modeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (InteractiveConsole::*)(bool )>(_a, &InteractiveConsole::visibleChanged, 2))
            return;
    }
}

const QMetaObject *InteractiveConsole::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *InteractiveConsole::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18InteractiveConsoleE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int InteractiveConsole::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void InteractiveConsole::scriptEngineChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void InteractiveConsole::modeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void InteractiveConsole::visibleChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
