/****************************************************************************
** Meta object code from reading C++ file 'submenu.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/applets/kicker/submenu.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'submenu.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7SubMenuE_t {};
} // unnamed namespace

template <> constexpr inline auto SubMenu::qt_create_metaobjectdata<qt_meta_tag_ZN7SubMenuE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SubMenu",
        "QML.Element",
        "auto",
        "offsetChanged",
        "",
        "facingLeftChanged",
        "dialogMirroredChanged",
        "availableScreenRectForItem",
        "QRect",
        "QQuickItem*",
        "item",
        "offset",
        "dialogMirrored",
        "facingLeft"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'offsetChanged'
        QtMocHelpers::SignalData<void() const>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'facingLeftChanged'
        QtMocHelpers::SignalData<void() const>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dialogMirroredChanged'
        QtMocHelpers::SignalData<void() const>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'availableScreenRectForItem'
        QtMocHelpers::MethodData<QRect(QQuickItem *) const>(7, 4, QMC::AccessPublic, 0x80000000 | 8, {{
            { 0x80000000 | 9, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'offset'
        QtMocHelpers::PropertyData<int>(11, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'dialogMirrored'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'facingLeft'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<SubMenu, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject SubMenu::staticMetaObject = { {
    QMetaObject::SuperData::link<PlasmaQuick::Dialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7SubMenuE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7SubMenuE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7SubMenuE_t>.metaTypes,
    nullptr
} };

void SubMenu::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SubMenu *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->offsetChanged(); break;
        case 1: _t->facingLeftChanged(); break;
        case 2: _t->dialogMirroredChanged(); break;
        case 3: { QRect _r = _t->availableScreenRectForItem((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QRect*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuickItem* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SubMenu::*)() const>(_a, &SubMenu::offsetChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SubMenu::*)() const>(_a, &SubMenu::facingLeftChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SubMenu::*)() const>(_a, &SubMenu::dialogMirroredChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->offset(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->dialogMirrored(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->facingLeft(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setOffset(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setDialogMirrored(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *SubMenu::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SubMenu::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7SubMenuE_t>.strings))
        return static_cast<void*>(this);
    return PlasmaQuick::Dialog::qt_metacast(_clname);
}

int SubMenu::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PlasmaQuick::Dialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void SubMenu::offsetChanged()const
{
    QMetaObject::activate(const_cast< SubMenu *>(this), &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SubMenu::facingLeftChanged()const
{
    QMetaObject::activate(const_cast< SubMenu *>(this), &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SubMenu::dialogMirroredChanged()const
{
    QMetaObject::activate(const_cast< SubMenu *>(this), &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
