/****************************************************************************
** Meta object code from reading C++ file 'nightlightsettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../nightlightsettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'nightlightsettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18NightLightSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto NightLightSettings::qt_create_metaobjectdata<qt_meta_tag_ZN18NightLightSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NightLightSettings",
        "ActiveEnabledChanged",
        "",
        "ActiveChanged",
        "ModeEnabledChanged",
        "ModeChanged",
        "NightTemperatureEnabledChanged",
        "DayTemperatureChanged",
        "NightTemperatureChanged",
        "activeEnabled",
        "isActiveEnabledImmutable",
        "defaultActiveEnabledValue",
        "active",
        "isActiveImmutable",
        "defaultActiveValue",
        "modeEnabled",
        "isModeEnabledImmutable",
        "defaultModeEnabledValue",
        "mode",
        "ColorCorrect::NightLightMode",
        "isModeImmutable",
        "defaultModeValue",
        "nightTemperatureEnabled",
        "isNightTemperatureEnabledImmutable",
        "defaultNightTemperatureEnabledValue",
        "dayTemperature",
        "isDayTemperatureImmutable",
        "defaultDayTemperatureValue",
        "nightTemperature",
        "isNightTemperatureImmutable",
        "defaultNightTemperatureValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ActiveEnabledChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ActiveChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ModeEnabledChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ModeChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'NightTemperatureEnabledChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DayTemperatureChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'NightTemperatureChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'activeEnabled'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isActiveEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultActiveEnabledValue'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'active'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isActiveImmutable'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultActiveValue'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'modeEnabled'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isModeEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultModeEnabledValue'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mode'
        QtMocHelpers::PropertyData<ColorCorrect::NightLightMode>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'isModeImmutable'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultModeValue'
        QtMocHelpers::PropertyData<ColorCorrect::NightLightMode>(21, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'nightTemperatureEnabled'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isNightTemperatureEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNightTemperatureEnabledValue'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dayTemperature'
        QtMocHelpers::PropertyData<int>(25, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isDayTemperatureImmutable'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDayTemperatureValue'
        QtMocHelpers::PropertyData<int>(27, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'nightTemperature'
        QtMocHelpers::PropertyData<int>(28, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isNightTemperatureImmutable'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNightTemperatureValue'
        QtMocHelpers::PropertyData<int>(30, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NightLightSettings, qt_meta_tag_ZN18NightLightSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN18NightLightSettingsE[] = {
    QMetaObject::SuperData::link<ColorCorrect::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject NightLightSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18NightLightSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18NightLightSettingsE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN18NightLightSettingsE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18NightLightSettingsE_t>.metaTypes,
    nullptr
} };

void NightLightSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NightLightSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ActiveEnabledChanged(); break;
        case 1: _t->ActiveChanged(); break;
        case 2: _t->ModeEnabledChanged(); break;
        case 3: _t->ModeChanged(); break;
        case 4: _t->NightTemperatureEnabledChanged(); break;
        case 5: _t->DayTemperatureChanged(); break;
        case 6: _t->NightTemperatureChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NightLightSettings::*)()>(_a, &NightLightSettings::ActiveEnabledChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NightLightSettings::*)()>(_a, &NightLightSettings::ActiveChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NightLightSettings::*)()>(_a, &NightLightSettings::ModeEnabledChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NightLightSettings::*)()>(_a, &NightLightSettings::ModeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (NightLightSettings::*)()>(_a, &NightLightSettings::NightTemperatureEnabledChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (NightLightSettings::*)()>(_a, &NightLightSettings::DayTemperatureChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (NightLightSettings::*)()>(_a, &NightLightSettings::NightTemperatureChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->activeEnabled(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isActiveEnabledImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultActiveEnabledValue(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->active(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isActiveImmutable(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->defaultActiveValue(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->modeEnabled(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isModeEnabledImmutable(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->defaultModeEnabledValue(); break;
        case 9: *reinterpret_cast<ColorCorrect::NightLightMode*>(_v) = _t->mode(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isModeImmutable(); break;
        case 11: *reinterpret_cast<ColorCorrect::NightLightMode*>(_v) = _t->defaultModeValue(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->nightTemperatureEnabled(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isNightTemperatureEnabledImmutable(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->defaultNightTemperatureEnabledValue(); break;
        case 15: *reinterpret_cast<int*>(_v) = _t->dayTemperature(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isDayTemperatureImmutable(); break;
        case 17: *reinterpret_cast<int*>(_v) = _t->defaultDayTemperatureValue(); break;
        case 18: *reinterpret_cast<int*>(_v) = _t->nightTemperature(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isNightTemperatureImmutable(); break;
        case 20: *reinterpret_cast<int*>(_v) = _t->defaultNightTemperatureValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setActiveEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setActive(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setModeEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setMode(*reinterpret_cast<ColorCorrect::NightLightMode*>(_v)); break;
        case 12: _t->setNightTemperatureEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 15: _t->setDayTemperature(*reinterpret_cast<int*>(_v)); break;
        case 18: _t->setNightTemperature(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *NightLightSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NightLightSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18NightLightSettingsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int NightLightSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void NightLightSettings::ActiveEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void NightLightSettings::ActiveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void NightLightSettings::ModeEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void NightLightSettings::ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void NightLightSettings::NightTemperatureEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void NightLightSettings::DayTemperatureChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void NightLightSettings::NightTemperatureChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
