// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "keyboardindicator_debug.h"


Q_LOGGING_CATEGORY(KEYBOARDINDICATOR_DEBUG, "org.kde.plasma.keyboardindicator", QtInfoMsg)

