/********************************************************************************
** Form generated from reading UI file 'killrunner_config.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KILLRUNNER_CONFIG_H
#define UI_KILLRUNNER_CONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_KillRunnerConfigUi
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *main;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *useTriggerWord;
    QHBoxLayout *layout_trigger;
    QLabel *label_trigger;
    KLineEdit *triggerWord;
    QHBoxLayout *layout_sorting;
    QLabel *label_sorting;
    KComboBox *sorting;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *KillRunnerConfigUi)
    {
        if (KillRunnerConfigUi->objectName().isEmpty())
            KillRunnerConfigUi->setObjectName("KillRunnerConfigUi");
        KillRunnerConfigUi->resize(308, 252);
        verticalLayout = new QVBoxLayout(KillRunnerConfigUi);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        main = new QGroupBox(KillRunnerConfigUi);
        main->setObjectName("main");
        verticalLayout_2 = new QVBoxLayout(main);
        verticalLayout_2->setObjectName("verticalLayout_2");
        useTriggerWord = new QCheckBox(main);
        useTriggerWord->setObjectName("useTriggerWord");
        useTriggerWord->setEnabled(true);
        useTriggerWord->setChecked(true);

        verticalLayout_2->addWidget(useTriggerWord);

        layout_trigger = new QHBoxLayout();
        layout_trigger->setObjectName("layout_trigger");
        label_trigger = new QLabel(main);
        label_trigger->setObjectName("label_trigger");

        layout_trigger->addWidget(label_trigger);

        triggerWord = new KLineEdit(main);
        triggerWord->setObjectName("triggerWord");
        triggerWord->setProperty("showClearButton", QVariant(true));

        layout_trigger->addWidget(triggerWord);


        verticalLayout_2->addLayout(layout_trigger);

        layout_sorting = new QHBoxLayout();
        layout_sorting->setObjectName("layout_sorting");
        label_sorting = new QLabel(main);
        label_sorting->setObjectName("label_sorting");

        layout_sorting->addWidget(label_sorting);

        sorting = new KComboBox(main);
        sorting->setObjectName("sorting");

        layout_sorting->addWidget(sorting);


        verticalLayout_2->addLayout(layout_sorting);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);


        verticalLayout->addWidget(main);

#if QT_CONFIG(shortcut)
        label_trigger->setBuddy(triggerWord);
        label_sorting->setBuddy(sorting);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(useTriggerWord, triggerWord);

        retranslateUi(KillRunnerConfigUi);
        QObject::connect(useTriggerWord, SIGNAL(toggled(bool)), triggerWord, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(KillRunnerConfigUi);
    } // setupUi

    void retranslateUi(QWidget *KillRunnerConfigUi)
    {
        main->setTitle(tr2i18n("Kill Applications Config", nullptr));
        useTriggerWord->setText(tr2i18n("&Use trigger word", nullptr));
        label_trigger->setText(tr2i18n("&Trigger word:", nullptr));
        label_sorting->setText(tr2i18n("&Sort by", nullptr));
#if QT_CONFIG(tooltip)
        sorting->setToolTip(tr2i18n("It is not sure, that this will take effect", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)KillRunnerConfigUi;
    } // retranslateUi

};

namespace Ui {
    class KillRunnerConfigUi: public Ui_KillRunnerConfigUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KILLRUNNER_CONFIG_H

