/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.impl.portal.Notification.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef PORTALNOTIFICATIONSADAPTOR_H
#define PORTALNOTIFICATIONSADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "portal_p.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.freedesktop.impl.portal.Notification
 */
class PortalNotificationsAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.freedesktop.impl.portal.Notification")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.freedesktop.impl.portal.Notification\">\n"
"    <property access=\"read\" type=\"u\" name=\"version\"/>\n"
"    <method name=\"AddNotification\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"app_id\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"id\"/>\n"
"      <arg direction=\"in\" type=\"a{sv}\" name=\"notification\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.In2\"/>\n"
"    </method>\n"
"    <method name=\"RemoveNotification\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"app_id\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"id\"/>\n"
"    </method>\n"
"    <signal name=\"ActionInvoked\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"app_id\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"id\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"action\"/>\n"
"      <arg direction=\"out\" type=\"av\" name=\"parameter\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    PortalNotificationsAdaptor(NotificationManager::Portal *parent);
    ~PortalNotificationsAdaptor() override;

    inline NotificationManager::Portal *parent() const
    { return static_cast<NotificationManager::Portal *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(uint version READ version)
    uint version() const;

public Q_SLOTS: // METHODS
    void AddNotification(const QString &app_id, const QString &id, const QVariantMap &notification);
    void RemoveNotification(const QString &app_id, const QString &id);
Q_SIGNALS: // SIGNALS
    void ActionInvoked(const QString &app_id, const QString &id, const QString &action, const QVariantList &parameter);
};

#endif
