// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#include "styledata.h"

#include "stylesettings.h"




StyleData::StyleData(QObject *parent)
: KCModuleData(parent)
, m_settings(new StyleSettings(this))

{
autoRegisterSkeletons();
}

StyleSettings *StyleData::settings() const
{
    return m_settings;
}





#include "moc_styledata.cpp"
