/****************************************************************************
** Meta object code from reading C++ file 'wallpapermodule.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/kcms/wallpaper/wallpapermodule.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'wallpapermodule.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15WallpaperModuleE_t {};
} // unnamed namespace

template <> constexpr inline auto WallpaperModule::qt_create_metaobjectdata<qt_meta_tag_ZN15WallpaperModuleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WallpaperModule",
        "wallpaperConfigurationChanged",
        "",
        "currentWallpaperPluginChanged",
        "selectedScreenChanged",
        "screensChanged",
        "allScreensChanged",
        "settingsSaved",
        "onScreenChanged",
        "onWallpaperChanged",
        "screenIdx",
        "setCurrentActivity",
        "activityId",
        "setSelectedScreen",
        "screenName",
        "configuration",
        "QQmlPropertyMap*",
        "currentWallpaper",
        "allScreens",
        "wallpaperPluginSource",
        "wallpaperConfigModel",
        "PlasmaQuick::ConfigModel*",
        "selectedScreen",
        "QScreen*",
        "screens",
        "QList<QScreen*>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'wallpaperConfigurationChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentWallpaperPluginChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectedScreenChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'screensChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'allScreensChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'settingsSaved'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onScreenChanged'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onWallpaperChanged'
        QtMocHelpers::SlotData<void(uint)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 10 },
        }}),
        // Slot 'setCurrentActivity'
        QtMocHelpers::SlotData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Method 'setSelectedScreen'
        QtMocHelpers::MethodData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'configuration'
        QtMocHelpers::PropertyData<QQmlPropertyMap*>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'currentWallpaper'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'allScreens'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'wallpaperPluginSource'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'wallpaperConfigModel'
        QtMocHelpers::PropertyData<PlasmaQuick::ConfigModel*>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'selectedScreen'
        QtMocHelpers::PropertyData<QScreen*>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'screens'
        QtMocHelpers::PropertyData<QList<QScreen*>>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WallpaperModule, qt_meta_tag_ZN15WallpaperModuleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WallpaperModule::staticMetaObject = { {
    QMetaObject::SuperData::link<KQuickConfigModule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15WallpaperModuleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15WallpaperModuleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15WallpaperModuleE_t>.metaTypes,
    nullptr
} };

void WallpaperModule::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WallpaperModule *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->wallpaperConfigurationChanged(); break;
        case 1: _t->currentWallpaperPluginChanged(); break;
        case 2: _t->selectedScreenChanged(); break;
        case 3: _t->screensChanged(); break;
        case 4: _t->allScreensChanged(); break;
        case 5: _t->settingsSaved(); break;
        case 6: _t->onScreenChanged(); break;
        case 7: _t->onWallpaperChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 8: _t->setCurrentActivity((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->setSelectedScreen((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WallpaperModule::*)()>(_a, &WallpaperModule::wallpaperConfigurationChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WallpaperModule::*)()>(_a, &WallpaperModule::currentWallpaperPluginChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (WallpaperModule::*)()>(_a, &WallpaperModule::selectedScreenChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (WallpaperModule::*)()>(_a, &WallpaperModule::screensChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (WallpaperModule::*)()>(_a, &WallpaperModule::allScreensChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (WallpaperModule::*)()>(_a, &WallpaperModule::settingsSaved, 5))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< PlasmaQuick::ConfigModel* >(); break;
        case 6:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QScreen*> >(); break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlPropertyMap* >(); break;
        case 5:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QScreen* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQmlPropertyMap**>(_v) = _t->wallpaperConfiguration(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->currentWallpaperPlugin(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->allScreens(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->wallpaperPluginSource(); break;
        case 4: *reinterpret_cast<PlasmaQuick::ConfigModel**>(_v) = _t->wallpaperConfigModel(); break;
        case 5: *reinterpret_cast<QScreen**>(_v) = _t->selectedScreen(); break;
        case 6: *reinterpret_cast<QList<QScreen*>*>(_v) = _t->screens(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setCurrentWallpaperPlugin(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setAllScreens(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *WallpaperModule::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WallpaperModule::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15WallpaperModuleE_t>.strings))
        return static_cast<void*>(this);
    return KQuickConfigModule::qt_metacast(_clname);
}

int WallpaperModule::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KQuickConfigModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void WallpaperModule::wallpaperConfigurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void WallpaperModule::currentWallpaperPluginChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void WallpaperModule::selectedScreenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void WallpaperModule::screensChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void WallpaperModule::allScreensChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void WallpaperModule::settingsSaved()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
