/****************************************************************************
** Meta object code from reading C++ file 'widgetexplorer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/components/shellprivate/widgetexplorer.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'widgetexplorer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12WidgetActionE_t {};
} // unnamed namespace

template <> constexpr inline auto WidgetAction::qt_create_metaobjectdata<qt_meta_tag_ZN12WidgetActionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WidgetAction",
        "separatorChanged",
        "",
        "separator"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'separatorChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'separator'
        QtMocHelpers::PropertyData<bool>(3, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WidgetAction, qt_meta_tag_ZN12WidgetActionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WidgetAction::staticMetaObject = { {
    QMetaObject::SuperData::link<QAction::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12WidgetActionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12WidgetActionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12WidgetActionE_t>.metaTypes,
    nullptr
} };

void WidgetAction::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WidgetAction *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->separatorChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WidgetAction::*)()>(_a, &WidgetAction::separatorChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isSeparator(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSeparator(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *WidgetAction::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WidgetAction::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12WidgetActionE_t>.strings))
        return static_cast<void*>(this);
    return QAction::qt_metacast(_clname);
}

int WidgetAction::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAction::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void WidgetAction::separatorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN14WidgetExplorerE_t {};
} // unnamed namespace

template <> constexpr inline auto WidgetExplorer::qt_create_metaobjectdata<qt_meta_tag_ZN14WidgetExplorerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WidgetExplorer",
        "QML.Element",
        "auto",
        "widgetsMenuActionsChanged",
        "",
        "extraActionsChanged",
        "shouldClose",
        "viewChanged",
        "applicationChanged",
        "containmentChanged",
        "providesChanged",
        "showSpecialFiltersChanged",
        "addApplet",
        "pluginName",
        "openWidgetFile",
        "downloadWidgets",
        "immutabilityChanged",
        "Plasma::Types::ImmutabilityType",
        "appletAdded",
        "Plasma::Applet*",
        "appletRemoved",
        "containmentDestroyed",
        "uninstall",
        "removeAllInstances",
        "widgetsModel",
        "filterModel",
        "showSpecialFilters",
        "widgetsMenuActions",
        "QList<QObject*>",
        "application",
        "provides",
        "containment",
        "Plasma::Containment*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'widgetsMenuActionsChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'extraActionsChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shouldClose'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'viewChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'applicationChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'containmentChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'providesChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showSpecialFiltersChanged'
        QtMocHelpers::SignalData<void() const>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addApplet'
        QtMocHelpers::SlotData<void(const QString &)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'openWidgetFile'
        QtMocHelpers::SlotData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'downloadWidgets'
        QtMocHelpers::SlotData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'immutabilityChanged'
        QtMocHelpers::SlotData<void(Plasma::Types::ImmutabilityType)>(16, 4, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 17, 4 },
        }}),
        // Slot 'appletAdded'
        QtMocHelpers::SlotData<void(Plasma::Applet *)>(18, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 4 },
        }}),
        // Slot 'appletRemoved'
        QtMocHelpers::SlotData<void(Plasma::Applet *)>(20, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 4 },
        }}),
        // Slot 'containmentDestroyed'
        QtMocHelpers::SlotData<void()>(21, 4, QMC::AccessPrivate, QMetaType::Void),
        // Method 'uninstall'
        QtMocHelpers::MethodData<void(const QString &)>(22, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Method 'removeAllInstances'
        QtMocHelpers::MethodData<void(const QString &)>(23, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'widgetsModel'
        QtMocHelpers::PropertyData<QObject*>(24, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'filterModel'
        QtMocHelpers::PropertyData<QObject*>(25, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showSpecialFilters'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'widgetsMenuActions'
        QtMocHelpers::PropertyData<QList<QObject*>>(27, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'application'
        QtMocHelpers::PropertyData<QString>(29, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'provides'
        QtMocHelpers::PropertyData<QStringList>(30, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'containment'
        QtMocHelpers::PropertyData<Plasma::Containment*>(31, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<WidgetExplorer, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject WidgetExplorer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14WidgetExplorerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14WidgetExplorerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14WidgetExplorerE_t>.metaTypes,
    nullptr
} };

void WidgetExplorer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WidgetExplorer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->widgetsMenuActionsChanged(); break;
        case 1: _t->extraActionsChanged(); break;
        case 2: _t->shouldClose(); break;
        case 3: _t->viewChanged(); break;
        case 4: _t->applicationChanged(); break;
        case 5: _t->containmentChanged(); break;
        case 6: _t->providesChanged(); break;
        case 7: _t->showSpecialFiltersChanged(); break;
        case 8: _t->addApplet((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->openWidgetFile(); break;
        case 10: _t->downloadWidgets(); break;
        case 11: _t->immutabilityChanged((*reinterpret_cast<std::add_pointer_t<Plasma::Types::ImmutabilityType>>(_a[1]))); break;
        case 12: _t->d->appletAdded((*reinterpret_cast<std::add_pointer_t<Plasma::Applet*>>(_a[1]))); break;
        case 13: _t->d->appletRemoved((*reinterpret_cast<std::add_pointer_t<Plasma::Applet*>>(_a[1]))); break;
        case 14: _t->d->containmentDestroyed(); break;
        case 15: _t->uninstall((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->removeAllInstances((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WidgetExplorer::*)()>(_a, &WidgetExplorer::widgetsMenuActionsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WidgetExplorer::*)()>(_a, &WidgetExplorer::extraActionsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (WidgetExplorer::*)()>(_a, &WidgetExplorer::shouldClose, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (WidgetExplorer::*)()>(_a, &WidgetExplorer::viewChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (WidgetExplorer::*)()>(_a, &WidgetExplorer::applicationChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (WidgetExplorer::*)()>(_a, &WidgetExplorer::containmentChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (WidgetExplorer::*)()>(_a, &WidgetExplorer::providesChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (WidgetExplorer::*)() const>(_a, &WidgetExplorer::showSpecialFiltersChanged, 7))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QObject*> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QObject**>(_v) = _t->widgetsModel(); break;
        case 1: *reinterpret_cast<QObject**>(_v) = _t->filterModel(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->showSpecialFilters(); break;
        case 3: *reinterpret_cast<QList<QObject*>*>(_v) = _t->widgetsMenuActions(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->application(); break;
        case 5: *reinterpret_cast<QStringList*>(_v) = _t->provides(); break;
        case 6: *reinterpret_cast<Plasma::Containment**>(_v) = _t->containment(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setShowSpecialFilters(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setApplication(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setProvides(*reinterpret_cast<QStringList*>(_v)); break;
        case 6: _t->setContainment(*reinterpret_cast<Plasma::Containment**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *WidgetExplorer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WidgetExplorer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14WidgetExplorerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QObject::qt_metacast(_clname);
}

int WidgetExplorer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void WidgetExplorer::widgetsMenuActionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void WidgetExplorer::extraActionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void WidgetExplorer::shouldClose()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void WidgetExplorer::viewChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void WidgetExplorer::applicationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void WidgetExplorer::containmentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void WidgetExplorer::providesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void WidgetExplorer::showSpecialFiltersChanged()const
{
    QMetaObject::activate(const_cast< WidgetExplorer *>(this), &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
