/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.impl.portal.Notification.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "portalnotificationsadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class PortalNotificationsAdaptor
 */

PortalNotificationsAdaptor::PortalNotificationsAdaptor(NotificationManager::Portal *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

PortalNotificationsAdaptor::~PortalNotificationsAdaptor()
{
    // destructor
}

uint PortalNotificationsAdaptor::version() const
{
    // get the value of property version
    return qvariant_cast< uint >(parent()->property("version"));
}

void PortalNotificationsAdaptor::AddNotification(const QString &app_id, const QString &id, const QVariantMap &notification)
{
    // handle method call org.freedesktop.impl.portal.Notification.AddNotification
    parent()->AddNotification(app_id, id, notification);
}

void PortalNotificationsAdaptor::RemoveNotification(const QString &app_id, const QString &id)
{
    // handle method call org.freedesktop.impl.portal.Notification.RemoveNotification
    parent()->RemoveNotification(app_id, id);
}


#include "moc_portalnotificationsadaptor.cpp"
