/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // main.xml
  0x0,0x0,0x1,0xcb,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x9c,0x5,0xd,0xe,0x0,0x26,0x97,0x46,0x1f,0x30,0xb1,0x1b,
  0x13,0x91,0x4c,0xd1,0xb2,0xdd,0x93,0xad,0x53,0xb1,0x17,0x4b,0x16,0xc5,0x41,0xb2,
  0x4d,0x53,0xb2,0x6f,0x8a,0x91,0x7d,0xb0,0xb0,0x40,0xa0,0x4,0x41,0x0,0x3d,0x0,
  0x3b,0x0,0x95,0x47,0x18,0xc,0xa,0x86,0x4d,0xba,0x6,0xb1,0xce,0x7b,0x3e,0x55,
  0x38,0x51,0xf8,0xfe,0xaa,0xda,0xf,0x4f,0xd7,0xb3,0x6d,0xdb,0x7b,0x88,0xec,0xdf,
  0x72,0x9,0xa7,0x5b,0x51,0xf1,0x82,0x9c,0x48,0xe1,0xe,0x82,0xc6,0x84,0xe2,0x12,
  0x15,0x95,0x53,0x47,0xca,0xeb,0x6,0xf,0xc1,0x25,0x68,0x4b,0xaf,0x9c,0xd9,0x89,
  0x69,0x14,0x50,0x17,0x38,0xdf,0xe5,0xa3,0xa2,0xb2,0xbe,0x94,0x6d,0x7e,0x5d,0xe5,
  0xa9,0x46,0x3c,0xc2,0x4d,0x7d,0xca,0x50,0xe4,0x26,0xac,0x4c,0xd9,0x91,0x69,0x5d,
  0x2b,0x27,0x7a,0xce,0x25,0x18,0x83,0x74,0x79,0x4a,0x6a,0xd7,0x89,0xd6,0x4d,0xae,
  0x79,0x1e,0xc6,0x7e,0x38,0x42,0x3a,0x47,0x2a,0x5,0x10,0x63,0x2b,0x4a,0xf,0x48,
  0x7d,0x61,0xc9,0x83,0xd8,0x27,0xa4,0xa2,0x9f,0x1a,0xa4,0x78,0xc2,0xf8,0x7d,0xe3,
  0x5b,0x4f,0xeb,0xdb,0xbf,0x59,0x2f,0x85,0xbb,0xb5,0x25,0xcd,0xee,0x5,0xdd,0x9a,
  0xf1,0x9a,0x25,0xbd,0xb3,0x86,0xe1,0x6a,0xd9,0xda,0xf2,0xf7,0xa0,0xe7,0x79,0x66,
  0x19,0x5c,0xb6,0x7e,0xa9,0xdc,0xa5,0x7a,0xa3,0xc9,0x1,0x4e,0x54,0x51,0xf1,0x7a,
  0x90,0xe3,0x44,0xf,0xc2,0xa0,0x24,0xc0,0xf,0x69,0xe5,0x8b,0xb4,0x0,0x7b,0x5d,
  0x2e,0x19,0x3d,0x99,0x28,0x67,0xae,0x79,0x65,0xd7,0xb6,0xb2,0x53,0xac,0xf8,0x72,
  0xf3,0x2b,0xf6,0xd4,0xea,0xfb,0xb2,0xf5,0xbb,0x81,0x33,0x73,0x39,0x31,0xd7,0x28,
  0x4d,0xad,0xab,0x7e,0xd4,0xef,0x42,0x20,0x30,0x86,0x10,0x82,0x8c,0x17,0x3,0x66,
  0x25,0x60,0x47,0x38,0x61,0xb8,0xc0,0x2f,0xa5,0x41,0x60,0x3a,0x3f,0x7b,0x73,0xa8,
  0xcc,0x80,0x97,0xc,0x78,0x99,0x3f,0x93,0x5,0x29,0xc7,0xc2,0x98,0x78,0x65,0x22,
  0x88,0x2c,0xc1,0x6e,0x5,0xf9,0x78,0x12,0x50,0x46,0x93,0xd2,0x2,0x85,0x8b,0x45,
  0x91,0x79,0x92,0x8f,0xd4,0x20,0x3a,0xc1,0xdb,0xb,0x91,0xee,0xe6,0x89,0x6b,0x7b,
  0xf7,0x60,0x56,0x20,0x1a,0x40,0xe4,0x5,0xdc,0xba,0x38,0x30,0xf0,0x90,0xb3,0xa0,
  0x71,0x7,0x28,0x7,0x22,0x7e,0x12,0x7c,0x9f,0xb0,0xfa,0x9e,0xa,0x19,0xb2,0x2d,
  0x8d,0x23,0xaa,0x52,0xd7,0x3,0xd5,0x2d,0x3a,0xc1,0xab,0x10,0xb0,0x23,0xcb,0xa,
  0xed,0x5c,0x5c,0x53,0x57,0x6d,0x23,0x69,0x7e,0x85,0x97,0xf,0x9a,0x1,0x40,0xf,
  0x4a,0x3d,0xed,0x68,0xe4,0xab,0xf8,0x92,0x2d,0xdd,0x16,0x6f,0x8f,0xae,0x39,0x0,
  0x1b,0x15,0x96,0x85,0x65,0x25,0x75,0x80,0xd0,0x3,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // plasma
  0x0,0x6,
  0x7,0x72,0x8a,0x31,
  0x0,0x70,
  0x0,0x6c,0x0,0x61,0x0,0x73,0x0,0x6d,0x0,0x61,
    // applet
  0x0,0x6,
  0x6,0x87,0x72,0xc4,
  0x0,0x61,
  0x0,0x70,0x0,0x70,0x0,0x6c,0x0,0x65,0x0,0x74,
    // org
  0x0,0x3,
  0x0,0x0,0x76,0x87,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,
    // kde
  0x0,0x3,
  0x0,0x0,0x71,0xa5,
  0x0,0x6b,
  0x0,0x64,0x0,0x65,
    // lock_logout
  0x0,0xb,
  0x6,0xd3,0x92,0xe4,
  0x0,0x6c,
  0x0,0x6f,0x0,0x63,0x0,0x6b,0x0,0x5f,0x0,0x6c,0x0,0x6f,0x0,0x67,0x0,0x6f,0x0,0x75,0x0,0x74,
    // main.xml
  0x0,0x8,
  0x8,0x1,0x51,0x5c,
  0x0,0x6d,
  0x0,0x61,0x0,0x69,0x0,0x6e,0x0,0x2e,0x0,0x78,0x0,0x6d,0x0,0x6c,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9e,0xf3,0xef,0xe5,0xf0,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9e,0xf3,0xef,0xe5,0xf0,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9e,0xf3,0xef,0xe5,0xf0,
  // :/qt/qml/plasma
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x9e,0xf3,0xef,0xe5,0xf0,
  // :/qt/qml/plasma/applet
  0x0,0x0,0x0,0x28,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x9e,0xf3,0xef,0xe5,0xf0,
  // :/qt/qml/plasma/applet/org
  0x0,0x0,0x0,0x3a,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x6,
0x0,0x0,0x1,0x9e,0xf3,0xef,0xe5,0xf0,
  // :/qt/qml/plasma/applet/org/kde
  0x0,0x0,0x0,0x46,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x7,
0x0,0x0,0x1,0x9e,0xf3,0xef,0xe5,0xf0,
  // :/qt/qml/plasma/applet/org/kde/plasma
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x8,
0x0,0x0,0x1,0x9e,0xf3,0xef,0xe5,0xf0,
  // :/qt/qml/plasma/applet/org/kde/plasma/lock_logout
  0x0,0x0,0x0,0x52,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x9,
0x0,0x0,0x1,0x9e,0xf3,0xef,0xe5,0xf0,
  // :/qt/qml/plasma/applet/org/kde/plasma/lock_logout/main.xml
  0x0,0x0,0x0,0x6e,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9e,0xf3,0xef,0xe5,0xf0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_org_kde_plasma_lock_logout_raw_res_1)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_org_kde_plasma_lock_logout_raw_res_1)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_org_kde_plasma_lock_logout_raw_res_1)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_org_kde_plasma_lock_logout_raw_res_1)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_org_kde_plasma_lock_logout_raw_res_1)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_org_kde_plasma_lock_logout_raw_res_1)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
