// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#ifndef NIGHTTIMEDATA_H
#define NIGHTTIMEDATA_H

#include <QObject>

#include "kcmoduledata.h"



class NightTimeSettings;


class NightTimeData : public KCModuleData
{
    Q_OBJECT

public:
    explicit NightTimeData(QObject *parent = nullptr);
    NightTimeSettings *settings() const;


private:
    NightTimeSettings *m_settings;

};



#endif
