/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<appletcontainer.h>)
#  include <appletcontainer.h>
#endif
#if __has_include(<appletslayout.h>)
#  include <appletslayout.h>
#endif
#if __has_include(<configoverlay.h>)
#  include <configoverlay.h>
#endif
#if __has_include(<itemcontainer.h>)
#  include <itemcontainer.h>
#endif
#if __has_include(<plasmabackground.h>)
#  include <plasmabackground.h>
#endif
#if __has_include(<resizehandle.h>)
#  include <resizehandle.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_plasma_private_containmentlayoutmanager()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<AppletContainer>("org.kde.plasma.private.containmentlayoutmanager", 1);
    qmlRegisterAnonymousType<QQuickItem, 254>("org.kde.plasma.private.containmentlayoutmanager", 1);
    qmlRegisterTypesAndRevisions<AppletsLayout>("org.kde.plasma.private.containmentlayoutmanager", 1);
    qmlRegisterEnum<AppletsLayout::PreferredLayoutDirection>("AppletsLayout::PreferredLayoutDirection");
    qmlRegisterEnum<AppletsLayout::EditModeCondition>("AppletsLayout::EditModeCondition");
    qmlRegisterTypesAndRevisions<ConfigOverlay>("org.kde.plasma.private.containmentlayoutmanager", 1);
    qmlRegisterTypesAndRevisions<ItemContainer>("org.kde.plasma.private.containmentlayoutmanager", 1);
    qmlRegisterEnum<ItemContainer::EditModeCondition>("ItemContainer::EditModeCondition");
    qmlRegisterTypesAndRevisions<PlasmaBackground>("org.kde.plasma.private.containmentlayoutmanager", 1);
    qmlRegisterTypesAndRevisions<ResizeHandle>("org.kde.plasma.private.containmentlayoutmanager", 1);
    qmlRegisterEnum<ResizeHandle::Corner>("ResizeHandle::Corner");
    QT_WARNING_POP
    qmlRegisterModule("org.kde.plasma.private.containmentlayoutmanager", 1, 0);
}

static const QQmlModuleRegistration orgkdeplasmaprivatecontainmentlayoutmanagerRegistration("org.kde.plasma.private.containmentlayoutmanager", qml_register_types_org_kde_plasma_private_containmentlayoutmanager);
