/****************************************************************************
** Meta object code from reading C++ file 'klookandfeelmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-workspace-6.7.1/libklookandfeel/klookandfeelmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'klookandfeelmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19KLookAndFeelManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto KLookAndFeelManager::qt_create_metaobjectdata<qt_meta_tag_ZN19KLookAndFeelManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KLookAndFeelManager",
        "message",
        "",
        "iconsChanged",
        "colorsChanged",
        "styleChanged",
        "newStyle",
        "cursorsChanged",
        "fontsChanged",
        "plasmaLockedChanged",
        "locked",
        "Contents",
        "ContentFlags",
        "Empty",
        "Colors",
        "WidgetStyle",
        "WindowDecoration",
        "Icons",
        "PlasmaTheme",
        "Cursors",
        "Fonts",
        "WindowSwitcher",
        "SplashScreen",
        "Wallpaper",
        "BorderSize",
        "AppearanceSettings",
        "DesktopLayout",
        "TitlebarLayout",
        "WindowPlacement",
        "ShellPackage",
        "LayoutSettings",
        "RunCommand",
        "LogOutScript",
        "KWinSettings",
        "AllSettings",
        "BlendChanges"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'message'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iconsChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorsChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'styleChanged'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'cursorsChanged'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'fontsChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'plasmaLockedChanged'
        QtMocHelpers::SignalData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // flag 'Contents'
        QtMocHelpers::EnumData<Contents>(11, 12, QMC::EnumIsFlag).add({
            {   13, ContentFlags::Empty },
            {   14, ContentFlags::Colors },
            {   15, ContentFlags::WidgetStyle },
            {   16, ContentFlags::WindowDecoration },
            {   17, ContentFlags::Icons },
            {   18, ContentFlags::PlasmaTheme },
            {   19, ContentFlags::Cursors },
            {   20, ContentFlags::Fonts },
            {   21, ContentFlags::WindowSwitcher },
            {   22, ContentFlags::SplashScreen },
            {   23, ContentFlags::Wallpaper },
            {   24, ContentFlags::BorderSize },
            {   25, ContentFlags::AppearanceSettings },
            {   26, ContentFlags::DesktopLayout },
            {   27, ContentFlags::TitlebarLayout },
            {   28, ContentFlags::WindowPlacement },
            {   29, ContentFlags::ShellPackage },
            {   30, ContentFlags::LayoutSettings },
            {   31, ContentFlags::RunCommand },
            {   32, ContentFlags::LogOutScript },
            {   33, ContentFlags::KWinSettings },
            {   34, ContentFlags::AllSettings },
            {   35, ContentFlags::BlendChanges },
        }),
    };
    return QtMocHelpers::metaObjectData<KLookAndFeelManager, qt_meta_tag_ZN19KLookAndFeelManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KLookAndFeelManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19KLookAndFeelManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19KLookAndFeelManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19KLookAndFeelManagerE_t>.metaTypes,
    nullptr
} };

void KLookAndFeelManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KLookAndFeelManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->message(); break;
        case 1: _t->iconsChanged(); break;
        case 2: _t->colorsChanged(); break;
        case 3: _t->styleChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->cursorsChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->fontsChanged(); break;
        case 6: _t->plasmaLockedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KLookAndFeelManager::*)()>(_a, &KLookAndFeelManager::message, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KLookAndFeelManager::*)()>(_a, &KLookAndFeelManager::iconsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KLookAndFeelManager::*)()>(_a, &KLookAndFeelManager::colorsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KLookAndFeelManager::*)(const QString & )>(_a, &KLookAndFeelManager::styleChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KLookAndFeelManager::*)(const QString & )>(_a, &KLookAndFeelManager::cursorsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KLookAndFeelManager::*)()>(_a, &KLookAndFeelManager::fontsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KLookAndFeelManager::*)(bool )>(_a, &KLookAndFeelManager::plasmaLockedChanged, 6))
            return;
    }
}

const QMetaObject *KLookAndFeelManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KLookAndFeelManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19KLookAndFeelManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KLookAndFeelManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void KLookAndFeelManager::message()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KLookAndFeelManager::iconsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KLookAndFeelManager::colorsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KLookAndFeelManager::styleChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KLookAndFeelManager::cursorsChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KLookAndFeelManager::fontsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KLookAndFeelManager::plasmaLockedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
