/****************************************************************************
** Meta object code from reading C++ file 'server.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-workspace-6.7.1/libnotificationmanager/server.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'server.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19NotificationManager6ServerE_t {};
} // unnamed namespace

template <> constexpr inline auto NotificationManager::Server::qt_create_metaobjectdata<qt_meta_tag_ZN19NotificationManager6ServerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NotificationManager::Server",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "validChanged",
        "",
        "notificationAdded",
        "Notification",
        "notification",
        "notificationReplaced",
        "replacedId",
        "notificationRemoved",
        "id",
        "CloseReason",
        "reason",
        "inhibitedChanged",
        "inhibited",
        "inhibitedByApplicationChanged",
        "inhibitionApplicationsChanged",
        "serviceOwnershipLost",
        "valid",
        "currentOwner",
        "NotificationManager::ServerInfo*",
        "Expired",
        "DismissedByUser",
        "Revoked"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'validChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'notificationAdded'
        QtMocHelpers::SignalData<void(const Notification &)>(7, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'notificationReplaced'
        QtMocHelpers::SignalData<void(uint, const Notification &)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 11 }, { 0x80000000 | 8, 9 },
        }}),
        // Signal 'notificationRemoved'
        QtMocHelpers::SignalData<void(uint, enum CloseReason)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 13 }, { 0x80000000 | 14, 15 },
        }}),
        // Signal 'inhibitedChanged'
        QtMocHelpers::SignalData<void(bool)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Signal 'inhibitedByApplicationChanged'
        QtMocHelpers::SignalData<void(bool)>(18, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Signal 'inhibitionApplicationsChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'serviceOwnershipLost'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'valid'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'currentOwner'
        QtMocHelpers::PropertyData<NotificationManager::ServerInfo*>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'inhibited'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'CloseReason'
        QtMocHelpers::EnumData<enum CloseReason>(14, 14, QMC::EnumIsScoped).add({
            {   24, CloseReason::Expired },
            {   25, CloseReason::DismissedByUser },
            {   26, CloseReason::Revoked },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<Server, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject NotificationManager::Server::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationManager6ServerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationManager6ServerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19NotificationManager6ServerE_t>.metaTypes,
    nullptr
} };

void NotificationManager::Server::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Server *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->validChanged(); break;
        case 1: _t->notificationAdded((*reinterpret_cast<std::add_pointer_t<Notification>>(_a[1]))); break;
        case 2: _t->notificationReplaced((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Notification>>(_a[2]))); break;
        case 3: _t->notificationRemoved((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<enum CloseReason>>(_a[2]))); break;
        case 4: _t->inhibitedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->inhibitedByApplicationChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->inhibitionApplicationsChanged(); break;
        case 7: _t->serviceOwnershipLost(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Server::*)()>(_a, &Server::validChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Server::*)(const Notification & )>(_a, &Server::notificationAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Server::*)(uint , const Notification & )>(_a, &Server::notificationReplaced, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Server::*)(uint , CloseReason )>(_a, &Server::notificationRemoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Server::*)(bool )>(_a, &Server::inhibitedChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Server::*)(bool )>(_a, &Server::inhibitedByApplicationChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Server::*)()>(_a, &Server::inhibitionApplicationsChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Server::*)()>(_a, &Server::serviceOwnershipLost, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isValid(); break;
        case 1: *reinterpret_cast<NotificationManager::ServerInfo**>(_v) = _t->currentOwner(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->inhibited(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setInhibited(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *NotificationManager::Server::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NotificationManager::Server::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationManager6ServerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int NotificationManager::Server::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void NotificationManager::Server::validChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void NotificationManager::Server::notificationAdded(const Notification & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void NotificationManager::Server::notificationReplaced(uint _t1, const Notification & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void NotificationManager::Server::notificationRemoved(uint _t1, CloseReason _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void NotificationManager::Server::inhibitedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void NotificationManager::Server::inhibitedByApplicationChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void NotificationManager::Server::inhibitionApplicationsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void NotificationManager::Server::serviceOwnershipLost()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
