/****************************************************************************
** Meta object code from reading C++ file 'configoverlay.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/components/containmentlayoutmanager/configoverlay.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'configoverlay.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13ConfigOverlayE_t {};
} // unnamed namespace

template <> constexpr inline auto ConfigOverlay::qt_create_metaobjectdata<qt_meta_tag_ZN13ConfigOverlayE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ConfigOverlay",
        "QML.Element",
        "auto",
        "openChanged",
        "",
        "open",
        "itemContainerChanged",
        "leftAvailableSpaceChanged",
        "topAvailableSpaceChanged",
        "rightAvailableSpaceChanged",
        "bottomAvailableSpaceChanged",
        "touchInteractionChanged",
        "itemContainer",
        "ItemContainer*",
        "leftAvailableSpace",
        "topAvailableSpace",
        "rightAvailableSpace",
        "bottomAvailableSpace",
        "touchInteraction"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'openChanged'
        QtMocHelpers::SignalData<void(bool)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'itemContainerChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'leftAvailableSpaceChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'topAvailableSpaceChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rightAvailableSpaceChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bottomAvailableSpaceChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'touchInteractionChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'open'
        QtMocHelpers::PropertyData<bool>(5, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'itemContainer'
        QtMocHelpers::PropertyData<ItemContainer*>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'leftAvailableSpace'
        QtMocHelpers::PropertyData<qreal>(14, QMetaType::QReal, QMC::DefaultPropertyFlags, 2),
        // property 'topAvailableSpace'
        QtMocHelpers::PropertyData<qreal>(15, QMetaType::QReal, QMC::DefaultPropertyFlags, 3),
        // property 'rightAvailableSpace'
        QtMocHelpers::PropertyData<qreal>(16, QMetaType::QReal, QMC::DefaultPropertyFlags, 4),
        // property 'bottomAvailableSpace'
        QtMocHelpers::PropertyData<qreal>(17, QMetaType::QReal, QMC::DefaultPropertyFlags, 5),
        // property 'touchInteraction'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ConfigOverlay, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ConfigOverlay::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ConfigOverlayE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ConfigOverlayE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13ConfigOverlayE_t>.metaTypes,
    nullptr
} };

void ConfigOverlay::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ConfigOverlay *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->openChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->itemContainerChanged(); break;
        case 2: _t->leftAvailableSpaceChanged(); break;
        case 3: _t->topAvailableSpaceChanged(); break;
        case 4: _t->rightAvailableSpaceChanged(); break;
        case 5: _t->bottomAvailableSpaceChanged(); break;
        case 6: _t->touchInteractionChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ConfigOverlay::*)(bool )>(_a, &ConfigOverlay::openChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConfigOverlay::*)()>(_a, &ConfigOverlay::itemContainerChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConfigOverlay::*)()>(_a, &ConfigOverlay::leftAvailableSpaceChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConfigOverlay::*)()>(_a, &ConfigOverlay::topAvailableSpaceChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConfigOverlay::*)()>(_a, &ConfigOverlay::rightAvailableSpaceChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConfigOverlay::*)()>(_a, &ConfigOverlay::bottomAvailableSpaceChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConfigOverlay::*)()>(_a, &ConfigOverlay::touchInteractionChanged, 6))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ItemContainer* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->open(); break;
        case 1: *reinterpret_cast<ItemContainer**>(_v) = _t->itemContainer(); break;
        case 2: *reinterpret_cast<qreal*>(_v) = _t->leftAvailableSpace(); break;
        case 3: *reinterpret_cast<qreal*>(_v) = _t->topAvailableSpace(); break;
        case 4: *reinterpret_cast<qreal*>(_v) = _t->rightAvailableSpace(); break;
        case 5: *reinterpret_cast<qreal*>(_v) = _t->bottomAvailableSpace(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->touchInteraction(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setOpen(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ConfigOverlay::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ConfigOverlay::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ConfigOverlayE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int ConfigOverlay::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void ConfigOverlay::openChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ConfigOverlay::itemContainerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ConfigOverlay::leftAvailableSpaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ConfigOverlay::topAvailableSpaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ConfigOverlay::rightAvailableSpaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ConfigOverlay::bottomAvailableSpaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ConfigOverlay::touchInteractionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
