/********************************************************************************
** Form generated from reading UI file 'setpreview.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETPREVIEW_H
#define UI_SETPREVIEW_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_setpreview
{
public:
    QGridLayout *gridLayout;
    QWidget *widgetFore0;
    QHBoxLayout *horizontalLayout;
    QLabel *labelFore0;
    QWidget *widgetFore3;
    QHBoxLayout *horizontalLayout_2;
    QLabel *labelFore3;
    QWidget *widgetFore4;
    QHBoxLayout *horizontalLayout_3;
    QLabel *labelFore4;
    QWidget *widgetFore2;
    QHBoxLayout *horizontalLayout_4;
    QLabel *labelFore2;
    QWidget *widgetFore1;
    QHBoxLayout *horizontalLayout_5;
    QLabel *labelFore1;
    QWidget *widgetFore5;
    QHBoxLayout *horizontalLayout_6;
    QLabel *labelFore5;
    QWidget *widgetFore6;
    QHBoxLayout *horizontalLayout_7;
    QLabel *labelFore6;
    QWidget *widgetFore7;
    QHBoxLayout *horizontalLayout_8;
    QLabel *labelFore7;
    QWidget *widgetFore8;
    QHBoxLayout *horizontalLayout_9;
    QLabel *labelFore8;
    QWidget *widgetBack0;
    QHBoxLayout *horizontalLayout_11;
    QLabel *labelBack0;
    QWidget *widgetBack3;
    QHBoxLayout *horizontalLayout_12;
    QLabel *labelBack3;
    QWidget *widgetBack4;
    QHBoxLayout *horizontalLayout_13;
    QLabel *labelBack4;
    QWidget *widgetBack2;
    QHBoxLayout *horizontalLayout_14;
    QLabel *labelBack2;
    QWidget *widgetBack1;
    QHBoxLayout *horizontalLayout_15;
    QLabel *labelBack1;
    QWidget *widgetBack5;
    QHBoxLayout *horizontalLayout_16;
    QLabel *labelBack5;
    QWidget *widgetBack6;
    QHBoxLayout *horizontalLayout_17;
    QLabel *labelBack6;
    QWidget *widgetBack7;
    QHBoxLayout *horizontalLayout_18;
    QLabel *labelBack7;
    QWidget *widgetFore9;
    QHBoxLayout *horizontalLayout_10;
    QLabel *labelFore9;

    void setupUi(QFrame *setpreview)
    {
        if (setpreview->objectName().isEmpty())
            setpreview->setObjectName("setpreview");
        setpreview->resize(550, 96);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(setpreview->sizePolicy().hasHeightForWidth());
        setpreview->setSizePolicy(sizePolicy);
        setpreview->setFrameShape(QFrame::StyledPanel);
        setpreview->setFrameShadow(QFrame::Sunken);
        gridLayout = new QGridLayout(setpreview);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setHorizontalSpacing(0);
        widgetFore0 = new QWidget(setpreview);
        widgetFore0->setObjectName("widgetFore0");
        horizontalLayout = new QHBoxLayout(widgetFore0);
        horizontalLayout->setObjectName("horizontalLayout");
        labelFore0 = new QLabel(widgetFore0);
        labelFore0->setObjectName("labelFore0");

        horizontalLayout->addWidget(labelFore0);


        gridLayout->addWidget(widgetFore0, 0, 0, 1, 1);

        widgetFore3 = new QWidget(setpreview);
        widgetFore3->setObjectName("widgetFore3");
        horizontalLayout_2 = new QHBoxLayout(widgetFore3);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        labelFore3 = new QLabel(widgetFore3);
        labelFore3->setObjectName("labelFore3");
        QFont font;
        font.setUnderline(true);
        labelFore3->setFont(font);

        horizontalLayout_2->addWidget(labelFore3);


        gridLayout->addWidget(widgetFore3, 0, 1, 1, 1);

        widgetFore4 = new QWidget(setpreview);
        widgetFore4->setObjectName("widgetFore4");
        horizontalLayout_3 = new QHBoxLayout(widgetFore4);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        labelFore4 = new QLabel(widgetFore4);
        labelFore4->setObjectName("labelFore4");
        labelFore4->setFont(font);

        horizontalLayout_3->addWidget(labelFore4);


        gridLayout->addWidget(widgetFore4, 0, 2, 1, 1);

        widgetFore2 = new QWidget(setpreview);
        widgetFore2->setObjectName("widgetFore2");
        horizontalLayout_4 = new QHBoxLayout(widgetFore2);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        labelFore2 = new QLabel(widgetFore2);
        labelFore2->setObjectName("labelFore2");

        horizontalLayout_4->addWidget(labelFore2);


        gridLayout->addWidget(widgetFore2, 0, 3, 1, 1);

        widgetFore1 = new QWidget(setpreview);
        widgetFore1->setObjectName("widgetFore1");
        horizontalLayout_5 = new QHBoxLayout(widgetFore1);
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        labelFore1 = new QLabel(widgetFore1);
        labelFore1->setObjectName("labelFore1");

        horizontalLayout_5->addWidget(labelFore1);


        gridLayout->addWidget(widgetFore1, 0, 4, 1, 1);

        widgetFore5 = new QWidget(setpreview);
        widgetFore5->setObjectName("widgetFore5");
        horizontalLayout_6 = new QHBoxLayout(widgetFore5);
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        labelFore5 = new QLabel(widgetFore5);
        labelFore5->setObjectName("labelFore5");

        horizontalLayout_6->addWidget(labelFore5);


        gridLayout->addWidget(widgetFore5, 0, 5, 1, 1);

        widgetFore6 = new QWidget(setpreview);
        widgetFore6->setObjectName("widgetFore6");
        horizontalLayout_7 = new QHBoxLayout(widgetFore6);
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        labelFore6 = new QLabel(widgetFore6);
        labelFore6->setObjectName("labelFore6");

        horizontalLayout_7->addWidget(labelFore6);


        gridLayout->addWidget(widgetFore6, 0, 6, 1, 1);

        widgetFore7 = new QWidget(setpreview);
        widgetFore7->setObjectName("widgetFore7");
        horizontalLayout_8 = new QHBoxLayout(widgetFore7);
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        labelFore7 = new QLabel(widgetFore7);
        labelFore7->setObjectName("labelFore7");

        horizontalLayout_8->addWidget(labelFore7);


        gridLayout->addWidget(widgetFore7, 0, 7, 1, 1);

        widgetFore8 = new QWidget(setpreview);
        widgetFore8->setObjectName("widgetFore8");
        horizontalLayout_9 = new QHBoxLayout(widgetFore8);
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        labelFore8 = new QLabel(widgetFore8);
        labelFore8->setObjectName("labelFore8");

        horizontalLayout_9->addWidget(labelFore8);


        gridLayout->addWidget(widgetFore8, 0, 8, 1, 1);

        widgetBack0 = new QWidget(setpreview);
        widgetBack0->setObjectName("widgetBack0");
        horizontalLayout_11 = new QHBoxLayout(widgetBack0);
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        labelBack0 = new QLabel(widgetBack0);
        labelBack0->setObjectName("labelBack0");

        horizontalLayout_11->addWidget(labelBack0);


        gridLayout->addWidget(widgetBack0, 1, 0, 1, 1);

        widgetBack3 = new QWidget(setpreview);
        widgetBack3->setObjectName("widgetBack3");
        horizontalLayout_12 = new QHBoxLayout(widgetBack3);
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        labelBack3 = new QLabel(widgetBack3);
        labelBack3->setObjectName("labelBack3");
        labelBack3->setFont(font);

        horizontalLayout_12->addWidget(labelBack3);


        gridLayout->addWidget(widgetBack3, 1, 1, 1, 1);

        widgetBack4 = new QWidget(setpreview);
        widgetBack4->setObjectName("widgetBack4");
        horizontalLayout_13 = new QHBoxLayout(widgetBack4);
        horizontalLayout_13->setObjectName("horizontalLayout_13");
        labelBack4 = new QLabel(widgetBack4);
        labelBack4->setObjectName("labelBack4");
        labelBack4->setFont(font);

        horizontalLayout_13->addWidget(labelBack4);


        gridLayout->addWidget(widgetBack4, 1, 2, 1, 1);

        widgetBack2 = new QWidget(setpreview);
        widgetBack2->setObjectName("widgetBack2");
        horizontalLayout_14 = new QHBoxLayout(widgetBack2);
        horizontalLayout_14->setObjectName("horizontalLayout_14");
        labelBack2 = new QLabel(widgetBack2);
        labelBack2->setObjectName("labelBack2");

        horizontalLayout_14->addWidget(labelBack2);


        gridLayout->addWidget(widgetBack2, 1, 3, 1, 1);

        widgetBack1 = new QWidget(setpreview);
        widgetBack1->setObjectName("widgetBack1");
        horizontalLayout_15 = new QHBoxLayout(widgetBack1);
        horizontalLayout_15->setObjectName("horizontalLayout_15");
        labelBack1 = new QLabel(widgetBack1);
        labelBack1->setObjectName("labelBack1");

        horizontalLayout_15->addWidget(labelBack1);


        gridLayout->addWidget(widgetBack1, 1, 4, 1, 1);

        widgetBack5 = new QWidget(setpreview);
        widgetBack5->setObjectName("widgetBack5");
        horizontalLayout_16 = new QHBoxLayout(widgetBack5);
        horizontalLayout_16->setObjectName("horizontalLayout_16");
        labelBack5 = new QLabel(widgetBack5);
        labelBack5->setObjectName("labelBack5");

        horizontalLayout_16->addWidget(labelBack5);


        gridLayout->addWidget(widgetBack5, 1, 5, 1, 1);

        widgetBack6 = new QWidget(setpreview);
        widgetBack6->setObjectName("widgetBack6");
        horizontalLayout_17 = new QHBoxLayout(widgetBack6);
        horizontalLayout_17->setObjectName("horizontalLayout_17");
        labelBack6 = new QLabel(widgetBack6);
        labelBack6->setObjectName("labelBack6");

        horizontalLayout_17->addWidget(labelBack6);


        gridLayout->addWidget(widgetBack6, 1, 6, 1, 1);

        widgetBack7 = new QWidget(setpreview);
        widgetBack7->setObjectName("widgetBack7");
        horizontalLayout_18 = new QHBoxLayout(widgetBack7);
        horizontalLayout_18->setObjectName("horizontalLayout_18");
        labelBack7 = new QLabel(widgetBack7);
        labelBack7->setObjectName("labelBack7");

        horizontalLayout_18->addWidget(labelBack7);


        gridLayout->addWidget(widgetBack7, 1, 7, 1, 1);

        widgetFore9 = new QWidget(setpreview);
        widgetFore9->setObjectName("widgetFore9");
        horizontalLayout_10 = new QHBoxLayout(widgetFore9);
        horizontalLayout_10->setObjectName("horizontalLayout_10");
        labelFore9 = new QLabel(widgetFore9);
        labelFore9->setObjectName("labelFore9");

        horizontalLayout_10->addWidget(labelFore9);


        gridLayout->addWidget(widgetFore9, 1, 8, 1, 1);


        retranslateUi(setpreview);

        QMetaObject::connectSlotsByName(setpreview);
    } // setupUi

    void retranslateUi(QFrame *setpreview)
    {
#if QT_CONFIG(tooltip)
        labelFore0->setToolTip(tr2i18n("Normal Text on Normal Background", nullptr));
#endif // QT_CONFIG(tooltip)
        labelFore0->setText(tr2i18n("normal", "color-kcm-set-preview"));
#if QT_CONFIG(tooltip)
        labelFore3->setToolTip(tr2i18n("Link Text on Normal Background", nullptr));
#endif // QT_CONFIG(tooltip)
        labelFore3->setText(tr2i18n("link", "color-kcm-set-preview"));
#if QT_CONFIG(tooltip)
        labelFore4->setToolTip(tr2i18n("Visited Text on Normal Background", nullptr));
#endif // QT_CONFIG(tooltip)
        labelFore4->setText(tr2i18n("visited", "color-kcm-set-preview"));
#if QT_CONFIG(tooltip)
        widgetFore2->setToolTip(tr2i18n("Active Text on Normal Background", nullptr));
#endif // QT_CONFIG(tooltip)
        labelFore2->setText(tr2i18n("active", "color-kcm-set-preview"));
#if QT_CONFIG(tooltip)
        labelFore1->setToolTip(tr2i18n("Inactive Text on Normal Background", nullptr));
#endif // QT_CONFIG(tooltip)
        labelFore1->setText(tr2i18n("inactive", "color-kcm-set-preview"));
#if QT_CONFIG(tooltip)
        labelFore5->setToolTip(tr2i18n("Negative Text on Normal Background", nullptr));
#endif // QT_CONFIG(tooltip)
        labelFore5->setText(tr2i18n("negative", "color-kcm-set-preview"));
#if QT_CONFIG(tooltip)
        labelFore6->setToolTip(tr2i18n("Neutral Text on Normal Background", nullptr));
#endif // QT_CONFIG(tooltip)
        labelFore6->setText(tr2i18n("neutral", "color-kcm-set-preview"));
#if QT_CONFIG(tooltip)
        labelFore7->setToolTip(tr2i18n("Positive Text on Normal Background", nullptr));
#endif // QT_CONFIG(tooltip)
        labelFore7->setText(tr2i18n("positive", "color-kcm-set-preview"));
#if QT_CONFIG(tooltip)
        widgetFore8->setToolTip(tr2i18n("Hover on Normal Background", nullptr));
#endif // QT_CONFIG(tooltip)
        labelFore8->setText(tr2i18n("hover", "color-kcm-set-preview"));
#if QT_CONFIG(tooltip)
        labelBack0->setToolTip(tr2i18n("Normal Text on Normal Background", nullptr));
#endif // QT_CONFIG(tooltip)
        labelBack0->setText(tr2i18n("normal", "color-kcm-set-preview"));
#if QT_CONFIG(tooltip)
        labelBack3->setToolTip(tr2i18n("Link Text on Link Background\n"
"(Note: Link Background is derived from Link Text and cannot be separately configured at this time)", nullptr));
#endif // QT_CONFIG(tooltip)
        labelBack3->setText(tr2i18n("link", "color-kcm-set-preview"));
#if QT_CONFIG(tooltip)
        labelBack4->setToolTip(tr2i18n("Visited Text on Visited Background\n"
"(Note: Visited Background is derived from Visited Text and cannot be separately configured at this time)", nullptr));
#endif // QT_CONFIG(tooltip)
        labelBack4->setText(tr2i18n("visited", "color-kcm-set-preview"));
#if QT_CONFIG(tooltip)
        labelBack2->setToolTip(tr2i18n("Active Text on Active Background\n"
"(Note: Active Background is derived from Active Text and cannot be separately configured at this time)", nullptr));
#endif // QT_CONFIG(tooltip)
        labelBack2->setText(tr2i18n("active", "color-kcm-set-preview"));
#if QT_CONFIG(tooltip)
        labelBack1->setToolTip(tr2i18n("Inactive Text on Alternate Background", nullptr));
#endif // QT_CONFIG(tooltip)
        labelBack1->setText(tr2i18n("alternate", "color-kcm-set-preview"));
#if QT_CONFIG(tooltip)
        labelBack5->setToolTip(tr2i18n("Negative Text on Negative Background\n"
"(Note: Negative Background is derived from Negative Text and cannot be separately configured at this time)", nullptr));
#endif // QT_CONFIG(tooltip)
        labelBack5->setText(tr2i18n("negative", "color-kcm-set-preview"));
#if QT_CONFIG(tooltip)
        labelBack6->setToolTip(tr2i18n("Neutral Text on Neutral Background\n"
"(Note: Neutral Background is derived from Neutral Text and cannot be separately configured at this time)", nullptr));
#endif // QT_CONFIG(tooltip)
        labelBack6->setText(tr2i18n("neutral", "color-kcm-set-preview"));
#if QT_CONFIG(tooltip)
        labelBack7->setToolTip(tr2i18n("Positive Text on Positive Background\n"
"(Note: Positive Background is derived from Positive Text and cannot be separately configured at this time)", nullptr));
#endif // QT_CONFIG(tooltip)
        labelBack7->setText(tr2i18n("positive", "color-kcm-set-preview"));
#if QT_CONFIG(tooltip)
        labelFore9->setToolTip(tr2i18n("Focus on Normal Background", nullptr));
#endif // QT_CONFIG(tooltip)
        labelFore9->setText(tr2i18n("focus", "color-kcm-set-preview"));
        (void)setpreview;
    } // retranslateUi

};

namespace Ui {
    class setpreview: public Ui_setpreview {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETPREVIEW_H

