// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#ifndef SOUNDTHEMEDATA_H
#define SOUNDTHEMEDATA_H

#include <QObject>

#include "kcmoduledata.h"



class SoundThemeSettings;


class SoundThemeData : public KCModuleData
{
    Q_OBJECT

public:
    explicit SoundThemeData(QObject *parent = nullptr);
    SoundThemeSettings *settings() const;


private:
    SoundThemeSettings *m_settings;

};



#endif
