/****************************************************************************
** Meta object code from reading C++ file 'itemcontainer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.1/components/containmentlayoutmanager/itemcontainer.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'itemcontainer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13ItemContainerE_t {};
} // unnamed namespace

template <> constexpr inline auto ItemContainer::qt_create_metaobjectdata<qt_meta_tag_ZN13ItemContainerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ItemContainer",
        "QML.Element",
        "auto",
        "DefaultProperty",
        "contentData",
        "userDrag",
        "",
        "QPointF",
        "newPosition",
        "dragCenter",
        "dragActiveChanged",
        "sizeHintsChanged",
        "layoutChanged",
        "keyChanged",
        "editModeConditionChanged",
        "editModeChanged",
        "editMode",
        "preferredLayoutDirectionChanged",
        "configOverlaySourceChanged",
        "configOverlayItemChanged",
        "initialSizeChanged",
        "configOverlayVisibleChanged",
        "configOverlayVisile",
        "backgroundChanged",
        "contentItemChanged",
        "leftPaddingChanged",
        "rightPaddingChanged",
        "topPaddingChanged",
        "bottomPaddingChanged",
        "contentWidthChanged",
        "contentHeightChanged",
        "onConfigOverlayComponentStatusChanged",
        "QQmlComponent::Status",
        "status",
        "QQmlComponent*",
        "component",
        "cancelEdit",
        "layout",
        "AppletsLayout*",
        "key",
        "editModeCondition",
        "ItemContainer::EditModeCondition",
        "dragActive",
        "preferredLayoutDirection",
        "AppletsLayout::PreferredLayoutDirection",
        "configOverlaySource",
        "QUrl",
        "configOverlayVisible",
        "configOverlayItem",
        "QQuickItem*",
        "initialSize",
        "QSizeF",
        "contentItem",
        "background",
        "leftPadding",
        "rightPadding",
        "topPadding",
        "bottomPadding",
        "contentWidth",
        "contentHeight",
        "QQmlListProperty<QObject>",
        "EditModeCondition",
        "Locked",
        "Manual",
        "AfterPressAndHold",
        "AfterPress",
        "AfterMouseOver"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'userDrag'
        QtMocHelpers::SignalData<void(const QPointF &, const QPointF &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 7, 9 },
        }}),
        // Signal 'dragActiveChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sizeHintsChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'layoutChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'keyChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'editModeConditionChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'editModeChanged'
        QtMocHelpers::SignalData<void(bool)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
        // Signal 'preferredLayoutDirectionChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'configOverlaySourceChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'configOverlayItemChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'initialSizeChanged'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'configOverlayVisibleChanged'
        QtMocHelpers::SignalData<void(bool)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Signal 'backgroundChanged'
        QtMocHelpers::SignalData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'contentItemChanged'
        QtMocHelpers::SignalData<void()>(24, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'leftPaddingChanged'
        QtMocHelpers::SignalData<void()>(25, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rightPaddingChanged'
        QtMocHelpers::SignalData<void()>(26, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'topPaddingChanged'
        QtMocHelpers::SignalData<void()>(27, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bottomPaddingChanged'
        QtMocHelpers::SignalData<void()>(28, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'contentWidthChanged'
        QtMocHelpers::SignalData<void()>(29, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'contentHeightChanged'
        QtMocHelpers::SignalData<void()>(30, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onConfigOverlayComponentStatusChanged'
        QtMocHelpers::SlotData<void(QQmlComponent::Status, QQmlComponent *)>(31, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 32, 33 }, { 0x80000000 | 34, 35 },
        }}),
        // Slot 'onConfigOverlayComponentStatusChanged'
        QtMocHelpers::SlotData<void(QQmlComponent::Status)>(31, 6, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
        // Method 'cancelEdit'
        QtMocHelpers::MethodData<void()>(36, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'layout'
        QtMocHelpers::PropertyData<AppletsLayout*>(37, 0x80000000 | 38, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'key'
        QtMocHelpers::PropertyData<QString>(39, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'editModeCondition'
        QtMocHelpers::PropertyData<ItemContainer::EditModeCondition>(40, 0x80000000 | 41, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'editMode'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'dragActive'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'preferredLayoutDirection'
        QtMocHelpers::PropertyData<AppletsLayout::PreferredLayoutDirection>(43, 0x80000000 | 44, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'configOverlaySource'
        QtMocHelpers::PropertyData<QUrl>(45, 0x80000000 | 46, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 8),
        // property 'configOverlayVisible'
        QtMocHelpers::PropertyData<bool>(47, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'configOverlayItem'
        QtMocHelpers::PropertyData<QQuickItem*>(48, 0x80000000 | 49, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 9),
        // property 'initialSize'
        QtMocHelpers::PropertyData<QSizeF>(50, 0x80000000 | 51, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 10),
        // property 'contentItem'
        QtMocHelpers::PropertyData<QQuickItem*>(52, 0x80000000 | 49, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 13),
        // property 'background'
        QtMocHelpers::PropertyData<QQuickItem*>(53, 0x80000000 | 49, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 12),
        // property 'leftPadding'
        QtMocHelpers::PropertyData<int>(54, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'rightPadding'
        QtMocHelpers::PropertyData<int>(55, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'topPadding'
        QtMocHelpers::PropertyData<int>(56, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'bottomPadding'
        QtMocHelpers::PropertyData<int>(57, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'contentWidth'
        QtMocHelpers::PropertyData<int>(58, QMetaType::Int, QMC::DefaultPropertyFlags, 18),
        // property 'contentHeight'
        QtMocHelpers::PropertyData<int>(59, QMetaType::Int, QMC::DefaultPropertyFlags, 19),
        // property 'contentData'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(4, 0x80000000 | 60, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'EditModeCondition'
        QtMocHelpers::EnumData<enum EditModeCondition>(61, 61, QMC::EnumFlags{}).add({
            {   62, EditModeCondition::Locked },
            {   63, EditModeCondition::Manual },
            {   64, EditModeCondition::AfterPressAndHold },
            {   65, EditModeCondition::AfterPress },
            {   66, EditModeCondition::AfterMouseOver },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<ItemContainer, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN13ItemContainerE[] = {
    QMetaObject::SuperData::link<AppletsLayout::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject ItemContainer::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ItemContainerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ItemContainerE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN13ItemContainerE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13ItemContainerE_t>.metaTypes,
    nullptr
} };

void ItemContainer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ItemContainer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->userDrag((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2]))); break;
        case 1: _t->dragActiveChanged(); break;
        case 2: _t->sizeHintsChanged(); break;
        case 3: _t->layoutChanged(); break;
        case 4: _t->keyChanged(); break;
        case 5: _t->editModeConditionChanged(); break;
        case 6: _t->editModeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->preferredLayoutDirectionChanged(); break;
        case 8: _t->configOverlaySourceChanged(); break;
        case 9: _t->configOverlayItemChanged(); break;
        case 10: _t->initialSizeChanged(); break;
        case 11: _t->configOverlayVisibleChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->backgroundChanged(); break;
        case 13: _t->contentItemChanged(); break;
        case 14: _t->leftPaddingChanged(); break;
        case 15: _t->rightPaddingChanged(); break;
        case 16: _t->topPaddingChanged(); break;
        case 17: _t->bottomPaddingChanged(); break;
        case 18: _t->contentWidthChanged(); break;
        case 19: _t->contentHeightChanged(); break;
        case 20: _t->onConfigOverlayComponentStatusChanged((*reinterpret_cast<std::add_pointer_t<QQmlComponent::Status>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QQmlComponent*>>(_a[2]))); break;
        case 21: _t->onConfigOverlayComponentStatusChanged((*reinterpret_cast<std::add_pointer_t<QQmlComponent::Status>>(_a[1]))); break;
        case 22: _t->cancelEdit(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQmlComponent* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ItemContainer::*)(const QPointF & , const QPointF & )>(_a, &ItemContainer::userDrag, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ItemContainer::*)()>(_a, &ItemContainer::dragActiveChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ItemContainer::*)()>(_a, &ItemContainer::sizeHintsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ItemContainer::*)()>(_a, &ItemContainer::layoutChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ItemContainer::*)()>(_a, &ItemContainer::keyChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ItemContainer::*)()>(_a, &ItemContainer::editModeConditionChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ItemContainer::*)(bool )>(_a, &ItemContainer::editModeChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ItemContainer::*)()>(_a, &ItemContainer::preferredLayoutDirectionChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ItemContainer::*)()>(_a, &ItemContainer::configOverlaySourceChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ItemContainer::*)()>(_a, &ItemContainer::configOverlayItemChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ItemContainer::*)()>(_a, &ItemContainer::initialSizeChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (ItemContainer::*)(bool )>(_a, &ItemContainer::configOverlayVisibleChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (ItemContainer::*)()>(_a, &ItemContainer::backgroundChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (ItemContainer::*)()>(_a, &ItemContainer::contentItemChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (ItemContainer::*)()>(_a, &ItemContainer::leftPaddingChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (ItemContainer::*)()>(_a, &ItemContainer::rightPaddingChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (ItemContainer::*)()>(_a, &ItemContainer::topPaddingChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (ItemContainer::*)()>(_a, &ItemContainer::bottomPaddingChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (ItemContainer::*)()>(_a, &ItemContainer::contentWidthChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (ItemContainer::*)()>(_a, &ItemContainer::contentHeightChanged, 19))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< AppletsLayout* >(); break;
        case 11:
        case 10:
        case 8:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<AppletsLayout**>(_v) = _t->layout(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->key(); break;
        case 2: *reinterpret_cast<ItemContainer::EditModeCondition*>(_v) = _t->editModeCondition(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->editMode(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->dragActive(); break;
        case 5: *reinterpret_cast<AppletsLayout::PreferredLayoutDirection*>(_v) = _t->preferredLayoutDirection(); break;
        case 6: *reinterpret_cast<QUrl*>(_v) = _t->configOverlaySource(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->configOverlayVisible(); break;
        case 8: *reinterpret_cast<QQuickItem**>(_v) = _t->configOverlayItem(); break;
        case 9: *reinterpret_cast<QSizeF*>(_v) = _t->initialSize(); break;
        case 10: *reinterpret_cast<QQuickItem**>(_v) = _t->contentItem(); break;
        case 11: *reinterpret_cast<QQuickItem**>(_v) = _t->background(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->leftPadding(); break;
        case 13: *reinterpret_cast<int*>(_v) = _t->rightPadding(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->topPadding(); break;
        case 15: *reinterpret_cast<int*>(_v) = _t->bottomPadding(); break;
        case 16: *reinterpret_cast<int*>(_v) = _t->contentWidth(); break;
        case 17: *reinterpret_cast<int*>(_v) = _t->contentHeight(); break;
        case 18: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->contentData(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setKey(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setEditModeCondition(*reinterpret_cast<ItemContainer::EditModeCondition*>(_v)); break;
        case 3: _t->setEditMode(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setPreferredLayoutDirection(*reinterpret_cast<AppletsLayout::PreferredLayoutDirection*>(_v)); break;
        case 6: _t->setConfigOverlaySource(*reinterpret_cast<QUrl*>(_v)); break;
        case 7: _t->setConfigOverlayVisible(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setInitialSize(*reinterpret_cast<QSizeF*>(_v)); break;
        case 10: _t->setContentItem(*reinterpret_cast<QQuickItem**>(_v)); break;
        case 11: _t->setBackground(*reinterpret_cast<QQuickItem**>(_v)); break;
        case 12: _t->setLeftPadding(*reinterpret_cast<int*>(_v)); break;
        case 13: _t->setRightPadding(*reinterpret_cast<int*>(_v)); break;
        case 14: _t->setTopPadding(*reinterpret_cast<int*>(_v)); break;
        case 15: _t->setBottomPadding(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ItemContainer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ItemContainer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ItemContainerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int ItemContainer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void ItemContainer::userDrag(const QPointF & _t1, const QPointF & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void ItemContainer::dragActiveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ItemContainer::sizeHintsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ItemContainer::layoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ItemContainer::keyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ItemContainer::editModeConditionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ItemContainer::editModeChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void ItemContainer::preferredLayoutDirectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void ItemContainer::configOverlaySourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void ItemContainer::configOverlayItemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void ItemContainer::initialSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void ItemContainer::configOverlayVisibleChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void ItemContainer::backgroundChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void ItemContainer::contentItemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void ItemContainer::leftPaddingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void ItemContainer::rightPaddingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void ItemContainer::topPaddingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void ItemContainer::bottomPaddingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void ItemContainer::contentWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void ItemContainer::contentHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}
QT_WARNING_POP
