/********************************************************************************
** Form generated from reading UI file 'scmeditorcolors.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SCMEDITORCOLORS_H
#define UI_SCMEDITORCOLORS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "previewwidget.h"
#include "setpreviewwidget.h"

QT_BEGIN_NAMESPACE

class Ui_ScmEditorColors
{
public:
    QGridLayout *gridLayout;
    QLabel *label_7;
    QComboBox *colorSet;
    QStackedWidget *stackColors;
    QWidget *pageCommonColors;
    QGridLayout *gridLayout1;
    QTableWidget *commonColorTable;
    QWidget *pageSetColors;
    QGridLayout *_2;
    QTableWidget *colorTable;
    QStackedWidget *stackPreview;
    QWidget *pageCommonPreview;
    QVBoxLayout *verticalLayout;
    PreviewWidget *colorPreview;
    QWidget *pageSetPreview;
    QVBoxLayout *verticalLayout_5;
    SetPreviewWidget *setPreview;

    void setupUi(QWidget *ScmEditorColors)
    {
        if (ScmEditorColors->objectName().isEmpty())
            ScmEditorColors->setObjectName("ScmEditorColors");
        ScmEditorColors->resize(400, 300);
        gridLayout = new QGridLayout(ScmEditorColors);
        gridLayout->setObjectName("gridLayout");
        label_7 = new QLabel(ScmEditorColors);
        label_7->setObjectName("label_7");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_7->sizePolicy().hasHeightForWidth());
        label_7->setSizePolicy(sizePolicy);

        gridLayout->addWidget(label_7, 1, 0, 1, 1);

        colorSet = new QComboBox(ScmEditorColors);
        colorSet->addItem(QString());
        colorSet->addItem(QString());
        colorSet->addItem(QString());
        colorSet->addItem(QString());
        colorSet->addItem(QString());
        colorSet->addItem(QString());
        colorSet->addItem(QString());
        colorSet->addItem(QString());
        colorSet->setObjectName("colorSet");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(colorSet->sizePolicy().hasHeightForWidth());
        colorSet->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(colorSet, 1, 1, 1, 1);

        stackColors = new QStackedWidget(ScmEditorColors);
        stackColors->setObjectName("stackColors");
        pageCommonColors = new QWidget();
        pageCommonColors->setObjectName("pageCommonColors");
        gridLayout1 = new QGridLayout(pageCommonColors);
        gridLayout1->setObjectName("gridLayout1");
        gridLayout1->setContentsMargins(0, 0, 0, 0);
        commonColorTable = new QTableWidget(pageCommonColors);
        if (commonColorTable->columnCount() < 2)
            commonColorTable->setColumnCount(2);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        commonColorTable->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        commonColorTable->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        if (commonColorTable->rowCount() < 26)
            commonColorTable->setRowCount(26);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        commonColorTable->setVerticalHeaderItem(0, __qtablewidgetitem2);
        QTableWidgetItem *__qtablewidgetitem3 = new QTableWidgetItem();
        commonColorTable->setVerticalHeaderItem(1, __qtablewidgetitem3);
        QTableWidgetItem *__qtablewidgetitem4 = new QTableWidgetItem();
        commonColorTable->setVerticalHeaderItem(2, __qtablewidgetitem4);
        QTableWidgetItem *__qtablewidgetitem5 = new QTableWidgetItem();
        commonColorTable->setVerticalHeaderItem(3, __qtablewidgetitem5);
        QTableWidgetItem *__qtablewidgetitem6 = new QTableWidgetItem();
        commonColorTable->setVerticalHeaderItem(4, __qtablewidgetitem6);
        QTableWidgetItem *__qtablewidgetitem7 = new QTableWidgetItem();
        commonColorTable->setVerticalHeaderItem(5, __qtablewidgetitem7);
        QTableWidgetItem *__qtablewidgetitem8 = new QTableWidgetItem();
        commonColorTable->setVerticalHeaderItem(6, __qtablewidgetitem8);
        QTableWidgetItem *__qtablewidgetitem9 = new QTableWidgetItem();
        commonColorTable->setVerticalHeaderItem(7, __qtablewidgetitem9);
        QTableWidgetItem *__qtablewidgetitem10 = new QTableWidgetItem();
        commonColorTable->setVerticalHeaderItem(8, __qtablewidgetitem10);
        QTableWidgetItem *__qtablewidgetitem11 = new QTableWidgetItem();
        commonColorTable->setVerticalHeaderItem(9, __qtablewidgetitem11);
        QTableWidgetItem *__qtablewidgetitem12 = new QTableWidgetItem();
        commonColorTable->setVerticalHeaderItem(10, __qtablewidgetitem12);
        QTableWidgetItem *__qtablewidgetitem13 = new QTableWidgetItem();
        commonColorTable->setVerticalHeaderItem(11, __qtablewidgetitem13);
        QTableWidgetItem *__qtablewidgetitem14 = new QTableWidgetItem();
        commonColorTable->setVerticalHeaderItem(12, __qtablewidgetitem14);
        QTableWidgetItem *__qtablewidgetitem15 = new QTableWidgetItem();
        commonColorTable->setVerticalHeaderItem(13, __qtablewidgetitem15);
        QTableWidgetItem *__qtablewidgetitem16 = new QTableWidgetItem();
        commonColorTable->setVerticalHeaderItem(14, __qtablewidgetitem16);
        QTableWidgetItem *__qtablewidgetitem17 = new QTableWidgetItem();
        commonColorTable->setVerticalHeaderItem(15, __qtablewidgetitem17);
        QTableWidgetItem *__qtablewidgetitem18 = new QTableWidgetItem();
        commonColorTable->setVerticalHeaderItem(16, __qtablewidgetitem18);
        QTableWidgetItem *__qtablewidgetitem19 = new QTableWidgetItem();
        commonColorTable->setVerticalHeaderItem(17, __qtablewidgetitem19);
        QTableWidgetItem *__qtablewidgetitem20 = new QTableWidgetItem();
        commonColorTable->setVerticalHeaderItem(18, __qtablewidgetitem20);
        QTableWidgetItem *__qtablewidgetitem21 = new QTableWidgetItem();
        commonColorTable->setVerticalHeaderItem(19, __qtablewidgetitem21);
        QTableWidgetItem *__qtablewidgetitem22 = new QTableWidgetItem();
        commonColorTable->setVerticalHeaderItem(20, __qtablewidgetitem22);
        QTableWidgetItem *__qtablewidgetitem23 = new QTableWidgetItem();
        commonColorTable->setVerticalHeaderItem(21, __qtablewidgetitem23);
        QTableWidgetItem *__qtablewidgetitem24 = new QTableWidgetItem();
        commonColorTable->setVerticalHeaderItem(22, __qtablewidgetitem24);
        QTableWidgetItem *__qtablewidgetitem25 = new QTableWidgetItem();
        commonColorTable->setVerticalHeaderItem(23, __qtablewidgetitem25);
        QTableWidgetItem *__qtablewidgetitem26 = new QTableWidgetItem();
        commonColorTable->setVerticalHeaderItem(24, __qtablewidgetitem26);
        QTableWidgetItem *__qtablewidgetitem27 = new QTableWidgetItem();
        commonColorTable->setVerticalHeaderItem(25, __qtablewidgetitem27);
        QTableWidgetItem *__qtablewidgetitem28 = new QTableWidgetItem();
        commonColorTable->setItem(0, 0, __qtablewidgetitem28);
        QTableWidgetItem *__qtablewidgetitem29 = new QTableWidgetItem();
        commonColorTable->setItem(1, 0, __qtablewidgetitem29);
        QTableWidgetItem *__qtablewidgetitem30 = new QTableWidgetItem();
        commonColorTable->setItem(2, 0, __qtablewidgetitem30);
        QTableWidgetItem *__qtablewidgetitem31 = new QTableWidgetItem();
        commonColorTable->setItem(3, 0, __qtablewidgetitem31);
        QTableWidgetItem *__qtablewidgetitem32 = new QTableWidgetItem();
        commonColorTable->setItem(4, 0, __qtablewidgetitem32);
        QTableWidgetItem *__qtablewidgetitem33 = new QTableWidgetItem();
        commonColorTable->setItem(5, 0, __qtablewidgetitem33);
        QTableWidgetItem *__qtablewidgetitem34 = new QTableWidgetItem();
        commonColorTable->setItem(6, 0, __qtablewidgetitem34);
        QTableWidgetItem *__qtablewidgetitem35 = new QTableWidgetItem();
        commonColorTable->setItem(7, 0, __qtablewidgetitem35);
        QTableWidgetItem *__qtablewidgetitem36 = new QTableWidgetItem();
        commonColorTable->setItem(8, 0, __qtablewidgetitem36);
        QTableWidgetItem *__qtablewidgetitem37 = new QTableWidgetItem();
        commonColorTable->setItem(9, 0, __qtablewidgetitem37);
        QTableWidgetItem *__qtablewidgetitem38 = new QTableWidgetItem();
        commonColorTable->setItem(10, 0, __qtablewidgetitem38);
        QTableWidgetItem *__qtablewidgetitem39 = new QTableWidgetItem();
        commonColorTable->setItem(11, 0, __qtablewidgetitem39);
        QTableWidgetItem *__qtablewidgetitem40 = new QTableWidgetItem();
        commonColorTable->setItem(12, 0, __qtablewidgetitem40);
        QTableWidgetItem *__qtablewidgetitem41 = new QTableWidgetItem();
        commonColorTable->setItem(13, 0, __qtablewidgetitem41);
        QTableWidgetItem *__qtablewidgetitem42 = new QTableWidgetItem();
        commonColorTable->setItem(14, 0, __qtablewidgetitem42);
        QTableWidgetItem *__qtablewidgetitem43 = new QTableWidgetItem();
        commonColorTable->setItem(15, 0, __qtablewidgetitem43);
        QTableWidgetItem *__qtablewidgetitem44 = new QTableWidgetItem();
        commonColorTable->setItem(16, 0, __qtablewidgetitem44);
        QTableWidgetItem *__qtablewidgetitem45 = new QTableWidgetItem();
        commonColorTable->setItem(17, 0, __qtablewidgetitem45);
        QTableWidgetItem *__qtablewidgetitem46 = new QTableWidgetItem();
        commonColorTable->setItem(18, 0, __qtablewidgetitem46);
        QTableWidgetItem *__qtablewidgetitem47 = new QTableWidgetItem();
        commonColorTable->setItem(19, 0, __qtablewidgetitem47);
        QTableWidgetItem *__qtablewidgetitem48 = new QTableWidgetItem();
        commonColorTable->setItem(20, 0, __qtablewidgetitem48);
        QTableWidgetItem *__qtablewidgetitem49 = new QTableWidgetItem();
        commonColorTable->setItem(21, 0, __qtablewidgetitem49);
        QTableWidgetItem *__qtablewidgetitem50 = new QTableWidgetItem();
        commonColorTable->setItem(22, 0, __qtablewidgetitem50);
        QTableWidgetItem *__qtablewidgetitem51 = new QTableWidgetItem();
        commonColorTable->setItem(23, 0, __qtablewidgetitem51);
        QTableWidgetItem *__qtablewidgetitem52 = new QTableWidgetItem();
        commonColorTable->setItem(24, 0, __qtablewidgetitem52);
        QTableWidgetItem *__qtablewidgetitem53 = new QTableWidgetItem();
        commonColorTable->setItem(25, 0, __qtablewidgetitem53);
        commonColorTable->setObjectName("commonColorTable");
        commonColorTable->setEditTriggers(QAbstractItemView::NoEditTriggers);
        commonColorTable->setSelectionMode(QAbstractItemView::SingleSelection);
        commonColorTable->setSelectionBehavior(QAbstractItemView::SelectRows);
        commonColorTable->setWordWrap(true);
        commonColorTable->setColumnCount(2);

        gridLayout1->addWidget(commonColorTable, 1, 0, 1, 1);

        stackColors->addWidget(pageCommonColors);
        pageSetColors = new QWidget();
        pageSetColors->setObjectName("pageSetColors");
        _2 = new QGridLayout(pageSetColors);
        _2->setObjectName("_2");
        _2->setContentsMargins(0, 0, 0, 0);
        colorTable = new QTableWidget(pageSetColors);
        if (colorTable->columnCount() < 2)
            colorTable->setColumnCount(2);
        colorTable->setObjectName("colorTable");
        colorTable->setEditTriggers(QAbstractItemView::NoEditTriggers);
        colorTable->setSelectionMode(QAbstractItemView::SingleSelection);
        colorTable->setSelectionBehavior(QAbstractItemView::SelectRows);
        colorTable->setWordWrap(true);
        colorTable->setColumnCount(2);

        _2->addWidget(colorTable, 0, 0, 1, 1);

        stackColors->addWidget(pageSetColors);

        gridLayout->addWidget(stackColors, 2, 0, 1, 2);

        stackPreview = new QStackedWidget(ScmEditorColors);
        stackPreview->setObjectName("stackPreview");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(stackPreview->sizePolicy().hasHeightForWidth());
        stackPreview->setSizePolicy(sizePolicy2);
        pageCommonPreview = new QWidget();
        pageCommonPreview->setObjectName("pageCommonPreview");
        verticalLayout = new QVBoxLayout(pageCommonPreview);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        colorPreview = new PreviewWidget(pageCommonPreview);
        colorPreview->setObjectName("colorPreview");
        sizePolicy2.setHeightForWidth(colorPreview->sizePolicy().hasHeightForWidth());
        colorPreview->setSizePolicy(sizePolicy2);
        colorPreview->setMinimumSize(QSize(0, 10));

        verticalLayout->addWidget(colorPreview);

        stackPreview->addWidget(pageCommonPreview);
        pageSetPreview = new QWidget();
        pageSetPreview->setObjectName("pageSetPreview");
        verticalLayout_5 = new QVBoxLayout(pageSetPreview);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalLayout_5->setContentsMargins(0, 0, 0, 0);
        setPreview = new SetPreviewWidget(pageSetPreview);
        setPreview->setObjectName("setPreview");
        sizePolicy2.setHeightForWidth(setPreview->sizePolicy().hasHeightForWidth());
        setPreview->setSizePolicy(sizePolicy2);
        setPreview->setMinimumSize(QSize(0, 10));

        verticalLayout_5->addWidget(setPreview);

        stackPreview->addWidget(pageSetPreview);

        gridLayout->addWidget(stackPreview, 0, 0, 1, 2);


        retranslateUi(ScmEditorColors);

        stackColors->setCurrentIndex(1);
        stackPreview->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(ScmEditorColors);
    } // setupUi

    void retranslateUi(QWidget *ScmEditorColors)
    {
        label_7->setText(tr2i18n("Color set:", nullptr));
        colorSet->setItemText(0, tr2i18n("Common colors", "color-sets"));
        colorSet->setItemText(1, tr2i18n("View", "color-sets"));
        colorSet->setItemText(2, tr2i18n("Window", "color-sets"));
        colorSet->setItemText(3, tr2i18n("Button", "color-sets"));
        colorSet->setItemText(4, tr2i18n("Selection", "color-sets"));
        colorSet->setItemText(5, tr2i18n("Tooltip", "color-sets"));
        colorSet->setItemText(6, tr2i18n("Complementary", "color-sets"));
        colorSet->setItemText(7, tr2i18n("Header", "color-sets"));

#if QT_CONFIG(tooltip)
        colorSet->setToolTip(tr2i18n("Colorset to view/modify", nullptr));
#endif // QT_CONFIG(tooltip)
        QTableWidgetItem *___qtablewidgetitem = commonColorTable->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(tr2i18n("0", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = commonColorTable->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(tr2i18n("1", nullptr));
        QTableWidgetItem *___qtablewidgetitem2 = commonColorTable->verticalHeaderItem(0);
        ___qtablewidgetitem2->setText(tr2i18n("New Row", nullptr));
        QTableWidgetItem *___qtablewidgetitem3 = commonColorTable->verticalHeaderItem(1);
        ___qtablewidgetitem3->setText(tr2i18n("New Row", nullptr));
        QTableWidgetItem *___qtablewidgetitem4 = commonColorTable->verticalHeaderItem(2);
        ___qtablewidgetitem4->setText(tr2i18n("New Row", nullptr));
        QTableWidgetItem *___qtablewidgetitem5 = commonColorTable->verticalHeaderItem(3);
        ___qtablewidgetitem5->setText(tr2i18n("New Row", nullptr));
        QTableWidgetItem *___qtablewidgetitem6 = commonColorTable->verticalHeaderItem(4);
        ___qtablewidgetitem6->setText(tr2i18n("New Row", nullptr));
        QTableWidgetItem *___qtablewidgetitem7 = commonColorTable->verticalHeaderItem(5);
        ___qtablewidgetitem7->setText(tr2i18n("New Row", nullptr));
        QTableWidgetItem *___qtablewidgetitem8 = commonColorTable->verticalHeaderItem(6);
        ___qtablewidgetitem8->setText(tr2i18n("New Row", nullptr));
        QTableWidgetItem *___qtablewidgetitem9 = commonColorTable->verticalHeaderItem(7);
        ___qtablewidgetitem9->setText(tr2i18n("New Row", nullptr));
        QTableWidgetItem *___qtablewidgetitem10 = commonColorTable->verticalHeaderItem(8);
        ___qtablewidgetitem10->setText(tr2i18n("New Row", nullptr));
        QTableWidgetItem *___qtablewidgetitem11 = commonColorTable->verticalHeaderItem(9);
        ___qtablewidgetitem11->setText(tr2i18n("New Row", nullptr));
        QTableWidgetItem *___qtablewidgetitem12 = commonColorTable->verticalHeaderItem(10);
        ___qtablewidgetitem12->setText(tr2i18n("New Row", nullptr));
        QTableWidgetItem *___qtablewidgetitem13 = commonColorTable->verticalHeaderItem(11);
        ___qtablewidgetitem13->setText(tr2i18n("New Row", nullptr));
        QTableWidgetItem *___qtablewidgetitem14 = commonColorTable->verticalHeaderItem(12);
        ___qtablewidgetitem14->setText(tr2i18n("New Row", nullptr));
        QTableWidgetItem *___qtablewidgetitem15 = commonColorTable->verticalHeaderItem(13);
        ___qtablewidgetitem15->setText(tr2i18n("New Row", nullptr));
        QTableWidgetItem *___qtablewidgetitem16 = commonColorTable->verticalHeaderItem(14);
        ___qtablewidgetitem16->setText(tr2i18n("New Row", nullptr));
        QTableWidgetItem *___qtablewidgetitem17 = commonColorTable->verticalHeaderItem(15);
        ___qtablewidgetitem17->setText(tr2i18n("New Row", nullptr));
        QTableWidgetItem *___qtablewidgetitem18 = commonColorTable->verticalHeaderItem(16);
        ___qtablewidgetitem18->setText(tr2i18n("New Row", nullptr));
        QTableWidgetItem *___qtablewidgetitem19 = commonColorTable->verticalHeaderItem(17);
        ___qtablewidgetitem19->setText(tr2i18n("New Row", nullptr));
        QTableWidgetItem *___qtablewidgetitem20 = commonColorTable->verticalHeaderItem(18);
        ___qtablewidgetitem20->setText(tr2i18n("New Row", nullptr));
        QTableWidgetItem *___qtablewidgetitem21 = commonColorTable->verticalHeaderItem(19);
        ___qtablewidgetitem21->setText(tr2i18n("New Row", nullptr));
        QTableWidgetItem *___qtablewidgetitem22 = commonColorTable->verticalHeaderItem(20);
        ___qtablewidgetitem22->setText(tr2i18n("New Row", nullptr));
        QTableWidgetItem *___qtablewidgetitem23 = commonColorTable->verticalHeaderItem(21);
        ___qtablewidgetitem23->setText(tr2i18n("New Row", nullptr));
        QTableWidgetItem *___qtablewidgetitem24 = commonColorTable->verticalHeaderItem(22);
        ___qtablewidgetitem24->setText(tr2i18n("New Row", nullptr));
        QTableWidgetItem *___qtablewidgetitem25 = commonColorTable->verticalHeaderItem(23);
        ___qtablewidgetitem25->setText(tr2i18n("New Row", nullptr));
        QTableWidgetItem *___qtablewidgetitem26 = commonColorTable->verticalHeaderItem(24);
        ___qtablewidgetitem26->setText(tr2i18n("New Row", nullptr));
        QTableWidgetItem *___qtablewidgetitem27 = commonColorTable->verticalHeaderItem(25);
        ___qtablewidgetitem27->setText(tr2i18n("New Row", nullptr));

        const bool __sortingEnabled = commonColorTable->isSortingEnabled();
        commonColorTable->setSortingEnabled(false);
        QTableWidgetItem *___qtablewidgetitem28 = commonColorTable->item(0, 0);
        ___qtablewidgetitem28->setText(tr2i18n("View Background", nullptr));
        QTableWidgetItem *___qtablewidgetitem29 = commonColorTable->item(1, 0);
        ___qtablewidgetitem29->setText(tr2i18n("View Text", nullptr));
        QTableWidgetItem *___qtablewidgetitem30 = commonColorTable->item(2, 0);
        ___qtablewidgetitem30->setText(tr2i18n("Window Background", nullptr));
        QTableWidgetItem *___qtablewidgetitem31 = commonColorTable->item(3, 0);
        ___qtablewidgetitem31->setText(tr2i18n("Window Text", nullptr));
        QTableWidgetItem *___qtablewidgetitem32 = commonColorTable->item(4, 0);
        ___qtablewidgetitem32->setText(tr2i18n("Button Background", nullptr));
        QTableWidgetItem *___qtablewidgetitem33 = commonColorTable->item(5, 0);
        ___qtablewidgetitem33->setText(tr2i18n("Button Text", nullptr));
        QTableWidgetItem *___qtablewidgetitem34 = commonColorTable->item(6, 0);
        ___qtablewidgetitem34->setText(tr2i18n("Selection Background", nullptr));
        QTableWidgetItem *___qtablewidgetitem35 = commonColorTable->item(7, 0);
        ___qtablewidgetitem35->setText(tr2i18n("Selection Text", nullptr));
        QTableWidgetItem *___qtablewidgetitem36 = commonColorTable->item(8, 0);
        ___qtablewidgetitem36->setText(tr2i18n("Selection Inactive Text", nullptr));
        QTableWidgetItem *___qtablewidgetitem37 = commonColorTable->item(9, 0);
        ___qtablewidgetitem37->setText(tr2i18n("Inactive Text", nullptr));
        QTableWidgetItem *___qtablewidgetitem38 = commonColorTable->item(10, 0);
        ___qtablewidgetitem38->setText(tr2i18n("Active Text", nullptr));
        QTableWidgetItem *___qtablewidgetitem39 = commonColorTable->item(11, 0);
        ___qtablewidgetitem39->setText(tr2i18n("Link Text", nullptr));
        QTableWidgetItem *___qtablewidgetitem40 = commonColorTable->item(12, 0);
        ___qtablewidgetitem40->setText(tr2i18n("Visited Text", nullptr));
        QTableWidgetItem *___qtablewidgetitem41 = commonColorTable->item(13, 0);
        ___qtablewidgetitem41->setText(tr2i18n("Negative Text", nullptr));
        QTableWidgetItem *___qtablewidgetitem42 = commonColorTable->item(14, 0);
        ___qtablewidgetitem42->setText(tr2i18n("Neutral Text", nullptr));
        QTableWidgetItem *___qtablewidgetitem43 = commonColorTable->item(15, 0);
        ___qtablewidgetitem43->setText(tr2i18n("Positive Text", nullptr));
        QTableWidgetItem *___qtablewidgetitem44 = commonColorTable->item(16, 0);
        ___qtablewidgetitem44->setText(tr2i18n("Focus Decoration", nullptr));
        QTableWidgetItem *___qtablewidgetitem45 = commonColorTable->item(17, 0);
        ___qtablewidgetitem45->setText(tr2i18n("Hover Decoration", nullptr));
        QTableWidgetItem *___qtablewidgetitem46 = commonColorTable->item(18, 0);
        ___qtablewidgetitem46->setText(tr2i18n("Tooltip Background", nullptr));
        QTableWidgetItem *___qtablewidgetitem47 = commonColorTable->item(19, 0);
        ___qtablewidgetitem47->setText(tr2i18n("Tooltip Text", nullptr));
        QTableWidgetItem *___qtablewidgetitem48 = commonColorTable->item(20, 0);
        ___qtablewidgetitem48->setText(tr2i18n("Active Titlebar", nullptr));
        QTableWidgetItem *___qtablewidgetitem49 = commonColorTable->item(21, 0);
        ___qtablewidgetitem49->setText(tr2i18n("Active Titlebar Text", nullptr));
        QTableWidgetItem *___qtablewidgetitem50 = commonColorTable->item(22, 0);
        ___qtablewidgetitem50->setText(tr2i18n("Active Titlebar Secondary", nullptr));
        QTableWidgetItem *___qtablewidgetitem51 = commonColorTable->item(23, 0);
        ___qtablewidgetitem51->setText(tr2i18n("Inactive Titlebar", nullptr));
        QTableWidgetItem *___qtablewidgetitem52 = commonColorTable->item(24, 0);
        ___qtablewidgetitem52->setText(tr2i18n("Inactive Titlebar Text", nullptr));
        QTableWidgetItem *___qtablewidgetitem53 = commonColorTable->item(25, 0);
        ___qtablewidgetitem53->setText(tr2i18n("Inactive Titlebar Secondary", nullptr));
        commonColorTable->setSortingEnabled(__sortingEnabled);

        (void)ScmEditorColors;
    } // retranslateUi

};

namespace Ui {
    class ScmEditorColors: public Ui_ScmEditorColors {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SCMEDITORCOLORS_H

