/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<plasma_wallpaper_imageplugin_static_plasma_wallpaper_image.h>)
#  include <plasma_wallpaper_imageplugin_static_plasma_wallpaper_image.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_plasma_wallpapers_image()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &BackgroundType::staticMetaObject;},
            "BackgroundType");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&BackgroundType::staticMetaObject, "org.kde.plasma.wallpapers.image", 2, nullptr, &BackgroundTypeForeign::staticMetaObject, nullptr);
    qmlRegisterEnum<BackgroundType::Type>("BackgroundType::Type");
    qmlRegisterTypesAndRevisions<DayNightSnapshotForeign>("org.kde.plasma.wallpapers.image", 2);
    qmlRegisterTypesAndRevisions<DayNightWallpaperForeign>("org.kde.plasma.wallpapers.image", 2);
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &DynamicMode::staticMetaObject;},
            "DynamicMode");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&DynamicMode::staticMetaObject, "org.kde.plasma.wallpapers.image", 2, nullptr, &DynamicModeForeign::staticMetaObject, nullptr);
    qmlRegisterEnum<DynamicMode::Mode>("DynamicMode::Mode");
    qmlRegisterTypesAndRevisions<ImageBackendForeign>("org.kde.plasma.wallpapers.image", 2);
    qmlRegisterEnum<ImageBackend::RenderingMode>("ImageBackend::RenderingMode");
    qmlRegisterTypesAndRevisions<MaximizedWindowMonitorForeign>("org.kde.plasma.wallpapers.image", 2);
    qmlRegisterTypesAndRevisions<MediaProxyForeign>("org.kde.plasma.wallpapers.image", 2);
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &Provider::staticMetaObject;},
            "Provider");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&Provider::staticMetaObject, "org.kde.plasma.wallpapers.image", 2, nullptr, &ProviderForeign::staticMetaObject, nullptr);
    qmlRegisterEnum<Provider::Type>("Provider::Type");
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &SortingMode::staticMetaObject;},
            "SortingMode");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&SortingMode::staticMetaObject, "org.kde.plasma.wallpapers.image", 2, nullptr, &SortingModeForeign::staticMetaObject, nullptr);
    qmlRegisterEnum<SortingMode::Mode>("SortingMode::Mode");
    qmlRegisterTypesAndRevisions<TransientImageForeign>("org.kde.plasma.wallpapers.image", 2);
    qmlRegisterEnum<TransientImage::Status>("TransientImage::Status");
    qmlRegisterEnum<TransientImage::FillMode>("TransientImage::FillMode");
    QT_WARNING_POP
    qmlRegisterModule("org.kde.plasma.wallpapers.image", 2, 0);
}

static const QQmlModuleRegistration orgkdeplasmawallpapersimageRegistration("org.kde.plasma.wallpapers.image", qml_register_types_org_kde_plasma_wallpapers_image);
