/****************************************************************************
** Meta object code from reading C++ file 'lookandfeelsettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../lookandfeelsettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'lookandfeelsettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19LookAndFeelSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto LookAndFeelSettings::qt_create_metaobjectdata<qt_meta_tag_ZN19LookAndFeelSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LookAndFeelSettings",
        "lookAndFeelPackageChanged",
        "",
        "defaultLightLookAndFeelChanged",
        "defaultDarkLookAndFeelChanged",
        "automaticLookAndFeelChanged",
        "automaticLookAndFeelOnIdleChanged",
        "automaticLookAndFeelIdleIntervalChanged",
        "lookAndFeelPackage",
        "isLookAndFeelPackageImmutable",
        "defaultLookAndFeelPackageValue",
        "defaultLightLookAndFeel",
        "isDefaultLightLookAndFeelImmutable",
        "defaultDefaultLightLookAndFeelValue",
        "defaultDarkLookAndFeel",
        "isDefaultDarkLookAndFeelImmutable",
        "defaultDefaultDarkLookAndFeelValue",
        "automaticLookAndFeel",
        "isAutomaticLookAndFeelImmutable",
        "defaultAutomaticLookAndFeelValue",
        "automaticLookAndFeelOnIdle",
        "isAutomaticLookAndFeelOnIdleImmutable",
        "defaultAutomaticLookAndFeelOnIdleValue",
        "automaticLookAndFeelIdleInterval",
        "isAutomaticLookAndFeelIdleIntervalImmutable",
        "defaultAutomaticLookAndFeelIdleIntervalValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'lookAndFeelPackageChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultLightLookAndFeelChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultDarkLookAndFeelChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'automaticLookAndFeelChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'automaticLookAndFeelOnIdleChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'automaticLookAndFeelIdleIntervalChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'lookAndFeelPackage'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isLookAndFeelPackageImmutable'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLookAndFeelPackageValue'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLightLookAndFeel'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isDefaultLightLookAndFeelImmutable'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDefaultLightLookAndFeelValue'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDarkLookAndFeel'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isDefaultDarkLookAndFeelImmutable'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDefaultDarkLookAndFeelValue'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'automaticLookAndFeel'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isAutomaticLookAndFeelImmutable'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAutomaticLookAndFeelValue'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'automaticLookAndFeelOnIdle'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isAutomaticLookAndFeelOnIdleImmutable'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAutomaticLookAndFeelOnIdleValue'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'automaticLookAndFeelIdleInterval'
        QtMocHelpers::PropertyData<uint>(23, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isAutomaticLookAndFeelIdleIntervalImmutable'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAutomaticLookAndFeelIdleIntervalValue'
        QtMocHelpers::PropertyData<uint>(25, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LookAndFeelSettings, qt_meta_tag_ZN19LookAndFeelSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LookAndFeelSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19LookAndFeelSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19LookAndFeelSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19LookAndFeelSettingsE_t>.metaTypes,
    nullptr
} };

void LookAndFeelSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LookAndFeelSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->lookAndFeelPackageChanged(); break;
        case 1: _t->defaultLightLookAndFeelChanged(); break;
        case 2: _t->defaultDarkLookAndFeelChanged(); break;
        case 3: _t->automaticLookAndFeelChanged(); break;
        case 4: _t->automaticLookAndFeelOnIdleChanged(); break;
        case 5: _t->automaticLookAndFeelIdleIntervalChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LookAndFeelSettings::*)()>(_a, &LookAndFeelSettings::lookAndFeelPackageChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (LookAndFeelSettings::*)()>(_a, &LookAndFeelSettings::defaultLightLookAndFeelChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (LookAndFeelSettings::*)()>(_a, &LookAndFeelSettings::defaultDarkLookAndFeelChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (LookAndFeelSettings::*)()>(_a, &LookAndFeelSettings::automaticLookAndFeelChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (LookAndFeelSettings::*)()>(_a, &LookAndFeelSettings::automaticLookAndFeelOnIdleChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (LookAndFeelSettings::*)()>(_a, &LookAndFeelSettings::automaticLookAndFeelIdleIntervalChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->lookAndFeelPackage(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isLookAndFeelPackageImmutable(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->defaultLookAndFeelPackageValue(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->defaultLightLookAndFeel(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isDefaultLightLookAndFeelImmutable(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->defaultDefaultLightLookAndFeelValue(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->defaultDarkLookAndFeel(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isDefaultDarkLookAndFeelImmutable(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->defaultDefaultDarkLookAndFeelValue(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->automaticLookAndFeel(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isAutomaticLookAndFeelImmutable(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->defaultAutomaticLookAndFeelValue(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->automaticLookAndFeelOnIdle(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isAutomaticLookAndFeelOnIdleImmutable(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->defaultAutomaticLookAndFeelOnIdleValue(); break;
        case 15: *reinterpret_cast<uint*>(_v) = _t->automaticLookAndFeelIdleInterval(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isAutomaticLookAndFeelIdleIntervalImmutable(); break;
        case 17: *reinterpret_cast<uint*>(_v) = _t->defaultAutomaticLookAndFeelIdleIntervalValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLookAndFeelPackage(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setDefaultLightLookAndFeel(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setDefaultDarkLookAndFeel(*reinterpret_cast<QString*>(_v)); break;
        case 9: _t->setAutomaticLookAndFeel(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setAutomaticLookAndFeelOnIdle(*reinterpret_cast<bool*>(_v)); break;
        case 15: _t->setAutomaticLookAndFeelIdleInterval(*reinterpret_cast<uint*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *LookAndFeelSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LookAndFeelSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19LookAndFeelSettingsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int LookAndFeelSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void LookAndFeelSettings::lookAndFeelPackageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void LookAndFeelSettings::defaultLightLookAndFeelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void LookAndFeelSettings::defaultDarkLookAndFeelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void LookAndFeelSettings::automaticLookAndFeelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void LookAndFeelSettings::automaticLookAndFeelOnIdleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void LookAndFeelSettings::automaticLookAndFeelIdleIntervalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
